@REM - ASB (10 Oct 2005 // 16 Oct 2023 / 27 Dec 2020 / 30 Nov 2020 / 25 Jan 2020 / 24 Dec 2019 / 30 Sep 2019 / 04 Jun 2019 / 10 Mar 2019): Configure Script Repository on Current System
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Ensure Valid Path
:EnsureGoodPath
 FOR /F "TOKENS=*" %%P IN ('ECHO "%@PATH%" ^| FIND /I /V "SCRIPTS\UTILS"') DO PATH %PATH%;%~d0\Scripts\BAT;%~d0\Scripts\Utils


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v4.10.0.500

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @SCRIPTS=%~d0\Scripts
 SET @BAT=%@SCRIPTS%\BAT
 SET @KIX=%@SCRIPTS%\BAT
 SET @VBS=%@SCRIPTS%\VBS
 SET @PERL=%@SCRIPTS%\Perl
 SET @PSHELL=%@SCRIPTS%\PowerShell
 SET @MUTILS=%@SCRIPTS%\UTILS\MISC
 SET @UTILS=%@SCRIPTS%\Utils
	 IF /I "%@OS_ARCH%"=="x64" SET @UTILS=%@SCRIPTS%\Utils\x64;%@SCRIPTS%\Utils
	 IF %@OSBUILD% LSS 6001 SET @UTILS=%@SCRIPTS%\Utils\XP;%@SCRIPTS%\Utils

 SET @SYSOPTIONS=%@BAT%\SystemOptions.VBS&  IF EXIST "%@VBS%\SystemOptions.VBS"  SET @SYSOPTIONS=%@VBS%\SystemOptions.VBS
 SET @CONSOLEOPTS=%@BAT%\ConsoleOptions.VBS& IF EXIST "%@VBS%\ConsoleOptions.VBS" SET @CONSOLEOPTS%@VBS%\ConsoleOptions.VBS

 rem -- Set New PATH
 SET @OLDPATH=%PATH%
 SET @NEWPATH=%@BAT%;%@UTILS%;%@PSHELL%;%@VBS%;%@PERL%
 PATH %@NEWPATH%;%PATH%;%@MUTILS%


 rem -- Create Scripts Folder and Optionally Set Restricted Permissions
:CreateFolder
 FOR %%D IN (%@NEWPATH%) DO MD "%%~D" 2>NUL
 ATTRIB +S +H %@SCRIPTS%
 FOR %%O IN ("" - /) DO FOR %%P IN (P PERMS) DO IF /I "%~1"=="%%~O%%~P" (
	 ECHO:
 	 ICACLS "%@SCRIPTS%\*" /grant:r "SYSTEM:(CI)(F)" "Administrators:(CI)(F)" /remove:g EVERYONE /inheritance:e /T /C
 	 ICACLS "%@SCRIPTS%"   /grant:r "SYSTEM:(CI)(F)" "Administrators:(CI)(F)" /remove:g EVERYONE /inheritance:e
 	 ICACLS "%@SCRIPTS%"
 )

 rem -- Exit After Setting Permissions if Following Parameters Found: -F -FIX -O -ONLY
 FOR %%O IN ("" - /) DO FOR %%P IN (O ONLY F FIX) DO IF /I "%~2"=="%%~O%%~P" (
 	 ECHO:
 	 ECHO Setting Restricted Permissions Only...
 	 GOTO :ExitBatch
 )


 rem -- Run Additional Configuration Scripts on Local Machine
:RunScripts
 IF EXIST "%@SYSOPTIONS%"  CSCRIPT //H:CScript "%@SYSOPTIONS%"
 IF EXIST "%@CONSOLEOPTS%" CSCRIPT //H:CScript "%@CONSOLEOPTS%"
 IF EXIST "%@BAT%\Configure.KIX"  KIX32 "%@BAT%\Configure.KIX"
 IF EXIST "%@BAT%\SetEULA.BAT"    CALL  "%@BAT%\SetEULA.BAT"
 IF EXIST "%@BAT%\NewConfig.BAT"  CALL  "%@BAT%\NewConfig.BAT"
 IF EXIST "%@BAT%\LabelDrive.BAT" CALL  "%@BAT%\LabelDrive.BAT" Basic

 rem -- Don't Schedule Jobs if the Script is Executed With a Parameter...
 IF "%~1"=="" CALL "%@BAT%\NewSched.BAT"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Configure Script Repository on Current System
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [^<-P^|-PERMS^> [-F^|-FIX^|-O^|-ONLY]]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       /P ..... Apply Permissions and Run Setup Files
 ECHO  /F,  /O ..... Apply/Repair Permissions and Exit
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 -P
	 ECHO  %~n0 -P -F
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
                                                                