@ECHO OFF
 rem ==========================================================================
 rem === Add Domain Users To A Specific Local Group (e.g. PwrUsers)
 rem ==========================================================================
 rem
 rem Created On: 06 Oct 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 05 Dec 2003
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: NT4 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.ultratech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This script uses CUSRMGR from the Win2K ResKit to add
 :::  your Global Domain Users group into the local Power Users
 :::  group (or any other group you choose at the command line).
 :::  If no file list is provided at the command line then all
 :::  of the machines in the domain (obtained via the NET VIEW
 :::  command) will be used.
 :::
 :::  This script can be modified to manipulate any domain
 :::  account or group.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 06 Sep 2001
 rem ==========================================================================
:NeedHelp
 IF "%~1"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 02 Dec 2003
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Calculate Date/Time (Short Procedure)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=4-6 DELIMS=: " %%T IN ('NOW') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG

 rem -- Standard Variables
 SET @LGROUP=%~1
 SET @GROUP=MyDOMAIN\Domain Users
 SET @COMPLIST=%~2& IF "%~2"=="" SET @COMPLIST='NET VIEW'
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Cycle Through Domain (or File List) And Add To Group
 rem === Last Modified On 02 Dec 2003
 rem ==========================================================================
:GetComputers
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 NOW Adding the "%@GROUP%" group to the local "@LGROUP% group >"%@LOGFILE%"
 ECHO Getting a List of Computers via "%@COMPLIST%"...
 ECHO:
 FOR /F %%V IN (%@COMPLIST%) DO CALL :AddGroup %%V
 ECHO Finished Adding "%@GROUP%" to the local "%@LGROUP%" group...
 ECHO:


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 05 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Add The "DOMAIN USERS" Group To Each Machine
 rem === Last Modified On 06 Oct 2001
 rem ==========================================================================
:AddGroup
 rem %1 = Current System To Be Updated
 SET @PARAM=%1
 IF /I NOT "%@PARAM:~0,2%"=="\\" GOTO :EOF
 ECHO Updating "%1"...
 CUSRMGR -u %@GROUP% -m %1 -alg "%@LGROUP%"
 IF ERRORLEVEL 1 (
   ECHO There were problems updating "%1"
   ECHO %1 - Could Not Update >>"%@LOGFILE%"
 )
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 06 Oct 2001
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for ADDTOGRP.BAT
 ECHO:
 ECHO === AddToGrp {new_local_group} [list_of_servers.txt]
 ECHO:
 ECHO Example: AddToGrp "Power Users"
 ECHO          AddToGrp "Backup Operators" C:\TEMP\SERVERS.TXT
 ECHO          AddToGrp "Administrators" "C:\Input\List Of Servers.TXT"
 ECHO          AddToGrp "MyLocalGroup" "'NET VIEW /DOMAIN:thatdomain'"
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: If the name of the List of Servers contains
 ECHO       spaces, it should be surrounded by quotation marks.
 ECHO       Same thing for the name of the local group.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
