@REM - ASB (14 Feb 2014 // 16 Oct 2023 / 30 Nov 2020 / 06 Aug 2020 / 24 Dec 2019 / 30 Sep 2019 / 23 Jan 2019 / 31 Aug 2018 / 26 Jul 2018 / 29 Apr 2018 / 27 Mar 2016): Configure Bandwidth Testing via PsPing
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.2.0.220

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Process Special Command-line Parameters
 SET @ALL_PARAMS=%*
 CALL :GetParams "P PORT"   @PORT    & IF NOT DEFINED @PORT SET @PORT=24
 CALL :GetParams "C CLIENT" @PARTNER & IF DEFINED @OK IF DEFINED @PARTNER (SET @MODE=CLIENT)
 CALL :GetParams "S SERVER"          & IF DEFINED @OK (SET @MODE=SERVER) ELSE (SET @MODE=UNDEFINED)
 CALL :GetParams "I INTERACTIVE"     & IF DEFINED @OK (SET @CMD_MSG=) ELSE (SET @CMD_MSG=START "PSPING Server Mode")

 rem -- Enforce Port Range
 IF %@PORT%0 LSS 1      SET @PORT=24
 IF %@PORT%0 GTR 655350 SET @PORT=24


 rem -- Execute PsPING in Server or Client Mode
:RunPsPING
 IF /I "%@MODE%"=="SERVER" (
	 ECHO:
	 ECHO Enabling PsPING Server Mode on Port %@PORT%
	 %@CMD_MSG% PSPING -4 -S %COMPUTERNAME%:%@PORT%
	 PSLIST %@PSPARAMS% PSPING
 ) ELSE (
	 IF NOT DEFINED @PARTNER ( ECHO *** Missing Remote Server ***& GOTO :ExitBatch )
	 ECHO:
	 ECHO Testing Latency/Bandwidth between %COMPUTERNAME% and %@PARTNER% on Port %@PORT%
	 FOR %%S IN (5 10 50 100 200 500) DO FOR %%P IN ("" "-R" "-B" "-B -R") DO PSPING %%~P -N 20 -L %%~Sk %@PARTNER%:%@PORT% -NoBanner
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Use CheckParams.exe to Capture Selected Parameters
:GetParams
 rem %1 = Parameters to Search For
 rem %2 = Variable to Set

 SET @OK=& IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=2-3*" %%v IN ('CHECKPARAMS -q -a -c "%~1" -s %@ALL_PARAMS% 2^>NUL') DO IF /I "%%~v"=="TRUE" (
	 SET @OK=T
	 SET @REQ=T
	 IF NOT "%~2"=="" SET %~2=%%~x
 )
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Configure Bandwidth Testing via PsPing
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<OPTIONS^>
 ECHO  %~n0  [-P:port] ^<-S [-I] ^| [-C:servername]^>
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message       (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       /S ..... Enable Server Mode
 ECHO       /C ..... Enable Client Mode              (must include remote servername)
 ECHO       /P ..... Port to use                     (Default = 24)
 ECHO       /I ..... Interactive Mode in Server Mode (for Remote Console sessions)
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 /S
	 ECHO  %~n0 /C:ThatServer
	 ECHO  %~n0 /P:2020 /S /I
	 ECHO  %~n0 /P:1010 /C:ThisServer.MyPlace.local
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Folder Paths containing spaces should be enclosed in quotes.
 )
 CALL :ShowStatus "FINISHED"
   