@REM - ASB (29 Jun 2016 // 25 Mar 2024 / 16 Oct 2023 / 29 Mar 2023 / 30 Nov 2020 / 16 Aug 2020 / 23 Mar 2020 / 24 Dec 2019 / 30 Sep 2019): Check VPN or Remote Host Connectivity
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v4.4.0.340

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Check VPN or Remote Host Connectivity
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [list of IPs to check]   {default = %~dp0Input\CheckVPN.TXT}
	 ECHO               %~n0  [list of IPs to check]   [non-blank-char = list-only]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q
 SET @INPUT=%~dp0Input
 FOR %%V IN (%@ALPHA11#%) DO IF EXIST "%%~V:\Storage\Logs" SET @STORAGE=%%~V:\Storage

 rem -- Get List of VPN Addresses to Check for Connectivity
 SET @LISTONLY=%~2
 SET @CURRENT=0
 SET @SOURCELIST="%~dp0Input\CheckVPN.TXT"  "%~dp0Input\CheckVPN.%COMPUTERNAME%.TXT"  "%~dp0Input\%~1"  "%~dp0Input\%~1.TXT"  "%~1"
 FOR %%F IN (%@SOURCELIST%) DO IF EXIST "%%~F" IF NOT "%%~nxF"=="" SET @VPNLIST=%%~F
 IF EXIST "%@VPNLIST%" (
	 ECHO USING: "%@VPNLIST%"
	 SET @COUNT=1000
	 FOR /F "USEBACKQ TOKENS=1-2 EOL=;" %%I IN ("%@VPNLIST%") DO (
		 IF NOT "%%~J"=="" SET $@SUMMARY-%%I=%%~J
		 SET @NAME-OR-IP=%%I
		 SET @NAME-OR-IP=!@NAME-OR-IP:\=!
		 SET #!@COUNT!!@NAME-OR-IP!=!@NAME-OR-IP!
		 SET /A @COUNT+=1
	 )
 ) ELSE (
	 ECHO *** NO LIST OF VPN ADDRESSES FOUND: "%@VPNLIST%"
	 SET #127.0.0.1=127.0.0.1
 )

 rem -- Shortcut for just displaying the list
 IF DEFINED @LISTONLY (SET @ECHO=ECHO) ELSE (SET @ECHO=)

 rem -- Standard Log Variables
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGROOT=%@STORAGE%\Logs\%~n0
 SET @LOGINFO=%~n0.%@DIRSTAMP_R%
 SET @LOGFILE=%@LOGPATH%\%@LOGINFO%.TXT


 rem -- Initialize Log Folders
:InitLogFolders
 FOR %%V IN ("%@LOGPATH%" "%@LOGROOT%") DO IF NOT EXIST "%%~V" MD "%%~V"
 IF EXIST "%@INPUT%\@ZipLogsOverride.INPUT" XCOPY /D /Y "%@INPUT%\@ZipLogsOverride.INPUT" "%@LOGROOT%" 2>NUL


 rem -- Make and Record Connectivity Attempts
:InitiateConnectivityTest
 ECHO:
 ECHO %@DIVIDER-%
 ECHO Preparing to Test the Following Segments
 ECHO %@DIVIDER-%
 FOR /F "TOKENS=1* DELIMS==" %%V IN ('SET # 2^>NUL') DO ECHO  -- %%W
 ECHO:
 ECHO Please Wait for Concurrent Processes to Finish Execution...
 FOR /F "TOKENS=1* DELIMS==" %%V IN ('SET # 2^>NUL') DO START "PING %%W" /MIN CMD /C "%@ECHO% PING %%W >%@LOGROOT%\%%W.LOG"
 SLEEP 1

 rem -- Wait for All Jobs to Finish
:Check4Running
 FOR /F %%C IN ('HANDLE %@PSPARAMS% "%@LOGROOT%" ^| FIND /C /I "PING.EXE"') DO SET @COUNT=%%C
 IF !@COUNT! NEQ !@CURRENT! (SET @CURRENT=!@COUNT!& ECHO  -- Processes still running: !@COUNT!)
 IF !@COUNT! NEQ 0 GOTO :Check4Running


 rem -- Process and Consolidate Connectivity Logs
:TestConnectivity
 ECHO:
 ( rem -- Write to Log
	 FOR /F "TOKENS=1* DELIMS==" %%V IN ('SET # 2^>NUL') DO IF EXIST "%@LOGROOT%\%%W.LOG" (
		 FOR /F "TOKENS=1" %%R IN ('TYPE "%@LOGROOT%\%%W.LOG" ^| FIND /C /I " time"') DO SET @RSPN=%%R
		 FOR /F "TOKENS=*" %%I IN ('TYPE "%@LOGROOT%\%%W.LOG" ^| FIND    /I " loss"') DO SET @INFO=%%I
		 FOR /F "TOKENS=10" %%L IN ('ECHO "!@INFO!"') DO SET @LOSS=%%L
		 (SET @STATUS= UP )
		 IF 10!@RSPN! LEQ 102 SET @STATUS=DOWN
		 IF 10!@LOSS! GEQ 102 SET @STATUS=DOWN
		 SET @SUMMARY=%%W ---------------
		 SET @SUMMARY= -- !@SUMMARY:~0,20! !@STATUS! -- !@INFO!
		 SET @SUMMARY-%%W=!@SUMMARY!

		 TYPE "%@LOGROOT%\%%W.LOG"
		 ECHO %@DIVIDER-%
		 ECHO:
 )) >"%@LOGFILE%"


 rem -- Generate Summary Report
:FinalReport
 ( rem -- Write to Log
	 ECHO:
	 ECHO Connection Testing Summary
	 ECHO %@DIVIDER-%
	 FOR /F "TOKENS=1* DELIMS==" %%V IN ('SET # 2^>NUL') DO CALL :ShowVar @SUMMARY-%%W
	 ECHO %@DIVIDER-%
	 FOR /F %%T IN ('SET @SUMMARY- ^| FIND " " /C') DO ECHO  Total Interfaces ....... %%T
	 FOR /F %%U IN ('SET @SUMMARY- ^| FIND "-  UP  -" /C') DO ECHO  Interfaces Up .......... %%U
	 FOR /F %%D IN ('SET @SUMMARY- ^| FIND "- DOWN -" /C') DO ECHO  Interfaces Down ........ %%D
	 ECHO %@DIVIDER-%
 ) >>"%@LOGFILE%"
 TYPE "%@LOGFILE%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 IF EXIST "%@TEMPFILE%" DEL "%@TEMPFILE%"
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Display Variable Value
:ShowVar
 rem %1 = Variable Name to Display Contents of

 IF /I "!$%~1!"=="NEW" ECHO:
 IF /I "!$%~1!"=="LINE" ECHO %@DIVIDER-%
 IF DEFINED %1 ECHO !%1!
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                                                