@REM - ASB (13 Feb 2017 // 25 Mar 2024 / 05 Jan 2024 / 16 Oct 2023 / 29 Mar 2023 / 30 Nov 2020 / 16 Aug 2020 / 23 Mar 2020 / 24 Dec 2019 / 30 Sep 2019): Resolve WAN IPs from a List of Hosts
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.1.0.210

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Resolve WAN IPs from a List of Hosts
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [list of hostnames to check]   {default = %~dp0Input\CheckWAN.TXT}
	 ECHO               %~n0  [list of hostnames to check]   [non-blank-char = list-only]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q
 SET @INPUT=%~dp0Input
 FOR %%V IN (%@ALPHA11#%) DO IF EXIST "%%~V:\Storage\Logs" SET @STORAGE=%%~V:\Storage

 rem -- Get List of VPN Addresses to Check for Connectivity
 SET @LISTONLY=%~2
 SET @ERROR=0
 SET @SOURCELIST="%~dp0Input\CheckWAN.TXT"  "%~dp0Input\CheckWAN.%COMPUTERNAME%.TXT"  "%~dp0Input\%~1"  "%~dp0Input\%~1.TXT"  "%~1"
 FOR %%F IN (%@SOURCELIST%) DO IF EXIST "%%~F" IF NOT "%%~nxF"=="" SET @WANLIST=%%~F
 IF EXIST "%@WANLIST%" (
	 ECHO USING: "%@WANLIST%"    	PLEASE WAIT...
	 SET @COUNT=1000
	 FOR /F "USEBACKQ TOKENS=1-2 EOL=;" %%I IN ("%@WANLIST%") DO (
		 IF NOT "%%~J"=="" SET $%%I=%%~J
		 SET #!@COUNT!%%I=%%I
		 SET /A @COUNT+=1
	 )
 ) ELSE (
	 ECHO *** NO LIST OF DNS ADDRESSES FOUND: "%@WANLIST%"
	 SET #WhatIsMyIp.com=WhatIsMyIp.com
 )

 rem -- Shortcut for just displaying the list
 IF DEFINED @LISTONLY (SET @ECHO=ECHO) ELSE (SET @ECHO=)

 rem -- Standard Log Variables
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGROOT=%@STORAGE%\Logs\%~n0
 SET @LOGINFO=%~n0.%@DIRSTAMP_R%
 SET @LOGFILE=%@LOGPATH%\%@LOGINFO%.TXT


 rem -- Initialize Log Folders
:InitLogFolders
 FOR %%V IN ("%@LOGPATH%" "%@LOGROOT%") DO IF NOT EXIST "%%~V" MD "%%~V"
 IF EXIST "%@INPUT%\@ZipLogsOverride.INPUT" XCOPY /D /Y "%@INPUT%\@ZipLogsOverride.INPUT" "%@LOGROOT%" 2>NUL


 rem -- Process and Consolidate Name Resolution Logs
:ResolveAddresses
 SET @COUNT=0
 ( rem -- Write to Log
	 ECHO:
	 ECHO %@DIVIDER-%
	 ECHO  Resolving WAN Address[es]
	 ECHO %@DIVIDER-%
	 FOR /F "TOKENS=1* DELIMS==" %%V IN ('SET # 2^>NUL') DO FOR /F "TOKENS=*" %%D IN ('%@ECHO% RESOLVE %%W') DO (
		 SET @DNSNAME= Resolving "%%~W" .............................
		 SET @DNSNAME=!@DNSNAME:~0,50!
		 IF /I "!$%%W!"=="NEW" ECHO:
		 IF /I "!$%%W!"=="LINE" (ECHO %@DIVIDER-%& ECHO:)
		 ECHO !@DNSNAME! %%D
		 NOW %%~W = %%D >>"%@LOGROOT%\%%~W.TXT" 2>&1
		 SET /A @COUNT+=1
		 FOR /F %%e IN ('ECHO %%D ^| FIND /I "ERROR: "') DO SET /A @ERROR+=1
	 )
	 ECHO %@DIVIDER-%
	 ECHO  Total WAN Addresses Checked ..................... !@COUNT!
	 ECHO  # of Unresolvable WAN Addresses ................. !@ERROR!
	 ECHO %@DIVIDER-%
 ) >"%@LOGFILE%"
 TYPE "%@LOGFILE%"
 DIR /OGD "%@LOGROOT%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 IF EXIST "%@TEMPFILE%" DEL "%@TEMPFILE%"
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                            