@REM - ASB (12 Sep 2013 // 16 Oct 2023 / 30 Nov 2020 / 12 Jul 2020 / 10 Jul 2020 / 24 Dec 2019 / 30 Sep 2019 / 31 Aug 2018 / 26 Jul 2018 / 27 Mar 2016 / 05 May 2015): Compare Two Folders by Extension
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.2.0.320

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @SOURCE_ONLY=0
 SET @DESTINATION_ONLY=0
 SET @DIFFERENT_FILES=0
 SET @USEHASH=FALSE
 SET @THISHASH=NOHASH
 SET @SORTLEN=46
 SET @RECURSE=
 SET @RECURSION=FALSE

 rem -- Get Names of Folders
 SET @FOLDER1=%~1& CALL :FixDirectoryPath @FOLDER1
 SET @FOLDER2=%~2& CALL :FixDirectoryPath @FOLDER2

 rem -- Standard Log Variables
 SET @LOGS=COMPARE RESULT SUMMARY
 SET @LOGPATH=%TEMP%\%~n0
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP_R%
 SET @TEMPLOG=%@LOGPATH%\TEMP\%~n0.TEMP.%@FILESTAMP_R%
 FOR %%N IN ("" 1 2 3) DO FOR %%F IN (%@LOGS%) DO SET @%%~F%%~N="%@LOGPATH%\TEMP\%%~F%%~N.%@FILESTAMP_R%"

 rem -- Process Special Command-line Parameters
 SET @ALL_PARAMS=%*
 CALL :GetParams "W WILDCARD"  @FILEEXT & IF DEFINED @OK IF NOT DEFINED @FILEEXT (SET @FILEEXT=*.*)
 CALL :GetParams "R RECURSE S"          & IF DEFINED @OK (SET @RECURSION=TRUE& SET @RECURSE=-R)
 CALL :GetParams "U USEHASH"            & IF DEFINED @OK (SET @USEHASH=TRUE&   SET @THISHASH=XX64& SET @SORTLEN=43)
 %@PAUSE_IF_DEBUG%


 rem -- Verify Folders
:VerifyFolders
 CALL :GetTime @STIME
 CALL :MapDrive @S_DRIVE "%@FOLDER1%" "FOLDER #1"
 CALL :MapDrive @D_DRIVE "%@FOLDER2%" "FOLDER #2"

 FOR %%D IN ("%@LOGPATH%" "%@LOGPATH%\TEMP") DO IF NOT EXIST "%%~D" MD "%%~D" >NUL 2>NUL
 FOR %%F IN ("%@FOLDER1%" "%@FOLDER2%" "%@S_DRIVE%" "%@D_DRIVE%") DO IF NOT EXIST "%%~F" (
	 ECHO *** Folder Does Not Exist: %%~F ***
	 GOTO :ExitBatch
 )


 rem -- Output Folder Contents to Files, Then Compare
:CompareDirectories
 ( rem -- Write Log to File
	 CALL :ShowHeader FOLDER COMPARE
	 ECHO *** Folder 1 ....: %@S_DRIVE% = %@FOLDER1%
	 ECHO *** Folder 2 ....: %@D_DRIVE% = %@FOLDER2%
	 ECHO *** Recursion ...: %@RECURSION%
	 ECHO *** Use Hash ....: %@USEHASH%
	 ECHO %@DIVIDER*%
	 ECHO:
 ) >"%@TEMPLOG%" 2>&1
 FOR %%O IN (CON "%@LOGFILE%") DO TYPE "%@TEMPLOG%" >>%%O

 rem -- Generate Comparison Files
 CALL :ShowHeader PERFORMING FOLDER COMPARISON
 START /MIN FILEHASH --%@THISHASH% --out %@COMPARE1% --summary %@SUMMARY1% -z --fsum %@RECURSE% -d "%@S_DRIVE%" %@FILEEXT%
 START /MIN FILEHASH --%@THISHASH% --out %@COMPARE2% --summary %@SUMMARY2% -z --fsum %@RECURSE% -d "%@D_DRIVE%" %@FILEEXT%

:WaitForList
 CALL :Check4CompletedFiles
 FOR %%V IN (1 2) DO IF NOT EXIST !@SUMMARY%%~V! GOTO :WaitForList
 CALL :Check4CompletedFiles

 rem -- Continue Processing
 SORT /+%@SORTLEN% %@COMPARE1% /O %@COMPARE1%
 SORT /+%@SORTLEN% %@COMPARE2% /O %@COMPARE2%
 DIFF -a -w -i -y --suppress-common-lines --width 520 %@COMPARE1% %@COMPARE2% >%@RESULT% 2>NUL

 CALL :ShowHeader FOLDER COMPARISON SUMMARY
 FOR /F %%C IN ('TYPE %@RESULT% ^| FIND /C "<" 2^>NUL') DO SET /A @SOURCE_ONLY+=%%C
 FOR /F %%C IN ('TYPE %@RESULT% ^| FIND /C ">" 2^>NUL') DO SET /A @DESTINATION_ONLY+=%%C
 FOR /F %%C IN ('TYPE %@RESULT% ^| FIND /C "|" 2^>NUL') DO SET /A @DIFFERENT_FILES+=%%C

 ( rem -- Write Log to File
	 ECHO  FILES FOUND ONLY IN SOURCE ................ !@SOURCE_ONLY!
	 MAKESTRING "<" 70
	 FOR /F "TOKENS=2 DELIMS=*|<>" %%F IN ('TYPE %@RESULT% 2^>NUL ^| FIND "<"') DO (CALL :RunCMD ECHO  - %~1\%%~F) >>%@RESULT1%
	 IF EXIST %@RESULT1% SORT %@RESULT1%
	 ECHO:
	 ECHO:
 ) >"%@TEMPLOG%" 2>&1
 FOR %%O IN (CON "%@LOGFILE%") DO TYPE "%@TEMPLOG%" >>%%O

 ( rem -- Write Log to File
	 ECHO  FILES FOUND ONLY IN DESTINATION ........... !@DESTINATION_ONLY!
	 MAKESTRING ">" 70
	 FOR /F "TOKENS=3 DELIMS=*|<>" %%F IN ('TYPE %@RESULT% 2^>NUL ^| FIND ">"') DO (CALL :RunCMD ECHO  + %~2\%%~F) >>%@RESULT2%
	 IF EXIST %@RESULT2% SORT %@RESULT2%
	 ECHO:
	 ECHO:
 ) >"%@TEMPLOG%" 2>&1
 FOR %%O IN (CON "%@LOGFILE%") DO TYPE "%@TEMPLOG%" >>%%O

 ( rem -- Write Log to File
	 ECHO  FILES WITH DIFFERENT DATE/TIME/CONTENT .... !@DIFFERENT_FILES!
	 MAKESTRING ":" 70
	 FOR /F "TOKENS=2 DELIMS=*|<>" %%F IN ('TYPE %@RESULT% 2^>NUL ^| FIND "|"') DO (CALL :RunCMD ECHO  ~ %%~F) >>%@RESULT3%
	 IF EXIST %@RESULT3% SORT %@RESULT3%
	 ECHO:
 ) >"%@TEMPLOG%" 2>&1
 FOR %%O IN (CON "%@LOGFILE%") DO TYPE "%@TEMPLOG%" >>%%O
 %@PRINT_IF_DEBUG%


 rem -- FinalReport
:FinalReport
 CALL :GetTime @ETIME

 ( rem -- Write Log to File
	 CALL :ShowHeader FINAL REPORT
	 CALL :UnMapDrive @S_DRIVE "FOLDER #1"
	 CALL :UnMapDrive @D_DRIVE "FOLDER #2"
	 FOR %%R IN (1 2) DO (
		 ECHO:
		 ECHO SUMMARY OF FILES FOUND IN FOLDER #%%~R
		 TYPE !@SUMMARY%%~R!
		 ECHO:
	 )
	 IF EXIST "%@LOGFILE%" DIR "%@LOGFILE%" | FIND ":"
	 ECHO:
	 ECHO %@DIVIDER%
	 ECHO  FILES FOUND ONLY IN SOURCE .................... !@SOURCE_ONLY!
	 ECHO  FILES FOUND ONLY IN DESTINATION ............... !@DESTINATION_ONLY!
	 ECHO  FILES WITH DIFFERENT DATE/TIME/CONTENT ........ !@DIFFERENT_FILES!
	 ECHO %@DIVIDER-%
	 ECHO  Folder Comparisons Started On ................. !@STIME!
	 ECHO  Folder #1 Comparison Ended On ................. !@TIME-SUMMARY1!
	 ECHO  Folder #2 Comparison Ended On ................. !@TIME-SUMMARY2!
	 ECHO  Folder Comparisons Ended On ................... !@ETIME!
	 DATEINFO -t !@STIME#! -n !@ETIME#! -e "dys hrs mins secs.ms" -o " Script Duration Was ........................... " 2>NUL
	 ECHO %@DIVIDER%
 ) >"%@TEMPLOG%" 2>&1
 FOR %%O IN (CON "%@LOGFILE%") DO TYPE "%@TEMPLOG%" >>%%O

 rem -- Perform Log Cleanup
 IF NOT DEFINED DEBUG (
	 IF EXIST "%@TEMPLOG%" DEL "%@TEMPLOG%" >NUL
	 FOR %%F IN (%@LOGS%) DO FOR %%N IN ("" 1 2 3) DO IF EXIST "!@%%F%%~N!" DEL "!@%%F%%~N!" >NUL
 )
 %@PRINT_IF_DEBUG%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Execute Dynamic Command From Variable
:RunCMD
 rem %* = Command To Execute

 %*
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Store Current Date and Time in Variable
:GetTime
 rem %1 = Variable to Store Date/Time

 SET %~1=!DATE! at !TIME: =0!
 FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET %~1#="%%~d"
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Show Header
:ShowHeader
 rem %* = Header Info to Display

 NOW \n\n\**** %* -- \v\n\*\n
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Use CheckParams.exe to Capture Selected Parameters
:GetParams
 rem %1 = Parameters to Search For
 rem %2 = Variable to Set

 SET @OK=& IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=2-3*" %%v IN ('CHECKPARAMS -q -a -c "%~1" -s %@ALL_PARAMS% 2^>NUL') DO IF /I "%%~v"=="TRUE" (
	 SET @OK=T
	 SET @REQ=T
	 IF NOT "%~2"=="" SET %~2=%%~x
 )
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Create a Mapped or SUBST Drive and Obtain Drive Letter
:MapDrive
 rem %1 = Variable to Assign the Drive Letter to
 rem %2 = UNC Path to Connect
 rem %3 = Description

 IF NOT EXIST "%~2" GOTO :EOF
 SET @DESCRIPTION=[%~3] & IF "%~3"=="" SET @DESCRIPTION=
 SET @DRV=
 SET @DPATH=%~2
 IF "%@DPATH:~0,2%"=="\\" (
	 FOR /F "TOKENS=2" %%D IN ('NET USE * "%~2" /PERSISTENT:NO ^| FIND ":"') DO (
		 SET @DRV=%%~D
		 SET %~1=%%~D
		 SET %~1-PATH=%~2
		 SET %~1-METHOD=NETUSE
	 )
 ) ELSE (
	 FOR %%a IN (%@ALPHABET%) DO IF NOT DEFINED @DRV (
		 SUBST %%a: "%~2" >NUL
		 FOR /F "TOKENS=1,3* DELIMS=\ " %%D IN ('SUBST ^| FIND /I "%~2"') DO (
			 SET @DRV=%%~D
			 SET %~1=%%~D
			 SET %~1-PATH=%~2
			 SET %~1-METHOD=SUBST
		 )
	 )
 )
 ECHO Mapping Drive %@DRV% to %@DESCRIPTION%"%@DPATH%"
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Delete an Existing Mapped or SUBST Drive
:UnMapDrive
 rem %1 = Current Variable
 rem %2 = Description

 SET @DESCRIPTION=[%~2] & IF "%~2"=="" SET @DESCRIPTION=
 CALL :RunCMD SET @DRV=%%%~1%%
 CALL :RunCMD SET @DPATH=%%%~1-PATH%%
 CALL :RunCMD SET @METHOD=%%%~1-METHOD%%
 IF /I "%@METHOD%"=="NETUSE" (
	 NET USE %@DRV% /D /Y >NUL 2>&1
 ) ELSE (
	 SUBST %@DRV% /D
 )
 ECHO Unmapping Drive %@DRV% from %@DESCRIPTION%"%@DPATH%"
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Remove Trailing \ From Supplied Folder Path
:FixDirectoryPath
 rem %1 = Folder Variable

 IF NOT DEFINED %1 GOTO :EOF
 IF "!%~1:~-1!"=="\" (
	 SET %~1=!%~1:~0,-1!
	 GOTO :FixDirectoryPath
 )
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Check for Completed Comparison Files
:Check4CompletedFiles
 rem -- No Variable Required

 FOR %%Z IN (1 2) DO IF NOT DEFINED @TIME-SUMMARY%%~Z IF EXIST !@SUMMARY%%~Z! (
	 CALL :GetTime @TIME-SUMMARY%%~Z
	 NOW Completed List File for Folder #%%~Z
 )
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Compare Two Folders by Extension
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<folder1^> ^<folder2^> [/W:wildcard_to_search] [/S^|/R]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       /R ..... Recurse Folders (same as /S)
 ECHO       /W ..... Wildcard Search Filter  (default = *.*)
 ECHO       /U ..... Use actual hash, rather than Date/Time
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 %SystemDrive%\Folder1 %SystemDrive%\Folder2 /U
	 ECHO  %~n0 "D:\This Folder" "E:\That Folder" /W:*.EXE /S
	 ECHO  %~n0 \\SERVER1\SomeFolder \\SERVER2\OtherFolder /W:*.DOC
	 ECHO  %~n0 /?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
  