@REM - ASB (08 Jun 2020 // 16 Oct 2023 / 30 Nov 2020 / 08 Jun 2020): Compare Processing Times from OpsLogs / SecurityLogs / UptimeReports
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.2.0.080

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @OLDER_LOG="%TEMP%\Older.%@FILESTAMP_R%"
 SET @NEWER_LOG="%TEMP%\Newer.%@FILESTAMP_R%"
 SET @SUMMARY=Script Processing Duration:


 rem -- Verify Source Logs and Process Temp Logs
:ProcessTempLogs
 ECHO Verifying Source Log Files...
 CALL :CreateTempLog "%~1" @OLDER_LOG
 CALL :CreateTempLog "%~2" @NEWER_LOG

 IF DEFINED @ERROR (
	 ECHO:
	 ECHO *** UNABLE TO PROCESS LOG FILES -- PLEASE VERIFY SOURCE LOGS
	 ECHO  - "%~1"
	 ECHO  - "%~2"
	 TIMEOUT 10
	 GOTO :HelpMessage
 )


 rem -- Perform Timing Comparisons
:PerformComparisons
 ECHO Performing Timing Comparisons...
 ECHO:
 DATEINFO --CompareOld=%@OLDER_LOG% --CompareNew=%@NEWER_LOG%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Create Temp Log and Ensure that it has Aggregate Timings
:CreateTempLog
 rem %1 = Log Filename
 rem %2 = Variable of Temp Log

 SET @ERROR=TRUE& IF NOT EXIST "%~1" GOTO :EOF
 SET @HAS_SUMMARY=
 SET @TOTAL_TIME=%@NO_TIME%

 ECHO Creating Temp Log for "%~1"
 TYPE "%~1" | FIND "\--- [#" >!%~2! 2>&1
 FOR /F %%F IN ('TYPE !%~2! ^| FIND /I "[#ZZ]"') DO SET @HAS_SUMMARY=TRUE
 IF NOT DEFINED @HAS_SUMMARY (
	 FOR /F "TOKENS=9" %%S IN ('TYPE "%~1" ^| FIND /I "%@SUMMARY%"') DO SET @TOTAL_TIME=%%S
	 ECHO \\--- [#ZZ] !@TOTAL_TIME! - *** AGGREGATE JOB TIME *** >>!%~2! 2>NUL
 )
 IF EXIST !%~2! SET @ERROR=
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Compare Processing Times from OpsLogs / SecurityLogs / UptimeReports
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<older_job_log^> ^<newer_job_log^>
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 C:\Logs\OlderLog.TXT C:\Logs\NewerLog.TXT
	 ECHO  %~n0 "D:\Job Logs\Yesterday.TXT" "D:\Job Logs\Today.TXT"
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Folder Paths containing spaces should be enclosed in quotes.
 )
 CALL :ShowStatus "FINISHED"
                                                                                            