@ECHO OFF
 rem ==========================================================================
 rem === Compare Member List between IFMEMBER and MEMBEROF
 rem ==========================================================================
 rem
 rem Created On: 06 Apr 2023
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 12 Jan 2024 / 16 Oct 2023              
 rem         By: Andrew S. Baker
 rem


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.2.0.120

 rem -- Check for Essential Utilities and/or Scripts
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f "NOW.EXE" "DATEINFO.EXE" "CHECKPARAMS.EXE" "READCONFIG.EXE" "IFMEMBER.EXE" "MEMBEROF.EXE"
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @MO_LIST=
 SET @IM_LIST=


 rem -- Get Domain Group Information via MemberOf.exe (JoeWare) and IFMEMBER (ResKit)
:ListDomainGroups

 rem -- Generate List via MEMBEROF
 NOW \s \n\---- List generated via MEMBEROF\n\-
 FOR /F "TOKENS=*" %%L IN ('MEMBEROF 2^>NUL ^| FINDSTR /R "sal.Security] bal.Security]"') DO (
	 SET @LINE=%%~L
	 SET @LINE=!@LINE:[Global Security] [=!
	 SET @LINE=!@LINE:[Universal Security] [=!
	 SET @LINE=!@LINE:] CN=♦!

	 FOR /F "TOKENS=1 DELIMS=♦" %%G IN ('ECHO !@LINE!') DO (
		 SET @MO_LIST=!@MO_LIST! "%USERDOMAIN%\%%~G"
		 ECHO  "%USERDOMAIN%\%%~G"
	 )
 )

 rem -- Generate List via IFMEMBER
 NOW \s \n\n\---- List generated via IFMEMBER\n\-
 FOR /F "TOKENS=6*" %%G IN ('IFMEMBER /LIST ^| FIND /I "%USERDOMAIN%\" ^| SORT') DO (
	 SET @ZZZ=%%~H
	 SET @IM_LIST=!@IM_LIST! "!@ZZZ:~0,-1!"
	 ECHO  "!@ZZZ:~0,-1!"
 )

 rem -- Compare Lists
 NOW \s \n\n\---- Comparing Both Lists\n\-
 FOR %%A IN (%@MO_LIST%) DO FOR %%B IN (%@IM_LIST%) DO (
	 IF NOT DEFINED ##%%~A SET ##%%~A= in MEMBEROF only ...
	 IF NOT DEFINED ##%%~B SET ##%%~B= in IFMEMBER only ...
	 IF DEFINED ##%%~A SET ##%%~A= in BOTH ............
 )

 rem -- Print List Comparison Results
 FOR /F "TOKENS=1-2 DELIMS==#" %%V IN ('SET ## 2^>NUL') DO ECHO %%W %%V
 ECHO %@DIVIDER%



 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 TIMEOUT 30
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                            