'==========================================================================
'=== Command Console Options for the Power User
'==========================================================================
'
'Requires WSH v5.1 or greater
'
'Created On: 24 Nov 2001
'        By: Andrew S. Baker
'
'Updated On: 31 Jan 2018  (Prior Update: 22 Feb 2015)
'        By: Andrew S. Baker
'

'--------------------------------------------------------------------------
'  This script uses enables Command Completion for the CMD processor
'  and enlarges the default CMD window and history. It also enables
'  Quick Edit for the command prompt, and changes the user prompt to
'  include the computer name.
'
'
'  ADDITIONAL SCRIPTING TOOLS/INFO:
'--------------------------------------------------------------------------
'  https://www.BrainWaveCC.com/knowledge-base/scripting-and-automation-options-for-windows/
'  https://www.BrainWaveCC.com/knowledge-base/must-have-utilities-for-windows-usersadmins/
'--------------------------------------------------------------------------


'==========================================================================
'=== Initialize Variables
'=== Updated On: 25 Feb 2014  (Prior Update: 20 Feb 2014)
'==========================================================================
 Option Explicit
 Dim DefCMDProcKey, CMDProcKey, AdminConsoleKey1, AdminConsoleKey2, DefConsoleKey, UserConsoleKey
 Dim SysEnvironment, MyPrompt
 Dim WshShell
 Set WshShell = WScript.CreateObject("WScript.Shell")

 DefCMDProcKey    = "HKEY_USERS\.DEFAULT\Software\Microsoft\Command Processor\CompletionChar"
 CMDProcKey       = "HKCU\Software\Microsoft\Command Processor\CompletionChar"
 DefConsoleKey    = "HKEY_USERS\.DEFAULT\Console\"
 UserConsoleKey   = "HKCU\Console\"
 AdminConsoleKey1 = UserConsoleKey + "%SystemRoot%_System32_CMD.exe\"
 AdminConsoleKey2 = UserConsoleKey + "%SystemRoot%_SysWOW64_CMD.exe\"

 SysEnvironment = "HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment\Prompt"
 MyPrompt       = "$T$_[" + WshShell.ExpandEnvironmentStrings("%COMPUTERNAME%") + "] $P$_$+$G"


'==========================================================================
'=== Display Initial Configuration Notices...
'==========================================================================
 WScript.Echo "START: Configuring Console Options... (v4.1.0)"


'==========================================================================
'=== Enable CMD Completion Characters
'==========================================================================
 WScript.Echo " - Enabling CMD Completion Characters"
 WshShell.RegWrite DefCMDProcKey, 9, "REG_DWORD"
 WshShell.RegWrite CMDProcKey, 9, "REG_DWORD"


'==========================================================================
'=== Expanding Console Window and Changing Edit Defaults
'=== Updated On: 22 Feb 2015  (Prior Update: 25 Feb 2014)
'==========================================================================
 WScript.Echo " - Setting Console Window Options"
 WshShell.RegWrite DefConsoleKey + "QuickEdit", 1, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "InsertMode", 1, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "HistoryNoDup", 1, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "HistoryBufferSize", 100, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "NumberOfHistoryBuffers", 10, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "ScreenBufferSize", 327680120, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "WindowSize", 2424952, "REG_DWORD"

 WshShell.RegWrite UserConsoleKey + "QuickEdit", 1, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "InsertMode", 1, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "HistoryNoDup", 1, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "HistoryBufferSize", 100, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "NumberOfHistoryBuffers", 10, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "ScreenBufferSize", 327680120, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "WindowSize", 2424952, "REG_DWORD"

 WshShell.RegWrite AdminConsoleKey1 + "QuickEdit", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "InsertMode", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "HistoryNoDup", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "HistoryBufferSize", 100, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "NumberOfHistoryBuffers", 10, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "ScreenBufferSize", 327680120, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "WindowSize", 2424952, "REG_DWORD"

 WshShell.RegWrite AdminConsoleKey2 + "QuickEdit", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "InsertMode", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "HistoryNoDup", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "HistoryBufferSize", 100, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "NumberOfHistoryBuffers", 10, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "ScreenBufferSize", 327680120, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "WindowSize", 2424952, "REG_DWORD"


'==========================================================================
'=== Change CMD Prompt
'==========================================================================
 WScript.Echo " - Changing CMD Prompt to " + MyPrompt
 WshShell.RegWrite SysEnvironment, MyPrompt


'==========================================================================
'=== Cleanup and Exit Script
'=== Updated On: 22 Feb 2015  (Prior Update: n/a)
'==========================================================================
 WScript.Echo "FINISHED: Configuring Console Options"
 Set WshShell = Nothing
 WScript.Quit(0)
                                        