@REM - ASB (20 Jan 2010 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 30 Apr 2018 / 27 Mar 2016 / 05 May 2015): Use SysInternals Tools to Move InUse Files
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.6.0.160

 FOR /F "TOKENS=1-5 DELIMS=*?" %%V IN ('ECHO %~1') DO SET @SOURCE_FILE=%%V%%W%%X%%Y%%Z
 FOR /F "TOKENS=1-5 DELIMS=*?" %%V IN ('ECHO %~2') DO SET @TARGET_FILE=%%V%%W%%X%%Y%%Z
 SET @TEMP_FILE=%@TARGET_FILE%.NEW


 rem -- Verify that Source File Actually Exists
:VerifySource
 IF NOT EXIST "%@SOURCE_FILE%" (
	 ECHO:
	 ECHO Could Not Find the Following SOURCE File:
	 ECHO   %@SOURCE_FILE%
	 GOTO :ExitBatch
 )


 rem -- Verify that Destination File Actually Exists
:VerifyTarget
 IF NOT EXIST "%@TARGET_FILE%" (
	 ECHO:
	 ECHO Could Not Find the Following TARGET File:
	 ECHO   %@TARGET_FILE%
	 GOTO :ExitBatch
 )


 rem -- Attempt to Copy Source to Target Directly
:CopyFile
 ECHO Attempting to Copy the Following File:
 ECHO -- SOURCE: "%@SOURCE_FILE%"
 ECHO -- TARGET: "%@TARGET_FILE%"
 ECHO:
 FOR /F %%C IN ('COPY "%@SOURCE_FILE%" "%@TARGET_FILE%" /Y 2^>NUL') DO IF "%%~C"=="1" (

	 rem -- If Copy was Successful, Then Report Status and Exit
	 ECHO File[s] Were Copied Successfully...
 ) ELSE (

	 rem -- If Target File is in Use, Then Copy Operation Needs to be Scheduled
	 ECHO Generating the Following Temp File:
	 ECHO   %@TEMP_FILE%
	 ECHO:
	 FOR /F %%T IN ('COPY "%@SOURCE_FILE%" "%@TEMP_FILE%" /Y 2^>NUL') DO IF "%%~T"=="1" (
		 MOVEFILE "%@TEMP_FILE%" "%@TARGET_FILE%"
		 PENDMOVES
	 ) ELSE (
		 ECHO:
		 ECHO OPERATION ABORTED: Could Not Create the Following TEMP file:
		 ECHO   %@TEMP_FILE%
	 )
 )


 rem -- Perform Final Job Report
:FinalReport
 DIR "%@SOURCE_FILE%" "%@TARGET_FILE%" "%@TEMP_FILE%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                                                