@REM - ASB (05 Apr 2006 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 12 Jun 2019 / 29 Mar 2019): Copy Files to Scripts Repository Sources
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.5.0.280

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Copy Files to Scripts Repository Sources
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<PATH\filename.exe^> [options]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  CMD OPTIONS:
	 ECHO    {any} .... Copy to WinPE, FTP Uploads and [Legacy]
	 ECHO    @ ........ Also copy to [Core] and KB-Public
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @SCRIPTS=%~d0\Scripts
 SET @SOURCE=%~1& IF NOT "%~1"=="" SET @SOURCE=!@SOURCE:%@SCRIPTS%\=!
 SET @SOURCELIST=%~dp0Input\ScriptSource.TXT
 SET @ROOTDIRS="Q:\Dropbox" "Q:\Storage\Dropbox" "%SystemDrive%\Cloud\CS.Work"
 SET @DROPBOX1=& FOR %%V IN (%@ROOTDIRS%) DO SET @DROPBOX1=!@DROPBOX1! "%%~V\Scripts\[Legacy]\Scripts"
 SET @DROPBOX2=& FOR %%V IN (%@ROOTDIRS%) DO SET @DROPBOX2=!@DROPBOX2! "%%~V\Scripts\[Core]\Scripts"
 SET @DROPBOX3=& FOR %%V IN (%@ROOTDIRS%) DO SET @DROPBOX3=!@DROPBOX3! "%%~V\Scripts\KB-Public\Scripts"
 SET @DROPBOX4="%SystemDrive%\Storage\Work\CustomInstalls\Scripts"
 SET @DROPBOX5="%SystemDrive%\Storage\Work\Custom_Upload\Scripts
 SET @DESTDIRS=& FOR /F "USEBACKQ SKIP=2 TOKENS=2 EOL=; DELIMS=, " %%D IN ("%@SOURCELIST%") DO SET @DESTDIRS=!@DESTDIRS! "%%~D"
 SET @DEST=& FOR %%D IN (%@DESTDIRS%) DO IF EXIST "%%~D" SET @DEST=%%~D
 FOR %%C IN (1 2 3 4 5 6) DO (SET @REMOTE_DEST%%C=& FOR %%D IN (!@DROPBOX%%C!) DO IF EXIST "%%~D" SET @REMOTE_DEST%%C=%%~D)


 rem -- Copy File To Repository Source
:CopyFile
 IF EXIST "%@SCRIPTS%\%@SOURCE%" (
	 CALL :CopyToDest "%@DEST%" "Copying Files to Local Script Source..."

	 IF NOT "%~2"=="" (
		 CALL :CopyToDest "%@REMOTE_DEST4%" "Copying Files to WinPE Source Repositories..."
		 CALL :CopyToDest "%@REMOTE_DEST5%" "Copying Files to FTP Upload Repository..."
		 CALL :CopyToDest "%@REMOTE_DEST1%" "Copying Files to Central Script Repository [Legacy]..."
	 )

	 IF "%~2"=="@" (
		 CALL :CopyToDest "%@REMOTE_DEST2%" "Copying Files to Central Script Repository [Core]..."
		 CALL :CopyToDest "%@REMOTE_DEST3%" "Copying Files to Public Knowledgebase Repository..."
	 )
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Copy to Remote Repository
:CopyToDest
 rem %1 = Destination Folder
 rem %2 = Display Message

 IF EXIST "%~1" (
	 MD "%~1\%@SOURCE%\.." >NUL 2>NUL
	 ECHO:
	 ECHO %~2
	 ECHO %@DIVIDER-%
	 ECHO Source ........: "%@SCRIPTS%\%@SOURCE%"
	 ECHO Destination ...: "%~1\%@SOURCE%"
	 COPY "%@SCRIPTS%\%@SOURCE%" "%~1\%@SOURCE%" /Y /V
	 ECHO:
 )
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                      