@ECHO OFF
 rem ==========================================================================
 rem === Count Number of Systems in List and Determine Max System Length
 rem ==========================================================================
 rem
 rem Created On: 04 May 2011
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 16 Oct 2023 / 30 Nov 2020              
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 25 Feb 2018              
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 30 Nov 2020 / 29 May 2020              
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.3.0.230

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Main Variables
 SET @INPUT=%SystemDrive%\Scripts\BAT\Input

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Determine Valid Source List
 SET @SOURCE=*%~n1*
	 IF "%~1"=="." SET @SOURCE=%@INPUT%ServerList
	 SET @FINDLIST="%~1" "%@SOURCE%" "%~dp0%@SOURCE%" "%~dp0Input\%@SOURCE%" "%@INPUT%%@SOURCE%" "%@INPUT%ServerList"
	 FOR %%F IN (%@FINDLIST%) DO FOR %%E IN ("" ".%COMPUTERNAME%.TXT" ".TXT") DO IF EXIST "%%~F%%~E" IF NOT DEFINED #ASKED_%%~F%%~E (
		 SET @SOURCE=%%~F%%~E
		 SET #ASKED_%%~F%%~E=TRUE
		 IF /I "!@SOURCE:~-4!"==".TXT" (
			 IF /I "%@CONSOLE_SESSION%"=="TRUE" (
				 CHOICE /C YNQEX /T 10 /D Y /N /M "Use the following system list? - '!@SOURCE!' "
			 ) ELSE (
				 CHOICE /C Y /T 0 /D Y /N
			 )
		 )
		 IF ERRORLEVEL 3 GOTO :ExitBatch
		 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 2 GOTO :CountLists
	 )

 rem -- Abort script if no system list has been provided/accepted
:AbortExecution
 ECHO:
 ECHO ERROR: No Valid System List Was Provided -- Script Execution Aborted...
 ECHO:
 GOTO :HelpMessage


 rem ==========================================================================
 rem === Get List Count and Maximum Length of All System Names in Server List
 rem === Updated On: 03 Feb 2020 / 10 Apr 2016              
 rem ==========================================================================
:CountLists
 SET @MAXLEN=0
 SET @NUMSYS=0
 SET @TOTALSYS=0
 FOR /F "USEBACKQ EOL=" %%V IN (%@SOURCE%) DO SET /A @TOTALSYS+=1
 FOR /F "USEBACKQ EOL=;" %%V IN (%@SOURCE%) DO (
	 SET @COUNT=
	 SET @STRING=%%~V& SET @STRING=!@STRING:\=!
	 SET /A @NUMSYS+=1
	 FOR /L %%Z IN (0,1,17) DO IF NOT "!@STRING:~%%~Z,%%~Z!"=="" SET @COUNT=%%~Z
	 SET /A @COUNT+=1
	 IF !@COUNT! GTR !@MAXLEN! (
		 SET @MAXLEN=!@COUNT!
		 SET @SYSNAME=!@STRING!
	 )
 )

 ECHO:
 ECHO  -- Name of System List ...... "%@SOURCE%"
 ECHO  -- Total Systems in List ..... %@TOTALSYS%
 ECHO  -- Live Systems in List ...... %@NUMSYS%
 ECHO  -- Longest System Name ...... "%@SYSNAME%" (%@MAXLEN% chars)
 ECHO:


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 03 Oct 2019 / 28 Feb 2019              
 rem ==========================================================================
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Execute Dynamic Command From Variable
 rem === Updated On: 06 May 2011                     
 rem ==========================================================================
:RunCMD
 rem %1 = Command To Execute

 %*
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019              
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Updated On: 30 Nov 2020 / 03 May 2018              
 rem ==========================================================================
:HelpMessage
 ECHO Count Number of Systems in List and Determine Max System Length
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<special_option ^| serverlist^>
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       .  ..... Use default server list
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 .
	 ECHO  %~n0 MyList
	 ECHO  %~n0 ThisList.TXT
	 ECHO  %~n0 "%~dp0Input\ServerList.TXT"
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Long filenames which contain spaces must be surrounded by quotes.
	 ECHO    Shortnames *can* be surrounded by quotes, but it is not mandatory.
 )
 CALL :ShowStatus "FINISHED"
               