@REM - ASB (06 Apr 2021 // 12 Jan 2024 / 16 Oct 2023 / 20 Feb 2022 / 01 Jan 2022 / 29 Dec 2021 / 14 Jul 2021 / 07 Apr 2021 / 06 Apr 2021): Create VHDX of Local System and Save Locally or Remotely
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.7.0.170

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Check for Essential Utilities and/or Scripts
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f "NOW.EXE" "DATEINFO.EXE" "CHECKPARAMS.EXE" "DISK2VHD.EXE" "SRVINFO.EXE"
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @BACKUP_PATH=%~1
 SET @BACKUP_FILE=%COMPUTERNAME%
 SET @PROCESS=DISK2VHD-tmp
 SET @FINISHED=
 SET @NOTFOUND=" was not found on "

 rem -- Process Special Command-line Parameters
 SET @ALL_PARAMS=%*
 CALL :GetParams "I INCLUDE" @INCLUDE
 CALL :GetParams "E EXCLUDE" @EXCLUDE
 CALL :GetParams "C CUSTOM"  @CUSTOMNAME & IF DEFINED @CUSTOMNAME SET @BACKUP_FILE=!@CUSTOMNAME!
 CALL :GetParams "R RANDOM"              & IF DEFINED @OK         SET @BACKUP_FILE=%@BACKUP_FILE%[%@RANDOM%]

 rem -- Standard Log Variables
 SET @LOGPATH=%@STORAGE%\Logs\Replication
 SET @LOGFILE=%@LOGPATH%\%~n0-%COMPUTERNAME%.%@FILESTAMP_R%


 rem -- Validate the Existence of the Log Folder
:ValidateLogFolder
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"
 IF NOT EXIST "%@LOGPATH%" (
	 ECHO *** Could Not Create Storage Folder ***
	 ECHO  -- "%@LOGPATH%"
	 GOTO :ExitBatch
 )


 rem -- Map EFI volume to drive Letter
:DetermineDrives
 CALL :GetTime @STIME
 CALL :GetFreeDrive @EFI
 FOR /F %%D IN ('MOUNTVOL /? ^| FIND /I " /S "') DO (
	 SET @VALIDDRIVES= %@EFI%
	 MOUNTVOL %@EFI% /S
 )

 rem -- Obtain Valid Local Drives
 IF DEFINED @INCLUDE (
	 FOR %%I IN (%@INCLUDE%) DO (
		 SET @DRV=%%I
		 SET @VALIDDRIVES=!@VALIDDRIVES! !@DRV:~0,1!:
	 )
 ) ELSE (
	 FOR /F "TOKENS=1 DELIMS=$ " %%D IN ('SRVINFO 2^>NUL ^| FIND /I " NTFS "') DO (
		 SET @SKIP=
		 FOR %%E IN (%@EXCLUDE%) DO (
			 SET @DRV=%%E
			 IF /I "!@DRV:~0,1!"=="%%~D" SET @SKIP=TRUE
		 )
		 IF "!@SKIP!"=="" SET @VALIDDRIVES=!@VALIDDRIVES! %%~D:
	 )
 )


 rem -- Create Disk Images via DISK2VHD
:CreateDiskImage
 CALL :EchoAll %@STIME% -- Creating Drive Images of %COMPUTERNAME% to %@BACKUP_PATH% [%@VALIDDRIVES% ]
 CALL :EchoAll %@DIVIDER%
 CALL :EchoAll 

 FOR %%D IN (%@VALIDDRIVES%) DO (
	 CALL :GetTime @BTIME
	 SET @DL=%%D
	 SET @THISBACKUP=%@BACKUP_PATH%\%@BACKUP_FILE%-!@DL:~0,1!.VHDX
	 CALL :EchoCON !@BTIME! -- Creating %%D Disk Image: !@THISBACKUP!
	 DISK2VHD -C %%D "!@THISBACKUP!"

	:WaitLoop
	 SLEEP 10
	 FOR /F "TOKENS=*" %%P IN ('PSLIST %@PSPARAMS% %@PROCESS% 2^>NUL ^| FIND /I %@NOTFOUND%') DO SET @FINISHED=TRUE
	 IF NOT DEFINED @FINISHED GOTO :WaitLoop

	 rem -- Get Current Drive Statistics
	 CALL :GetTime @CTIME
	 CALL :EchoCON !@CTIME! -- Disk Image of %%D Completed
	 ECHO:
	 ECHO %@DIVIDER~%
	 ECHO  Backup Started On ........................... !@BTIME!
	 ECHO  Backup Ended On ............................. !@CTIME!
	 DATEINFO -t !@BTIME#! -n !@CTIME#! -e "dys hrs mins secs.ms" -o " Backup Duration Was ......................... " 2>NUL
	 ECHO %@DIVIDER~%
	 CALL :EchoCON 
	 ECHO:
 ) >>"%@LOGFILE%" 2>&1


 rem -- Get Full Job Statistics
:GetFullStats
 CALL :GetTime @ETIME
 CALL :EchoAll %@ETIME% -- Finished Saving All Drive Images to %@BACKUP_PATH%

 ( rem -- Write to Log
	 ECHO:
	 ECHO %@DIVIDER-%
	 ECHO  Source of Drive Images ...................... %COMPUTERNAME%%@VALIDDRIVES%
	 ECHO  Backup Location ............................. %@BACKUP_PATH%
	 ECHO  Disk Imaging Job Started On ................. !@STIME!
	 ECHO  Disk Imaging Job Ended On ................... !@ETIME!
	 DATEINFO -t !@STIME#! -n !@ETIME#! -e "dys hrs mins secs.ms" -o " Total Job Duration Was ...................... " 2>NUL
	 ECHO %@DIVIDER-%
	 ECHO:
	 CALL DRIVEINFO.BAT
 ) >>%@LOGFILE% 2>&1


 rem -- Generate Final Report
:FinalReport
 FOR /L %%V IN (1,1,5) DO ECHO:
 IF EXIST %@LOGFILE% (
	 ECHO:
	 TYPE %@LOGFILE%
	 DIR %@LOGFILE% | FIND /V " Volume "
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Echo Output to Console and File
:EchoCON
:EchoAll
 IF "%~1"=="" (SET @ECHO=ECHO:) ELSE (SET @ECHO=ECHO %*)
 !@ECHO!
 IF /I "%~0"==":EchoCON" !@ECHO! >CON 2>&1
 IF /I "%~0"==":EchoAll" !@ECHO! >>"%@LOGFILE%" 2>&1
 GOTO :EOF


 rem -- SUBROUTINE: Store Current Date and Time in Variable
:GetTime
 rem %1 = Variable to Store Date/Time

 SET %~1=!DATE! at !TIME: =0!
 FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET %~1#="%%~d"
 GOTO :EOF


 rem -- SUBROUTINE: Use CheckParams.exe to Capture Selected Parameters
:GetParams
 rem %1 = Parameters to Search For
 rem %2 = Variable to Set

 SET @OK=& IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=2-3*" %%v IN ('CHECKPARAMS -q -a -c "%~1" -s %@ALL_PARAMS% 2^>NUL') DO IF /I "%%~v"=="TRUE" (
	 SET @OK=T
	 SET @REQ=T
	 IF NOT "%~2"=="" SET %~2=%%~x
	 IF "%%~w"=="" GOTO :EOF
	 SET @USED=%%~w
	 SET @USED=!@USED:[=!
	 SET @USED=!@USED:]=!
	 SET @SELECTED=!@SELECTED! !@USED!
 )
 GOTO :EOF


 rem -- SUBROUTINE: Get Free Drive Letter
:GetFreeDrive
 rem %1 = Variable to Set

 IF "%~1"=="" GOTO :EOF
 SET %~1=NOT SET

 PUSHD \\%COMPUTERNAME%\ADMIN$
 IF NOT ERRORLEVEL 1 SET %~1=%CD%
 POPD
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" CALL :GetTime @SCRIPT_BEG
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Create VHDX of Local System and Save Locally or Remotely...
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<backup_path^> [OPTIONS]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       /C: .... Use a custom filename (no extension)
 ECHO       /I: .... Indicate Drives which should be Included (Ignores /E)
 ECHO       /E: .... Indicate Drives which should be Excluded
 ECHO       /R ..... Add Random Number to Make Filename Unique
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 %SystemDrive%\Backups
	 ECHO  %~n0 D:\Storage /E:"D: E:"
	 ECHO  %~n0 E:\Backups /E:"B D F"
	 ECHO  %~n0 F:\Backups /I:"C D"
	 ECHO  %~n0 G:\Images /C:MyServer
	 ECHO  %~n0 \\REMOTESYS\Archives /C:OtherServer /R
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Long PATHS which contain spaces must be surrounded by quotes.
	 ECHO  * Drive letters to be skipped can be provided with or without the colon ^(:^)
 )
 CALL :ShowStatus "FINISHED"
                                    