    @REM - ASB (31 Oct 2014 // 16 Oct 2023 / 30 Nov 2020 / 22 Jan 2020 / 24 Dec 2019 / 14 Oct 2019 / 30 Sep 2019 / 18 Feb 2019 / 27 Jan 2019 / 06 Oct 2018): Display Active Directory DNS Zone Information
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.5.0.250

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @DOMAINLIST=%*& IF "%~1"=="" SET @DOMAINLIST=%USERDNSDOMAIN%
 SET @BASEDN=& CALL :GetDomainName %@DOMAINLIST%
 SET @RESOLVE=%~dp0..\Utils\Resolve.EXE
 SET @ADQUERY=ADFind %@BASEDN% -f "(&(objectCategory=computer)(|(primaryGroupId=516)(primaryGroupId=521)))" -nodn -s SUB -maxe 500 -csv attr name operatingSystem
 SET @SERVERS=& FOR /F "SKIP=1 TOKENS=1-2 DELIMS=," %%S IN ('!@ADQUERY!') DO SET @SERVERS=!@SERVERS! %%~S


 rem -- Loop Through DC List and Generate DNS Information
:GetDNSInfo
 FOR %%D IN (%@DOMAINLIST%) DO (
	 SET @VALID_DOMAIN=FALSE
	 IF EXIST "%@RESOLVE%" (
		 %@RESOLVE% %%~D >NUL 2>NUL
		 IF ERRORLEVEL 0 IF NOT ERRORLEVEL 1 SET @VALID_DOMAIN=TRUE
	 ) ELSE (
		 FOR /F "TOKENS=2-3 DELIMS=[] " %%I IN ('PING -n 1 %%~D ^| FIND "["') DO SET @VALID_DOMAIN=TRUE
	 )

	 rem -- DNS Info Header
	 ECHO Obtaining DNS Info for: %%~D
	 ECHO:
	 ECHO %@DIVIDER-%
	 ECHO   Renewal  ^|  Serial # ^| Refresh ^|   Retry ^| Expires ^|   TTL -- SERVER
	 ECHO %@DIVIDER-%

	 IF /I "!@VALID_DOMAIN!"=="TRUE" (
		 SET @COUNT_%%~D=0
		 SET @BASEDN=& CALL :GetDomainName "%%~D"
		 SET @SERVERS=& FOR /F "SKIP=1 TOKENS=1-2 DELIMS=," %%S IN ('!@ADQUERY!') DO SET @SERVERS=!@SERVERS! %%~S
	 )

	 FOR %%S IN (!@SERVERS!) DO (
		 FOR /F "TOKENS=1-2,5-9" %%a IN ('dnscmd %%~S /enumrecords %%~D @ ^| FIND " SOA" ^| FIND /V " RRSIG"') DO (
			 SET /A @COUNT_%%~D+=1
			 CALL :PadLeft @RN "%%~a" " " 5
			 CALL :PadLeft @RC "%%~b" " " 4
			 CALL :PadLeft @SN "%%~c" " " 9
			 CALL :PadLeft @RF "%%~d" " " 7
			 CALL :PadLeft @RT "%%~e" " " 7
			 CALL :PadLeft @EX "%%~f" " " 7
			 CALL :PadLeft @TT "%%~g" " " 5
			 ECHO !@RN! !@RC! ^| !@SN! ^| !@RF! ^| !@RT! ^| !@EX! ^| !@TT! -- %%S
		 )
	 )
	 ECHO %@DIVIDER-%
	 ECHO:
	 ECHO TOTAL ACCESSABLE DOMAIN CONTROLLERS for "%%~D" = !@COUNT_%%~D!
	 ECHO:
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Pad Variable Content to the Left/Right for Display in Logs
:PadLeft
:PadRight
 rem %1 = Variable to Store New Content
 rem %2 = Existing Value to Pad
 rem %3 = Character to use as padding [typically " ", "." or "0"]
 rem %4 = New String Length

 SET @STR=%~2
 SET @LEN=& FOR /L %%c IN (0,1,199) DO IF "!@STR:~%%c,1!"=="" IF NOT DEFINED @LEN SET @LEN=%%c
 IF 1%@LEN% GEQ 1%~4 (
	 SET %~1=%~2
 ) ELSE (
	 IF /I "%~0"==":PadLeft" (
		 SET @TEMPVAR=& FOR /L %%c IN (1,1,%~4) DO SET @TEMPVAR=!@TEMPVAR!%~3
		 SET @TEMPVAR=!@TEMPVAR!%~2
		 SET %~1=!@TEMPVAR:~-%~4!
	 )
	 IF /I "%~0"==":PadRight" (
		 SET @TEMPVAR=%~2& FOR /L %%c IN (1,1,%~4) DO SET @TEMPVAR=!@TEMPVAR!%~3
		 SET %~1=!@TEMPVAR:~0,%~4!
	 )
 )
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Get Active Directory Domain Name If Provided
:GetDomainName
 rem %1 = Domain Name Input

 SET #DOMAIN=%~1& IF "%~1"=="" SET #DOMAIN=%USERDNSDOMAIN%
 SET #DOMAIN=!#DOMAIN: =!
 SET #DOMAIN=!#DOMAIN:,=.!
 SET #DOMAIN=!#DOMAIN:dc=!
 SET @DOMAIN=& FOR %%D IN (!#DOMAIN!) DO SET @DOMAIN=!@DOMAIN!%%D
 SET #DOMAIN=
 SET @BASEDN=

 FOR /F "TOKENS=1-5 DELIMS=.= " %%D IN ('ECHO !@DOMAIN!') DO (
	 FOR %%z IN ("%%~D" "%%~E" "%%~F" "%%~G" "%%~H") DO IF NOT "%%~z"=="" SET @BASEDN=!@BASEDN!,DC=%%~z
 )

 SET @BASEDN=-b "!@BASEDN:~1,999!"
 SET @SEARCHDOMAIN=!@DOMAIN!
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Display Active Directory DNS Zone Information
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [Fully Qualified AD domain name] [Fully Qualified AD domain name] [...]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 mydomain.local
	 ECHO  %~n0 thisdomain.home thatdomain.com
	 ECHO  %~n0 domainone.com domaintwo.com domain3.com
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
