@REM - ASB (29 Aug 2013 // 16 Oct 2023 / 10 Mar 2021 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 26 Jul 2018 / 01 May 2018): Pre-pend Dates to Executable Files
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.6.0.370

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -a -c "H HELP ?" -x ". D" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 8 (
	 ECHO Pre-pend Dates to Executable Files
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<.^|/D^> [[*] ["additional extensions"]]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 IF NOT ERRORLEVEL 10 GOTO :ExitBatch

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @FOLDERCHECK="%SystemDrive%\" "%SystemDrive%\Windows" "%SystemDrive%\Windows\System" "%SystemDrive%\Windows\System32" "%ProgramFiles%" "%ProgramFiles(x86)%" "%ProgramData%"
 SET @FILEEXT=EXE MSI& IF "%~2"=="*" SET @FILEEXT=!@FILEEXT! EXE MSI RAR ZIP 7z gz bz2 %~3
 SET @BYPASS=@AppRepositoryOverride.INPUT& IF EXIST "%@BYPASS:@=+%" REN "%@BYPASS:@=+%" "%@BYPASS%"
 SET @EXTENSIONS=%@FILEEXT%& IF EXIST "%@BYPASS%" FOR /F "EOL=; USEBACKQ TOKENS=*" %%B IN ("%@BYPASS%") DO SET @EXTENSIONS=%%~B


 rem -- Verify That We Are Not In a Critical Folder
:Verify
 FOR /F "TOKENS=1-2*" %%C IN ('DIR ^| find /I "Directory of"') DO SET @FOLDER=%%~E
 FOR %%C IN (%@FOLDERCHECK%) DO IF /i "%%~C"=="%@FOLDER%" (
	 ECHO THIS SCRIPT IS NOT SAFE TO RUN FROM THIS FOLDER...
	 ECHO MISSION ABORTED.
	 GOTO :ExitBatch
 )


 rem -- Search Through Current Folder for Folders to Update
:RenameFolders
 FOR %%P IN (/D -D) DO IF /I "%~1"=="%%~P" FOR /F "TOKENS=*" %%V IN ('DIR /AD /B /OGN 2^>NUL ^| FINDSTR /V /R "^[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]"') DO (
	 SET @A_FOLDER=%%~V
	 SET @FILEDATE=%%~tV
	 SET @FILEDATE_M=!@FILEDATE:~0,2!
	 SET @FILEDATE_D=!@FILEDATE:~3,2!
	 SET @FILEDATE_Y=!@FILEDATE:~6,4!
	 SET @NEW_NAME=!@FILEDATE_Y!-!@FILEDATE_M!-!@FILEDATE_D! %%~nxV

	 IF NOT EXIST "!@NEW_NAME!" (
		 ECHO Renaming "!@A_FOLDER!" to "!@NEW_NAME!"
		 REN "!@A_FOLDER!" "!@NEW_NAME!"
	 )
 )
 ECHO %@DIVIDER-%
 ECHO:


 rem -- Search Through Current Folder for Files to Update
:RenameFiles
 FOR %%E IN (%@EXTENSIONS%) DO FOR /F "TOKENS=*" %%V IN ('DIR /A-D /B /OGN "*.%%~E" 2^>NUL ^| FINDSTR /V /R "^[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]"') DO (
	 SET @THISFILE=%%~V
	 SET @FILEDATE=%%~tV
	 SET @FILEDATE_M=!@FILEDATE:~0,2!
	 SET @FILEDATE_D=!@FILEDATE:~3,2!
	 SET @FILEDATE_Y=!@FILEDATE:~6,4!
	 SET @NEWFILE=!@FILEDATE_Y!-!@FILEDATE_M!-!@FILEDATE_D! %%~nxV

	 IF NOT EXIST "!@NEWFILE!" (
		 ECHO Renaming "!@THISFILE!" to "!@NEWFILE!"
		 REN "!@THISFILE!" "!@NEWFILE!"
	 )
 )
 ECHO %@DIVIDER-%
 ECHO:
 DIR /OGN


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
            