@ECHO OFF
 rem ==========================================================================
 rem === Defrag All Drives on Local Machine
 rem ==========================================================================
 rem
 rem Created On: 12 Jun 2003
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 16 Oct 2023 / 22 Jan 2022              
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows XP or Server 2003
 rem
 rem  Non-Native Utilities Required:
 rem    Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem
 rem  Required Scripts:
 rem    SetDrive.BAT ........... Set Global Variables for this Environment
 rem ==========================================================================

 :::  This script defrags all local drives using the native defrag utility in
 :::  Windows XP/2003 and later. It uses SRVINFO from the Resource Kit to make
 :::  the determination about which drives are local on the system, or you can
 :::  set the list of drives with in the environment variable @LOCALDRIVES. A
 :::  daily scheduled job is automatically created to run the defrag.
 :::
 :::  This script also logs the time that each drive started its defrag, along
 :::  with the toal time taken for the defragmentation job.  The schedule is
 :::  set to defrag weekly, on Sunday morning.
 :::
 :::  NOTE: It won't run properly if the Computer Management MMC is already
 :::        running at the time that the script runs.
 :::
 :::  (Nov 2010) Changed the default log extension of the reports from .LOG to
 :::  .TXT so that the reports that are mailed to mobile devices can be read
 :::  automatically. (Not too many devices can natively handle .LOG files)
 :::
 :::  (Dec 2012) Made it possible for the scheduled tasks to be stored in their
 :::  own folder, rather than the default root folder of the Task Scheduler.
 :::
 :::  (Mar 2019) v3.2 -- Enabled Code Page 1252 Support;
 :::
 :::  (Oct 2019) v3.3 -- Updated :ShowStatus routine to reset TITLE/CodePage;
 :::  -- Changed Script Documentation to www.BrainWaveCC.com
 :::  -- Corrected and expanded the DEBUG logging routine;
 :::  -- Generate Filtered CMD Title;
 :::
 :::  (May 2020) v3.4 -- Migrated :DebugMode routine to SetDrive.BAT;
 :::
 :::  (Nov 2020) v3.5 -- Provided extended HELP options (--?? / --H2);
 :::  -- New CHECKPARAMS syntax for processing extended help options;
 :::
 :::  (Jan 2022) v3.6 -- Modify the @NAMECHK verification to include \ prefix;
 :::
 :::  (Oct 2023) v3.7 -- Change the way the @SCRIPT_BEG# variable is
 :::  calculated in various subroutines by using DATEINFO instead of %DATE%;
 :::
 :::
 :::  ADDITIONAL SCRIPTING TOOLS/INFO:
 :::  -------------------------------------------------------------------------
 :::  https://www.BrainWaveCC.com/knowledge-base/scripting-and-automation-options-for-windows/
 :::  https://www.BrainWaveCC.com/knowledge-base/must-have-utilities-for-windows-usersadmins/
 :::  -------------------------------------------------------------------------


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 05 Oct 2019              
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 30 Nov 2020 / 26 May 2020              
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.7.0.370

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Job Scheduling Variables
 SET @JOBNAME=defrag local drives
 SET @JOBUSER=SYSTEM
 SET @JOBFREQ=WEEKLY
 SET @JOBTIME=01:45:00
 SET @JOBDATE=/D SAT
 SET @JOBPATH=%~f0
 SET @JOBTYPE=

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 ECHO:
	 GOTO :ExitBatch
 )

 rem -- Accept a Specific Defrag Variable as a CLI Parameter
 SET @LOCALDRIVES=
 FOR %%L IN (B C D E F G H I J K L M N O P Q R S T U V W X Y Z) DO IF /I "%~1"=="%%~L:" SET @LOCALDRIVES=%%~L

 rem -- Add Valid Parameters Depending on Current Version of Defrag.exe Running
 FOR %%V IN (W F V X) DO (
	 SET @FOUND1=FALSE
	 FOR /F "TOKENS=*" %%P IN ('DEFRAG /? ^| FIND /I "-%%~V"') DO SET @FOUND1=TRUE
	 IF /I "!@FOUND1!"=="TRUE" SET @PARAMS=!@PARAMS! -%%~V

	 SET @FOUND2=FALSE
	 FOR /F "TOKENS=*" %%P IN ('DEFRAG /? ^| FIND /I "/%%~V"') DO SET @FOUND2=TRUE
	 IF /I "!@FOUND2!"=="TRUE" SET @PARAMS=!@PARAMS! /%%~V
 )

 rem -- Check for Variable to Force Rescheduling
 FOR %%P IN (%*) DO IF "%%~P"=="." (
	 SET @UPDATESCHED=TRUE
	 SET @SCHEDULEONLY=TRUE
 )

 rem -- Standard Log Variables
 SET @NODEFRAG=%~dp0INPUT\NoDefrag.DAT
 SET @LOGPATH=%@STORAGE%\Logs\Defrag
 SET @SAVELOG=%@LOGPATH%\%~n0.%@FILESTAMP%
 SET @LOGFILE=%@LOGPATH%\%~n0.TXT
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Create Scheduled Job using SCHTASKS (XP/2003/Vista/+)
 rem === Updated On: 22 Jan 2022 / 09 Mar 2019              
 rem ==========================================================================
:ScheduleJobs
 IF /I NOT "%@UNSCHED%"=="TRUE" IF /I "%@NOSCHED%"=="TRUE" (
	 SET @JOBTYPE= // ONE-TIME
	 ECHO:
	 ECHO *** Job Scheduling Disabled ***
	 ECHO:
	 GOTO :ScheduleJobs_END
 )

 ECHO:
 ECHO Scheduling "%@JOBNAME%" on %COMPUTERNAME%...
 ECHO:

 IF EXIST "%SystemRoot%\System32\SCHTASKS.EXE" (
	 IF %@OSBUILD% LSS 6000 SET @TASKFOLDER=
	 SET @NAMECHK=%@JOBNAME:[=\[%
	 SET @NAMECHK=!@NAMECHK:]=\]!
	 SET @CHK_SCHED=SCHTASKS /QUERY /V /FO LIST
	 SET @SET_SCHED=SCHTASKS /CREATE /TN "!@TASKFOLDER!%@JOBNAME%" /TR "%@JOBPATH%" /RU "%@JOBUSER%" /SC %@JOBFREQ% %@JOBDATE% /ST %@JOBTIME% %@JOBLEVEL% %@FORCE%
 ) ELSE (
	 SET @CHK_SCHED=AT
	 SET @SET_SCHED=AT %@JOBTIME% %@AT_DATE% %@AT_PATH%
 )

 rem -- Delete Scheduled Task from Old Custom Folders on Vista/2008+
 IF %@OSBUILD% GEQ 6000 (
	 FOR /F "TOKENS=1* DELIMS=\ " %%s IN ('%@CHK_SCHED% ^| FIND "TaskName:" ^| FINDSTR /I /R /C:"\\%@NAMECHK%$"') DO (
		 IF /I NOT "%@TASKFOLDER%%@JOBNAME%"=="%%t" SCHTASKS /DELETE /TN "%%t" /F >NUL 2>&1
	 )
 )

 rem -- Check for Schedule Update Parameters
 IF /I "%@UPDATESCHED%"=="TRUE" (!@SET_SCHED!) ELSE (CALL :CheckSched "%~f0")
 ECHO %@MINORDIV%
 ECHO:
 IF /I "%@SCHEDULEONLY%"=="TRUE" (
	 ECHO Task has been scheduled.  Now exiting script...
	 IF %@OSBUILD% LSS 6000 (SCHTASKS) ELSE (%@CHK_SCHED% /TN "!@TASKFOLDER!%@JOBNAME%")
	 GOTO :ExitBatch
 )
:ScheduleJobs_END
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Defrag Each Drive and Log Results
 rem === Updated On: 08 Mar 2019 / 24 Feb 2015              
 rem ==========================================================================
:RunDefrag
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 CALL :GetTime @STIME
 ECHO *** %@VER% - Please Wait ***
 IF "%~1"=="" FOR /F "DELIMS=$" %%D IN ('SRVINFO -NS ^| FIND "$"') DO  SET @LOCALDRIVES=!@LOCALDRIVES! %%~D

 IF EXIST "%@NODEFRAG%" (
	 ECHO %DATE% at %TIME% -- Disk Defragmentation is Disabled for %COMPUTERNAME% >>"%@SAVELOG%"
 ) ELSE (
	 FOR %%V IN (%@LOCALDRIVES%) DO (
			ECHO Defragging Drive %%~V: @ !TIME!
			ECHO Defrag Parameters: %@PARAMS%

			( rem -- Write to Log
				ECHO:
				ECHO Defragging Drive %%~V: @ !TIME!
				ECHO Defrag Parameters: %@PARAMS%

				IF EXIST %%~V:\ (
					DEFRAG %%~V: %@PARAMS%
				) ELSE (
					ECHO *** NO DRIVE %%~V: FOUND *** >CON
					ECHO *** NO DRIVE %%~V: FOUND ***
					ECHO:
				)
				ECHO %@DIVIDER*%
			) >>"%@SAVELOG%"
	 )
 )
 CALL :GetTime @ETIME


 rem ==========================================================================
 rem === Close Out Defragmentation Log Files
 rem === Updated On: 05 Feb 2015 / 10 Oct 2013              
 rem ==========================================================================
:FinishLog
 ( rem -- Write to Log
	 ECHO:
	 ECHO %@MINORDIV%
	 ECHO  Defrag Started On ............................. %@STIME%
	 ECHO  Defrag Ended On ............................... %@ETIME%
	 ECHO:
	 ECHO Logfile Generated by %@VER%
	 ECHO:
 ) >>"%@SAVELOG%"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 04 Oct 2019 / 28 Feb 2019              
 rem ==========================================================================
:ExitBatch
 COPY "%@SAVELOG%" "%@LOGFILE%" /V

 IF /I "%@CONSOLE_SESSION%"=="TRUE" (
	 START "Defrag Logs" "%@SAVELOG%" & DIR "%@SAVELOG%"
 ) ELSE (
	 TYPE "%@SAVELOG%" & DIR "%@SAVELOG%"
 )
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Check if Scheduled Job is Already Running
 rem === Updated On: 08 Mar 2019 / 05 Feb 2015              
 rem ==========================================================================
:CheckSched
 rem %1 = Standard Search Criteria
 rem %2 = Advanced Search Criteria

 SET @CHK=%2
 IF DEFINED @CHK (
	 %@CHK_SCHED% 2>NUL | FIND /I "%~1" | FINDSTR /I /R /C:%2 >NUL
 ) ELSE (
	 %@CHK_SCHED% 2>NUL | FIND /I "%~1" >NUL
 )
 IF ERRORLEVEL 1 %@SET_SCHED%
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Store Current Date and Time in Variable
 rem === Updated On: 16 Oct 2023 / 10 Oct 2013              
 rem ==========================================================================
:GetTime
 rem %1 = Variable to Store Date/Time

 SET %~1=%DATE% at %TIME: =0%
 FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET %~1#="%%~d"
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019              
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" CALL :GetTime @SCRIPT_BEG
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Updated On: 30 Nov 2020 / 13 Oct 2013              
 rem ==========================================================================
:HelpMessage
 ECHO Defrag All Drives on Local Machine...
 ECHO:
 ECHO:
 ECHO    YOU TYPED: %0 %*
 ECHO:
 ECHO   CMD SYNTAX: %~n0  [OPTIONS]
 ECHO               %~n0  [-h ^| -?]
 ECHO:
 ECHO  DEFINITIONS:
 ECHO  -?,  /H ... Display This Help Message  (also --HELP)
 ECHO       .  ... Schedule the Job Only, Without Executing It Now
 ECHO:
 ECHO  EXAMPLE(S): %~n0
 ECHO              %~n0 .
 ECHO:
 ECHO  USAGE NOTES:
 ECHO    * Parameters surrounded by ^<^> are mandatory.
 ECHO    * Parameters surrounded by [] are optional.
 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
 CALL :ShowStatus "FINISHED"
                                                                                        