@ECHO OFF
 rem ==========================================================================
 rem === Delete Empty Folders (Reiterative Version)
 rem ==========================================================================
 rem
 rem Created On: 07 Dec 2000
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 06 Sep 2001
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: NT4 or later
 rem
 rem  Non-Native Utilities Required: NONE
 rem ==========================================================================

 :::  This script will delete folders which are empty. To avoid
 :::  having to run the script multiple times, it will check to
 :::  see if any folders were deleted during the current run, and
 :::  if so, it will run again until no folders are deleted.  If
 :::  no folder is provided as a paramter (e.g. DelEmpty C:\Junk)
 :::  then the variable @FOLDER will contain the default C:\TEMP
 :::
 :::  Folder names containing spaces should be entered AT the
 :::  command line with a '+' character in place of each space.
 :::  They will be converted back to a spaces in the script.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 06 Sep 2001
 rem ==========================================================================
:NeedHelp
 IF "%~1"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 23 Aug 2001
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @DELETE=FALSE
 SET @FOLDER=%*
 SET @FOLDER=%@FOLDER:+= %
 IF EXIST "%@FOLDER%" GOTO :Main


 rem ==========================================================================
 rem === ERROR: Folder Not Found
 rem === Last Modified On 07 Dec 2000
 rem ==========================================================================
:Error
 ECHO:
 ECHO ERROR: The folder "%@FOLDER%" does not exist...
 ECHO:
 ECHO Script aborted...
 ECHO:
 GOTO :EOF


 rem ==========================================================================
 rem === Recurse Through All Folders Starting From @FOLDER
 rem === Last Modified On 07 Dec 2000
 rem ==========================================================================
:Main
 PUSHD "%@FOLDER%"
 FOR /R %%V IN (.) DO CALL :CheckFolder %%V
 POPD
 ECHO:
 IF /I "%@DELETE%"=="TRUE" GOTO :Variables
 ECHO:
 IF /I "%@DELETE%"=="FALSE" ECHO No Folders Were Empty...
 IF /I "%@DELETE%"=="TRUE"  ECHO Empty Folders Deleted...


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 07 Dec 2000
 rem ==========================================================================
:ExitBatch
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Find Empty Folders To Delete
 rem === Last Modified On 07 Dec 2000
 rem ==========================================================================
:CheckFolder
 rem %1 = Current Folder Name To Check
 SET @EMPTY=TRUE
 SET @CURRENT=%1
 SET @CURRENT=%@CURRENT:\.=%
 FOR /F %%E IN ('DIR /B /A "%@CURRENT%"') DO SET @EMPTY=FALSE
 IF /I "%@EMPTY%"=="FALSE" GOTO :EOF
 ECHO The following folder (%@CURRENT%) is EMPTY
 RD /Q "%@CURRENT%"
 SET @DELETE=TRUE
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 23 Aug 2001
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for DELEMPTY.BAT
 ECHO:
 ECHO === DelEmpty {initial_dir}
 ECHO:
 ECHO Example: DelEmpty C:\STORAGE
 ECHO          DelEmpty D:\ARCHIVES
 ECHO          DelEmpty E:\OLD+ARCHIVES
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Spaces in the Folder Name should
 ECHO       be represented by a '+' symbol.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
