@ECHO OFF
 rem ==========================================================================
 rem === Delete Old Files (Win2K/FORFILES Version)
 rem ==========================================================================
 rem
 rem Created On: 10 Oct 1998
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 08 Jan 2007  (Prior Update: 23 Oct 2005)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2000 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem
 rem  Other Scripts Called:
 rem    SetDrive.BAT ........... Primary Script for Setting Common Variables
 rem ==========================================================================

 :::  This version will work on Win2K only.  The use of FORFILES from the
 :::  ResKit makes it much smaller and faster.
 :::
 :::  Folder names containing spaces should be entered at the command line
 :::  surrounded by Quotation Marks. This is only supported in Win2K, not NT4.
 :::  Thanks to Gerald Gaston for the idea and the code. This will require less
 :::  grief (than versions A - D of DELOLD) for anyone who has folders which
 :::  contain weird characters (such as '+').
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to "TRUE"
 rem === Last Modified On: 25 Oct 2005
 rem ==========================================================================
:DebugMode
 IF /I "%Debug%"=="TRUE" (
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE (
	 SET @PAUSE_IF_DEBUG=
	 SET @END_DEBUG_MODE=
 )


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On: 06 Sep 2001
 rem ==========================================================================
:NeedHelp
 SET @VER=%~nx0 v1.5.1

 IF "%~1"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On: 08 Jan 2007  (Prior Update: 23 Oct 2005)
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION

 rem -- Calculate Date/Time (Short Procedure - No ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=1-3 DELIMS=:. " %%T IN ('ECHO %TIME: =0%') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG
 SET @TIMESTAMP=%DATE% at %TIME%

 rem -- Get Official Drive Letters and Calculate Date/Time for NON-US Regions
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Standard Variables
 SET @FOLDER=%~1
 SET @AGE=%~2& IF "%~2"=="" SET @AGE=30
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Recurse Through Subfolders And Delete Old Files
 rem === Last Modified On: 20 May 2005
 rem ==========================================================================
:SetFolders
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"
 %@PAUSE_IF_DEBUG%

 NOW Hunting Through "%@FOLDER%" And Subfolders For Old Files... >"%@LOGFILE%"
 ECHO:                                                          >>"%@LOGFILE%"
 ECHO:
 ECHO Hunting Through "%@FOLDER%" And Subfolders For Old Files...
 ECHO:
 FOR /F "TOKENS=*" %%D IN ('FORFILES -p"%@FOLDER%" -d-%@AGE% -s -c"CMD /C IF @ISDIR==FALSE ECHO @PATH\@FILE"') DO CALL :RemoveFiles "%%D"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On: 04 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Remove Files That Are Over XX Days Old
 rem === Last Modified On: 20 May 2005
 rem ==========================================================================
:RemoveFiles
 rem %* = Current Filename
 ECHO:                 >>"%@LOGFILE%"
 ECHO -- Purging %*...
 ECHO -- Purging %*... >>"%@LOGFILE%"
 ATTRIB -R -S -H %*
 DEL %*                >>"%@LOGFILE%"
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Remove Surrounding Quotes From Variable
 rem === Last Modified On: 01 Jul 2001
 rem ==========================================================================
:NoQuotes
 rem %1 = Current Filename
 SET %1=%~2
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On: 09 Mar 2006
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for %@VER%
 ECHO:
 ECHO === %~n0 {initial_dir} [age_of_files]
 ECHO:
 ECHO Example: %~n0 C:\STORAGE 10
 ECHO          %~n0 D:\HOME 90
 ECHO          %~n0 E:\ARCHIVES
 ECHO          %~n0 "F:\OLD ARCHIVES"
 ECHO          %~n0 "G:\MISCELLANEOUS STUFF" 45
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Folder names which contain spaces should be surrounded by quotes.
 ECHO       Shortnames *can* be surrounded by quotes if you choose, but it is
 ECHO       not mandatory by any means.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
