@ECHO OFF
 rem ==========================================================================
 rem === Delete Old Files (Win2K/FORFILES Version)
 rem ==========================================================================
 rem
 rem Created On: 10 Oct 1998
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 28 Feb 2019  (Prior Update: 28 Oct 2018)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2000 or later
 rem
 rem  Non-Native Utilities Used/Required:
 rem    BrainWave Utilities .... https://www.BrainWaveCC.com/brainwave-utilities
 rem
 rem    Resource Kit ........... https://en.wikipedia.org/wiki/Resource_Kit
 rem
 rem  Other Scripts Called:
 rem    SetDrive.BAT ........... Set Global Variables for this Environment
 rem ==========================================================================

 :::  This version will work on Win2K and later OSes only.  The use of FORFILES
 :::  from the ResKit makes it much smaller and faster.
 :::
 :::  Folder names containing spaces should be entered at the command line
 :::  surrounded by Quotation Marks. This is only supported in Win2K, not NT4.
 :::  Thanks to Gerald Gaston for the idea and the code. This will require less
 :::  grief (than versions A - D of DELOLD) for anyone who has folders which
 :::  contain weird characters (such as '+').
 :::
 :::  (Nov 2010) Changed the default log extension of the reports from .LOG to
 :::  .TXT so that the reports that are mailed to mobile devices can be read
 :::  automatically. (Not too many devices can natively handle .LOG files)
 :::
 :::  (Nov 2012) v1.8 -- Added the ability to use the newer, native version of
 :::  FORFILES found in the SYSTEM32 folder of Windows 2003+ systems, making
 :::  the necessary accomodations for their slightly different syntax.
 :::
 :::  (Oct 2018) v3.0 -- The new BrainWave CheckParams utility is now used to
 :::  check for the /H and /? parameters, replacing the use of FIND/FINDSTR;
 :::  -- Added new Filtered CMD Title and Syntax Help processing routines;
 :::  -- Changed Script Documentation to www.BrainWaveCC.com;
 :::  -- Corrected and expanded the DEBUG logging routine;
 :::
 :::  (Feb 2019) v3.1 -- Enabled Code Page 1252 Support;
 :::
 :::
 :::  ADDITIONAL SCRIPTING TOOLS/INFO:
 :::  -------------------------------------------------------------------------
 :::  https://www.BrainWaveCC.com/knowledge-base/scripting-and-automation-options-for-windows/
 :::  https://www.BrainWaveCC.com/knowledge-base/must-have-utilities-for-windows-usersadmins/
 :::  -------------------------------------------------------------------------


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Last Modified On: 25 Oct 2018  (Prior Update: n/a)
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL
 SET @TTT=


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to TRUE, LOG, or VERBOSE
 rem === Last Modified On: 28 Oct 2018  (Prior Update: 05 May 2015)
 rem ==========================================================================
:DebugMode
 SET #DEBUG=& FOR %%d IN (LOG TRUE VERBOSE) DO IF /I "%Debug%"=="%%~d" SET #DEBUG=TRUE
 IF DEFINED #DEBUG (
	 SET @DIAGMODE=TRUE
	 SET @DEBUG_MODE=[DEBUG MODE ON]
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:^& TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 IF /I "%Debug%"=="LOG" (SET @PAUSE_IF_DEBUG=& SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:)
	 IF /I "%Debug%"=="VERBOSE" (SET @VERBOSE_OFF=ECHO ON) ELSE (FOR %%t IN (ON OFF) DO SET @VERBOSE_%%t=ECHO %%t)
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE ( FOR %%d IN (DEBUG_MODE PAUSE_IF_DEBUG PRINT_IF_DEBUG END_DEBUG_MODE VERBOSE_ON VERBOSE_OFF) DO SET @%%d=)


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On: 28 Oct 2018  (Prior Update: 27 Mar 2016)
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.1.0.320

 rem -- Display Syntax Help if Required/Requested
 IF "%~1"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 %@VERBOSE_OFF%
	 CALL %@VARIABLES%
	 %@VERBOSE_ON%
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Standard Variables
 SET @FOLDER=%~1
 SET @FILESPEC=%~2& IF "%~2"=="" SET @FILESPEC=*.*
 SET @AGE=%~3& IF "%~3"=="" SET @AGE=30
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Recurse Through Subfolders And Delete Old Files
 rem === Last Modified On: 14 Nov 2012  (Prior Update: 20 May 2005)
 rem ==========================================================================
:SetFolders
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"
 %@PAUSE_IF_DEBUG%

 SET @DELETE_COUNT=0
 SET @FORFILES=FORFILES -p"%@FOLDER%" -m%@FILESPEC% -d-%@AGE% -s -c"CMD /C IF @ISDIR==FALSE ECHO @PATH\@FILE"
 IF EXIST "%SystemRoot%\System32\FORFILES.EXE" (
	 SET @FORFILES=%SystemRoot%\System32\FORFILES -p "%@FOLDER%" -m %@FILESPEC% -d -%@AGE% -s -c "CMD /C IF @ISDIR==FALSE ECHO @PATH"
 )

 ( rem -- Create Header
	 NOW Hunting Through "%@FOLDER%" And Subfolders For Old %@FILESPEC% Files...
	 ECHO:
 ) >"%@LOGFILE%" 2>&1

 TYPE "%@LOGFILE%"
 FOR /F "TOKENS=*" %%D IN ('%@FORFILES%') DO CALL :RemoveFiles "%%~D"

 ( rem -- Create Footer
	 ECHO:
	 NOW TOTAL %@FILESPEC% FILES DELETED: %@DELETE_COUNT%
	 ECHO:
 ) >>"%@LOGFILE%" 2>&1
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On: 28 Feb 2019  (Prior Update: 15 Feb 2015)
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 CALL :ShowStatus "FINISHED"
 TITLE Command Prompt (%USERDOMAIN%\%USERNAME%)   %@DEBUG_MODE%
 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO ECHO Restoring Active Code Page:%%C
 ENDLOCAL
 GOTO :EOF                                                                                  


 rem ==========================================================================
 rem === SUBROUTINE: Remove Files That Are Over XX Days Old
 rem === Last Modified On: 14 Nov 2012  (Prior Update: 20 May 2005)
 rem ==========================================================================
:RemoveFiles
 rem %* = Current Filename

 SET /A @DELETE_COUNT+=1
 ECHO:                 >>"%@LOGFILE%"
 ECHO -- Purging %*...
 ECHO -- Purging %*... >>"%@LOGFILE%"
 ATTRIB -R -S -H %*
 DEL %*                >>"%@LOGFILE%"
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Remove Surrounding Quotes From Variable
 rem === Last Modified On: 01 Jul 2001  (Prior Update: n/a)
 rem ==========================================================================
:NoQuotes
 rem %1 = Current Filename

 SET %1=%~2
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Last Modified On: 27 Mar 2016  (Prior Update: 05 May 2015)
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" SET @SCRIPT_BEG#="!DATE:~4,99! !TIME: =0!"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 ECHO:
 ECHO *** %@SCRIPTSTATUS%: %@VER% [%DATE% at %TIME: =0%] ***
 ECHO:
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Last Modified On: 25 Oct 2018  (Prior Update: 14 Nov 2012)
 rem ==========================================================================
:HelpMessage
 ECHO Delete Old Files (Win2K/FORFILES Version)
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<initial_dir^> [file_spec] [age_of_files]
 ECHO  %~n0  [-h^|-?]
 ECHO:
 ECHO ----------------
 ECHO SYNTAX EXAMPLES:
 ECHO ----------------
 ECHO  %~n0 C:\STORAGE *.LOG 10
 ECHO  %~n0 D:\HOME *.* 90
 ECHO  %~n0 E:\ARCHIVES OLD*.*
 ECHO  %~n0 "F:\OLD ARCHIVES"
 ECHO  %~n0 "G:\MISCELLANEOUS STUFF" *.OLD 45
 ECHO  %~n0 -?
 ECHO:
 ECHO ------------
 ECHO USAGE NOTES:
 ECHO ------------
 ECHO  * Parameters surrounded by ^<^> are mandatory.
 ECHO  * Parameters surrounded by [] are optional.
 ECHO:
 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 ECHO:
 ECHO  * Folder names which contain spaces should be surrounded by quotes.
 ECHO  * Shortnames *can* be surrounded by quotes if you choose, but it is
 ECHO    not mandatory by any means.
 CALL :ShowStatus "FINISHED"
                                                                