@REM - ASB (19 Sep 2013 // 16 Oct 2023 / 30 Nov 2020 / 26 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 28 Oct 2018 / 31 Aug 2018 / 26 Jul 2018 / 29 Apr 2018 / 27 Mar 2016): Delete All Test/Temporary Scheduled Jobs
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.2.0.220

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @COUNT=0
 SET @DELETED=


 rem -- Check through All Scheduled Tasks for Test/Obsolete Jobs
:DeleteJobs
 ECHO Searching for Test/Obsolete Scheduled Jobs to Delete...
 ECHO:
 FOR /F "USEBACKQ EOL=; TOKENS=*" %%J IN ("%@TESTJOBS%") DO (
	 SET @THISJOB=%%~J
	 SET @THISJOB=!@THISJOB:  = !
	 FOR /F "TOKENS=*" %%S IN ('SUBSTRING "!@THISJOB!" * ""') DO SET @SUBSTITUTE=%%~S
	 ECHO  - Checking for ... !@THISJOB!

	 rem -- Determine Whether or Not to Perform Drive Substitutions
	 IF "!@THISJOB!"=="!@SUBSTITUTE!" (SET @LIST=:) ELSE (SET @LIST=%@ALPHA11%)

	 FOR %%L IN (!@LIST!) DO (
		 FOR /F "TOKENS=*" %%S IN ('SUBSTRING "!@THISJOB!" * %%~L') DO (
			 SET @SUBSTITUTE=%%S

			 FOR /F "TOKENS=*" %%V IN ('SCHTASKS /DELETE /TN "!@TASKFOLDER!!@SUBSTITUTE!" %@FORCE% 2^>NUL') DO (
				 SET @DELETED=!@DELETED! "!@TASKFOLDER!!@SUBSTITUTE!"
				 SET /A @COUNT+=1
			 )
		 )
	 )
 )


 rem -- Produce Final Report
:FinalReport
 SCHTASKS
 ECHO:
 ECHO:
 ECHO *** Deleted Temp Jobs: %@COUNT% ***
 ECHO %@MINORDIV%
 IF DEFINED @DELETED (
	 FOR %%J IN (%@DELETED%) DO ECHO  -- %%~J
 ) ELSE (
	 ECHO  No Scheduled Tasks Deleted.
 )
 ECHO %@MINORDIV%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Delete All Test/Temporary Scheduled Jobs
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H  .... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 /?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
                                      