@ECHO OFF
 rem ==========================================================================
 rem === Disable a Service on Remote Systems
 rem ==========================================================================
 rem
 rem Created On: 28 Feb 1998
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 27 Mar 2011  (Prior Update: 14 Nov 2010)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: NT4 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem
 rem  Other Scripts Called:
 rem    SetDrive.BAT ........... Primary Script for Setting Common Variables
 rem ==========================================================================

 :::  This script uses SC from the ResKit to set the startup parameters of a
 :::  service (supplied at the command line) to Disabled, and also stops it if
 :::  it's running. You must use the shortname of the service (use SCLIST to
 :::  determine the shortname of any installed service).
 :::
 :::  If no list of systems is provided at the command line, then a list will
 :::  be created of all of the machines in the domain (as determined via the
 :::  NET VIEW command).
 :::
 :::  (Nov 2010) Changed the default log extension of the reports from .LOG to
 :::  .TXT so that the reports that are mailed to mobile devices can be read
 :::  automatically. (Not too many devices know what to do with the .LOG files)
 :::
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On: 23 Mar 2011  (Prior Update: 14 Nov 2010)
 rem ==========================================================================
:Variables
 SETLOCAL & CALL :ShowStatus "STARTED" v1.7.0b

 rem -- Display Syntax Help if Required/Requested
 IF "%~1"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage

 rem -- Call Centralized Script for Setting Global Log and Date/Time Variables
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" (
	 CALL "%~dp0SetDrive.BAT"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %~dp0SetDrive.BAT
	 ECHO:
	 DIR "%~dp0SetDrive.BAT"
	 ECHO:
	 GOTO :EOF
 )

 rem -- Standard Variables
 SET @SERVICE=%1
 SET @COMPLIST=%~2& IF /I "%~2"=="" SET @COMPLIST='NET VIEW'
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Cycle Through Domain (or File List) And Disable Service
 rem === Last Modified On: 05 Dec 2003
 rem ==========================================================================
:GetComputers
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 NOW Disabling The "%@SERVICE%" Service >"%@LOGFILE%"
 ECHO Getting a List of Computers via "%@COMPLIST%"...
 ECHO:
 FOR /F %%V IN (%@COMPLIST%) DO CALL :Disable %%V
 ECHO Finished Disabling The "%@SERVICE%" Service...
 ECHO:


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On: 23 Mar 2011  (Prior Update: 04 Dec 2003)
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Disable Designated Service and Stop It
 rem === Last Modified On: 05 Sep 2001
 rem ==========================================================================
:Disable
 rem %1 = Current System To Be Updated
 SET @SYS=%1
 IF /I NOT "%@SYS:~0,2%"=="\\" GOTO :EOF
 ECHO Disabling the "%@SERVICE%" service on "%1" >>"%@LOGFILE%"
 ECHO Disabling the "%@SERVICE%" service on "%1"
 SC %1 QC %@SERVICE%                     >NUL
 SC %1 CONFIG %@SERVICE% START= disabled >NUL
 SC %1 STOP %@SERVICE%                   >NUL
 SC %1 QC %@SERVICE%                     >NUL
 SC %1 QC %@SERVICE% >>"%@LOGFILE%"
 ECHO ************** >>"%@LOGFILE%"
 ECHO:               >>"%@LOGFILE%"
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Last Modified On: 03 Apr 2011  (Prior Update: 23 Mar 2011)
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" SET @VER=%~nx0 %~2
 IF /I "%~2"=="FINISHED" "%@END_DEBUG_MODE%"
 ECHO:
 ECHO *** %@SCRIPTSTATUS%: %@VER% [%DATE% at %TIME%] ***
 ECHO:
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Last Modified On: 28 Mar 2011  (Prior Update: 09 Mar 2006)
 rem ==========================================================================
:HelpMessage
 ECHO Disable a Service on Remote Systems
 ECHO:
 ECHO:
 ECHO   YOU TYPED: %0 %*
 ECHO:
 ECHO  CMD SYNTAX: %~n0  ^<service^> [list_of_servers.txt]
 ECHO:
 ECHO  EXAMPLE(S): %~n0 Browser
 ECHO              %~n0 LicenseService C:\TEMP\SERVERS.TXT
 ECHO              %~n0 LicenseService "%~dp0Input\ServerList.TXT"
 ECHO              %~n0 Schedule "'NET VIEW /DOMAIN:my_domain'"
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: If the name of the List of Servers contains spaces, it should be
 ECHO       surrounded by quotation marks as in the examples above.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
