@REM - ASB (04 Jan 2021 // 16 Oct 2023 / 22 Jan 2022 / 08 Jan 2021 / 05 Jan 2021 / 04 Jan 2021): Get Disk I/O Metrics for Multiple Hard Drives
@ECHO OFF


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.5.0.090

 rem -- Main Variables
 SET @DISK1=%SystemDrive%\Temp\TestFile1.dat
 SET @DISK2=& FOR /F "DELIMS= " %%D IN ('WMIC LogicalDisk GET DeviceID^,DriveType 2^>NUL ^| FIND "3"') DO IF NOT DEFINED @DISK2 (
	 SET @TMP=%%~D\Temp
	 IF NOT EXIST "!@TMP!" MD "!@TMP!" >NUL 2>NUL
	 IF /I NOT "%%~D"=="%SystemDrive%" IF EXIST "!@TMP!" SET @DISK2=!@TMP!\TestFile2.dat
 )
 SET @AND=& IF DEFINED @DISK2 (SET @AND= and & SET @DRV2=%@DISK2:~0,2%)
 SET @IO_OPTIONS=-c1G -b4K -t2 -d30 -w30 -si %@DISK1% %@DISK2%
 SET @WINSAT=& FOR /F %%V IN ('WHERE WINSAT 2^>NUL') DO SET @WINSAT=TRUE


 rem -- Evaluate Disk I/O using DiskSpd and WinSat
:GetDiskIO
 NOW \z EVALUATING DISK PERFORMANCE ON %SystemDrive% %@AND% %@DRV2%
 DiskSpd %@IO_OPTIONS%

 IF DEFINED WINSAT (
	 NOW \n\n\v - EVALUATING SYSTEM PERFORMANCE\n\-
	 FOR %%C IN (FEATURES MEM DISK) DO (WinSat %%C& ECHO:)
	 IF DEFINED @DISK2 WinSat DISK -drive %@DRV2%
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                