@REM - ASB (07 Sep 2001 // 12 Jan 2024 / 16 Oct 2023 / 07 Jun 2023 / 23 Mar 2022 / 17 Mar 2022 / 16 Feb 2022 / 30 Nov 2020 / 29 Sep 2020 / 05 May 2020 / 29 Apr 2020 / 24 Dec 2019 / 13 Nov 2019): Execute One Command Against Selected Systems
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %1 %2 %3 %4
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=
 SET @CRLF=@CRLF-FINISHED
 SET %@CRLF%=\#\n\n


 rem -- Enable Debug Mode If 'Debug' Variable is Set to TRUE/LOG/STEP/VERBOSE
:DebugMode
 SET #DEBUG=& FOR %%d IN (LOG STEP TRUE VERBOSE) DO IF /I "%Debug%"=="%%~d" SET #DEBUG=TRUE
 IF DEFINED #DEBUG (
	 SET @DIAGMODE=TRUE
	 SET @DEBUG_MODE=[DEBUG MODE ON]
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:^& TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 IF /I "%Debug%"=="LOG" (SET @PAUSE_IF_DEBUG=& SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:)
	 IF /I "%Debug%"=="STEP" (SET @PAUSE_IF_DEBUG=ECHO ##PAUSE##& SET @PRINT_IF_DEBUG=ECHO ##PRINT##)
	 IF /I "%Debug%"=="VERBOSE" (SET @VERBOSE_OFF=ECHO ON) ELSE (FOR %%t IN (ON OFF) DO SET @VERBOSE_%%t=ECHO %%t)
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE ( FOR %%d IN (DEBUG_MODE PAUSE_IF_DEBUG PRINT_IF_DEBUG END_DEBUG_MODE VERBOSE_ON VERBOSE_OFF) DO SET @%%d=)


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v6.3.0.1230

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H- HELP- ?-" -x "??- H2-" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Check for Essential Utilities and/or Scripts
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f "NOW.EXE" "DATEINFO.EXE" "CHECKPARAMS.EXE" "ADFIND.EXE"
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Standard Log Variables
 SET @LOGROOT=%TEMP%\%~n0.%@DIRSTAMP_R%
 SET @DYNAMIC=%@LOGROOT%\SourceList.TXT

 rem -- Main Variables
 SET @TOTAL=0
 SET @COUNT=0
 SET @GROUP=Custom List
 SET @INPUT=%~d0\Scripts\BAT\Input

 rem -- AD Search Variables (using ADFind)
 SET @xPARAMS=-nodn -s SUB -maxe 2000 -list attr name -excldn "OBSOLETE;RETIRED;DECOMMISSIONED"
 SET @ADQUERY_C=ADFind -f "(&(objectcategory=computer)(operatingSystem=Windows*))" %@xPARAMS%
 SET @ADQUERY_D=ADFind -f "(&(objectCategory=computer)(|(primaryGroupId=516)(primaryGroupId=521)))" %@xPARAMS%
 SET @ADQUERY_N=ADFind -f "(&(objectcategory=computer)(operatingSystem=Windows*)($$$(primaryGroupID=516)))" %@xPARAMS%
 SET @ADQUERY_S=ADFind -f "(&(objectcategory=computer)(|(operatingSystem=Windows*Server*)(operatingSystem=Windows*Storage*)))" %@xPARAMS%
 SET @ADQUERY_O=ADFind -f "(&(objectcategory=computer)(|(operatingSystem=Windows*Server*)(operatingSystem=Windows*Storage*))($$$(primaryGroupID=516)))" %@xPARAMS%
 SET @ADQUERY_W=ADFind -f "(&(&(objectcategory=computer)(operatingSystem=Windows*))($$$(|(operatingSystem=Windows*Server*)(operatingSystem=Windows*Storage*))))" %@xPARAMS%

 rem -- Determine Which Console Session is Active for the Script
 SET @SERVICE_ACCTS="SYSTEM" "NTAUTHORITY" "Services"
 SET @CONSOLE_SESSION=TRUE& FOR %%u IN (%@SERVICE_ACCTS%) DO IF /I "%USERNAME%"=="%%~u" SET @CONSOLE_SESSION=FALSE
 IF DEFINED @NOPROMPT SET @CONSOLE_SESSION=FALSE

 rem -- Isolate the command string that is to be executed
 FOR /F "TOKENS=1*" %%C IN ('ECHO "%*"') DO SET @CMD=%%D& SET @CMD=!@CMD:~0,-1!
 CALL :ReplaceTokens @CMD @EXECUTE

 rem -- Determine Which Source File to Use for Input
 IF NOT EXIST "%@LOGROOT%" MD "%@LOGROOT%"
 SET @SOURCE=*%~1*
	 IF "%~1"=="***" SET @SOURCE=%@DYNAMIC%& SET @GROUP=All Systems via NET VIEW& NET VIEW | FIND "\\" >"%@DYNAMIC%"
	 IF "%~1"=="**"  SET @SOURCE=%@DYNAMIC%& SET @GROUP=All Systems via ADFIND&   %@ADQUERY_C:$$$=^!%  >"%@DYNAMIC%"
	 IF "%~1"=="*"   SET @SOURCE=%@DYNAMIC%& SET @GROUP=All Systems [Minus DCs]&  %@ADQUERY_N:$$$=^!%  >"%@DYNAMIC%"
	 IF "%~1"=="+"   SET @SOURCE=%@DYNAMIC%& SET @GROUP=All NON-Server Systems&   %@ADQUERY_W:$$$=^!%  >"%@DYNAMIC%"
	 IF "%~1"=="$"   SET @SOURCE=%@DYNAMIC%& SET @GROUP=All Servers [with DCs]&   %@ADQUERY_S:$$$=^!%  >"%@DYNAMIC%"
	 IF "%~1"=="#"   SET @SOURCE=%@DYNAMIC%& SET @GROUP=All Servers [Minus DCs]&  %@ADQUERY_O:$$$=^!%  >"%@DYNAMIC%"
	 IF "%~1"=="@"   SET @SOURCE=%@DYNAMIC%& SET @GROUP=Domain Controllers Only&  %@ADQUERY_D:$$$=^!%  >"%@DYNAMIC%"
	 IF "%~1"=="."   SET @SOURCE=%@INPUT%\ServerList
	 SET @FINDLIST="%@SOURCE%" "%~1" "%~1*" "%~dp0%@SOURCE%" "%~dp0Input\%@SOURCE%" "%@INPUT%\%@SOURCE%" "%@INPUT%\ServerList"
	 FOR %%F IN (%@FINDLIST%) DO FOR %%E IN ("" ".%COMPUTERNAME%.TXT" ".TXT") DO IF EXIST "%%~F%%~E" IF NOT DEFINED #ASKED_%%~F%%~E (
		 SET @SOURCE=%%~F%%~E
		 SET #ASKED_%%~F%%~E=TRUE
		 IF /I "!@SOURCE:~-4!"==".TXT" (
			 IF /I "%@CONSOLE_SESSION%"=="TRUE" (
				 CHOICE /C YNQEX /T 10 /D Y /N /M "Use the following system list? - '!@SOURCE!' "
			 ) ELSE (
				 CHOICE /C Y /T 0 /D Y /N
			 )
		 )
		 IF ERRORLEVEL 3 GOTO :ExitBatch
		 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 2 (
			 FOR /F %%S IN ('TYPE "!@SOURCE!"') DO (
				 SET /A @TOTAL+=1
				 SET @SYS=%%~S
				 IF "!@SYS!"=="!@SYS:;=!" (
					 CALL :MakeHostList %%~S
					 SET /A @COUNT+=1
				 )
			 )
			 GOTO :ProcessJob
		 )
	 )


 rem -- Abort script if no system list has been provided/accepted
:AbortExecution
 ECHO:
 ECHO ERROR: No Valid System List Was Provided -- Script Execution Aborted...
 ECHO:
 GOTO :HelpMessage


 rem -- Execute a Command Against Selected Systems
:ProcessJob
 ECHO Preparing to Execute a Command Job Against Selected Systems...
 ECHO %@DIVIDER-%
 ECHO  List of Systems .......: "!@SOURCE:%TEMP%=%%TEMP%%!"
 ECHO  Type of Systems .......: %@GROUP%
 ECHO  Target System Count ...: %@COUNT% of %@TOTAL%
 ECHO  Target System Names ...:%@HOSTLIST%
 ECHO  Command to Execute ....: %@EXECUTE%
 ECHO %@DIVIDER-%
 ECHO:
 IF /I "%@CONSOLE_SESSION%"=="TRUE" (
	 CHOICE /C YNQEX /T 20 /D Y /N /M "Continue running this script? (Y/N/Q) "
	 IF ERRORLEVEL 2 GOTO :ExitBatch
 )

 rem -- Loop Through Systems
 FOR %%V IN (%@HOSTLIST%) DO CALL :ExecuteCMD %%~V


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 SET %@CRLF%=
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 SET %@CRLF%=
 GOTO :EOF


 rem -- SUBROUTINE: Generate Concatenated List of UNC or non-UNC Hosts
:MakeHostList
 rem %1 = System to Execute the Command on

 SET @UNAME=%~1
 SET @HNAME=%@UNAME:\=%
 SET @UNAME=\\%@HNAME%

 IF /I "%@UNC%"=="TRUE" (SET @CNAME=!@UNAME!) ELSE (SET @CNAME=!@HNAME!)
 SET @HOSTLIST=!@HOSTLIST! !@CNAME!
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Expand Command with Token Substitutions, including $$ for each UNC Name and ## for Host Name
:ExecuteCMD
 rem %1 = System to Execute the Command on

 SET @UNAME=%~1
 SET @HNAME=%@UNAME:\=%
 SET @UNAME=\\%@HNAME%
 SET @CURRENTCMD=!@CMD:$$=%@UNAME%!
 SET @CURRENTCMD=!@CURRENTCMD:##=%@HNAME%!
 CALL :ReplaceTokens @CURRENTCMD @EXECUTE

 IF DEFINED @SANITIZED (SET @MSG= Some commands on %@UNAME%) ELSE (SET @MSG=%@EXECUTE%)
 ECHO [!TIME:~0,8!]:!@MSG!
 ECHO %@DIVIDER-%
 CMD /C %@EXECUTE%
 ECHO:
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Make Token Substitutions, Except ## and $$
:ReplaceTokens
 rem %1 = Source Variable
 rem %2 = Destination Variable

 SET @ZZ=!%~1!
 SET @ZZ=!@ZZ:[[=^(!
 SET @ZZ=!@ZZ:]]=^)!
 SET @ZZ=!@ZZ:``=^^^&!
 SET @ZZ=!@ZZ://=^^^|!
 SET @ZZ=!@ZZ:__= !
 SET @ZZ=!@ZZ:''="!
 SET @ZZ=!@ZZ:""=''!
 SET @ZZ=!@ZZ:++=//!
 SET %~2=!@ZZ!
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Execute a Command Against Selected Systems
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<OPTION ^| list_of_systems^> ^<command with token substitution^>
 ECHO  %~n0  [-h-^|-?-^|--help-^|-??-^|-h2-]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO   -?-, /H- ... Display This Help Message  (also --HELP-)
 ECHO  -??-, /H2- .. Display Extended Help Message
 ECHO      .  ...... Use the default systems list  **DEFAULT**
 ECHO      @  ...... Generate a dynamic list of ALL domain controllers using the ADFIND command
 ECHO      #  ...... Generate a dynamic list of domain servers (minus DCs) using the ADFIND command
 ECHO      $  ...... Generate a dynamic list of ALL domain servers using the ADFIND command
 ECHO      +  ...... Generate a dynamic list of domain computers (minus ALL servers) using the ADFIND command
 ECHO      *  ...... Generate a dynamic list of domain computers (minus DCs) using the ADFIND command
 ECHO     **  ...... Generate a dynamic list of ALL domain computers (everything) using the ADFIND command
 ECHO    ***  ...... Generate a dynamic list of domain/workgroup computers using the NET VIEW command
 ECHO:
 ECHO    The following token substitutions are available within valid commands:
 ECHO:
 ECHO        $$ .... Represents the current "\\servername" from the list (without quotes)
 ECHO        ## .... Represents the current "servername" from the list (without quotes)
 ECHO        [[ .... Represents a  "("  character
 ECHO        ]] .... Represents a  ")"  character
 ECHO        `` .... Represents a  "&"  character
 ECHO        // .... Represents a  "|"  character
 ECHO        __ .... Represents a  " "  character  (regular space)
 ECHO        '' .... Represents a   "   character  (one double quote)
 ECHO        "" .... Represents two ''  characters (two single quotes)
 ECHO        ++ .... Represents two "/" characters (two forward slashes)
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 . DIR $$\Admin$
	 ECHO  %~n0 $ PING ##
	 ECHO  %~n0 @ ECHO   ## `` ECHO $$
	 ECHO  %~n0 . ECHO   $$ // FIND "0" /C
	 ECHO  %~n0 $ for %v in [[1 2 3]] do @ECHO $$ - %v
	 ECHO  %~n0 * XCOPY %SystemDrive%\Folder $$\Share$\Stuff
	 ECHO  %~n0 ** CALL E:\Scripts\MyScript.BAT Some_Parameter
	 ECHO  %~n0 MyList NET TIME $$
	 ECHO  %~n0 E:\ThisList.TXT DCDIAG /s:##
	 ECHO  %~n0 %~dp0Input\ServerList.TXT DEL "$$\D$\Old File.DAT" /S
	 ECHO  %~n0 -?-
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Long filenames which contain spaces must be surrounded by quotes.
	 ECHO:
	 ECHO  * The filename of the list used for processing must be a short name.
	 ECHO:
	 ECHO  * This script uses -?-, -H-, and --HELP- as help syntax parameters to
	 ECHO    avoid conflicting with the normal -?, -H, and --HELP parameters that
	 ECHO    could be used by commands it is trying to process.
	 ECHO:
	 ECHO  * Please be sure to add the "CALL" command as a prefix to your desired
	 ECHO    string of commands if using %~nx0 to process batch files.
	 ECHO:
	 ECHO  * The NET VIEW option [***] rarely works on modern Windows networks.
	 ECHO    Please use the other options instead.
	 ECHO:
	 ECHO  * Using the \\ and `` substitition parameters ^(among others^) with
	 ECHO    this command can be tricky. Be sure to test diligently...
	 ECHO:
	 ECHO  * Alternate ServerList files can be specified using their full path.
	 ECHO    For files which reside in the default INPUT folder, you can use the
	 ECHO    filename or filename.ext only.  ^(The default INPUT folder is typically
	 ECHO    %SystemDrive%\Scripts\Bat\Input^)
 )
 CALL :ShowStatus "FINISHED"
                                                            