@REM - ASB (18 Dec 2006 // 12 Jan 2024 / 16 Oct 2023 / 11 Feb 2022 / 18 Jan 2022 / 15 Jul 2021 / 29 Mar 2021 / 08 Mar 2021 / 05 Mar 2021 / 30 Nov 2020 / 26 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 28 Oct 2018 / 26 Jul 2018 / 30 Apr 2018 / 26 May 2016): DCDiag, DFSDiag, ReplAdmin and GPOTool Across All Domain Co
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.3.0.630

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO DCDiag, DFSDiag, ReplAdmin and GPOTool Across All Domain Controllers
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [NetBIOS domain name] [.]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  CMD OPTIONS:
	 ECHO    .  ....... Extended DCDIAG diagnostics
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Check for Essential Utilities and/or Scripts
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f "NOW.EXE" "DATEINFO.EXE" "CHECKPARAMS.EXE" "DCDIAG.EXE" "NETDOM.EXE" "REPADMIN.EXE" "DFSDIAG.EXE" "DFSRDIAG.EXE" "GPOTOOL.EXE"
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @NETBIOS=%@NETBIOS_DOMAIN%& IF "!@NETBIOS!"=="" SET @NETBIOS=%USERDOMAIN%
 SET @DOMAIN=%~1& IF "%~1"=="" SET @DOMAIN=%@NETBIOS%
 SET @LOGFILE=%@STORAGE%\Logs\Maint\%~n0-%@DOMAIN%.%@TODAY%-%@NOW%.TXT
 SET @SERVERS=
 SET @EXCLUDE=The command completed successfully.

 IF DEFINED LOGONSERVER (SET @LOGONSERVER=%LOGONSERVER:\=%) ELSE (SET @LOGONSERVER=%COMPUTERNAME%)
 IF "%~2"=="." (
	 SET @DURATION=30
	 SET @DCDIAG=/C /E /V /FIX
 ) ELSE (
	 SET @DURATION=10
	 SET @DCDIAG=/C /FIX
 )


:LogHeader
 ECHO Get Domain Diagnostics for %@DOMAIN% from %COMPUTERNAME%
 ECHO:
 FOR /F "SKIP=1" %%C IN ('NETDOM QUERY /DOMAIN:%@DOMAIN% DC 2^>NUL ^| FIND /V "%@EXCLUDE%"') DO SET @SERVERS=!@SERVERS! %%C
 ECHO  -- SERVER LIST: %@SERVERS%
 ECHO:
 ECHO     Please Wait... [up to %@DURATION% minutes per server]
 ECHO:

 ( rem -- Write to Log
	 ECHO %@DIVIDER*%
	 ECHO  Get Domain Diagnostics for %@DOMAIN% from %COMPUTERNAME% [by %@VER%]
	 ECHO %@DIVIDER*%
	 ECHO:
	 ECHO  -- SERVER LIST: %@SERVERS%
	 ECHO:
	 CALL "%~dp0DNSCheck.BAT"
 ) >>"%@LOGFILE%" 2>&1


:ReplicationInfo
 ECHO  !TIME! on !DATE! -- Get Replication Info for %@DOMAIN%
 ECHO:
 ( rem -- Write to Log
	 NETDOM QUERY /DOMAIN:%@DOMAIN% DC
	 NETDOM QUERY /DOMAIN:%@DOMAIN% FSMO
	 REPADMIN /REPLSUMMARY * /bysrc /bydest /sort:delta
	 REPADMIN /KCC
	 REPADMIN /SHOWREPL * /ALL
	 DFSDIAG /testdcs
	 GPOTOOL
 ) >>"%@LOGFILE%" 2>&1


:GetDiagnostics
 FOR %%C IN (%@SERVERS%) DO (
	 IF NOT "%%~C"=="The" (
		 ECHO  !TIME! on !DATE! -- Performing Diagnostics for %%C...

		 ( rem -- Write to Log
			 FOR %%L IN (1 2 3) DO ECHO:
			 NOW Performing Diagnostics for %%C...
			 ECHO %@DIVIDER-%
		 ) >>"%@LOGFILE%"

		 DCDIAG /S:%%C /F:"%@LOGFILE%" %@DCDIAG%
		 DFSRDIAG backlog /rgname:"Domain System Volume" /rfname:"Sysvol Share" /smem:%@LOGONSERVER% /rmem:%%C /v  >>"%@LOGFILE%" 2>&1
	 )
 )
 CALL "%~dp0DNSCheck.BAT" >>"%@LOGFILE%" 2>&1


:LogFooter
 ECHO:
 ECHO Completed Domain Diagnostics for %@DOMAIN% from %COMPUTERNAME%
 ECHO:

 ( rem -- Write to Log
	 ECHO:
	 ECHO %@DIVIDER*%
	 ECHO  Completed Domain Diagnostics for %@DOMAIN% from %COMPUTERNAME% [!TIME! on !DATE!]
	 ECHO %@DIVIDER*%
 ) >>"%@LOGFILE%"


:FinalReport
 DIR "%@LOGFILE%" & START "Domain Diagnostics" "%@LOGFILE%"


:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Execute Dynamic Command From Variable
:RunCMD
 rem %1 = Command To Execute

 %*
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
               