@ECHO OFF
 rem ==========================================================================
 rem === Duplicate From One Group To Another (NT4 Version)
 rem ==========================================================================
 rem
 rem Created On: 28 May 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 05 Dec 2003
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: NT4 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.ultratech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This script will duplicate the permissions granted to an
 :::  account or group in a folder (and subfolders) and grant
 :::  them to a different account or group within the same set
 :::  of folders.  This script will only handle READ, CHANGE,
 :::  FULL and NOACCESS ACLs, but it could be modified to work
 :::  with others.
 :::
 :::  If the name of the user account or group that you are
 :::  providing contains spaces, you should substitute the '+'
 :::  character. It will be converted to a space in the script.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 06 Sep 2001
 rem ==========================================================================
:NeedHelp
 IF "%~3"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 05 Dec 2003
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Calculate Date/Time (Short Procedure - ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=4-6 DELIMS=: " %%T IN ('NOW') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG

 rem -- Standard Variables
 SET @SACCT=%1
 SET @DACCT=%2
 SET @FOLDER=%3
 SET @SACCT=%@SACCT:+= %
 SET @DACCT=%@DACCT:+= %
 SET @FOLDER=%@FOLDER:+= %
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Recurse Through Subfolders And Duplicate Permissions
 rem === Last Modified On 05 Sep 2001
 rem ==========================================================================
:SetFolders
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 NOW Copying ACLs For "%@FOLDER%" From "%@SACCT%" To "%@DACCT%"... >"%@LOGFILE%"
 ECHO:                                                            >>"%@LOGFILE%"
 ECHO:
 ECHO Copying ACLs For "%@FOLDER%" From "%@SACCT%" To "%@DACCT%"...
 ECHO:
 FOR /F "TOKENS=*" %%D IN ('DIR /B /AD /S "%@FOLDER%"') DO CALL :GetPerms %%D
 CALL :GetPerms %@FOLDER%


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 04 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Recurse Through Subfolders For ACLs
 rem === Last Modified On 31 May 2001
 rem ==========================================================================
:GetPerms
 rem %* = Complete Folder Name
 SET @DIR=%*
 SET @DIR=%@DIR:~1,99%
 ECHO:
 ECHO Obtaining ACLs From "%@DIR%"...
 ECHO Obtaining ACLs From "%@DIR%"... >>"%@LOGFILE%"
 FOR /F "TOKENS=2 DELIMS=[]" %%A IN ('SHOWACLS %@DIR% ^| FIND /I "%@SACCT%"') DO CALL :CopyPerms %%A
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Copy Permissions From Source To Dest Account
 rem === Last Modified On 30 May 2001
 rem ==========================================================================
:CopyPerms
 rem %1 = Current Permissions On File
 SET @ACL=%1
 SET @PERMS=
 IF /I "%@ACL%"=="ALL" SET @PERMS=/P "%@DACCT%":F
 IF /I "%@ACL%"=="RWXD" SET @PERMS=/P "%@DACCT%":C
 IF /I "%@ACL%"=="RX" SET @PERMS=/P "%@DACCT%":R
 IF /I "%@ACL%"=="NONE" SET @PERMS=/D "%@DACCT%"
 IF /I "%@ACL%"=="DdrwarEwEfx" SET @PERMS=/D "%@DACCT%"

 ECHO Modifying ACLS For "%@DACCT%"...
 ECHO Modifying ACLS For "%@DACCT%"... >>"%@LOGFILE%"
 ECHO:                                 >>"%@LOGFILE%"
 XCACLS "%@DIR%" /E %@PERMS%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 23 Aug 2001
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for DUPPERMS.BAT
 ECHO:
 ECHO === DupPerms {source_account} {destination_account} {initial_folder}
 ECHO:
 ECHO Example: DupPerms MYDOMAIN\USER1 MYDOMAIN\GROUP2 C:\STORAGE
 ECHO          DupPerms MACHINE\GROUP4 MACHINE\USER2 D:\ARCHIVES
 ECHO          DupPerms MACHINE\Long+Group MACHINE\Group+With+Space D:\OLD+ARCHIVES
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Spaces in the Account, Group, or Folder Names
 ECHO       should be represented by a '+' symbol.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
