@REM - ASB (16 Mar 2006 // 16 Oct 2023 / 26 May 2021 / 09 Mar 2021 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 29 Apr 2018 / 13 Nov 2017 / 25 Mar 2015): Enable RemoteDesktop on a Remote Windows System
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.7.0.170

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Enable RemoteDesktop on a Remote Windows System
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [name_of_system]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Verify Remote System Provided
 IF "%~1"=="" (
	 ECHO *** Enter a System to run this script against ***
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @SVC_CTRL=%2
 SET @RD_KEY=HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Terminal Server
 SET @RD_DATA=fDenyTSConnections
 SET @RDSERVICE=TermService
 SET @RDSERVICE2="Remote Desktop Services UserMode Port Redirector"
 SET @PSSERVICE=PSSERVICE %@PSPARAMS% \\%~1
 SET @DELAY=SLEEP 5


 rem -- Enable Remote Desktop for Administrators
:ConfigureRemote Desktop
 ECHO Enabling Remote Desktop Functionality on %~1
 REG QUERY "\\%~1\%@RD_KEY%" /v "%@RD_DATA%"
 REG ADD   "\\%~1\%@RD_KEY%" /v "%@RD_DATA%" /t REG_DWORD /d 0 /f
 REG QUERY "\\%~1\%@RD_KEY%" /v "%@RD_DATA%"
 CALL CONNECT %~1 @@T NETSH advfirewall firewall add rule name=''allow RemoteDesktop'' dir=in protocol=TCP localport=3389 action=allow

 IF DEFINED @SVC_CTRL (
	 %@PSSERVICE% stop    %@RDSERVICE2% & %@DELAY%
	 %@PSSERVICE% restart %@RDSERVICE%  & %@DELAY%
	 %@PSSERVICE% start   %@RDSERVICE%  & %@DELAY%
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                        