@ECHO OFF
 CLS
 rem ==========================================================================
 rem === Get Memory Usage Info for a Group of Exchange Servers
 rem ==========================================================================
 rem
 rem Created On: 10 Feb 2006
 rem         By: Juan Moreno
 rem
 rem Updated On: 31 May 2009  (Prior Update: 13 Jan 2007)
 rem         By: Juan Moreno / Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2000 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Blat ................... http://www.blat.net/
 rem  	PSTOOLS ................ http://www.microsoft.com/technet/sysinternals/utilities/PsTools.mspx
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem
 rem  Input Files Used By Script (stored in \Scripts\Bat\Input folder):
 rem    CustomVariables.TXT .... Configure SMTP Mail Settings, Including Alert Recipients
 rem ==========================================================================

 :::  This script uses various utilites from the Windows Resource kit as well
 :::  as the SysInternals site to capture serveral key statistics from a list
 :::  of Exchange Servers.  In particular, the size of the STORE.EXE process,
 :::  along with total RAM, the OS version, current uptime, and the service
 :::  account for the Exchange services are all captured and emailed to a
 :::  group of administrators.
 :::
 :::  This script is a little sibling of the Operations Log script: OpsLogs.BAT
 :::
 :::  This script can be set to obtain its SMTP configuration options via
 :::  the \Scripts\Bat\Input\CustomVariables.TXT file.  Or, if you choose, you
 :::  can modify the script directly to set the mail-related variables.  This
 :::  will reduce the number of files needed to operate the script, but the
 :::  CustomVariables.TXT approach makes it easier to manage custom configs.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to "TRUE"
 rem === Last Modified On: 10 Feb 2006
 rem ==========================================================================
:DebugMode
 IF /I "%Debug%"=="TRUE" (
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE (
	 SET @PAUSE_IF_DEBUG=
	 SET @END_DEBUG_MODE=
 )


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On: 31 May 2009  (Prior Update: 13 Jan 2007)
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION
 SET @VER=%~nx0 v1.6.0

 rem -- Calculate Date/Time (Short Procedure - ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=4-6 DELIMS=: " %%T IN ('NOW') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG
 SET @TIMESTAMP=%DATE% at %TIME%

 rem -- Get Official Drive Letters and Calculate Date/Time for NON-US Regions
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Custom Variables -- Grab from CustomVariables.TXT -OR- Set Manually
 IF EXIST "%@CUSTOM-VARS%" (
	 FOR /F "USEBACKQ TOKENS=1-2* DELIMS=,; " %%M IN ("%@CUSTOM-VARS%") DO IF /I "%%~M"=="%~n0" CALL :RunCMD SET %%N=%%O
 ) ELSE (
	 SET @MAIL=FALSE
	 SET @MAILSERVER=smtp.mydomain.com
	 SET @MAILSENDER=LogAdmin@MyDomain.com
	 SET @RECIPIENTS=-to EmailAdmins@MyDomain.com
	 SET @SUBJECT=Exchange Server Report [Memory Usage and Uptime]
 )

 rem -- Standard LogFile Variables
 SET @SOURCE=%@EXCHANGELIST%
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem -- Determine If The Test List Should Be Used
:TestList
 FOR %%L IN (. T TEST /T /TEST) DO IF /I "%~1"=="%%L" (
	 SET @RECIPIENTS=%@TEST-RCPTS%
	 SET @SUBJECT=**TEST** %@SUBJECT%
	 SET @SOURCE=%@EXCHANGETEST%

	 ECHO Generating Report From Small Exchange List...
	 ECHO:
	 ECHO:
 )


 rem ==========================================================================
 rem === Cycle Through List and Capture Exchange Stats
 rem === Last Modified On: 28 Feb 2006
 rem ==========================================================================
:GetStats
 CALL :GetTime @STIME
 ECHO **********************************************************************
 ECHO *** EXCHANGE SERVER MEMORY USAGE REPORT - %@VER%
 ECHO **********************************************************************
 ECHO:

 FOR /F %%V IN (%@SOURCE%) DO (
	 NOW Getting Exchange Stats for %%V... >CON
	 NOW Getting Exchange Stats for %%V...

	 rem -- Capture Server-Specific Variables
	 SET @USAGE=
	 FOR /F "TOKENS=3*" %%O IN ('SRVINFO %%V ^| FIND /I "Product Name"') DO SET @OS=%%P
	 FOR /F "TOKENS=2 DELIMS= " %%S IN ('PSSERVICE %%V CONFIG MSExchangeIS ^| FIND /I "START_NAME"') DO SET @SVC=%%S
	 FOR /F "TOKENS=5*" %%Q IN ('UPTIME %%V ^| FIND "\"') DO SET @UPTIME=%%R
	 FOR /F "TOKENS=4" %%T IN ('SRVMEM %%V') DO SET @TOTAL=%%T
	 FOR /F "TOKENS=5" %%M IN ('TASKLIST /S %%V /fi "IMAGENAME eq STORE.EXE" /V ^| FIND /I "STORE"') DO SET @USAGE=%%M
	 IF /I "!@USAGE!"=="" FOR /F "TOKENS=4" %%M IN ('PSLIST %%V STORE -M ^| FIND /I "STORE"') DO SET @USAGE=%%M

	 rem -- Generate Memory Usage Output
	 ECHO ------------------------------------------------------------------------------
	 ECHO %%V [!@SVC!] is running !@OS!
	 ECHO:
	 ECHO Current Uptime: !@UPTIME!
	 ECHO:
	 ECHO STORE.EXE is using !@USAGE! KB of !@TOTAL! KB
	 ECHO ==============================================================================
	 ECHO:
	 ECHO:
 ) >>"%@LOGFILE%" 2>NUL


 rem ==========================================================================
 rem === Generate Summary Log Info
 rem === Last Modified On: 10 Mar 2006
 rem ==========================================================================
:MakeSummary
 CALL :GetTime @ETIME

 ( rem -- Consolidate LogFile Output
	 ECHO:
	 ECHO ------------------------------------------------------------------------------
	 ECHO  ServerList: "%@SOURCE:~-65%"
	 ECHO ------------------------------------------------------------------------------
	 ECHO  Started At ................................... %@STIME%
	 ECHO  Ended At ..................................... %@ETIME%
	 ECHO:
	 ECHO:
 ) >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Mail Log File To Messaging Support Team
 rem === Last Modified On: 10 Feb 2006
 rem ==========================================================================
:MailLogs
 ECHO:
 ECHO Please Wait: Mailing Logs To %@RECIPIENTS%
 ECHO:
 BLAT -install %@MAILSERVER% %@MAILSENDER% 5 25
 BLAT "%@LOGFILE%" %@RECIPIENTS% -s "%@SUBJECT%"
 ECHO:
 ECHO:
 CALL :GetTime @STIME


 rem ==========================================================================
 rem === Reset Variables and Exit Batch File
 rem === Last Modified On: 20 Feb 2006
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Store Current Date and Time in Variable
 rem === Last Modified On: 28 Feb 2006
 rem ==========================================================================
:GetTime
 rem - %1 = Variable to Store Date/Time
 SET %~1=%TIME: =0% on %DATE%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Execute Dynamic Command From Variable
 rem === Last Modified On: 12 Jan 2007
 rem ==========================================================================
:RunCMD
 rem %1 = Command To Execute
 %*
 GOTO :EOF
