@REM - ASB (03 Mar 2007 // 16 Oct 2023 / 28 Sep 2021 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 30 Apr 2018 / 27 Mar 2016 / 05 May 2015): Expand IP Ranges to 3 Digits for Each Octet
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.1.0.210

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @N=[0-9]
 SET @AN=[a-f,0-9]
 SET @IPV4-FORMAT=%@N%*\.%@N%*\.%@N%*\.%@N%*\/%@N%*
 SET @IPV6-FORMAT=%@AN%%@AN%%@AN%%@AN%:%@AN%%@AN%%@AN%%@AN%:%@AN%%@AN%%@AN%%@AN%::\/%@N%*
 SET @INPUT=%~d0\Scripts\BAT\Input
 SET @SOURCE=%@INPUT%\NetworkSegments.TXT
 SET @OUTPUT=%@INPUT%\NetworkSegments-Expanded.TXT


 rem -- Expand the IP Address Segments Listing
:Main
 ECHO Expanding IPs from %@SOURCE%
 ECHO:

 BREAK ON >"%@OUTPUT%"
 FOR /F "TOKENS=* EOL=" %%L IN ('READABLE "%@SOURCE%" -p') DO (
	 IF "%%~L"=="" (SET @THISLINE=%%L ) ELSE (SET @THISLINE=%%L)
	 SET @THISLINE=!@THISLINE:^&=and!
	 SET @THATLINE=!@THISLINE:	= !
	 SET @PREFIX= & IF "!@THISLINE:~0,1!"==";" SET @PREFIX=;
	 FOR %%V IN (IPV4 IPV6) DO (SET @%%V=FALSE& FOR /F "EOL=" %%z IN ('ECHO !@THISLINE! ^| FINDSTR "!@%%V-FORMAT!"') DO SET @%%V=TRUE)

	 rem -- Format IPv4 Content
 	 IF /I "!@IPV4!"=="TRUE" (
		 FOR /F "TOKENS=1* EOL=" %%a IN ('ECHO !@THISLINE!') DO SET @DESC=%%b
		 FOR /F "TOKENS=1-5 DELIMS=;./ " %%a IN ('ECHO !@THATLINE!') DO (
			 SET @OCT1=00%%a
			 SET @OCT2=00%%b
			 SET @OCT3=00%%c
			 SET @OCT4=00%%d
			 SET @MASK=%%e
			 SET @THISLINE=!@PREFIX!!@OCT1:~-3!.!@OCT2:~-3!.!@OCT3:~-3!.!@OCT4:~-3!/!@MASK!   	!@DESC!
			 ECHO   %%a.%%b.%%c.%%d	= !@OCT1:~-3!.!@OCT2:~-3!.!@OCT3:~-3!.!@OCT4:~-3!/!%%e
			 IF /I "%DEBUG%"=="TRUE" FOR %%D IN (CON "%@OUTPUT%") DO (
				 ECHO %@DIVIDER-%
				 FOR %%R IN (THISLINE OCT1 OCT2 OCT3 OCT4 MASK DESC) DO ECHO  @%%R="!@%%R!"
				 ECHO %@DIVIDER-%
				 ECHO:
			 ) >>%%D
		 )
	 )

	 rem -- Format Non-IPv6 Content
	 IF /I NOT "!@IPV6!"=="TRUE" SET @PREFIX=

	 rem -- Print to File
	 ECHO:!@PREFIX!!@THISLINE! >>"%@OUTPUT%"
 )


 rem -- Generate Final Job Report
:FinalReport
 ECHO:
 TYPE "%@OUTPUT%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
        