@REM - ASB (22 Feb 2019 // 16 Oct 2023 / 22 Nov 2022 / 31 Mar 2021 / 30 Nov 2020 / 24 Dec 2019 / 10 Dec 2019 / 30 Sep 2019 / 17 Jun 2019 / 27 Feb 2019 / 24 Feb 2019): Use Native DiskUsage -OR- DU plus CCalc to Find Largest Subfolder, Recursively
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.1.0.310

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Enable Debug Mode
 FOR /F "TOKENS=2" %%T IN ('CHECKPARAMS -q -c "D DEBUG" -s %* 2^>NUL') DO (SET @DEBUGMODE=TRUE& SHIFT)

 rem -- Main Variables
 SET @FOLDER=%~1& IF "%~1"=="" SET @FOLDER=%SystemDrive%\Programs
 CALL :FixDirectoryPath @FOLDER


 rem -- Verify that Folder Exists
:VerifyFolder
 IF NOT EXIST "%@FOLDER%" (
	 ECHO *** FOLDER DOES NOT EXIST: "%@FOLDER%"
	 GOTO :ExitBatch
 )


 rem -- Check for Native Windows DiskUsage Utility, and Use DU if not found
:Check4DiskUsage
 FINDFILES -m -f "DiskUsage.EXE"
 IF ERRORLEVEL 64 GOTO :RootFolderInfo
 ECHO [!TIME: =0!] Evaluating: "!@FOLDER!" !@CURRENTSIZE!
 FOR /F "SKIP=1 TOKENS=1,3,4 DELIMS=," %%S IN ('DiskUsage -T:1 -C "%@FOLDER%" 2^>NUL') DO (
	 SET @MAXSIZE=%%S
	 SET @MAXNAME=%%U
	 SET @DIRCOUNT=%%T
 )
 GOTO :FinalReport


 rem -- Get Root Folder Size Info -- Using DU Method
:RootFolderInfo
 ECHO [!TIME: =0!] Getting Initial Info for "!@FOLDER!" ...   Please Wait...
 ECHO:
 FOR /F "SKIP=1 TOKENS=6 DELIMS=," %%S IN ('DU %@PSPARAMS% -C "%@FOLDER%" 2^>NUL') DO SET @CURRENTSIZE=%%S
 CALL :FormatNumber !@CURRENTSIZE! @CURRENTSIZE --


 rem -- Set Tracking Variables for Current Folder
:BeginLoop
 SET @MINSIZE=999999999999
 SET @MINNAME=
 SET @MAXSIZE=0
 SET @MAXNAME=
 SET @DIRCOUNT=0
 SET @EXITLOOP=FALSE
 SET @ROOTNAME=!@FOLDER!
 SET @ROOTSIZE=


 rem -- Recurse Through Directory Tree, Selecting Largest Folder Each Time
:InvestigateCurrentFolder
 ECHO [!TIME: =0!] Evaluating: "!@FOLDER!" !@CURRENTSIZE!
 FOR /F "SKIP=1 TOKENS=1,5,7 DELIMS=," %%D IN ('DU %@PSPARAMS% -C -L 1 "%@FOLDER%" 2^>NUL') DO (

	 rem -- If the Current Folder is the Original Folder, Capture Additional Info
	 SET @CHECK=%%~D
	 CALL :FixDirectoryPath @CHECK
	 IF /I "!@CHECK!"=="!@FOLDER!" (
		 SET @ROOTNAME=%%~D
		 SET @ROOTSIZE=%%~F

	 ) ELSE (

		 rem -- Capture Info about Smallest Folder
		 FOR /F %%S IN ('CCALC %%~F "<" !@MINSIZE! 2^>NUL') DO IF /I "%%~S"=="TRUE" (
			 SET @MINNAME=%%~D
			 SET @MINSIZE=%%~F
		 )

		 rem -- Capture Info about Largest Folder
		 FOR /F %%L IN ('CCALC %%~F ">" !@MAXSIZE! 2^>NUL') DO IF /I "%%~L"=="TRUE" (
			 SET @MAXNAME=%%~D
			 SET @MAXSIZE=%%~F
			 SET @DIRCOUNT=%%~E
		 )
	 )

	 rem -- Display Debug Values if Enabled
	 IF DEFINED @DEBUGMODE (
		 ECHO:
		 ECHO %@DIVIDER-%
		 ECHO ROOTNAME .......... !@ROOTNAME!
		 ECHO ROOTSIZE .......... !@ROOTSIZE!
		 ECHO %@DIVIDER-%
		 ECHO CURRENT FOLDER .... !@CHECK!
		 ECHO CURRENT SIZE ...... %%~F
		 ECHO ---
		 ECHO MAXNAME ........... !@MAXNAME!
		 ECHO MAXSIZE ........... !@MAXSIZE!
		 ECHO DIRCOUNT .......... !@DIRCOUNT!
		 ECHO ---
		 ECHO MINNAME ........... !@MINNAME!
		 ECHO MINSIZE ........... !@MINSIZE!
		 ECHO %@DIVIDER-%
		 ECHO:
	 )
 )

 rem -- Determine If Current Folder is Best Match
 FOR /F %%R IN ('CCALC !@ROOTSIZE! / !@MAXSIZE! 2^>NUL') DO (
	 SET @RATIO=%%~R
	 IF %%~R GEQ 4.0 (
		 SET @MAXNAME=!@ROOTNAME!
		 SET @MAXSIZE=!@ROOTSIZE!
		 SET @EXITLOOP=TRUE
	 )
 )

 rem -- Continue Iterating Subfolders If There Are Any Remaining
 IF "!@DIRCOUNT!"=="1" SET @EXITLOOP=TRUE
 IF /I "!@MINNAME!"=="!@MAXNAME!" IF "!@DIRCOUNT!"=="1" SET @EXITLOOP=TRUE
 IF /I "!@MAXNAME!"=="" (
	 SET @MAXNAME=!@ROOTNAME!
	 SET @MAXSIZE=!@ROOTSIZE!
	 SET @EXITLOOP=TRUE
 )

 rem -- Display Debug Values if Enabled
 IF DEFINED @DEBUGMODE (
	 ECHO RATIO ............. !@RATIO!
	 ECHO EXITLOOP .......... !@EXITLOOP!
	 ECHO %@DIVIDER-%
	 ECHO:
	 ECHO:
 )

 IF /I "!@EXITLOOP!"=="FALSE" (
	 CALL :FormatNumber !@MAXSIZE! @CURRENTSIZE --
	 SET @FOLDER=!@MAXNAME!
	 GOTO :BeginLoop
 )


 rem -- Generate Final Report
:FinalReport
 CALL :FormatNumber !@MAXSIZE! @MAXSIZE
 ECHO [!TIME: =0!] ***FOUND*** "!@MAXNAME!" -- !@MAXSIZE!
 ECHO:
 DIR /OGS "!@MAXNAME!"
 ECHO:
 ECHO %@DIVIDER-%
 DU %@PSPARAMS% -L 1 "!@MAXNAME!"
 ECHO %@DIVIDER*%
 ECHO *** FOUND: "!@MAXNAME!" [!@MAXSIZE!]
 ECHO %@DIVIDER*%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Remove Trailing \ From Supplied Folder Path
:FixDirectoryPath
 rem %1 = Folder Variable

 IF NOT DEFINED %1 GOTO :EOF
 IF "!%~1:~-1!"=="\" (
	 SET %~1=!%~1:~0,-1!
	 GOTO :FixDirectoryPath
 )
 GOTO :EOF


 rem -- SUBROUTINE: Format Numbers with Thousands Separator
:FormatNumber
 rem %1 = Current Number to be Formatted
 rem %2 = New Variable To Store Formatted Number
 rem %3 = Optional Separator Characters

 SET @NUMBER=%~1
 SET @FORMATTED=
 SET @SEPARATOR=%~3 & IF "%~3"=="" SET @SEPARATOR=

 FOR /L %%F IN (1,1,100) DO (
	 IF !@NUMBER! GEQ 1000 (
		 SET @FORMATTED=,!@NUMBER:~-3!!@FORMATTED!
		 SET @NUMBER=!@NUMBER:~0,-3!
	 )
	)

 IF NOT "!@NUMBER!"=="" SET @FORMATTED=!@NUMBER!!@FORMATTED!
 SET %~2=!@SEPARATOR!!@FORMATTED! bytes
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Use DU to Find Largest Subfolder, Recursively
 ECHO:
 ECHO    YOU TYPED: %0 %*
 ECHO:
 ECHO   CMD SYNTAX: %~n0  [/D^|/DEBUG] [folder]
 ECHO:
 ECHO   MY OPTIONS:
 ECHO   -?,  /H ....... Display This Help Message  (also --HELP)
 ECHO   -??, /H2 ...... Display Extended Help Message
 ECHO   /D,  /DEBUG ... Enable Debug Mode and Display Key Variables
 ECHO:
 ECHO  USAGE NOTES:
 ECHO    * Parameters surrounded by ^<^> are mandatory.
 ECHO    * Parameters surrounded by [] are optional.
 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
 ECHO    * If present, /D or /DEBUG must be found prior to the Folder Name
 ECHO    * Default Folder, in none provided, is %SystemDrive%\Programs
 CALL :ShowStatus "FINISHED"
                                                       