@REM - ASB (12 Aug 2004 // 16 Oct 2023 / 05 Mar 2021 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 18 Feb 2019 / 31 Aug 2018): Generate List of Domain Controllers from AD and Obtain IP Addresses
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.5.0.350

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @DOMAINNAME=%*& IF "%~1"=="" SET @DOMAINNAME=%USERDNSDOMAIN%
 SET @BASEDN=& CALL :GetDomainName %@DOMAINNAME%
 SET @RESOLVE=%~dp0..\Utils\Resolve.EXE
 SET @ADQUERY=ADFind %@BASEDN% -f "(&(objectCategory=computer)(|(primaryGroupId=516)(primaryGroupId=521)))" -nodn -s SUB -maxe 500 -nocsvheader -csv attr name operatingSystem
 SET @NOIP={No-IP-Found}

 rem -- Search-Related Variables
 SET @FILTER=%~2
 SET @WHICHSYS=where Name OR Desc Contains: "%~2"
 SET @FSUMMARY=FILTERED
 IF "%~2"=="" (
	 SET @FILTER=.
	 SET @WHICHSYS=[ALL DCs]
	 SET @FSUMMARY=UNFILTERED
 )


 rem -- Get Computer Names and Editions from Active Directory
:GetComputerInfo
 ECHO Search Domain: %@DOMAINNAME% [%@BASEDN:~3,999%] %@WHICHSYS%
 ECHO %@DIVIDER-%
 FOR /F "TOKENS=1-2* DELIMS=," %%S IN ('%@ADQUERY% ^| FINDSTR /I /R "%@FILTER%"') DO (
	 SET @SERVER=%%~S!@SPACES!
	 SET @SERVER=!@SERVER:~0,20!
	 SET @IPAnswer=%@NOIP%	!@SERVER!
	 SET @OS=@@@@%%~T& SET @OS=!@OS: =@!& IF NOT DEFINED !@OS! (SET !@OS!=1) ELSE (SET /A !@OS!+=1)
	 SET /A @TOTAL+=1
	 IF EXIST "%@RESOLVE%" (
		 FOR /F "TOKENS=1" %%I IN ('%@RESOLVE% %%~S ^| FIND /V "ERROR:"') DO SET @IPAnswer=%%I	!@SERVER!
	 ) ELSE (
		 FOR /F "TOKENS=2-3 DELIMS=[] " %%I IN ('PING -n 1 %%~S ^| FIND "["') DO SET @IPAnswer=%%J	%%I
	 )
	 ECHO !@IPAnswer!	%%~T
 )
 ECHO %@DIVIDER-%
 FOR /F "TOKENS=1-2 DELIMS==" %%V IN ('SET @@@@ 2^>NUL') DO (
	 SET @COUNT=     %%W
	 SET @OS=%%V
	 ECHO !@COUNT:~-6! each !@OS:@= !
 )
 ECHO %@DIVIDER*%
 ECHO 		TOTAL SYSTEMS = !@TOTAL!	[%@FSUMMARY%]
 ECHO %@DIVIDER*%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Get Active Directory Domain Name If Provided
:GetDomainName
 rem %1 = Domain Name Input

 SET #DOMAIN=%~1& IF "%~1"=="" SET #DOMAIN=%USERDNSDOMAIN%
 SET #DOMAIN=!#DOMAIN: =!
 SET #DOMAIN=!#DOMAIN:,=.!
 SET #DOMAIN=!#DOMAIN:dc=!
 SET @DOMAIN=& FOR %%D IN (!#DOMAIN!) DO SET @DOMAIN=!@DOMAIN!%%D
 SET #DOMAIN=
 SET @BASEDN=

 FOR /F "TOKENS=1-5 DELIMS=.= " %%D IN ('ECHO !@DOMAIN!') DO (
	 FOR %%z IN ("%%~D" "%%~E" "%%~F" "%%~G" "%%~H") DO IF NOT "%%~z"=="" SET @BASEDN=!@BASEDN!,DC=%%~z
 )

 SET @BASEDN=-b "!@BASEDN:~1,999!"
 SET @DOMAINNAME=!@DOMAIN!
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Generate List of Domain Controllers from AD and Obtain IP Addresses
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [Fully Qualified AD domain name] [search_for]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 mydomain.local
	 ECHO  %~n0 thisdomain.home "NY"
	 ECHO  %~n0 thatdomain.com
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO  * Folder Paths containing spaces should be enclosed in quotes.
 )
 CALL :ShowStatus "FINISHED"
                               