@REM - ASB (02 Feb 2022 // 12 Jan 2024 / 16 Oct 2023 / 28 Mar 2022 / 11 Feb 2022 / 02 Feb 2022 / 02 Feb 2022): Find File Version Across Drives [Locally or Remotely]
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.4.0.100

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Find File Version Across Drives [Locally or Remotely]
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<file_to_search_for^> [remote_system_name] ["semicolon_delimited_drives_or_paths"]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO     EXAMPLES:
	 ECHO               %~n0 DateInfo.exe
	 ECHO               %~n0 log4net.dll MYSERVER
	 ECHO               %~n0 SomeScript.bat ThatServer "C$;D$;Sharename"
	 ECHO               %~n0 ThatUtil.exe "" "C:\Someplace;D:\OtherPlace"
	 ECHO               %~n0 ThatUtil.exe "" "C:\Some?place;D:\Other?Place"
	 ECHO               %~n0 -h
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO    * Use a "?" in place of spaces for the optional semicolon delimited paths.
	 GOTO :ExitBatch
 )

 rem -- Check for Essential Utilities and/or Scripts
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f "NOW.EXE" "DATEINFO.EXE" "CHECKPARAMS.EXE" "READABLE.EXE" "PRINTFILEINFO.EXE"
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @PATHLIST=
 SET @CUSTOMPATHS=%~3
 SET @SELECTED= !@CUSTOMPATHS!
 SET @SELECTED=!@SELECTED:?=!
 SET @SEARCHFOR=%~1
 SET @SYSTEM=%~2
	 IF DEFINED @SYSTEM (
		 SET @LOCAL=
		 SET @HOSTNAME=!@SYSTEM:\=!
		 SET @SYSTEM=\\!@HOSTNAME!\
		 IF DEFINED @CUSTOMPATHS (
			 FOR %%S IN (!@SELECTED!) DO SET @PATHLIST=!@PATHLIST! "!@SYSTEM!%%~S"
		 ) ELSE (
			 SET @PATHLIST="!@SYSTEM!C$"
		 )
	 ) ELSE (
		 SET @LOCAL=TRUE
		 SET @HOSTNAME=%COMPUTERNAME%
		 IF DEFINED @CUSTOMPATHS (
			 FOR %%S IN (!@SELECTED!) DO SET @PATHLIST=!@PATHLIST! "%%~S"
		 ) ELSE (
			 SET @PATHLIST="!@SYSTEM!C:"
		 )
	 )

 rem -- Standard Log Variables
 SET @LOGFILE=%TEMP%\%~n0.%@FILESTAMP_R%
 SET @TEMPLOG=%TEMP%\%~n0.TEMP.%@FILESTAMP_R%


 rem -- Determine if Remote System is Available
:VerifyAccess
 IF DEFINED @SYSTEM (
	 CALL :ShowHeader Determine if Remote System [%@HOSTNAME%] is available...

	 SET @ACCESSIBLE=
	 FOR /F %%R IN ('DIR "%@SYSTEM%C$" 2^>NUL') DO SET @ACCESSIBLE=TRUE
	 IF DEFINED @ACCESSIBLE (
		 ECHO  +++ SYSTEM IS ONLINE AND ACCESSIBLE +++
	 ) ELSE (
		 ECHO  *** SYSTEM NOT ACCESSIBLE ***
		 ECHO:
		 GOTO :ExitBatch
	 )
 )


 rem -- Search for Files and Obtain Version Info
:Search4Files
 CALL :ShowHeader2 Searching for %@SEARCHFOR% on %@HOSTNAME%
 FOR %%P IN (%@PATHLIST%) DO (
	 SET @CURRENT="%%~P"
	 ECHO  --- !@CURRENT:= !
 )

 FOR %%P IN (%@PATHLIST%) DO (
	 SET @CURRENT=%%~P
	 SET @CURRENT=!@CURRENT:= !
	 CALL :ShowHeader Searching: !@CURRENT! >CON
	 CALL :ShowHeader Searching: !@CURRENT!
	 FOR /F "TOKENS=1-3*" %%F IN ('FILEHASH -N -S -R -D "!@CURRENT!\" %@SEARCHFOR%') DO (
		 SET #MYFILE-%%~dpI=%%F %%G %%H -- "%%~I"
		 ECHO %%F %%G %%H -- "%%~I" >CON
		 ECHO %%F %%G %%H -- "%%~I"
		 ECHO:
		 PRINTFILEINFO "%%~I" -Q
		 ECHO %@DIVIDER*%
	 )
 ) >> "%@LOGFILE%" 2>&1


 rem -- Generate Final Report
:FinalReport
 CALL :ShowHeader2 List of Found Files on %@HOSTNAME%...
 READABLE "%@LOGFILE%" --DL 2 --NL 1
 FOR /F "TOKENS=2 DELIMS==" %%V IN ('SET #MYFILE 2^>NUL') DO @ECHO "%%~V"
 ECHO:
 DIR "%@LOGFILE%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Show the Header
:ShowHeader
:ShowHeader2
 rem %* = Header Info to Display

 IF /I "%~0"==":ShowHeader2" (SET @DIV=%@DIVIDER*%) ELSE (SET @DIV=%@DIVIDER-%)
 ECHO:
 ECHO:
 ECHO %@DIV%
 ECHO %*
 ECHO %@DIV%
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                               