@REM - ASB (24 Nov 2010 // 16 Oct 2023 / 30 Nov 2020 / 03 Feb 2020 / 24 Dec 2019 / 30 Sep 2019 / 12 Jun 2019 / 03 Jun 2019 / 11 Mar 2019 / 31 Aug 2018): Search for Strings within Batch File Repository
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.8.0.280

 SET @ROOT=%~d0\Scripts\BAT
 SET @FILESPEC=%@ROOT%\*.*
 SET @EXEMPT.=.ZXYWVUT
 SET @STATUS.=Full Content Search
 SET @EXEMPT#=\.git\ \OLD\ .EXE .DLL .COM
 SET @STATUS#=Extended Document Search
 SET @EXEMPT=%@EXEMPT#% .TXT .LOG .RTF .DOC .PDF
 SET @STATUS=Basic Script Search
 SET @FOUND=0
 SET @COUNT=0
 SET @MOD=0
 SET @MSG=---------- Zero [0] matches found for "%~1"

 rem -- Establish Which Search Exemptions to Implement
 SET @DONTSHOW=[Skip %2]
 SET @SKIPSEARCH=^| FINDSTR /I /V %2& IF "%~2"=="" (SET @DONTSHOW=& SET @SKIPSEARCH=)
 FOR %%E IN (# .) DO IF "%~3"=="%%~E" (SET @EXEMPT=!@EXEMPT%%~E!& SET @STATUS=!@STATUS%%~E!)

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Search for Strings within Batch File Repository
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<"search string"^> ["search exemption"] [.^|#]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  CMD OPTIONS:
	 ECHO    #  ....... Extended Document Search ^(include .TXT, .LOG^)
	 ECHO    .  ....... Full Content Search
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )


 rem -- Find Number of Occurrences of Desired String
:GetCount
 PUSHD %@ROOT%
 ECHO *** Search Mode: %@STATUS% ***
 ECHO:
 ECHO Searching for "%~1" in "%@FILESPEC%" %@DONTSHOW%
 FOR /F %%C IN ('FINDSTR /M /I /S /C:"%~1" "%@FILESPEC%" ^| FINDSTR /I /V "%@EXEMPT%" ^| FIND /C /I "%@ROOT%" ') DO (
	 SET @FOUND=%%~C
	 SET @MSG=---------- %%~C matches found for "%~1"
 )
 ECHO %@MSG%
 IF DEFINED @DONTSHOW ECHO Will Ignore Lines Containing "%~2"
 ECHO:


 rem -- Ask for Permission to Display Results (Defaults to YES in 10 Seconds)
:DisplayResults
 IF %@FOUND% GTR 0 (
	 CHOICE /C YNQEX /T 10 /D Y /N /M "Do you want to show the results? (Y/N) "
	 IF !ERRORLEVEL! GTR 1 GOTO :FinalReport
 )


 rem -- Search for Strings within Batch Files [no executables or documents: .EXE, .COM, .DLL, .RTF, .DOC, .TXT ...]
:FindString
 FOR /F "TOKENS=*" %%D IN ('FINDSTR /M /I /S /C:"%~1" "%@FILESPEC%" ^| FINDSTR /I /V "%@EXEMPT%" ') DO (
	 SET @SKIPEXE=FALSE& FOR %%V IN (%@EXEMPT%) DO IF /I "%%~xD"=="%%~V" SET @SKIPEXE=TRUE
	 SET @SKIPGIT=FALSE& FOR /F %%V IN ('ECHO %%~fpD ^| FIND /I ".GIT"') DO SET @SKIPGIT=TRUE
	 IF "!@SKIPEXE!!@SKIPGIT!"=="FALSEFALSE" (
		 FIND /I "%~1" "%%~D" %@SKIPSEARCH%
		 SET /A @COUNT+=1
		 SET /A @MOD=@COUNT %% 10
		 IF !@MOD! EQU 0 (
			 CHOICE /C YNQEX /T 10 /D Y /N /M "Show More? [will continue automatically in 10 seconds] (Y/N) "
			 IF !ERRORLEVEL! GTR 1 GOTO :FinalReport
			 ECHO:
		 )
		 ECHO:
	 )
 )


 rem -- Final Report
:FinalReport
 IF NOT "%@FOUND%"=="0" (
	 ECHO:
	 ECHO %@MSG%
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 POPD
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                              