@REM - ASB (05 Apr 2007 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 13 Jan 2019 / 26 Jul 2018 / 08 May 2018): Find New Files in any Given Folder (default = Windows)
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v4.3.0.230

 rem -- List of Default Extensions to Search
 SET @DEFAULT_EXT=SYS EXE MSC MSI COM DLL OCX BAT CMD VBS WSH PS1 KIX PL PY JAVA

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Main Variables
 SET @SHOWHELP=FALSE
 SET @FILECOUNT=0
 SET @FOLDER=%~1& IF "%~1"=="" SET @FOLDER=%SystemRoot%
 SET @FOLDER=%@FOLDER:\\=\%& SET @WHICHDIR=!@FOLDER!
 SET @FOLDER=%@FOLDER%?
 SET @FOLDER=%@FOLDER:\?=%
 SET @FOLDER=%@FOLDER:?=%
 SET @RECENT=%~2& IF "%~2"=="" SET @RECENT=10
 SET @EXTENSIONS=%~3& IF "%~3"=="" SET @EXTENSIONS=%@DEFAULT_EXT%
                      IF "%@EXTENSIONS:~0,1%"=="*" SET @EXTENSIONS=%@DEFAULT_EXT% %@EXTENSIONS:~1,999%
 SET @SEARCHDATE=& FOR /F "TOKENS=2 DELIMS=." %%D IN ('DATEINFO -p %@RECENT% "mm/dd/yyyy"') DO SET @SEARCHDATE=%%D


 rem -- Generate the List of Recent Files
:Main
 PUSHD %@WHICHDIR%
 ECHO Searching for Recently Changed Files...
 ECHO  --- Start Search In ... "%@WHICHDIR%"
 ECHO  --- Search For ........ %@EXTENSIONS:+=*%
 ECHO  --- Maximum File Age .. %@RECENT% days
 ECHO:
 FOR %%E IN (%@EXTENSIONS%) DO (
	 SET @EXT=%%~E
	 SET @FORFILES=FORFILES -p"%@FOLDER%" -m*.!@EXT! -s -d+%@SEARCHDATE% -c"CMD /C IF @ISDIR==FALSE ECHO	@FDATE	@FTIME	@PATH\@FILE"
	 IF EXIST "%SystemRoot%\System32\FORFILES.EXE" (
		 SET @FORFILES=%SystemRoot%\System32\FORFILES -p "%@FOLDER%" -m *.!@EXT! -s -d +%@SEARCHDATE% -c "CMD /C IF @ISDIR==FALSE ECHO	@FDATE	@FTIME	@PATH"
	 )

	 ECHO  -- Searching for recently changed *.!@EXT! files...
	 FOR /F "TOKENS=*" %%v IN ('!@FORFILES! 2^>NUL') DO (
		 SET /A @FILECOUNT+=1
		 ECHO     %%~v
	 )
	 ECHO:
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 ECHO:
 ECHO Recently Modified Files Found: %@FILECOUNT%
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 POPD
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Find New Files in any Given Folder (default = Windows)
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [Folder] [Age to Search] [Extensions]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 D:\ 20
	 ECHO  %~n0 %SystemRoot% 30 "EXE DLL"
	 ECHO  %~n0 %SystemDrive% 10 "+ EXE DLL EXT1 EXT2"
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * Default extenstion list = %@DEFAULT_EXT%
	 ECHO:
	 ECHO  * Use "+" to ADD to the list of currently searched extensions.
	 ECHO  * Use "*" to select an extended list of executable extensions to search.
	 ECHO  * Multiple extenstions, including "+" is supplied, must be surrounded in doublequotes.
 )
 CALL :ShowStatus "FINISHED"
                       