@REM - ASB (10 May 2006 // 16 Oct 2023 / 30 Nov 2020 / 26 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 28 Jul 2019 / 28 Oct 2018 / 31 Aug 2018 / 26 Jul 2018 / 27 Mar 2016 / 05 May 2015): Query AD For User and Computer Objects
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.4.0.240

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Query AD For User and Computer Objects
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<NetBIOS domain name^>
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Generate Active Directory Domain Variables
 SET @DNSNAME=%~1
 FOR %%D IN (%@DNSNAME:.= %) DO SET @AD_DOMAIN=!@AD_DOMAIN!,dc=%%D
 SET @AD_DOMAIN=%@AD_DOMAIN:~1,99%
 SET @ELEMENTS=CN DC OU

 rem -- DSMOD/DSQUERY Variables
 SET @LIMIT=-limit 15000

 rem -- Standard Log Variables
 SET @LOGPATH=%@STORAGE%\Logs\AD
 SET @TEMPFILE=%@LOGPATH%\%~n0-Temp.%@FILESTAMP%
 SET @LOGFILE1=%@LOGPATH%\%~n0-Users.%@FILESTAMP%
 SET @LOGFILE2=%@LOGPATH%\%~n0-Computers.%@FILESTAMP%


 rem -- Query AD For User Objects
:QueryUsers
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"
 ECHO Querying %@DNSNAME% for User Objects [%@AD_DOMAIN%]
 ECHO:
 dsquery user "%@AD_DOMAIN%" %@LIMIT% >"%@TEMPFILE%" 2>&1

:UserReport
 NOW Generated By %@VER% [USERS] >"%@LOGFILE1%"
 ECHO:
 ECHO Reformatting the User Report...
 FOR /F "TOKENS=*" %%U IN ('TYPE "%@TEMPFILE%"') DO CALL :ConvertFormat "%@LOGFILE1%" "%%~U"
 SORT /+4 "%@LOGFILE1%" /O "%@LOGFILE1%"


 rem -- Query AD For Computer Objects
:QueryComputers
 ECHO:
 ECHO Querying %@DNSNAME% for User Objects [%@AD_DOMAIN%]
 ECHO:
 dsquery computer "%@AD_DOMAIN%" %@LIMIT% >"%@TEMPFILE%" 2>&1

:ComputerReport
 NOW Generated By %@VER% [COMPUTERS] >"%@LOGFILE2%"
 ECHO:
 ECHO Reformatting the Computer Report...
 FOR /F "TOKENS=*" %%C IN ('TYPE "%@TEMPFILE%"') DO CALL :ConvertFormat "%@LOGFILE2%" "%%~C"
 SORT /+4 "%@LOGFILE2%" /O "%@LOGFILE2%"


 rem -- Display Final Report
:FinalReport
 IF EXIST "%@TEMPFILE%" DEL "%@TEMPFILE%" >NUL
 DIR "%@LOGFILE1%" "%@LOGFILE2%" & START "List of Users" "%@LOGFILE1%" & START "List of Computers" "%@LOGFILE2%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Convert Format of Output to DSN
:ConvertFormat
 rem %1 = Filename to use for Converted Output
 rem %2 = Current Line in Current File

 SET @NEWFILE=%~1
 SET @OLDLINE=%~2
 SET @OLDLINE=%@OLDLINE:(=[%
 SET @OLDLINE=%@OLDLINE:)=]%
 SET @NEWLINE=

 FOR %%E IN (%@OLDLINE: =@%) DO (
	 SET @ADD=TRUE
	 FOR %%A IN (%@ELEMENTS% %@DNSNAME:.= %) DO IF /I "%%~E"=="%%~A" SET @ADD=FALSE
	 IF "!@ADD!"=="TRUE" SET @NEWLINE=%%~E/!@NEWLINE!
 )

 SET @NEWLINE=%@NEWLINE:@= %
 SET @NEWLINE=%@NEWLINE:[=(%
 SET @NEWLINE=%@NEWLINE:]=)%
 SET @NEWLINE=%@DNSNAME%/%@NEWLINE:~0,-1%
 ECHO %@NEWLINE% >>%@NEWFILE%
 GOTO :EOF
      