@REM - ASB (31 Oct 2005 // 16 Oct 2023 / 30 Nov 2020 / 08 May 2020 / 31 Jan 2020 / 24 Dec 2019): Find Executables in PATH and Obtain Version Info
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.4.0.340

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @WHERE=& FOR /F %%V IN ('WHERE WHERE 2^>NUL') DO SET @WHERE=TRUE
 SET @UTILS=%~d0\Scripts\Utils
 SET @FULLPATH=%~d0\;%CD%;%@UTILS%\x64;%@UTILS%;%@UTILS%\Misc;%PATH%


 rem -- Verify that WHERE.EXE is available
:UseWHERE
 IF DEFINED @WHERE GOTO :FindFiles_Basic
 ECHO:
 ECHO *** ERROR: COULD NOT FIND WHERE.EXE ***
 GOTO :ExitBatch


 rem -- Find Version Info, Depending on Version of Windows
:FindFiles_Basic
 FOR %%F IN (%*) DO (
	 SET @COUNT=0

	 ECHO %@DIVIDER*%
	 ECHO *** PRELIMINARY REPORT
	 ECHO %@DIVIDER*%
	 ECHO:
	 WHERE "%%~F" 2>NUL
	 ECHO:

	 IF "%~2"=="*" (
		 ECHO Searching for Instances of "%%~F" [EXTENDED] -- Please Wait...
		 ECHO %@DIVIDER-%
		 ECHO:
		 FOR /F "TOKENS=*" %%V IN ('WHERE /R "%~d0" "%%~F" 2^>NUL') DO CALL :DisplayFileInfo "%%~V"
	 ) ELSE (
		 ECHO Searching for Instances of "%%~F"
		 ECHO %@DIVIDER-%
		 ECHO:
		 FOR /F "TOKENS=*" %%V IN ('WHERE "$@FULLPATH:%%~F" 2^>NUL') DO CALL :DisplayFileInfo "%%~V"
	 )

	:Summary
	 SET @TOTAL=!@COUNT!
	 ECHO Number of instances of "%%~F" found: !@TOTAL!
	 ECHO:
	 TIMEOUT 30


	:FindFiles_Detailed
	 ECHO:
	 ECHO %@DIVIDER*%
	 ECHO *** DETAILED REPORT  [Total Instances found: !@TOTAL!]
	 ECHO %@DIVIDER*%
	 ECHO:

	 IF "%~2"=="*" (
		 ECHO Getting File Version Info for: "%%~F" [EXTENDED]
		 ECHO %@DIVIDER-%
		 ECHO:
		 FOR /F "TOKENS=*" %%V IN ('WHERE /R "%~d0" "%%~F" 2^>NUL') DO CALL :DisplayFileInfo "%%~V" "/v" "-a -h" .
	 ) ELSE (
		 ECHO Getting File Version Info for: "%%~F"
		 ECHO %@DIVIDER-%
		 ECHO:
		 FOR /F "TOKENS=*" %%V IN ('WHERE "$@FULLPATH:%%~F" 2^>NUL') DO CALL :DisplayFileInfo "%%~V" "/v" "-a -h" .
	 )


	 rem -- Final Report of Searched Files
	:FinalReport
	 IF NOT "%@TOTAL%"=="0" (
		 ECHO:
		 ECHO %@DIVIDER-%
		 WHERE "%%~F" 2>NUL
		 ECHO %@DIVIDER-%
		 ECHO:
	 )
	 ECHO Number of instances of "%%~F" found: !@TOTAL!
	 ECHO:
	 ECHO:
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Get and Display File Info
:DisplayFileInfo
 rem %1 = Current File
 rem %2 = Additional Params for FILEVER.EXE
 rem %3 = Additional Params for SIGCHECK.EXE
 rem %4 = Blank Value = Extra Blank Line

 SET /A @COUNT+=1
 ECHO -- %~1
 ECHO %@DIVIDER-%
 PrintFileInfo "%~1" -q
 ECHO %@DIVIDER-%
 ECHO:
 DIR "%~1" | FIND /I "%~nx1"
 ECHO:
 FILEVER "%~1" %~2
 ECHO %@DIVIDER-%
 ECHO:
 SIGCHECK %@PSPARAMS% %~3 "%~1" 2>NUL
 ECHO %@DIVIDER#%
 ECHO:
 IF "%~4"=="" ECHO:
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Find Executables in PATH and Obtain Version Info
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  %~n0  ^<some_file_name.ext^> [OPTIONS]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       * ...... Search in extended path for more files
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 cmd
	 ECHO  %~n0 find
	 ECHO  %~n0 findstr.exe
	 ECHO  %~n0 explorer
	 ECHO  %~n0 filehash filehash64
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
                 