@REM - ASB (22 Dec 2021 // 12 Jan 2024 / 16 Oct 2023 / 05 Dec 2022 / 12 Feb 2022 / 11 Jan 2022 / 22 Dec 2021): Fix Machine Trust within a Domain [using NETDOM, NLTEST, ADFIND, ADMOD, MACHINEPWD]
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.5.0.150

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Fix Machine Trust within a Domain [using NETDOM, NLTEST, ADFIND, ADMOD, MACHINEPWD]
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<machine^> [make_changes^|/FORCE] [/RESET]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Check for Essential Utilities and/or Scripts
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f "NOW.EXE" "DATEINFO.EXE" "CHECKPARAMS.EXE" "ADMOD" "ADFIND" "MACHINEPWD" "NETDOM" "NLTEST"
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @SYSTEM=\\%~1& SET @SYSTEM=!@SYSTEM:\=!
 SET @READ-WRITE=%~2& IF /I "%~2"=="/FORCE" (SET @SET_IN_AD=TRUE) ELSE (SET @SET_IN_AD=)
 SET @VERIFYONLY=TRUE& IF /I "%~3"=="/RESET" (SET @VERIFYONLY=)
 SET @DC=
 SET @TRUST=
 SET @ERRMSG=
 SET @RESETPWD=FixMeNow
 SET @BADIP="ERROR:" "Email"
 SET @SUCCESS=The command completed successfully.
 SET @FAILURE=The target account name is incorrect.
 SET @VERIFIED= has been verified.

 rem -- Check for Utilities
 FOR /F "TOKENS=*" %%U IN ('WHERE NETDOM.EXE 2^>NUL') DO SET @NETDOM=%%~nxU
 FOR /F "TOKENS=*" %%U IN ('WHERE NLTEST.EXE 2^>NUL') DO SET @NLTEST=%%~nxU
 IF DEFINED @READ-WRITE (
	 FOR /F "TOKENS=*" %%U IN ('WHERE AdMod.exe 2^>NUL')      DO SET @ADMOD=%%~nxU
	 FOR /F "TOKENS=*" %%U IN ('WHERE AdFind.exe 2^>NUL')     DO SET @ADFIND=%%~nxU
	 FOR /F "TOKENS=*" %%U IN ('WHERE MachinePwd.exe 2^>NUL') DO SET @MACHINEPWD=%%~U
 ) ELSE (
	 FOR %%U IN (ADMOD ADFIND MACHINEPWD) DO SET @%%U=BYPASS
 )


 rem -- Confirm that this is Being Run in a Domain Environment, with necessary Utilities
:VerifyOperation
 FOR %%U IN (ADMOD ADFIND MACHINEPWD NETDOM NLTEST) DO IF NOT DEFINED @%%U SET @ERRMSG=This script requires a machine running %%U.
 IF /I "%USERDOMAIN%"=="%COMPUTERNAME%" SET @ERRMSG=This script requires a domain environment, not a workgroup environment.

 IF DEFINED @ERRMSG (
	 ECHO:
	 ECHO %@DIVIDER*%
	 ECHO *** %@ERRMSG%
	 ECHO %@DIVIDER*%
	 ECHO:
	 ECHO --- Please See Syntax Help Below...
	 CALL %~n0 %* --HELP
	 GOTO :ExitBatch
 )


 rem -- Verify the Domain is Reachable
:VerifyDomain
 ECHO Verifying Access to Domain: %USERDOMAIN%
 ECHO %@DIVIDER-%
 FOR /F "TOKENS=2 DELIMS=\_" %%D IN ('NLTEST /DCNAME:%USERDOMAIN% 2^>^&1') DO SET @DC=%%~D
 IF /I "!@DC!"=="DCNotFound" (
	 ECHO Cannot Reach the %USERDOMAIN% Domain from %COMPUTERNAME%
	 GOTO :ExitBatch
 )


 rem -- Verify Machine Trust in the Domain / Start "Remote Registry" service on Remote System if not running
:VerifyMachineTrust
 FOR /F "TOKENS=4" %%S IN ('SC %@SYSTEM% QUERY "RemoteRegistry" ^| FIND "STATE"') DO (
	 IF NOT "%%~S"=="RUNNING" (
		 ECHO:
		 ECHO Starting Remote Registry Service on %@SYSTEM%...
		 SC %@SYSTEM% CONFIG RemoteRegistry start= AUTO
		 SC %@SYSTEM% START RemoteRegistry
		 ECHO:
	 )
 )

 ECHO:
 ECHO Verifying Domain Trust for %@SYSTEM% in %USERDOMAIN%
 ECHO %@DIVIDER-%
 IF /I "%@DC%"=="%@SYSTEM%" (
	 SET @VALID=TRUE
	 SET @TRUST= Cannot Verify Secure Channel of PDC Emulator [%@DC%] with Itself
 ) ELSE (
	 FOR /F "TOKENS=*" %%V IN ('NETDOM VERIFY %@SYSTEM% /DOMAIN:%USERDOMAIN% 2^>NUL ^| FIND /I "%@VERIFIED%"') DO SET @VALID=TRUE
	 FOR /F "TOKENS=*" %%V IN ('NETDOM VERIFY %@SYSTEM% /DOMAIN:%USERDOMAIN% 2^>NUL ^| FIND /I /V "%@SUCCESS%"') DO SET @TRUST=!@TRUST! %%V
	 IF /I "%@DC%"=="DCNotFound" SET @TRUST= Cannot Reach the %%~D Domain from %@SYSTEM%
 )


 rem -- Try to Identify System IP
:ResolveIP
 ECHO:
 ECHO Trying to Reach System: %@SYSTEM%
 ECHO %@DIVIDER-%

 ECHO:
 ECHO Resolving IP Address...
 FOR /F %%X IN ('RESOLVE %@SYSTEM%') DO SET @IP=%%X

 FOR %%B IN (%@BADIP%) DO IF "!@IP!"=="%%~B" (
	 ECHO Invalid IP Address or Hostname for %@SYSTEM%
	 GOTO :ExitBatch
 )


 rem -- Display Summary System Info
:SummaryInfo
 ECHO:
 ECHO %@DIVIDER*%
 ECHO Verifying Trust for:  %@SYSTEM% [%@IP%] in %USERDOMAIN%
 ECHO Machine Trust Status:!@TRUST!
 IF NOT DEFINED @VALID (ECHO:& ECHO *** NO VALID DOMAIN TRUST FOUND FOR "%@SYSTEM%" ***)
 ECHO %@DIVIDER*%
 ECHO:
 IF NOT DEFINED @READ-WRITE (
	 ECHO *** NO PASSWORD CHANGES MADE ON MACHINE OR IN DOMAIN ***
	 ECHO:
	 GOTO :ExitBatch
 )


 rem -- If Remote System Reachable, Try Resetting Machine Password (on Machine and in Domain)
:ResetMachinePassword
 ECHO Resetting Machine Password at the System Level on %@SYSTEM% [%@IP%]
 PSEXEC \\%@IP% %@PSPARAM% -C -F -H -N 30 %@MACHINEPWD% /setpwd:%@RESETPWD%
 IF ERRORLEVEL 0 IF NOT ERRORLEVEL 1 SET @SET_IN_AD=TRUE

 rem -- If Machine Password Reset was Successful OR Domain Password Change is Forced...
 IF DEFINED @SET_IN_AD (
	 ECHO:
	 ECHO Resetting Machine Password for %@SYSTEM% [%@IP%] at the Domain Level [%USERDOMAIN%]
	 FOR /F "TOKENS=*" %%S IN ('adfind -default -f samaccountname^=%%V$ -csv -nocsvheader attr') DO (
		 SET @DN=%%~S
		 SET @DN=!@DN:~0,-3!
		 ECHO DN: !@DN!
		 admod -b "!@DN!" -optenc unicodepwd::%@RESETPWD%
	 )

	 TIMEOUT 15
	 ECHO:
	 ECHO Checking / Verifying Trust between machine %@SYSTEM% and domain %USERDOMAIN%
	 FOR %%C IN (VERIFY RESET VERIFY) DO (
		 IF DEFINED @VERIFYONLY IF /I "%%~C"=="VERIFY" (
			 ECHO:
			 ECHO EXECUTING: NETDOM %%~C ...
			 NETDOM %%C %@SYSTEM% /DOMAIN:%USERDOMAIN%
		 )
	 )
 ) ELSE (
	 ECHO:
	 ECHO ERROR: Could Not Set Machine Password on %@SYSTEM% [%@IP%]
	 ECHO:
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                               