@REM - ASB (26 Dec 2013 // 16 Oct 2023 / 27 Dec 2020 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 17 Dec 2018): Repair Busted/Corrupt PATH
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v4.1.0.410

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Repair Busted/Corrupt PATH
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [\\remote_computer]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @COMPUTER=%~1& IF "%~1"=="" SET @COMPUTER=%COMPUTERNAME%
 SET @COMPUTER=\\!@COMPUTER:\=!
 SET @PATH_ENV=%@COMPUTER%\HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Session Manager\Environment
 SET @SCRIPTS=%~d0\Scripts
 SET @BAT=%@SCRIPTS%\BAT
 SET @KIX=%@SCRIPTS%\BAT
 SET @VBS=%@SCRIPTS%\VBS
 SET @PERL=%@SCRIPTS%\Perl
 SET @PSHELL=%@SCRIPTS%\PowerShell
 SET @M_UTILS=%@SCRIPTS%\Utils\Misc

 rem -- Identify OS Architecture by CPU Info in Registry
 SET @CPUINFO=%@COMPUTER%\HKEY_LOCAL_MACHINE\Hardware\Description\System\CentralProcessor\0
 SET @OS_ARCH=x64& FOR /F "TOKENS=*" %%O IN ('REG QUERY "%@CPUINFO%" /v "Identifier" ^| FIND /I "x86"') DO SET @OS_ARCH=x86
 SET @OSBUILD=6002& FOR /F "TOKENS=6 DELIMS=[]. " %%B IN ('VER') DO SET @OSBUILD=%%B
 SET @UTILS=%@SCRIPTS%\Utils
	 IF /I "%@OS_ARCH%"=="x64" SET @UTILS=%@SCRIPTS%\Utils\x64;%@SCRIPTS%\Utils
	 IF %@OSBUILD% LSS 6001 SET @UTILS=%@SCRIPTS%\Utils\XP;%@SCRIPTS%\Utils
 SET @WINDIR=%%SystemRoot%%\System32;%%SystemRoot%%;%%SystemRoot%%\System32\Wbem
 SET @BW_PATH=%@BAT%;%@UTILS%;%@PSHELL%;%@VBS%;%@PERL%


 rem -- Enable "Remote Registry" and Display OLD Path
:ShowPathInfo
 ECHO Attempting to START "Remote Registry" ...
 SC %@COMPUTER% CONFIG RemoteRegistry START= Auto
 SC %@COMPUTER% START RemoteRegistry
 ECHO OLD PATH
 CALL :DisplayPATH


 rem -- Update Current Path
:FixPathInfo
 FOR /F "TOKENS=2*" %%P IN ('REG QUERY "%@PATH_ENV%" /V PATH') DO @SET @PATH=%%Q
 SET @OLDPATH=!@PATH!
 FOR %%P IN (%@M_UTILS%;%@BW_PATH%) DO (
	 SET @PATH=!@PATH:%%~P;=!
	 SET @PATH=!@PATH:;%%~P=!
 )
 SET @PATH=!@PATH:%WINDIR%=%%SystemRoot%%!
 SET @PATH=!@PATH:System=System!
 SET @PATH=!@PATH:%@WINDIR%;=;!
 SET @PATH=!@PATH:\\=\!
 SET @PATH=!@PATH:"=!
 SET @PATH=%@BW_PATH%;%@WINDIR%;%@PATH%;%@M_UTILS%
 SET @PATH=!@PATH:;\Misc;=;!
 FOR /L %%P IN (1,1,20) DO SET @PATH=!@PATH:;;=;!
 SET PATH=!@PATH!
 REG ADD "%@PATH_ENV%" /v OLDPATH /t REG_EXPAND_SZ /f /d "!@OLDPATH!"
 REG ADD "%@PATH_ENV%" /v PATH /t REG_EXPAND_SZ /f /d "!@PATH!"
 CALL :DisplayPATH


 rem -- Generate Final Report
:FinalReport
 ECHO:
 ECHO Please Start a New CMD Instance to Get the New PATH Variable...


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Display Path and OldPath Variables
:DisplayPATH
 ECHO Displaying Registry Info for: %@COMPUTER% [%@OS_ARCH%]
 FOR %%V IN (OLDPATH PATH) DO (
	 REG QUERY "%@PATH_ENV%" /v %%~V
	 ECHO ----------
 )
 ECHO:
 ECHO:
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                          