@REM - ASB (20 Feb 2006 // 16 Oct 2023 / 08 Jul 2021 / 11 Jan 2021 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 06 Dec 2018 / 29 Apr 2018 / 27 Mar 2016 / 26 Jul 2015): View/Delete Stray Remote Console Processes...
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.2.0.320

 rem -- Defaults
 SET @SOURCELIST1=%SystemDrive%\Scripts\BAT\Input\ServerList.%COMPUTERNAME%.TXT
 SET @SOURCELIST2=!@SOURCELIST1:.%COMPUTERNAME%.=.!

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @DIAGMODE=0& IF /I "%DEBUG%"=="TRUE" SET @DIAGMODE=1
 SET @SOURCE=%~1& IF "%~1"=="" SET @SOURCE=%@SOURCELIST1%
 IF NOT EXIST "%@SOURCE%" SET @SOURCE=%@SOURCELIST2%

 rem -- Service Variables
 SET @MSG=Checking for Stray Remote Console Processes and Services
 SET @SVCLIST=PSEXESVC PSEXECSVR REXESVR PAEXEC BWRemote
 SET @TK_SYNTAX=TASKKILL /S @@@@@ /F /T /IM $$$$$.EXE
 SET @PK_SYNTAX=PSKILL %@PSPARAMS% -t \\@@@@@ $$$$$

 rem -- TaskKill vs PsKill Default
 IF EXIST "%WINDIR%\System32\TASKKILL.EXE" (SET @KILL_PROCESS=%@TK_SYNTAX%) ELSE (SET @KILL_PROCESS=%@PK_SYNTAX%)

 rem -- Process Special Command-line Parameters
 SET @ALL_PARAMS=%*
 CALL :GetParams "P PSKILL"   & IF DEFINED @OK SET @KILL_PROCESS=%@PK_SYNTAX%
 CALL :GetParams "T TASKKILL" & IF DEFINED @OK SET @KILL_PROCESS=%@TK_SYNTAX%


 rem -- Cycle Through Systems and Search for Stray Remote Console Services
:Main
 ECHO [!DATE! @ !TIME: =0!] %@MSG% on %COMPUTERNAME%...
 SET @TERMINATE_CMD=!@KILL_PROCESS:@@@@@=%COMPUTERNAME%!
 FOR %%P IN (%@SVCLIST%) DO (
	 NOW \n \s  !TIME: =0! -- Searching for Stray %%P Processes...
	 FOR /F %%S IN ('PSLIST %@PSPARAMS% %%~P 2^>NUL ^| FINDSTR /I "%@SVCLIST%"') DO (
		 CMD /C !@TERMINATE_CMD:$$$$$=%%~P! 2>NUL
		 SLEEP 2
		 IF /I "%%~P"=="PAEXEC" (
			 FOR /F "TOKENS=2" %%T IN ('PSSERVICE %@PSPARAMS% QUERY PAEXEC 2^>NUL ^| FIND /I "PAEXEC"') DO SC DELETE %%~T
		 ) ELSE (
			 SC DELETE %%~P >NUL 2>NUL
		 )
		 SLEEP 2
	 )
	 FOR %%D IN (%SystemRoot%\%%~P*.EXE %SystemRoot%\System32\%%~P*.EXE) DO (
		 IF EXIST "%%~D" (
			 ECHO Deleting "%%~D" ...
			 DEL "%%~D"
			 TIMEOUT 10
		 )
	 )
 )
 ECHO %@DIVIDER-%
 ECHO:

 FOR /F %%V IN (%@SOURCE%) DO IF /I NOT "%%~V"=="%COMPUTERNAME%" (
	 SET @FOUND=0
	 SET @THISSYS=%%V
	 SET @THISSYS=!@THISSYS:\=!
	 SET @TERMINATE_CMD=%@KILL_PROCESS:@@@@@=!@THISSYS!%
	 ECHO [!DATE! @ !TIME: =0!] %@MSG% on !@THISSYS!...

	 FOR %%P IN (%@SVCLIST%) DO FOR /F %%S IN ('PSLIST %@PSPARAMS% %%~V %%~P 2^>NUL ') DO SET @FOUND=1
	 SET /A @RUNMODE=@DIAGMODE + @FOUND

	 IF !@RUNMODE! GEQ 1 (
		 rem -- Delete all remnants of Remote Console Services and Processes...
		 FOR %%P IN (%@SVCLIST%) DO (
			 NOW \n \s  !TIME: =0! -- Searching for Stray %%P Processes...
			 FOR /F %%S IN ('PSLIST %@PSPARAMS% %%~V %%~P 2^>NUL ^| FINDSTR /I "%@SVCLIST%"') DO (
				 CMD /C !@TERMINATE_CMD:$$$$$=%%~S! 2>NUL
				 SLEEP 2
				 IF /I "%%~P"=="PAEXEC" (
					 FOR /F "TOKENS=2" %%T IN ('PSSERVICE %@PSPARAMS% %%~V QUERY PAEXEC 2^>NUL ^| FIND /I "PAEXEC"') DO SC %%~V DELETE %%~T
				 ) ELSE (
					 SC %%~V DELETE %%~P >NUL 2>NUL
				 )
				 SLEEP 2
			 )
			 FOR %%D IN (%%~V\Admin$\%%~P*.EXE %%~V\Admin$\System32\%%~P*.EXE) DO (
				 IF EXIST "%%~D" (
					 ECHO Deleting "%%~D" ...
					 DEL "%%~D"
					 TIMEOUT 10
				 )
			 )
		 )
	 )

	 ECHO %@DIVIDER-%
	 ECHO:
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Use CheckParams.exe to Capture Selected Parameters
 rem === Updated On: 21 Jan 2020 / 24 Sep 2019              
 rem ==========================================================================
:GetParams
 rem %1 = Parameters to Search For
 rem %2 = Variable to Set

 SET @OK=& IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=2-3*" %%v IN ('CHECKPARAMS -q -a -c "%~1" -s %@ALL_PARAMS% 2^>NUL') DO IF /I "%%~v"=="TRUE" (
	 SET @OK=T
	 SET @REQ=T
	 IF NOT "%~2"=="" SET %~2=%%~x
 )
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO View/Delete Stray Remote Console Processes...
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [server_list] [OPTIONS]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       /P  .... Use PSKILL for terminating processes
 ECHO       /T  .... Use Native TASKKILL for terminating processes  [DEFAULT]
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 /P
	 ECHO  %~n0 CustomServerList.TXT /T
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * No matter what list is selected, the local system will also be
	 ECHO    included in the job.
	 ECHO:
	 ECHO  * The default server list is: "%@SOURCELIST1%"
 )
 CALL :ShowStatus "FINISHED"
                                                            