@REM - ASB (13 May 2018 // 16 Oct 2023 / 30 Nov 2020 / 26 Oct 2020 / 24 Dec 2019 / 30 Oct 2019 / 13 May 2018): Enable/Disable Spectre and Meltdown Mitigations for Intel, AMD and ARM based systems
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.3.0.070

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @MEM_KEY="HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Session Manager\Memory Management"
 SET @FSOM=FeatureSettingsOverrideMask
 SET @FSO=FeatureSettingsOverride
 SET @FSO_VAL=72
 SET @FSO_DEFAULT=3
 SET @FSOM_DEFAULT=3
 SET @VM_KEY="HKLM\SOFTWARE\Microsoft\Windows NT\CurrentVersion\Virtualization"
 SET @VM_MINVER=MinVmVersionForCpuBasedMitigations
 SET @ISSERVER=FALSE& FOR /F %%V IN ('ECHO %@OSNAME% ^| FIND /I "SERVER"') DO SET @ISSERVER=TRUE

 rem -- Check to Disable Mitigations, Otherwise Enable Them
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "U UNDO OFF D DISABLE" -s %* 2^>NUL') DO GOTO :Undo_CPU_Mitigations

 rem -- Determine CPU Type
 FOR /F %%V IN ('SYSTEMINFO 2^>NUL ^| FIND /I "AuthenticAMD"') DO SET @FSO_VAL=72
 FOR /F %%V IN ('SYSTEMINFO 2^>NUL ^| FIND /I "ARM"') DO SET @FSO_VAL=64


:Set_Correct_Mitigations
 ECHO Fixing Spectre and Meltdown Vulnerabilities on %COMPUTERNAME%
 ECHO:
 IF /I "%@ISSERVER%"=="TRUE" reg add %@VM_KEY% /v %@VM_MINVER% /t REG_SZ /d "1.0" /f
 reg add %@MEM_KEY% /v %@FSO%  /t REG_DWORD /d %@FSO_VAL%      /f
 reg add %@MEM_KEY% /v %@FSOM% /t REG_DWORD /d %@FSOM_DEFAULT% /f
 GOTO :FinalReport


:Undo_CPU_Mitigations
 ECHO Undo Spectre and Meltdown Mitigations on %COMPUTERNAME%
 ECHO:
 IF /I "%@ISSERVER%"=="TRUE" reg add %@VM_KEY% /v %@VM_MINVER% /t REG_SZ /d "1.0" /f
 reg add %@MEM_KEY% /v %@FSO%  /t REG_DWORD /d %@FSO_DEFAULT%  /f
 reg add %@MEM_KEY% /v %@FSOM% /t REG_DWORD /d %@FSOM_DEFAULT% /f


 rem -- Display Current Registry Settings
:FinalReport
 ECHO:
 ECHO %@DIVIDER-%
 reg query %@VM_KEY%
 reg query %@MEM_KEY%
 ECHO %@DIVIDER-%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Enable/Disable Spectre and Meltdown Mitigations for Intel, AMD and ARM based systems
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [options]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H  ........ Display This Help Message  (also --HELP)
 ECHO  -??, /H2 ........ Display Extended Help Message
 ECHO  /U,  /UNDO ...... Optional parameter to undo all CPU mitigations for Spectre/Meltdown
 ECHO  /D,  /DISABLE ... Same as /U and /UNDO
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 /UNDO
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
   