@REM - ASB (18 May 2016 // 16 Oct 2023 / 30 Nov 2020 / 26 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 28 Oct 2018 / 26 Jul 2018 / 30 Apr 2018): Archive and Refresh the WindowsUpdate.Log for Diagnostics
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.6.0.060

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Archive and Refresh the WindowsUpdate.Log for Diagnostics
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Standard Log Variables
 SET @LOGPATH=%@STORAGE%\Logs\Archiving
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%
 SET @ARCHIVE=%@ZIPPATH%\WindowsUpdateLog.%@ZIPSTAMP%
 SET @WINUPDATELOG=%SystemRoot%\WindowsUpdate.LOG


 rem -- Archive and Refresh the WindowsUpdate.Log for Diagnostics
:ArchiveLog
 FOR %%V IN ("%@ZIPPATH%" "%@LOGPATH%") DO IF NOT EXIST "%%~V" MD "%%~V"

 IF EXIST "%@WINUPDATELOG%" ( rem -- Write to Log
 	 ECHO *** STOPPING WINDOWS UPDATE SERVICE ***
 	 FOR %%S IN ("AUTOMATIC UPDATES" "WINDOWS UPDATE") DO NET STOP "%%~S"
 	 ECHO:

 	 ECHO *** OPENING CURRENT UPDATE LOG ***
 	 START "WINDOWS UPDATE LOG" "%@WINUPDATELOG%"
 	 ECHO:

 	 ECHO *** ARCHIVING CURRENT UPDATE LOG ***
 	 NOW Archiving Current Windows Update Logfile...
 	 ECHO:
	 DIR %@WINUPDATELOG%
	 ECHO:
	 ZIP -m -9 -v -dgds 1m -T "%@ARCHIVE%" "%@WINUPDATELOG%"
 	 ECHO:

	 IF EXIST "%@ARCHIVE%" (
		 ECHO *** CLEARING OLD UPDATE LOG ***
		 NOW Manually Archived... >"%@WINUPDATELOG%"
		 ECHO:
		 DIR %@WINUPDATELOG%
		 ECHO:
	 )

 	 ECHO *** RESTARTING WINDOWS UPDATE SERVICE ***
 	 FOR %%S IN ("AUTOMATIC UPDATES" "WINDOWS UPDATE") DO NET START "%%~S"
 	 ECHO:
 ) | TEE -a "%@LOGFILE%"
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                 