@REM - ASB (29 Dec 2013 // 16 Oct 2023 / 05 Mar 2021 / 30 Nov 2020 / 03 Feb 2020 / 24 Dec 2019 / 30 Sep 2019 / 18 Feb 2019 / 25 Oct 2018 / 26 Jul 2018 / 14 May 2018): Generate List of Windows Computers from AD and Obtain IP Addresses
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.1.0.310

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @DOMAINNAME=%*& IF "%~1"=="" SET @DOMAINNAME=%USERDNSDOMAIN%
 SET @BASEDN=& CALL :GetDomainName %@DOMAINNAME%
 SET @RESOLVE=%~dp0..\Utils\Resolve.EXE
 SET @xPARAMS=-nodn -s SUB -maxe 5000 -nocsvheader -csv attr name operatingSystem description -excldn "OBSOLETE;RETIRED;DECOMMISSIONED"
 SET @ADQUERY=ADFind %@BASEDN% -f "(&(objectcategory=computer)(operatingSystem=Windows*))" %@xPARAMS%
 SET @NOIP={No-IP-Found}
 SET @L_TOTAL=0
 SET @D_TOTAL=0
 SET @TOTAL=0

 rem -- Search-Related Variables
 SET @FILTER=%~2
 SET @WHICHSYS=where Name OR Desc Contains: "%~2"
 SET @FSUMMARY=FILTERED
 IF "%~2"=="" (
	 SET @FILTER=.
	 SET @WHICHSYS=[ALL SYSTEMS]
	 SET @FSUMMARY=UNFILTERED
 )

 rem -- Standard Log Variables
 SET @LIVELOG=%TEMP%\%~n0-L.%@FILESTAMP_R%
 SET @DEADLOG=%@LIVELOG:-L=-D%


 rem -- Get Computer Names and Editions from Active Directory
:GetComputerInfo
 ECHO Search Domain: %@DOMAINNAME% [%@BASEDN:~3,999%] %@WHICHSYS%
 ECHO %@DIVIDER-%
 FOR /F "TOKENS=1-2* DELIMS=," %%S IN ('%@ADQUERY% ^| FINDSTR /I /R "%@FILTER%"') DO (
	 SET @SERVER=%%~S!@SPACES!
	 SET @SERVER=!@SERVER:~0,20!
	 SET @IPAnswer=%@NOIP%	!@SERVER!
	 SET @WINVER=%%~T!@SPACES!
	 SET @WINVER=!@WINVER:~0,40!
	 SET @DESC=%%~U& IF "%%~U"=="attr" SET @DESC=[none]
	 SET @DESC=!@DESC:^&=+!
	 SET @OS=@@@@%%~T
	 SET @OS=!@OS: =@!
	 SET /A !@OS!+=1
	 SET /A @TOTAL+=1
	 IF EXIST "%@RESOLVE%" (
		 FOR /F "TOKENS=1" %%I IN ('%@RESOLVE% %%~S ^| FIND /V "ERROR:"') DO SET @IPAnswer=%%I	!@SERVER!
	 ) ELSE (
		 FOR /F "TOKENS=2-3 DELIMS=[] " %%I IN ('PING -n 1 %%~S ^| FIND "["') DO SET @IPAnswer=%%J	%%I
	 )
	 ECHO !@IPAnswer!	!@WINVER! !@DESC!
	 ECHO !@IPAnswer!	!@WINVER!         | FIND    "%@NOIP%" >>"%@DEADLOG%"
	 ECHO !@IPAnswer!	!@WINVER!         | FIND /V "%@NOIP%" >>"%@LIVELOG%"
 )
 ECHO %@DIVIDER-%
 FOR /F "TOKENS=1-2 DELIMS==" %%V IN ('SET @@@@ 2^>NUL') DO (
	 SET @COUNT=     %%W
	 SET @OS=%%V
	 ECHO !@COUNT:~-6! each !@OS:@= !
 )
 ECHO %@DIVIDER*%
 ECHO 		TOTAL SYSTEMS = !@TOTAL!	[%@FSUMMARY%]
 ECHO %@DIVIDER*%


 rem -- Consolidate List of Live Systems (with IP Address)
:LiveSystems
 IF EXIST "%@LIVELOG%" (
	 ECHO:
	 ECHO:
	 ECHO LIST OF LIVE SYSTEMS (with current IP Addresses^)
	 ECHO %@DIVIDER-%
	 TYPE "%@LIVELOG%" | SORT
	 FOR /F "TOKENS=2*" %%S IN ('TYPE "%@LIVELOG%"') DO (
		 SET @OS=____%%~T
		 SET @OS=!@OS: =_!
		 SET /A !@OS!+=1
		 SET /A @L_TOTAL+=1
	 )
	 ECHO %@DIVIDER-%
	 FOR /F "TOKENS=1-2 DELIMS==" %%V IN ('SET ____ 2^>NUL') DO (
		 SET @COUNT=     %%W
		 SET @OS=%%V
		 ECHO !@COUNT:~-6! each !@OS:_= !
	 )
	 ECHO %@DIVIDER*%
	 ECHO 		TOTAL LIVE SYSTEMS = !@L_TOTAL!	[%@FSUMMARY%]
	 ECHO %@DIVIDER*%
 )


 rem -- Consolidate List of Dead Systems (without IP Address)
:DeadSystems
 IF EXIST "%@DEADLOG%" (
	 ECHO:
	 ECHO:
	 ECHO LIST OF DEAD SYSTEMS (without IP Addresses^)
	 ECHO %@DIVIDER-%
	 TYPE "%@DEADLOG%" | SORT /+41
	 FOR /F "TOKENS=2*" %%S IN ('TYPE "%@DEADLOG%"') DO (
		 SET @OS=$$$$%%~T
		 SET @OS=!@OS: =$!
		 SET /A !@OS!+=1
		 SET /A @D_TOTAL+=1
	 )
	 ECHO %@DIVIDER-%
	 FOR /F "TOKENS=1-2 DELIMS==" %%V IN ('SET $$$$ 2^>NUL') DO (
		 SET @COUNT=     %%W
		 SET @OS=%%V
		 ECHO !@COUNT:~-6! each !@OS:$= !
	 )
	 ECHO %@DIVIDER*%
	 ECHO 		TOTAL DEAD SYSTEMS = !@D_TOTAL!	[%@FSUMMARY%]
	 ECHO %@DIVIDER*%
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 FOR %%V IN ("%@LIVELOG%" "%@DEADLOG%") DO IF EXIST "%%~V" DEL "%%~V"
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Get Active Directory Domain Name If Provided
:GetDomainName
 rem %1 = Domain Name Input

 SET #DOMAIN=%~1& IF "%~1"=="" SET #DOMAIN=%USERDNSDOMAIN%
 SET #DOMAIN=!#DOMAIN: =!
 SET #DOMAIN=!#DOMAIN:,=.!
 SET #DOMAIN=!#DOMAIN:dc=!
 SET @DOMAIN=& FOR %%D IN (!#DOMAIN!) DO SET @DOMAIN=!@DOMAIN!%%D
 SET #DOMAIN=
 SET @BASEDN=

 FOR /F "TOKENS=1-5 DELIMS=.= " %%D IN ('ECHO !@DOMAIN!') DO (
	 FOR %%z IN ("%%~D" "%%~E" "%%~F" "%%~G" "%%~H") DO IF NOT "%%~z"=="" SET @BASEDN=!@BASEDN!,DC=%%~z
 )

 SET @BASEDN=-b "!@BASEDN:~1,999!"
 SET @DOMAINNAME=!@DOMAIN!
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Generate List of Windows Computers from AD and Obtain IP Addresses...
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [Fully Qualified AD domain name] [search_for]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 mydomain.local
	 ECHO  %~n0 thisdomain.home "NY"
	 ECHO  %~n0 thatdomain.com
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
                