@REM - ASB (11 Oct 2005 // 16 Oct 2023 / 30 Nov 2020 / 26 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 28 Oct 2018 / 30 Apr 2018 / 27 Mar 2016 / 05 May 2015): Get Event Log Info From Remote System
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.11.0.210

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

rem -- Main Variables
 SET @CONNECT=%~1
 SET @CONNECT=\\%@CONNECT:\=%
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%
 SET @CHECKLOG=PSLOGLIST %@CONNECT% -H 36 -S SECURITY %@PSACCEPT%


 rem - Create Logfile
:Main
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"
 ( rem -- Write to Log
	 ECHO Get EventLog Info - %DATE% %TIME%
	 ECHO %@DIVIDER-%
	 ECHO:
 ) >>"%@LOGFILE%"


 rem - Get Time-Related Info About The Remote System
:GetTime
 ( rem -- Write to Log
	 ECHO Getting Local and Remote Time Info on %@CONNECT% >CON
	 NET TIME %@CONNECT% | FIND /I "local time"
	 NET TIME %@CONNECT% | FIND /I "current time"
 ) >>"%@LOGFILE%" 2>&1


 rem - Get Other System-Related Info About The Remote System
:GetInfo
 ( rem -- Write to Log
	 ECHO:
	 ECHO Getting Service Info on %@CONNECT%
	 ECHO:
	 ECHO %@DIVIDER-%
	 PSINFO %@CONNECT% | FIND ":"
	 ECHO:
	 UPTIME /P:7 %@CONNECT%
	 ECHO:
	 FOR /F "TOKENS=5* DELIMS=," %%S IN ('%@CHECKLOG% ^| FINDSTR "failed failure"') DO ECHO %%S %%T
 ) >>"%@LOGFILE%" 2>&1


 rem - Close Out Logfile
:FinalReport
 ( rem -- Write to Log
	 ECHO:
	 ECHO %@DIVIDER-%
	 ECHO --- FINISHED GETTING REMOTE EVENTS on %@TIMESTAMP%
	 ECHO %@DIVIDER-%
	 ECHO:
 ) >>"%@LOGFILE%"


 rem -- Generate Final Job Report
:FinalReport
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%" & "%@LOGFILE%"


 rem - Reset Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                  