@REM - ASB (18 May 2006 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 30 Apr 2018 / 27 Mar 2016 / 05 May 2015): Determine The Logon Script Location of Current User
@ECHO OFF
 CLS

 :::  This script will have problems running in a RUNAS session, because
 :::  while the %USERNAME% variable will properly reflect the RUNAS user,
 :::  the "NET USER /DOMAIN" command will reference the actual domain of
 :::  the user logged on to the actual console.   Shouldn't cause any
 :::  problems for the intended user community, though.
 :::
 :::  NOTE: This will only work with NT4-style logon scripts.  Group Policy
 :::        logon script information is stored in a different way.


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.8.0.180

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @DOMAIN_MSG=The request will be processed at a domain controller for
 SET @SCRIPT_MSG=Logon script


 rem -- Get Local and Domain User Information
:GetUserInfo
 FOR /F "TOKENS=11*" %%C IN ('NET USER "%USERNAME%" /DOMAIN ^| FIND "%@DOMAIN_MSG%"') DO SET @DOMAIN=%%D
 FOR /F "TOKENS=2*"  %%R IN ('NET USER "%USERNAME%" /DOMAIN ^| FIND "%@SCRIPT_MSG%"') DO SET @SCRIPT=%%S
 IF "%@DOMAIN%"=="" SET @DOMAIN=Logged On Locally
 IF "%@SCRIPT%"=="" SET @SCRIPT=No LogonScript Assigned


 rem -- Execute the Logon Script
:CallLogonScript
 ECHO %@DIVIDER-%
 ECHO Running Logon Script for %USERNAME%
 ECHO  Logon Domain ...: %@DOMAIN%
 ECHO  Logon Script ...: %@SCRIPT%
 ECHO %@DIVIDER-%
 ECHO:
 IF EXIST "%@SCRIPT%" CALL "%@SCRIPT%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                            