@REM - ASB (02 Feb 2020 // 16 Oct 2023 / 30 Nov 2020 / 26 May 2020 / 02 Feb 2020): Get Current WSUSSCN2.CAB file for Checking Patch Status
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.2.0.040

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Verify that CURL Exists, Or Exit
 SET @CURL=& FOR /F %%V IN ('WHERE CURL 2^>NUL') DO SET @CURL=TRUE
 IF NOT DEFINED @CURL (
	 ECHO:
	 ECHO *** ERROR: We are unable to download the updated WSUS CAB file ***
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @WSUS_CAB_DIR=%@STORAGE%\Patches
 SET @GET_ARCHIVE=http://go.microsoft.com/fwlink/p/?LinkID=74689
 SET @SAV_ARCHIVE=%@WSUS_CAB_DIR%\WSUSSCN2.CAB


 rem -- Initiate WSUS CAB Download
:Download
 IF NOT EXIST "%@WSUS_CAB_DIR%" MD "%@WSUS_CAB_DIR%" >NUL
 ECHO --- Attempting to download latest WSUSSCN2.CAB archive.  Please Wait...
 CURL --url "%@GET_ARCHIVE%" --location --output "%@SAV_ARCHIVE%"
 ECHO:


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                      