@REM - ASB (05 Mar 2018 // 16 Oct 2023 / 30 Nov 2020 / 21 Jul 2020 / 05 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 09 Aug 2018 / 14 May 2018 / 29 Apr 2018): Compare Hashing Output and Performance of FSUM vs FILEHASH
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v4.3.0.430

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ? H2 ??" -x "A ALL" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 8  GOTO :HelpMessage
 IF ERRORLEVEL 9 IF NOT ERRORLEVEL 16 (SET @SPECIAL=ALL) ELSE (SET @SPECIAL=)

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Hashing Variables
 SET @FILEHASH_LIST=FILEHASH[2.1] FILEHASH[3.0] FILEHASH[old] FILEHASH[test] FILEHASH64[test] FILEHASH FILEHASH64
 SET @HUTILS_OLD=FSUM FILEHASH[1.0] FILEHASH[2.1]
 SET @HUTILS_ALL=FSUM %@FILEHASH_LIST%
 SET @NO_SHA256=FILEHASH[1.0]
 SET @NO_SHA384=FILEHASH[1.0] FILEHASH[2.1]
 SET @NO_SHA512=FILEHASH[1.0] FILEHASH[2.1] FILEHASH[3.0]
 SET @NO_SHA3=%@HUTILS_OLD%
 SET @NO_SHA3_256=%@HUTILS_OLD% FILEHASH[3.0] FILEHASH[old]
 SET @NO_SHA3_384=%@NO_SHA3_256%
 SET @NO_SHA3_512=%@NO_SHA3_256%
 SET @NO_BLAKE2=%@HUTILS_OLD% FILEHASH[3.0] FILEHASH[OLD]
 SET @NO_BLAKE2S=%@NO_BLAKE2%
 SET @NO_BLAKE2B=%@NO_BLAKE2S%
 SET @NO_BLAKE3=%@HUTILS_OLD% FILEHASH[3.0]
 SET @NO_XXHASH64=%@HUTILS_OLD% FILEHASH[3.0]
 SET @NO_MURMURHASH3=%@HUTILS_OLD% FILEHASH[3.0] FILEHASH[OLD]
 SET @NO_MURMURHASH3_x86=%@NO_MURMURHASH3%
 SET @NO_MURMURHASH3_x64=%@NO_MURMURHASH3_x86%

 rem -- Main Variables
 SET @FOLDER=%~d0\Temp
 SET @BASIC_OPTIONS=XXHASH64 MURMURHASH3 MURMURHASH3_x64 MURMURHASH3_x86 MD5 SHA1 BLAKE2 BLAKE2B BLAKE2S BLAKE3 SHA256 SHA384 SHA512 SHA3 SHA3_256 SHA3_384 SHA3_512 %@SPECIAL%
 SET @GROUP_OPTIONS=-MD5 -SHA1 -SHA256 -SHA384 -SHA512
 SET @MORE_FILES=%~1& CALL :SanitizeParam @MORE_FILES
 SET @FH_OPTIONS=%~2& CALL :SanitizeParam @FH_OPTIONS
 SET @SORT_18=XXHASH64
 SET @SORT_34=MD5 MURMURHASH3 MURMURHASH3_x86 MURMURHASH3_x64
 SET @SORT_42=SHA1
 SET @SORT_66=SHA2 SHA3 SHA256 SHA2_256 SHA3_256 BLAKE2S BLAKE3
 SET @SORT_98=SHA384 SHA2_384 SHA3_384
 SET @SORT_130=SHA512 SHA2_512 SHA3_512 BLAKE2 BLAKE2B
 FOR %%S IN (18 34 42 66 98 130) DO CALL :SetSortPosition %%S

 rem -- Log File Variables
 SET @LOGROOT=HashTest\%@DIRSTAMP_R%
 SET @LOGDIR=%@FOLDER%\%@LOGROOT%& IF NOT EXIST "!@LOGDIR!" MD "!@LOGDIR!" >NUL
 SET @STATS=%@LOGDIR%\#FILEHASH-STATS.TXT
 SET @SUMMARY=%@LOGDIR%\%~n0-SUMMARY.TXT
 FOR %%L IN (%@HUTILS_ALL% "FILEHASH64[slow]") DO SET @%%~L-HASHLOG=%@LOGDIR%\%%~L-HASHLOG.TXT

 rem -- File Inclusion / Exclusion Variables
 SET @EXCLUDE[default]="%~d0\Scripts\Bat\Input\[CopyExemption-Plus].TXT"
 SET @EXCLUDE="%@LOGDIR%\#SKIPFILES.TXT"
 SET @FIND=FINDSTR /V /I /L /G:%@EXCLUDE%
 SET @SEARCHFOR=*.exe a*.* %@MORE_FILES%

 rem -- Add Hashing Utilities to PATH
 SET @DEVPOINT="%SystemDrive%\Cloud\CS.Personal\Development\[Code Signing]"
 SET @HASHPATH=%~d0\Scripts\Utils;%~d0\Scripts\Utils\x64;%~d0\Scripts\Utils\Misc;%~d0\Scripts\Hash;%@DEVPOINT%
 PATH %@HASHPATH%;%PATH%

 rem -- Determine Existence/Location/Version of Hashing Utilities
 FOR %%F IN (%@HUTILS_ALL%) DO (
	 SET @%%F$=
	 FOR %%P IN (%@HASHPATH%) DO IF EXIST "%%~P\%%F.EXE" (
		 SET @%%F$=%%~P\%%~F.EXE
		 CALL :GetVersionInfo "%%~P\%%~F.EXE" @%%F$_VER @%%F$_TYPE
	 )
 )


 rem -- Initialize Hash Processing
:InitializeProcessing
 ECHO HASHING STARTED... (PLEASE WAIT) & ECHO:
 ECHO  !TIME: =0! - Generating Hashing Exemption File...
 (TYPE %@EXCLUDE[default]% & ECHO %@LOGROOT%) >%@EXCLUDE%
 (ECHO Generated on %@TODAY% at !TIME: =0! using %@VER%& ECHO:& TYPE %@EXCLUDE%& MAKESTRING * 80& ECHO:) >%@SUMMARY%


 rem -- Use FSUM w/Secondary Filtering
:Main-FSUM-Secondary
 CALL :SetLogVars FSUM

 rem -- Log Tests if Utility Exists
 IF DEFINED @H_VAR (
	 CALL :SaveSyntax !@H_UTIL!
	 FOR %%A IN (!@OPTIONS!) DO (
		 IF /I "%%~A"=="ALL" (SET @HASHOPT=!@OPT_ALL!) ELSE (SET @HASHOPT=-%%A)
		 SET @CMD=!@H_UTIL! !@HASHOPT! -jnc -r -d"%@FOLDER%" %@SEARCHFOR%
		 CALL :DisplayHeader %%~A
		 !@CMD! >"!@OUTPUT!.TEMP" 2>NUL
		 CALL :ProcessFilteredResults "!@OUTPUT!.TEMP" "!@OUTPUT!.%%A" "%%~A"
	 )
	 CALL :ShowTimings
 ) >"!@OUTPUT!" 2>&1


 rem -- Use FileHash64 w/Secondary Filtering
:Main-FileHash64-Secondary
 CALL :SetLogVars FILEHASH64 [SLOW]

 rem -- Log Tests if Utility Exists
 IF DEFINED @H_VAR (
	 CALL :SaveSyntax !@H_UTIL! "-h -v"
	 FOR %%A IN (!@OPTIONS!) DO (
		 IF /I "%%~A"=="ALL" (SET @HASHOPT=!@OPT_ALL!) ELSE (SET @HASHOPT=-%%A)
		 SET @CMD=!@H_UTIL! !@HASHOPT! %@FH_OPTIONS% -fsum -c -r -d "%@FOLDER%" %@SEARCHFOR%
		 CALL :DisplayHeader %%~A
		 !@CMD! >"!@OUTPUT!.TEMP" 2>NUL
		 CALL :ProcessFilteredResults "!@OUTPUT!.TEMP" "!@OUTPUT!.%%A" "%%~A"
	 )
	 CALL :ShowTimings
 ) >"!@OUTPUT!" 2>&1


 rem -- Loop Through Current FileHash Versions w/Native Filtering
:IterateFileHashVersions
 FOR %%F IN (%@FILEHASH_LIST%) DO (
	 CALL :SetLogVars %%~F

	 rem -- Log Tests if Utility Exists
	 IF DEFINED !@H_VAR! (
		 CALL :SaveSyntax !@H_UTIL! "-h -v"
		 FOR %%A IN (!@OPTIONS!) DO (
			 IF /I "%%~A"=="ALL" (SET @HASHOPT=!@OPT_ALL!) ELSE (SET @HASHOPT=-%%A)

			 rem -- Special Conditional Variables due to changes in v4.0
			 IF "!@H_VER!" GEQ "4.0.0.800" (SET @SHA3_SORT=66) ELSE (SET @SHA3_SORT=98)
			 IF /I "!@H_TYPE!"=="64-bit" (SET @BLAKE2_SORT=130) ELSE (SET @BLAKE2_SORT=66)

			 IF /I "%%~F"=="FileHash[2.1]" (
				 SET @CMD=!@H_UTIL! !@HASHOPT! %@FH_OPTIONS% -fsum -c -exc %@EXCLUDE% -r -d "%@FOLDER%" %@SEARCHFOR%
			 ) ELSE (
				 SET @CMD=!@H_UTIL! !@HASHOPT! %@FH_OPTIONS% -fsum -exc %@EXCLUDE% -u "%@STATS%" -out "!@OUTPUT!.%%A" -r -d "%@FOLDER%" %@SEARCHFOR%
			 )
			 CALL :DisplayHeader %%~A
			 !@CMD!
			 IF /I "%%~F"=="FileHash[2.1]" (
				 CALL :ProcessNativeResults "!@OUTPUT!.%%A" "%%~A"
			 ) ELSE (
				 CALL :ProcessNativeResults "!@OUTPUT!.%%A" "%%~A" "%@STATS%"
			 )
		 )
		 CALL :ShowTimings Native
	 ) >"!@OUTPUT!" 2>&1
 )


 rem -- Generate Final Report
:FinalReport
 ECHO:
 ECHO Copying Final Reports to "%@FOLDER%"
 XCOPY "%@LOGDIR%\*.*" "%@FOLDER%" /R /Y >>"%@SUMMARY%"
 TYPE "%@SUMMARY%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Display Header Info for Hash Processing
:DisplayHeader
 rem %1 = Which Hash

 IF "%~1"=="" GOTO :EOF
 SET @START-%~1=!TIME: =0!
 SET @MSG=!@START-%~1! - Generating %~1 hashes %@DOTS:~-15%
 SET @BANNER=!@CMD:%@H_UTIL%=%@H_NAME%!
 SET @BANNER=!@BANNER:%@LOGDIR%\=!
 SET @BANNER=!@BANNER:"=`!
 ECHO:
 FOR %%V IN (1 2 3) DO ECHO ~~~ %~1 %@DIVIDER~%
 ECHO  !@MSG:~0,50! !@BANNER:~0,64! >CON
 ECHO  !@MSG:~0,50! %@BANNER:`="%
 GOTO :EOF


 rem -- SUBROUTINE: Process Manually Filtered Hash Results File[s] and Print Summary Counts
:ProcessFilteredResults
 rem %1 = Current Logfile
 rem %2 = New, Filtered Logfile
 rem %3 = Which Hash
 rem %4 = Stats Summary File

 SET @FILTER-%~3=!TIME: =0!
 SET @ALLFILES=0
 SET @SUCCESS=0
 SET @ERRORS=0
 IF NOT EXIST "%~1" GOTO :EOF
 IF "%~3"=="" GOTO :EOF
 FOR /F "TOKENS=1" %%C IN ('TYPE "%~1" ^| FIND "*" /C') DO SET @ALLFILES=%%C
 %@FIND% "%~1" >"%~2"
 SET @END-%~3=!TIME: =0!
 IF DEFINED @%~3_SORT (SORT /+!@%~3_SORT! "%~2") ELSE (TYPE "%~2")
 FOR /F "TOKENS=1" %%C IN ('TYPE "%~2" ^| FIND /V "**" ^| FIND "*" /C') DO SET @SUCCESS=%%C
 FOR /F "TOKENS=1" %%C IN ('TYPE "%~2" ^| FIND "**" /C') DO SET @ERRORS=%%C
 ECHO Success = !@SUCCESS!   Unfiltered = !@ALLFILES!   Error = !@ERRORS!
 FOR %%E IN ("%~1" "%~2") DO IF EXIST "%%~E" DEL "%%~E"
 IF EXIST "%~4" TYPE "%~4"
 GOTO :EOF


 rem -- SUBROUTINE: Process Natively Filtered Hash Results File[s] and Print Summary Counts
:ProcessNativeResults
 rem %1 = Current Logfile
 rem %2 = Which Hash
 rem %3 = Stats Summary File

 SET @END-%~2=!TIME: =0!
 IF NOT EXIST "%~1" GOTO :EOF
 IF "%~2"=="" GOTO :EOF
 IF DEFINED @%~2_SORT (SORT /+!@%~2_SORT! "%~1") ELSE (TYPE "%~1")
 FOR %%E IN ("%~1" "%~2") DO IF EXIST "%%~E" DEL "%%~E"
 IF EXIST "%~3" TYPE "%~3"
 GOTO :EOF


 rem -- SUBROUTINE: Sanitize Parameters
:SanitizeParam
 rem %1 = Current Parameter Variable to be Sanitized

 IF NOT DEFINED %~1 GOTO :EOF
 SET @PARAM=!%~1!
 SET @PARAM=!@PARAM:'="!
 SET %~1=!@PARAM!
 GOTO :EOF


 rem -- SUBROUTINE: Save Syntax Log
:SaveSyntax
 rem %1 = FileName Variable
 rem %2 = Parameters, If Necessary

 DATEINFO -Q -S -F "yyyy-mm-dd @ hh:mm:ss"
 IF DEFINED #%1 GOTO :EOF

 ( rem -- Write to Log
	 ECHO GENERATING LOG FOR: "!%~1!" %~2
	 "!%~1!" %~2
	 MAKESTRING = 80
	 ECHO:
 ) >>"%@SUMMARY%" 2>&1

 SET #%1=DONE
 GOTO :EOF


 rem -- SUBROUTINE: Remove Unsupported Hashes from Current Options
:RemoveUnsupportedHashes
 rem %1 = Name of Utility to Validate

 SET @OPTIONS=%@BASIC_OPTIONS%
 SET @OPT_ALL=%@GROUP_OPTIONS%
 FOR %%U IN (%@NO_SHA3_256%) DO        IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:SHA3_256=!
 FOR %%U IN (%@NO_SHA3_384%) DO        IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:SHA3_384=!
 FOR %%U IN (%@NO_SHA3_512%) DO        IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:SHA3_512=!
 FOR %%U IN (%@NO_SHA3%) DO            IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:SHA3 = !
 FOR %%U IN (%@NO_SHA256%) DO          IF /I "%%~U"=="%~1" (SET @OPTIONS=!@OPTIONS:SHA256=!& SET @OPT_ALL=!@OPT_ALL:-SHA256=!)
 FOR %%U IN (%@NO_SHA384%) DO          IF /I "%%~U"=="%~1" (SET @OPTIONS=!@OPTIONS:SHA384=!& SET @OPT_ALL=!@OPT_ALL:-SHA384=!)
 FOR %%U IN (%@NO_SHA512%) DO          IF /I "%%~U"=="%~1" (SET @OPTIONS=!@OPTIONS:SHA512=!& SET @OPT_ALL=!@OPT_ALL:-SHA512=!)
 FOR %%U IN (%@NO_BLAKE2S%) DO         IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:BLAKE2S=!
 FOR %%U IN (%@NO_BLAKE2B%) DO         IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:BLAKE2B=!
 FOR %%U IN (%@NO_BLAKE2%) DO          IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:BLAKE2=!
 FOR %%U IN (%@NO_BLAKE3%) DO          IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:BLAKE3=!
 FOR %%U IN (%@NO_XXHASH64%) DO        IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:XXHASH64=!
 FOR %%U IN (%@NO_MURMURHASH3_x86%) DO IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:MURMURHASH3_x86=!
 FOR %%U IN (%@NO_MURMURHASH3_x64%) DO IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:MURMURHASH3_x64=!
 FOR %%U IN (%@NO_MURMURHASH3%) DO     IF /I "%%~U"=="%~1"  SET @OPTIONS=!@OPTIONS:MURMURHASH3=!
 GOTO :EOF


 rem -- SUBROUTINE: Set Variables for Output Logs
:SetLogVars
 rem %1 = Name of Current Utility
 rem %2 = Optional Modifier, If Non-Blank

 SET @H_VAR=@%~1$
 SET @H_VER=@%~1$_VER
 SET @H_TYPE=@%~1$_TYPE
 SET @H_NAME=%~1%~2
 SET @H_UTIL="!@%~1$!"
 SET @OUTPUT=!@%~1%~2-HASHLOG!

 CALL :RemoveUnsupportedHashes %~1
 ECHO %@DIVIDER-%
 GOTO :EOF


 rem -- SUBROUTINE: Set Sort Position Variables
:SetSortPosition
 rem %1 = Sort Position

 FOR %%s IN (!@SORT_%~1!) DO SET @%%~s_SORT=%~1
 GOTO :EOF


 rem -- SUBROUTINE: Get Utility Version and Bittedness (x64 vs x86)
:GetVersionInfo
 rem %1 = Utility to Obtain Info From
 rem %2 = Variable to Store Version Info
 rem %3 = Variable to Store 32-bit/64-bit Info

 FOR /F "TOKENS=*" %%U IN ('PRINTFILEINFO "%~1" /F /Q 2^>NUL') DO SET %~1=%%~U
 FOR /F "TOKENS=4 DELIMS=: " %%U IN ('PRINTFILEINFO "%~1" /Q 2^>NUL ^| FIND /I "Product Type"') DO SET %~2=%%~U
 GOTO :EOF


 rem -- SUBROUTINE: Display Job Timings
:ShowTimings
 rem %1 = If Blank then Full Timings

 SET @CR=
 ECHO:
 ECHO %@DIVIDER#%
 FOR %%A IN (%@OPTIONS%) DO (
	 IF "%~1"=="" (
		 SET @CR=\n\-
		 DATEINFO -t "!@START-%%A!"  -n "!@FILTER-%%A!" -o "\v = Duration for %%A hashing..."
		 DATEINFO -t "!@FILTER-%%A!" -n "!@END-%%A!"    -o "\v = Duration for %%A filtering..."
	 )
	 DATEINFO -t "!@START-%%A!"  -n "!@END-%%A!"    -o "\v = Duration for %%A processing...!@CR!"
 )
 ECHO %@DIVIDER#%
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Compare Hashing Output and Performance of FSUM vs FILEHASH
 ECHO:
 ECHO    YOU TYPED: %0 %*
 ECHO:
 ECHO   CMD SYNTAX: %~n0  ["additional_wildcards"] ["additional_FILEHASH_options"] [/ALL]
 ECHO               %~n0  [-h^|-?]
 ECHO:
 ECHO  DEFINITIONS:
 ECHO  -?,  /H .... Display This Help Message  (also --HELP)
 ECHO  -A,  /ALL .. Generate ALL Hashes at once [MD5, SHA1, SHA256 and SHA512]
 ECHO:
 ECHO  USAGE NOTES:
 ECHO  * Parameters surrounded by ^<^> are mandatory.
 ECHO  * Parameters surrounded by [] are optional.
 ECHO:
 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 ECHO:
 ECHO  * If you have more than one wildcard, surround them all in doublequotes
 ECHO  * Use the ' character if you need doublequotes in your parameters
 CALL :ShowStatus "FINISHED"
                                  