@ECHO OFF
 rem ==========================================================================
 rem === Create Home Folders Based on NET USER Info (NT4/2000)
 rem ==========================================================================
 rem
 rem Created On: 30 May 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 27 Mar 2003
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: NT4 or later
 rem
 rem  Non-Native Utilities Required: NONE
 rem ==========================================================================

 :::  This script uses the results from a "NET USER /DOMAIN" to
 :::  generate Home Folders under the selected directory. You
 :::  can run "HomePerms.BAT" to set the appropriate permissions.
 :::  In the FOR command, you need to skip 4 lines if you are
 :::  looking AT the local SAM database, but you must skip 6 lines
 :::  if you are looking AT a domain SAM database.
 :::
 :::  This script supports UNC to allow it to operate remotely,
 :::  making it a bad candidate for creating individual shares
 :::  (which you can get with HomeShares.BAT).  As written, the
 :::  Home Directory root directory must exist prior to the
 :::  execution of the script.
 :::
 :::  Folder names containing spaces should be entered AT the
 :::  command line with a '+' character in place of each space.
 :::  They will be converted back to a spaces in the script. It
 :::  could be modified to create a share for each user, rather
 :::  than relying on the default directory access.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 06 Sep 2001
 rem ==========================================================================
:NeedHelp
 IF "%~1"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 23 Aug 2001
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @HOME=%1
 SET @HOME=%@HOME:+= %


 rem ==========================================================================
 rem === Create Home Folders
 rem === Last Modified On 27 Mar 2003
 rem ==========================================================================
:MakeFolders
 IF NOT EXIST "%@HOME%" (
   ECHO The folder "%@HOME%" does not exist.
   ECHO:
   GOTO :EOF
 )

 FOR /F "TOKENS=1-3 SKIP=4" %%F IN ('NET USER /DOMAIN') DO (
   IF "%%F"=="The" GOTO :EOF
   IF /I NOT "%%F"=="" MD "%@HOME%\%%F" 2>NUL
   IF /I NOT "%%G"=="" MD "%@HOME%\%%G" 2>NUL
   IF /I NOT "%%H"=="" MD "%@HOME%\%%H" 2>NUL
 )


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 26 May 2001
 rem ==========================================================================
:ExitBatch
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 12 Oct 2001
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for HOMEDIRS.BAT
 ECHO:
 ECHO === HomeDirs {\\remote_server\share}
 ECHO === HomeDirs {drive:\folder}
 ECHO:
 ECHO Example: HomeDirs \\MyPDC\SomeResource
 ECHO          HomeDirs \\FileServer\SomeDir\OtherResource
 ECHO          HomeDirs "\\Server\Long Dir\Name With Spaces"
 ECHO          HomeDirs "\\Server\ShortDir\SmallName"
 ECHO          HomeDirs C:\MyUsers\HomeDirs
 ECHO          HomeDirs "C:\My Users\Home Directories"
 ECHO          HomeDirs "C:\ShortName\Long Name Folder"
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Folder names containing spaces should
 ECHO       be surrounded by quotation marks.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
