@ECHO OFF
 rem ==========================================================================
 rem === Create Home Folders Based on NET USER Info (Win2K Hidden)
 rem ==========================================================================
 rem
 rem Created On: 30 May 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 06 Dec 2003
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2000 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.ultratech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This script uses the results from a "NET USER /DOMAIN" to
 :::  generate Home Folders under the selected directory. This
 :::  script also sets permissions on the folders such that the
 :::  users will only be able to see their own folder, and not
 :::  anyone else's (that's the goal, but I can't get that to
 :::  work as yet... <g>  I can get all hidden, or none).
 :::
 :::  Thanks to Erik Goldoff and Roger Seielstad for suggestions
 :::  on which permissions to try...  :)
 :::
 :::  In the FOR command, you need to skip 4 lines if you are
 :::  looking AT the local SAM database, but you must skip 6
 :::  lines if you are looking AT a domain SAM database.
 :::
 :::  This script supports UNC to allow it to operate remotely,
 :::  making it a bad candidate for creating individual shares
 :::  (which you can get with HomeShares.BAT).  As written, the
 :::  Home Directory root directory must exist prior to the
 :::  execution of the script.
 :::
 :::  Folder names containing spaces should be entered AT the
 :::  command line surrounded by quotes.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 27 Mar 2003
 rem ==========================================================================
:NeedHelp
 IF "%~3"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 06 Dec 2003
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Calculate Date/Time (Short Procedure - ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=4-6 DELIMS=: " %%T IN ('NOW') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG

 rem -- Standard Variables
 SET @NORMAL="Administrators":F "SYSTEM":F
 SET @HIDDEN="Administrators":F "SYSTEM":F "EVERYONE":X
 SET @EXEMPT=Administrator Guest TsInternetUser ServiceAcct ASPNET krbtgt NetShowServices
 SET @HOME=%~1
 SET @HOMEDRIVE=%2
 SET @HOMEROOT=%~3
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Create Home Folders
 rem === Last Modified On 28 Aug 2001
 rem ==========================================================================
:MakeFolders
 IF NOT EXIST "%@HOME%" (
   ECHO The folder "%@HOME%" does not exist.
   ECHO:
   GOTO :EOF
 )

 FOR /F "TOKENS=1-3 SKIP=4" %%F IN ('NET USER /DOMAIN') DO (
   IF "%%F"=="The" GOTO :SetPerms
   CALL :ConfigUser "%%F"
   CALL :ConfigUser "%%G"
   CALL :ConfigUser "%%H"
 )


 rem ==========================================================================
 rem === Go To Home Directory and Set Permissions For Each Folder
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:SetPerms
 IF NOT EXIST "%@HOME%" (
   ECHO The folder "%@HOME%" does not exist.
   ECHO:
   GOTO :EOF
 )

 PUSHD "%@HOME%"
 XCACLS "%@HOME%" /Y /C /T /G %@HIDDEN%
 FOR /F %%V IN ('DIR /B /AD "%@HOME%"') DO (
   ECHO Setting New Permissions for "%@HOME%\%%V"
   XCACLS "%@HOME%\%%V"     /Y /C    /G "%%V":C %@NORMAL%
   XCACLS "%@HOME%\%%V\*.*" /Y /C /T /G "%%V":C %@NORMAL%
 )
 POPD


 rem ==========================================================================
 rem === Create Log File
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:MakeLog
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 NOW Creating Logfile for Home Directory Creation >"%@LOGFILE%"
 DIR "%@HOME%" /OGD                              >>"%@LOGFILE%"
 XCACLS "%@HOME%" /Y /C /T                       >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 06 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Create User Folder and Change Drive Setting
 rem === Last Modified On 27 Mar 2003
 rem ==========================================================================
:ConfigUser
 rem %1 = Current Username
 SET @TEMPUSER=%1
 SET @TEMPUSER=%@TEMPUSER:~0,4%
 FOR %%U IN (IWAM IUSR) DO IF /I "%@TEMPUSER%"=="%%U_" GOTO :EOF
 FOR %%U IN (%@EXEMPT%) DO IF /I "%1"=="%%U" GOTO :EOF
 IF /I NOT "%1"=="" MD "%@HOME%\%1" 2>NUL
 NET USER "%1" /HOMEDIR:%@HOMEROOT%\%%V
 NET USER "%1" /PROFILEPATH:
 CUSRMGR -u "%1" -H %@HOMEDRIVE%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 27 Mar 2003
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for HOMEDIRS.BAT
 ECHO:
 ECHO === HomeDirs {\\remote_server\share} {HomeDrive} {drive:\folder}
 ECHO:
 ECHO Example: HomeDirs \\MyPDC\SomeResource U  E:\Users
 ECHO          HomeDirs \\FileServer\SomeDir\OtherResource P  D:\Users
 ECHO          HomeDirs "\\Server\Long Dir\Name With Spaces" H  "F:\User Folders"
 ECHO          HomeDirs "\\Server\ShortDir\SmallName" V  "E:\Home\Folders"
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Folder names containing spaces must
 ECHO       be surrounded by quotation marks.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
