@ECHO OFF
 rem ==========================================================================
 rem === Set Permissions On Your Home Directory Folders
 rem ==========================================================================
 rem
 rem Created On: 30 May 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 11 Jan 2007  (Prior Update: 06 Dec 2003)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2000 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This script uses CACLS or XCACLS to set the permissions on each Home
 :::  Directory folder to ADMINISTRATORS:FULL and CHANGE for the user of that
 :::  specific folder (overwriting previously set permissions). The path of
 :::  the Home Directory can be changed in the Variables section.  You can use
 :::  PUSHD/POPD to map the remote directories on the fly, but I generally find
 :::  it safer to use explicit paths when setting permissions.
 :::
 :::  Folder names containing spaces should be entered at the command line
 :::  surrounded by quotation marks. This will only work in Windows 2000 and
 :::  later.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:NeedHelp
 IF /I "%~1"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 11 Jan 2007  (Prior Update: 06 Dec 2003)
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @VER=%~nx0 v2.0.0

 rem -- Calculate Date/Time (Short Procedure - ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=4-6 DELIMS=: " %%T IN ('NOW') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG
 SET @TIMESTAMP=%DATE% at %TIME%

 rem -- Get Official Drive Letters and Calculate Date/Time for NON-US Regions
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Standard Variables
 SET @PERMS="Administrators":F "SYSTEM":F
 SET @HOME=%~1
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Go To Home Directory and Set Permissions For Each Folder
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:SetPerms
 IF /I NOT EXIST "%@HOME%" (
   ECHO The folder "%@HOME%" does not exist.
   ECHO:
   GOTO :EOF
 )

 PUSHD "%@HOME%"
 XCACLS "%@HOME%" /Y /C /G %@PERMS%
 FOR /F %%V IN ('DIR /B /AD "%@HOME%"') DO (
   ECHO Setting New Permissions for "%@HOME%\%%V"
   XCACLS "%@HOME%\%%V\*.*" /Y /C /T /G "%%V":C %@PERMS%
   XCACLS "%@HOME%\%%V"     /Y /C /G    "%%V":C %@PERMS%
 )
 POPD


 rem ==========================================================================
 rem === Create Log File
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:MakeLog
 IF /I NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 NOW Creating Logfile for Home Directory Creation >"%@LOGFILE%"
 DIR "%@HOME%" /OGD                              >>"%@LOGFILE%"
 XCACLS "%@HOME%" /Y /C /T                       >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 06 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 11 Jan 2007  (Prior Update: 15 Mar 2003)
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for %~nx0
 ECHO:
 ECHO === %~n0 {\\remote_server\share}
 ECHO:
 ECHO Example: %~n0 \\MyPDC\SomeResource
 ECHO          %~n0 \\FileServer\SomeDir\OtherResource
 ECHO          %~n0 "\\Server\Long Dir\Name With Spaces"
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Any parameters which contain spaces should be surrounded by quotes.
 ECHO       Shortnames *can* be surrounded by quotes if you choose, but it is
 ECHO       not mandatory by any means.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
