@ECHO OFF
 rem ==========================================================================
 rem === Create Hidden Shares For Your Home Directories
 rem ==========================================================================
 rem
 rem Created On: 26 May 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 11 Jan 2007  (Prior Update: 06 Dec 2003)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2000 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This script uses RMTSHARE to create hidden shares for the purpose of
 :::  Home Directories.  It must be run locally on the machine in question.
 :::  The directory structure will be created if it doesn't already exist.
 :::  The script will create or remove the folders and/or shares based on the
 :::  parameters entered at the command line.  Directory removal and Share
 :::  removal occur before creation, so you can purge the existing directory
 :::  structure before creating a new one.
 :::
 :::  User names which contain a space will cause problems...
 :::
 :::  Folder names containing spaces should be entered AT the command line
 :::  surrounded by quotation marks.  This syntax will only work with Windows
 :::  2000 and later.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 06 Sep 2001
 rem ==========================================================================
:NeedHelp
 IF /I "%~2"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 11 Jan 2007  (Prior Update: 06 Dec 2003)
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @VER=%~nx0 v2.0.0

 rem -- Calculate Date/Time (Short Procedure - ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=4-6 DELIMS=: " %%T IN ('NOW') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG
 SET @TIMESTAMP=%DATE% at %TIME%

 rem -- Get Official Drive Letters and Calculate Date/Time for NON-US Regions
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Standard Variables
 SET @PERMS="Administrators":F
 SET @EXEMPT=Administrator Guest TsInternetUser ServiceAcct ASPNET krbtgt NetShowServices
 SET @HOMEDIR=%~1
 SET @MAKEDIR=FALSE
 SET @KILLDIR=FALSE
 SET @MAKESHARE=TRUE
 SET @KILLSHARE=FALSE
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Process Commandline Parameters
 rem === Last Modified On 28 Aug 2001
 rem ==========================================================================
:Params
 FOR %%P IN (%*) DO IF /I "%%P"=="/CF" SET @MAKEDIR=TRUE
 FOR %%P IN (%*) DO IF /I "%%P"=="/RF" SET @KILLDIR=TRUE
 FOR %%P IN (%*) DO IF /I "%%P"=="/CS" SET @MAKESHARE=TRUE
 FOR %%P IN (%*) DO IF /I "%%P"=="/RS" SET @KILLSHARE=TRUE
 FOR %%P IN (%*) DO IF /I "%%P"=="/H" GOTO :HelpMessage


 rem ==========================================================================
 rem === Remove Home Directory Folders (If Selected Option)
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:RemoveDirs
 IF /I NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 NOW Altering Home Directory Structure... >"%@LOGFILE%"

 IF /I "%@KILLDIR%"=="TRUE" (
   SET @MAKEDIR=FALSE
   ECHO Deleting Home Directory Structure AT "%@HOMEDIR%"...
   RD /S /Q "%@HOMEDIR%" >>"%@LOGFILE%"
   MD "%@HOMEDIR%" 2>>"%@LOGFILE%"
 )


 rem ==========================================================================
 rem === Create Home Directory Structure (If Selected Option)
 rem === Last Modified On 27 Mar 2003
 rem ==========================================================================
:CreateDirs
 IF /I NOT EXIST "%@HOMEDIR%" (
   ECHO The folder "%@HOMEDIR%" does not exist.
   ECHO:
   MD "%@HOMEDIR%" 2>>"%@LOGFILE%"
   SET @MAKEDIR=TRUE
 )

 IF /I "%@MAKEDIR%"=="TRUE" (
   ECHO Creating Home Directory Structure AT "%@HOMEDIR%"...
   ECHO:

   FOR /F "TOKENS=1-3 SKIP=4" %%F IN ('NET USER /DOMAIN') DO (
     IF "%%F"=="The" GOTO :KillShares
     CALL :Sub_CreateDir "%%F"
     CALL :Sub_CreateDir "%%G"
     CALL :Sub_CreateDir "%%H"
   )
 )


 rem ==========================================================================
 rem === Remove Hidden User Shares (If Selected Option)
 rem === Last Modified On 27 Mar 2003
 rem ==========================================================================
:KillShares
 IF /I "%@KILLSHARE%"=="TRUE" (
   SET @MAKESHARE=FALSE
   FOR /F %%V IN ('DIR /B /AD "%@HOMEDIR%"') DO (
     ECHO Removing The Hidden Share for "%@HOMEDIR%\%%V"
     RMTSHARE \\%COMPUTERNAME%\"%%V$" /D >>"%@LOGFILE%"
   )

   FOR /F "TOKENS=1-3 SKIP=4" %%F IN ('NET USER /DOMAIN') DO (
     IF "%%F"=="The" GOTO :MakeShares
     CALL :Sub_RemoveShare "%%F"
     CALL :Sub_RemoveShare "%%G"
     CALL :Sub_RemoveShare "%%H"
   )
 )


 rem ==========================================================================
 rem === Create Hidden User Shares (If Selected Option)
 rem === Last Modified On 28 Aug 2001
 rem ==========================================================================
:MakeShares
 IF /I "%@MAKESHARE%"=="TRUE" (
   FOR /F %%V IN ('DIR /B /AD "%@HOMEDIR%"') DO (
     ECHO Creating A Hidden Share for "%@HOMEDIR%\%%V"
     RMTSHARE \\%COMPUTERNAME%\"%%V$"="%@HOMEDIR%\%%V" /USERS:1 /GRANT %@PERMS% /GRANT "%%V":C >>"%@LOGFILE%"
   )
 )


 rem ==========================================================================
 rem === Display Log File
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:DisplayLog
 DIR "%@HOMEDIR%" /OGD /A  >>"%@LOGFILE%"
 RMTSHARE \\%COMPUTERNAME% >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 06 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Remove Share for User Account
 rem === Last Modified On 27 Mar 2003
 rem ==========================================================================
:Sub_RemoveShare
 rem %1 = Current Username
 SET @TEMPUSER=%1
 SET @TEMPUSER=%@TEMPUSER:~0,4%
 FOR %%U IN (IWAM IUSR) DO IF /I "%@TEMPUSER%"=="%%U_" GOTO :EOF
 FOR %%U IN (%@EXEMPT%) DO IF /I "%1"=="%%U" GOTO :EOF
 IF /I NOT "%1"=="" RMTSHARE \\%COMPUTERNAME%\"%1$" /D >>"%@LOGFILE%"
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Create User Folder and Change Drive Setting
 rem === Last Modified On 27 Mar 2003
 rem ==========================================================================
:Sub_CreateDir
 rem %1 = Current Username
 SET @TEMPUSER=%1
 SET @TEMPUSER=%@TEMPUSER:~0,4%
 FOR %%U IN (IWAM IUSR) DO IF /I "%@TEMPUSER%"=="%%U_" GOTO :EOF
 FOR %%U IN (%@EXEMPT%) DO IF /I "%1"=="%%U" GOTO :EOF
 IF /I NOT "%1"=="" MD "%@HOME%\%1" 2>NUL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 11 Jan 2007  (Prior Update: 28 Aug 2001)
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for %~nx0
 ECHO:
 ECHO === %~n0 {local_path_of_home_directories} {options}
 ECHO:
 ECHO Where OPTIONS are as follows...
 ECHO:
 ECHO === /CF - Create User Folders
 ECHO === /RF - Remove User Folders
 ECHO === /CS - Create Hidden User Shares
 ECHO === /RS - Remove Hidden User Shares
 ECHO:
 ECHO Example: %~n0 D:\HomeFolders /CF
 ECHO          %~n0 E:\Storage\HomeDir /RF /CF
 ECHO          %~n0 "F:\Users\Home Dirs" /RF /RS
 ECHO          %~n0 "G:\Users\Home Directories" /CF
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Any parameters which contain spaces should be surrounded by quotes.
 ECHO       Shortnames *can* be surrounded by quotes if you choose, but it is
 ECHO       not mandatory by any means.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
