@REM - ASB (19 Jan 2024 // 25 Mar 2024 / 21 Mar 2024 / 15 Mar 2024 / 19 Jan 2024): Display WAN IP History from CheckWAN.BAT Output
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.2.0.50

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q
 SET @INPUT=%~dp0Input
 FOR %%V IN (%@ALPHA11#%) DO IF EXIST "%%~V:\Storage\Logs" SET @STORAGE=%%~V:\Storage

 rem -- Determine Which Console Session is Active for the Script
 SET @SERVICE_ACCTS="SYSTEM" "NTAUTHORITY" "Services"
 SET @CONSOLE_SESSION=TRUE& FOR %%u IN (%@SERVICE_ACCTS%) DO IF /I "%USERNAME%"=="%%~u" SET @CONSOLE_SESSION=FALSE
 IF DEFINED @NOPROMPT SET @CONSOLE_SESSION=FALSE

 rem -- Main Variables
 SET @LOGROOT=%@STORAGE%\Logs\CheckWAN
 SET @WAIT=20


 rem -- Determine Correct Server Input List
:DetermineList
 IF "%~1"=="" (
	 SET @FINDLIST="%@LOGROOT%\*.TXT"
 ) ELSE (
	 SET @FINDLIST="%@LOGROOT%\%~n1*.TXT" "%@LOGROOT%\*%~1*.TXT" "%@LOGROOT%\*%~1*"
 )

 FOR %%F IN (%@FINDLIST%) DO IF EXIST "%%~F" IF NOT DEFINED #ASKED_%%~F (
	 SET @SOURCE=%%~F
	 SET #ASKED_%%~F=TRUE
	 IF /I "!@SOURCE:~-4!"==".TXT" (
		 IF /I "%@CONSOLE_SESSION%"=="TRUE" (
			 CHOICE /C AYNQEX /T !@WAIT! /D Y /N /M "Use the following system list? - '!@SOURCE!' "
		 ) ELSE (
			 CHOICE /C Y /T 0 /D Y /N
		 )
	 )
	 IF ERRORLEVEL 4 (GOTO :ExitBatch)
	 IF ERRORLEVEL 2 IF NOT ERRORLEVEL 3 (CALL :ShowWANIPs)
	 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 2 (SET @WAIT=0& CALL :ShowWANIPs)
 )


 rem -- Abort script if no IP list has been provided/accepted
:AbortExecution
 IF DEFINED @SOURCE GOTO :ExitBatch
 ECHO:
 ECHO ERROR: No Valid IP List Was Provided -- Script Execution Aborted...
 ECHO:
 GOTO :HelpMessage


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Display WAN IP History for Selected List
:ShowWANIPs
 TITLE Display WAN IP History
 ECHO:
 ECHO %@DIVIDER-%
 ECHO  Using IP List: "%@SOURCE%"
 ECHO %@DIVIDER-%
 ECHO:
 TYPE %@SOURCE% 
 ECHO %@DIVIDER#%
 ECHO:
 ECHO:
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
	 TITLE Display WAN IP History (%USERDOMAIN%\%USERNAME%)   %@DEBUG_MODE%
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Display WAN IP History from CheckWAN.BAT Output
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [list_of_IP_addresses]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:
 ECHO -------------------
 ECHO CHOICE SELECTIONS:
 ECHO -------------------
 ECHO        Y ..... Select YES to current entry; continue making requests
 ECHO        N ..... Select NO to current entry; continue making requests
 ECHO        X ..... EXIT immediately without processing any requests
 ECHO        Q ..... QUIT immediately without processing any requests (same as X)
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 MyList
	 ECHO  %~n0 E:\IPHistory.TXT
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Long filenames which contain spaces must be surrounded by quotes.
	 ECHO:
	 ECHO  * The filename of the list used for processing must be a short name.
	 ECHO:
	 ECHO  * Alternate IP lists can be specified using their full path.
 )
 CALL :ShowStatus "FINISHED"
                                              