@REM - ASB (28 Jan 2015 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 30 Apr 2018 / 27 Mar 2016 / 05 May 2015): Get IP Information for a Block of IPs
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.6.0.160

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @SOURCE=%~1& IF "%~1"=="" SET @SOURCE=%TEMP%\IPList.TXT
 SET @LOGFILE=%TEMP%\IP-Details.%@FILESTAMP%
 SET @TOTAL=0


 rem -- Check for Existence of Source File
:CheckForFile
 IF EXIST "%@SOURCE%" (
	 FOR /F %%C IN ('TYPE "%@SOURCE%" ^| FIND /C "."') DO SET @SIZE=%%C
 ) ELSE (
	 ECHO:
	 ECHO *** ERROR: Could Not Access "%@SOURCE%"
	 ECHO:
	 GOTO :ExitBatch
 )


 rem -- Get IP Information (Unique Output)
:GetIPInfo
 NOW Obtaining IP Information >"%@LOGFILE%"
 ECHO Obtaining IP Information for the following list of servers...
 ECHO %@DIVIDER-%
 ECHO  INPUT .... %@SOURCE%   [Size: %@SIZE%]
 ECHO  OUTPUT ... %@LOGFILE%
 ECHO %@DIVIDER-%
 ECHO:

 FOR /F "USEBACKQ EOL=; DELIMS=: " %%I IN ("%@SOURCE%") DO (
	 SET /A #%%I+=1
	 IF "!#%%I!"=="1" (
		 SET /A @TOTAL+=1
		 ECHO Searching for: %%~I >CON
		 NOW Searching for: %%~I
		 ECHO %@DIVIDER-:~-60%
		 FOR %%L IN ("RESOLVE" "NSLOOKUP" "WHOSIP") DO (
			 ECHO:
			 ECHO %%~L %%~I
			 %%~L %%~I
		 )
		 ECHO %@DIVIDER-:-=*%
		 ECHO:
		 ECHO:
	 )
 ) >>"%@LOGFILE%" 2>&1

 rem -- Show Summary Count
 ( rem -- Write to Log
	 ECHO SUMMARY: Number of Instances
	 ECHO %@DIVIDER-:~-30%
	 FOR /F "TOKENS=1-2 DELIMS=#=" %%C IN ('SET #') DO (
		 SET @IP=%%C %@DOTS%
		 SET @IP=!@IP:~0,21!
		 ECHO  !@IP! %%D
	 )
	 ECHO %@DIVIDER-:~-30%
	 ECHO  UNIQUE IPs .......... %@TOTAL%
	 ECHO %@DIVIDER-:~-30%
	 ECHO:
 ) >>"%@LOGFILE%" 2>&1

 rem -- Logfile Maintenance
 COPY "%@LOGFILE%" "!@LOGFILE:%@FILESTAMP%=TXT!"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 FOR %%V IN (TYPE DIR) DO %%V "%@LOGFILE%"
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                       