@ECHO OFF
 rem ==========================================================================
 rem === Install EventLog to SysLog Service on remote box (SNARE)
 rem ==========================================================================
 rem
 rem Created On: 26 Sep 2005
 rem         By: Andrew S. Baker (based on a Steven Chase script)
 rem
 rem Updated On: 26 Oct 2005
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: 2000/2003 Servers; 2000/XP/2003 Clients
 rem
 rem  Non-Native Utilities Required:
 rem  	Snare .................. http://www.intersectalliance.com/projects/
 rem  	PSTOOLS ................ http://www.microsoft.com/technet/sysinternals/utilities/PsTools.mspx
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This script installs an EventLog-to-SysLog service (SNARE) to enable the
 :::  consolidation of Event Log information to a centralized SysLog server.
 :::
 :::  It scripts the installation of SNARE, with all the necessary registry
 :::  updates.  This is based on a script by Steven Chase and was tested on
 :::  SNARE v2.4.5
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to "TRUE"
 rem === Last Modified On 25 Oct 2005
 rem ==========================================================================
:DebugMode
 IF /I "%Debug%"=="TRUE" (
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE (
	 SET @PAUSE_IF_DEBUG=
	 SET @END_DEBUG_MODE=
 )


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 29 Sep 2005
 rem ==========================================================================
:NeedHelp
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Set Environment Variables
 rem === Last Modified On 26 Oct 2005
 rem ==========================================================================
:Variables
 SETLOCAL

 rem -- IP Address OR DNS Name for SysLog Server
 SET @SYSLOG=10.1.1.100
 SET @SYSLOG=syslog.mydomain.com

 rem -- Generic Installation Variables
 SET @SOURCE=%~dp0Snare
 SET @SERVER=%~1& IF "%~1"=="" SET @SERVER=%COMPUTERNAME%
 SET @SERVER=%@SERVER:\\=%
 SET @DEST=\\%@SERVER%\ADMIN$\Snare
 SET @SYSLOG=%~2& IF "%~2"=="" SET @SYSLOG=syslog.mydomain.com

 rem -- Snare-Specific Installation Variables
 SET @EVENTLOG=HKLM\SYSTEM\CurrentControlSet\Services\EventLog
 SET @SNAREVER=Snare v2.4.5
 SET @SNAREREG=HKLM\Software\InterSect Alliance\AuditService
 SET @UNINSTALL=HKLM\Software\Microsoft\Windows\CurrentVersion\Uninstall\Snare_is1
 SET @WININFO=HKLM\SOFTWARE\Microsoft\Windows NT\CurrentVersion


 rem ==========================================================================
 rem === Obtain Latest Version of SNARE files
 rem === Last Modified On 29 Sep 2005
 rem ==========================================================================
:CopyFiles
 ECHO:
 ECHO Updating Files and Installing SNARE Service on \\%@SERVER%...
 ECHO:
 NET STOP EVTSYS >NUL 2>&1
 EVTSYS -u       >NUL 2>&1
 XCOPY "%@SOURCE%" "%@DEST%" /C /I /D /F /H /K /Y

 ECHO:
 ECHO Querying the Registry for SystemRoot Info...
 FOR /F "TOKENS=3*" %%I IN ('REG QUERY "\\%@SERVER%\%@WININFO%" /v SystemRoot') DO SET @SYSROOT=%%I
 ECHO System Root on \\%@SERVER% is %@SYSROOT%
 IF "%@SYSROOT%"=="" GOTO :NoRoot


 rem ==========================================================================
 rem === Configure Registry Entries
 rem === Last Modified On 30 Sep 2005
 rem ==========================================================================
:RegModify
 ECHO Modifying the registry...

 rem -- Configure Snare Registry Entries
:ConfigureSnare
 reg add "\\%@SERVER%\%@SNAREREG%\Config" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Config" /v Activate   /t REG_DWORD /d 1   /f
 reg add "\\%@SERVER%\%@SNAREREG%\Config" /v Audit      /t REG_DWORD /d 0   /f
 reg add "\\%@SERVER%\%@SNAREREG%\Config" /v Checksum   /t REG_DWORD /d 0   /f
 reg add "\\%@SERVER%\%@SNAREREG%\Config" /v Clientname /t REG_SZ    /d "%@SERVER%" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Config" /v CritAudit  /t REG_DWORD /d 0   /f
 reg add "\\%@SERVER%\%@SNAREREG%\Config" /v Delimiter  /t REG_SZ    /d "," /f
 reg add "\\%@SERVER%\%@SNAREREG%\Config" /v FileAudit  /t REG_DWORD /d 0   /f
 reg add "\\%@SERVER%\%@SNAREREG%\Config" /v FileExport /t REG_DWORD /d 0   /f

 reg add "\\%@SERVER%\%@SNAREREG%\Network" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Network" /v Destination         /t REG_SZ    /d %@SYSLOG% /f
 reg add "\\%@SERVER%\%@SNAREREG%\Network" /v DestPort            /t REG_DWORD /d 514 /f
 reg add "\\%@SERVER%\%@SNAREREG%\Network" /v Syslog              /t REG_DWORD /d 1   /f
 reg add "\\%@SERVER%\%@SNAREREG%\Network" /v SyslogDest          /t REG_DWORD /d 47  /f
 reg add "\\%@SERVER%\%@SNAREREG%\Network" /v SyslogDynamicCritic /t REG_DWORD /d 0   /f

 reg add "\\%@SERVER%\%@SNAREREG%\Objective" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Objective" /v Objective0 /t REG_SZ /d "1	31	24	*	***	0	*" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Objective" /v Objective1 /t REG_SZ /d "3	31	32	516,517,608,609,610,611,612,613,614,615,616,617,618,620,643	***	0	*" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Objective" /v Objective2 /t REG_SZ /d "1	24	32	512,513	***	0	*" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Objective" /v Objective3 /t REG_SZ /d "2	31	32	624,625,626,627,628,629,630,631,632,633,634,635,636,637,638,639,640,641,642,643,644,645,646,647,648,649,650,651,652,653,654,655,656,657,658,659,660,661,662,663,664,665,666,667,668,669,670	***	0	*" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Objective" /v Objective4 /t REG_SZ /d "0	31	32	592,593,594,595	***	0	*" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Objective" /v Objective5 /t REG_SZ /d "1	31	32	528,529,530,531,532,533,534,535,536,537,538,539,540,541,542,543,544,545,546,547,672,673,674,675,676,677,678,680,681,682,683	***	0	*" /f

 reg add "\\%@SERVER%\%@SNAREREG%\Remote" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Remote" /v AccessKey     /t REG_DWORD /d 1         /f
 reg add "\\%@SERVER%\%@SNAREREG%\Remote" /v AccessKeySet  /t REG_SZ    /d "%@SERVER%" /f
 reg add "\\%@SERVER%\%@SNAREREG%\Remote" /v Allow         /t REG_DWORD /d 0         /f
 reg add "\\%@SERVER%\%@SNAREREG%\Remote" /v Restrict      /t REG_DWORD /d 1         /f
 reg add "\\%@SERVER%\%@SNAREREG%\Remote" /v RestrictIP    /t REG_SZ    /d 127.0.0.1 /f
 reg add "\\%@SERVER%\%@SNAREREG%\Remote" /v WebPort       /t REG_DWORD /d 6161      /f
 reg add "\\%@SERVER%\%@SNAREREG%\Remote" /v WebPortChange /t REG_DWORD /d 1         /f

 reg add "\\%@SERVER%\%@UNINSTALL%" /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v DisplayIcon /t REG_SZ /d "%@SYSROOT%\Snare\Snare.exe" /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v DisplayName /t REG_SZ /d "%@SNAREVER%" /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v DisplayVersion /t REG_SZ /d "2.1c" /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v "Inno Setup: App Path" /t REG_SZ /d "%@SYSROOT%\Snare" /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v "Inno Setup: Icon Group" /t REG_SZ /d "InterSect Alliance" /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v "Inno Setup: Setup Version" /t REG_SZ /d "1.3.24" /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v "Inno Setup: User /t REG_SZ" /d local /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v Publisher /t REG_SZ /d "InterSect Alliance Pty Ltd" /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v UninstallString /t REG_SZ /d "%@SYSROOT%\Snare\unins000.exe" /f
 reg add "\\%@SERVER%\%@UNINSTALL%" /v URLInfoAbout /t REG_SZ /d "http://www.intersectalliance.com/" /f

 rem -- Configure the eventlog to overwrite as required, and only keep 16MB of data, and secure access
:ConfigureEventLog
 reg add "\\%@SERVER%\%@EVENTLOG%\Security"    /v MaxSize             /t REG_DWORD /d 16777216 /f
 reg add "\\%@SERVER%\%@EVENTLOG%\Security"    /v Retention           /t REG_DWORD /d 0 /f
 reg add "\\%@SERVER%\%@EVENTLOG%\Security"    /v RestrictGuestAccess /t REG_DWORD /d 1 /f

 reg add "\\%@SERVER%\%@EVENTLOG%\System"      /v MaxSize             /t REG_DWORD /d 16777216 /f
 reg add "\\%@SERVER%\%@EVENTLOG%\System"      /v Retention           /t REG_DWORD /d 0 /f
 reg add "\\%@SERVER%\%@EVENTLOG%\System"      /v RestrictGuestAccess /t REG_DWORD /d 1 /f

 reg add "\\%@SERVER%\%@EVENTLOG%\Application" /v MaxSize             /t REG_DWORD /d 16777216 /f
 reg add "\\%@SERVER%\%@EVENTLOG%\Application" /v Retention           /t REG_DWORD /d 0 /f
 reg add "\\%@SERVER%\%@EVENTLOG%\Application" /v RestrictGuestAccess /t REG_DWORD /d 1 /f

 ECHO:
 ECHO At your earliest opportunity, please clear the remote Security,
 ECHO Application and System logs using EVENTVWR, for the new log size
 ECHO settings to take effect.
 ECHO:


 rem ==========================================================================
 rem === Create and Manage SNARE Service
 rem === Last Modified On 29 Sep 2005
 rem ==========================================================================
:ManageService
 ECHO:
 ECHO Creating the service...
 SC \\%@SERVER% create SNARE binPath= "%@SYSROOT%\Snare\SnareCore.exe" start= auto DisplayName= SNARE

 ECHO:
 ECHO Starting the service...
 PSSERVICE \\%@SERVER% restart SNARE


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 26 Oct 2005
 rem ==========================================================================
:ExitBatch
 ECHO *** SysLog (SNARE) Installation Script Completed ***
 %@END_DEBUG_MODE%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 09 Mar 2006
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for %~n0.BAT
 ECHO:
 ECHO === %~n0 {servername} [syslog_server]
 ECHO:
 ECHO Example: %~n0 MYSERVER syslog.wmg.com
 ECHO          %~n0 SERVER1 syslog1.server.com
 ECHO          %~n0 SERVER2
 ECHO:
