@REM - ASB (25 Sep 2011 // 16 Oct 2023 / 30 Nov 2020 / 26 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 28 Oct 2018 / 31 Aug 2018 / 26 Jul 2018 / 30 Apr 2018 / 02 Oct 2017): Install Select Applications/Utilities on Citrix/RDP Servers
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v5.20.0.380

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Install Select Applications/Utilities on Standard Systems
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  MAIN CONFIG: %@TS_SOFTWARE%
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @WAIT=20
 SET @ABORT=FALSE
 SET @MORE=TRUE

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )


 rem -- Verify Existence of Installation Source Files
:VerifySource
 IF NOT EXIST "%@TS_SOFTWARE%" (
	 ECHO:
	 ECHO Missing Software Installation Input File: %@TS_SOFTWARE%
	 GOTO :ExitBatch
 )


 rem -- Main Section for Installing Applications
:InstallApps
 CHANGE USER /INSTALL
 ECHO %@DIVIDER%
 ECHO === Selecting Applications (will auto select after %@WAIT% seconds)
 ECHO %@DIVIDER%
 ECHO:
 ECHO Y=Yes ^| N=No ^| F=Start Installations Now ^| Q=Quit Now without Installation
 ECHO:
 FOR /F "USEBACKQ SKIP=2 TOKENS=* EOL=;" %%I IN ("%@TS_SOFTWARE%") DO (
	 IF "!@ABORT!"=="FALSE" (
		 IF "!@MORE!"=="TRUE" CALL :ConfirmInstallList %%I
	 ) ELSE (
		 ECHO  Aborting Software Installation...
		 GOTO :ExitBatch
	 )
 )
 ECHO:
 ECHO:
 ECHO:
 ECHO %@DIVIDER%
 ECHO === Installing Selected Applications (will auto install after 10 seconds)
 ECHO %@DIVIDER%
 ECHO:
 FOR /F "TOKENS=1 DELIMS==" %%Z IN ('SET ') DO @ECHO  - %%Z
 TIMEOUT 10
 FOR /F "USEBACKQ SKIP=2 TOKENS=* EOL=;" %%I IN ("%@TS_SOFTWARE%") DO CALL :InstallApp %%I
 TIMEOUT 10


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 CHANGE USER /EXECUTE
 GOTO :EOF


 rem -- SUBROUTINE: Obtain Approvals for Which Applications to Install
:ConfirmInstallList
 rem %1 = Message to display before installation
 rem %2 = Determine if Allowed on Citrix or Terminal Server
 rem %3 = Name of application to install

 IF NOT EXIST "%~3" GOTO :EOF
 SET "%~1"=
 CHOICE /T %@WAIT% /C YNFQ /D Y /M "Install %~1...?"
 IF %ERRORLEVEL% EQU 1 SET "%~1"="%~3"
 IF %ERRORLEVEL% EQU 3 SET @MORE=FALSE
 IF %ERRORLEVEL% EQU 4 SET @ABORT=TRUE
 GOTO :EOF


 rem -- SUBROUTINE: Display Message and Install Application
:InstallApp
 rem %1 = Message to display before installation
 rem %2 = Determine if Allowed on Citrix or Terminal Server
 rem %3 = Name of application to install

 IF NOT DEFINED "%~1" GOTO :EOF
 IF DEFINED DEBUG ECHO Install from: "%~3"
 IF NOT EXIST "%~3" GOTO :EOF
 ECHO Installing "%~1..."
 CALL "%~3"
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                               