@REM - ASB (16 Dec 2014 // 16 Oct 2023 / 30 Nov 2020 / 18 May 2020 / 16 Feb 2020 / 24 Dec 2019): Obtain Most Current Job History Update for Scheduled Jobs
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.7.0.270

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Default Variables (Override via CustomVariables.*.TXT)
 SET @VARIABLES="%~dp0SetDrive.BAT"
 SET @LOGFOLDERS="OperationsLog" "SecurityLog" "UptimeReport" "Maint" "EventLogs" "Archiving" "Replication" "Backups" "Audit"

 rem -- Set Global Variables from Centralized Script
 IF EXIST %@VARIABLES% (
	 %@VERBOSE_OFF%
	 CALL %@VARIABLES% "%~n0"
	 %@VERBOSE_ON%
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Check for Valid History Count
 IF NOT "%~1"=="" SET /A @HISTORY=%1& IF 1!@HISTORY! LEQ 10 (
	 ECHO *** ERROR:  CMD SYNTAX: %~n0  [# of entries] [remote system] [CLEAR]
	 ECHO:
	 ECHO For More Details, type: %~n0 -?
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @SYSTEM=%~2& IF "%~2"=="" SET @SYSTEM=%COMPUTERNAME%
 CALL :GetSysName @SYSTEM
 SET @LOGSOURCE=%@SYSTEM#%\Logs$
 SET @LOGDIR=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGDIR%\%~n0.%@SYSTEM%.%@FILESTAMP%
 SET @REMOTESYS=& IF /I NOT "%@SYSTEM%"=="%COMPUTERNAME%" SET @REMOTESYS=TRUE


 rem -- Cleanup Failed SysLog Responses in *.RECORDING.TXT files
:CleanupErrors
 IF NOT "%~3"=="" FOR /R "%@LOGSOURCE%" %%f IN (*.RECORDING.TXT) DO FOR %%s IN ("%%%%Failed" "%%%%Unable") DO CALL %~dp0\RemoveLine "%%~f" "%%~s"


 rem -- Generate Consolidated Job History Report for Local or Remote System
:ObtainHistory
 IF NOT EXIST "%@LOGDIR%" MD "%@LOGDIR%"

 ECHO Please Wait...
 ECHO:
 IF DEFINED @REMOTESYS FOR /F "TOKENS=*" %%I IN ('RESOLVE %@SYSTEM% 2^>NUL') DO (ECHO Trying to Access: %@SYSTEM% [%%I] & ECHO:)

 ( rem -- Write to Log
	 NOW [\v] Generate Consolidated Job History Report for %@SYSTEM% via %~n0 %@VERSION%\n\=
	 IF DEFINED @REMOTESYS (PING %@SYSTEM% & ECHO %@DIVIDER-%) ELSE (ECHO "%@OSEDITION%"  & ECHO %@DIVIDER%)
	 ECHO:
	 FOR %%F IN (%@LOGFOLDERS%) DO FOR %%V IN ("%@LOGSOURCE%\%%~F\*.RECORDING.TXT") DO (
		 TAIL -%@HISTORY% "%%~V"
		 ECHO:
	 )
 ) >"%@LOGFILE%" 2>&1


 rem -- Generate Final Job Report
:FinalReport
 TYPE "%@LOGFILE%"
 COPY "%@LOGFILE%" "!@LOGFILE:%@FILESTAMP%=TXT!" /Y /V
 IF /I "%@CONSOLE_SESSION%"=="TRUE" START "Job History Log" "%@LOGFILE%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Get System Name and UNC
:GetSysName
 rem %1 = Variable Name containing name to be parsed

 IF "!%~1!"=="" (
	 ECHO *** ERROR: No System Name Found ***
 ) ELSE (
	 FOR /F "TOKENS=1 DELIMS=\ " %%s IN ('ECHO: !%~1!') DO (
		 SET %~1=%%~s
		 SET %~1#=\\%%~s
	 )
 )
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Obtain Most Current Job History Update for Scheduled Jobs
 ECHO:
 ECHO    YOU TYPED: %0 %*
 ECHO:
 ECHO   CMD SYNTAX: %~n0  [# of entries] [remote system] [CLEAR]
 ECHO               %~n0  [-h^|-?]
 ECHO:
 ECHO  USAGE NOTES:
 ECHO    * Parameters surrounded by ^<^> are mandatory.
 ECHO    * Parameters surrounded by [] are optional.
 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
 CALL :ShowStatus "FINISHED"
