@REM - ASB (26 Jan 2006 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 15 May 2018 / 27 Mar 2016 / 05 May 2015): Set Label For Each Drive Based on Server Type
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.6.0.260

 SET @DESCRIPTION=Generic Server
 SET @SERVERTYPES=Tiny TinyApp App AppServer Basic InfraStructure OldEx OldExchange Ex Exchange AD SmallAD BigAD DB Database Web BigWeb

 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:Applications
 SET @LABEL-E=LABEL E:Data Drive
 SET @LABEL-F=LABEL F:Logs


:VerifyParameters
 FOR %%T IN (%@SERVERTYPES%) DO IF /I "%~1"=="%%T" GOTO :Set_%%T
 IF "%~1"=="." GOTO :ChangeLabels
 GOTO :HelpMessage


:Set_Tiny
:Set_TinyApp
 SET @DESCRIPTION=Tiny App Server
 SET @LABEL-C=LABEL C:OS / Admin Logs
 SET @LABEL-D=LABEL D:Applications
 SET @LABEL-E=
 SET @LABEL-F=
 GOTO :ChangeLabels

:Set_App
:Set_AppServer
 SET @DESCRIPTION=Large Application Server
 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:Apps / Admin Logs
 SET @LABEL-E=
 SET @LABEL-F=
 GOTO :ChangeLabels


:Set_Azure
:Set_Basic
:Set_Cloud
 SET @DESCRIPTION=Minimal Cloud Server
 SET @LABEL-C=LABEL C:OS Drive / Logs
 SET @LABEL-D=
 SET @LABEL-E=
 SET @LABEL-F=
 GOTO :ChangeLabels

:Set_Infrastructure
 SET @DESCRIPTION=Basic Infrastructure Server (WINS/DHCP/etc)
 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:Apps / Admin Logs
 SET @LABEL-E=
 SET @LABEL-F=
 GOTO :ChangeLabels


:Set_OldEx
:Set_OldExchange
 SET @DESCRIPTION=Exchange Server
 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:Exchange Databases
 SET @LABEL-E=LABEL E:Exchange Logs
 SET @LABEL-F=
 GOTO :ChangeLabels

:Set_Ex
:Set_Exchange
 SET @DESCRIPTION=Exchange Server
 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:Apps / Admin Logs
 SET @LABEL-E=LABEL E:Exchange Databases
 SET @LABEL-F=LABEL F:Exchange Logs
 GOTO :ChangeLabels


:Set_DB
:Set_Database
 SET @DESCRIPTION=Database Server
 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:Apps / Admin Logs
 SET @LABEL-E=LABEL E:Databases
 SET @LABEL-F=LABEL F:DB Transaction Logs
 GOTO :ChangeLabels


:Set_SmallAD
 SET @DESCRIPTION=Active Directory Server [Small]
 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:AD Database and Logs
 SET @LABEL-E=
 SET @LABEL-F=
 GOTO :ChangeLabels

:Set_AD
:Set_BigAD
 SET @DESCRIPTION=Active Directory Server [Big]
 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:Apps / Admin Logs
 SET @LABEL-E=LABEL E:AD Database
 SET @LABEL-F=LABEL F:AD Logs
 GOTO :ChangeLabels


:Set_Web
:Set_SmallWeb
 SET @DESCRIPTION=Small Web Server
 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:Apps / Websites
 SET @LABEL-E=
 SET @LABEL-F=
 GOTO :ChangeLabels

:Set_BigWeb
 SET @DESCRIPTION=Big Web Server
 SET @LABEL-C=LABEL C:OS Drive
 SET @LABEL-D=LABEL D:Apps / Admin Logs
 SET @LABEL-E=LABEL E:Websites
 SET @LABEL-F=
 GOTO :ChangeLabels


:ChangeLabels
 ECHO Setting Drive Labels for a %@DESCRIPTION%
 %@LABEL-C%
 %@LABEL-D%
 %@LABEL-E%
 %@LABEL-F%


:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 DRIVEINFO
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO:
 ECHO Options for %@VER%
 ECHO ---------------------------------------------------------------------------
 ECHO OldEx .......... Exchange 5.5/2000 Server  (2 Drives)
 ECHO OldExchange .... Exchange 5.5/2000 Server  (2 Drives)
 ECHO Ex ............. Exchange 2010/2013 Server (3 Drives)
 ECHO Exchange ....... Exchange 2010/2013 Server (3 Drives)
 ECHO DB ............. Database Server (3 Drives)
 ECHO Database ....... Database Server (3 Drives)
 ECHO SmallAD ........ Small Active Directory Server (2 Drives)
 ECHO AD ............. Large Active Directory Server (3 Drives)
 ECHO BigAD .......... Large Active Directory Server (3 Drives)
 ECHO Web ............ Small Web Server (Single Drive)
 ECHO SmallWeb ....... Small Web Server (Single Drive)
 ECHO BigWeb ......... Web Application Servers
 ECHO TinyApp ........ Small Application Server (2 Drives)
 ECHO App ............ Large Application Server (2 Drives)
 ECHO AppServer ...... Large Application Server (2 Drives)
 ECHO Basic .......... Basic Infrastructure Server (2 Drives)
 ECHO Infrastructure . Basic Infrastructure Server (2 Drives)
 ECHO Azure .......... Minimal Cloud Config (Single Drive)
 ECHO ---------------------------------------------------------------------------
 ECHO:
 ECHO Example:  %~n0 SmallAD
 ECHO:
 CALL :ShowStatus "FINISHED"
                                     