@ECHO OFF
 rem ==========================================================================
 rem === Generic Logon Script (Windows 2000, XP and higher)
 rem ==========================================================================
 rem
 rem Created On: 26 Mar 2003
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 24 Apr 2011  (Prior Update: 23 Mar 2011)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: 2000/2003 Servers; 2000/XP/2003 Clients
 rem
 rem  Non-Native Utilities Required:
 rem  	PSTOOLS ................ http://www.microsoft.com/technet/sysinternals/utilities/PsTools.mspx
 rem  	Event-to-SysLog ........ http://KB.UltraTech-llc.com/?File=EventLog.TXT
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This is a generic logon script which maps drives based on domain group
 :::  membership.  You can make it do lots of other things.  Lots of ResKit
 :::  utilities, including Kixtart, are used to compile some system info which
 :::  will allow you to more quickly resolve client-side issues.  This info is
 :::  copied to a centralized network share.
 :::
 :::  This script allows you to update scripts and utilities on on your client
 :::  machines, as well as installing an EventLog to SysLog tool.
 :::
 :::  Be sure to add all of the files/folders into the appropriate GPO folder
 :::  in order to have them copied to your client systems.
 :::
 :::  Example:
 :::        -- Logon.BAT
 :::        ----- Scripts\Util1.bat
 :::        ----- Scripts\Util2.exe
 :::        ----- Scripts\Util3.exe
 :::        ----- System32\File1.bat
 :::        ----- System32\File2.exe
 :::        ----- System32\File3.sys
 :::
 :::  This script has been modified to support 2000/XP/2003+ clients only and
 :::  would need to be edited to once again support NT4 and Win9x clients.
 :::
 :::  (Nov 2010) Changed the default log extension of the reports from .LOG to
 :::  .TXT so that the reports that are mailed to mobile devices can be read
 :::  automatically. (Not too many devices know what to do with the .LOG files)
 :::
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to "TRUE"
 rem === Last Modified On: 26 Dec 2006
 rem ==========================================================================
:DebugMode
 IF /I "%Debug%"=="TRUE" (
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE (
	 SET @PAUSE_IF_DEBUG=
	 SET @END_DEBUG_MODE=
 )


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On: 23 Mar 2011  (Prior Update: 06 Mar 2011)
 rem ==========================================================================
:Variables
 SETLOCAL & CALL :ShowStatus "STARTED" v5.5.0b
 SET @MAJORDIV=**********************************************************************
 SET @MINORDIV=----------------------------------------------------------------------

 SET @STRICT=FALSE
 SET @NOTFOUND=The specified service does not exist as an installed service.
 SET @RESERVED=%HOMEDRIVE% V: W: X: Y: Z:
 SET @MARKER=C:\SkipLogon.TXT

 SET @ACCOUNTS=Administrator ServiceAcct
 SET @SERVERS=SERVER1 SERVER2 SERVER3 SERVER4
 SET @SPECIAL=MYSERVER10
 SET @DOMAIN=%USERDOMAIN%
 SET @FILESERVER=\\MyFILESERVER
 SET @NETLOG=\\MyMainServer\LogonData$
 SET @LOGPATH=%SystemDrive%\Storage\LogonData

 SET @SRC_FILES=%TEMP%\EventSysUtils-SOURCE.TXT
 SET @CUR_FILES=%TEMP%\EventSysUtils-CURRENT.TXT
 SET @NO_DIFF=FC: no differences encountered
 SET @NOTFOUND=The specified service does not exist as an installed service.
 SET @UPTODATE=FALSE
 SET @SVCFOUND=TRUE
 SET @SVCSTATE=*****
 SET @EDITION=[EvtSys x86]

 SET @FOLDERS=Bat Utils
 SET @SOURCE1=%~dp0Scripts
 SET @SOURCE2=%~dp0System32& IF EXIST "%SystemRoot%\SysWOW64" ( SET @SOURCE2=%~dp0System32\x64& SET @EDITION=[EvtSys x64])
 SET @DEST1=%SystemDrive%\Scripts
 SET @DEST2=%SystemRoot%\System32

 rem -- IP Address OR DNS Name for SysLog Server
 SET @SYSLOG=10.1.1.200
 SET @SYSLOG=syslog.mydomain.local


 rem ==========================================================================
 rem === Update Local Repository of Scripts and Utilities
 rem === Last Modified On: 17 Feb 2011  (Prior Update: 14 Jun 2010)
 rem ==========================================================================
:UpdateScripts
 ECHO:
 ECHO Updating System Scripts...
 ECHO:
 FOR %%V IN (%@FOLDERS%) DO XCOPY "%@SOURCE1%" "%@DEST1%" /C /I /D /F /H /K /Y
                            XCOPY "%@SOURCE2%" "%@DEST2%" /C /I /D /F /H /K /Y

 rem -- Verify that EventLog-to-SysLog files are current
 ECHO:
 ECHO %@VER%: Validating EventLog-to-SysLog Installation...
 ECHO:
 DIR /OGN "%@SOURCE2%\EVTSYS.*" | FIND /I "EVTSYS." | FIND /I /V ".CFG" >"%@SRC_FILES%"
 DIR /OGN "%@DEST2%\EVTSYS.*"   | FIND /I "EVTSYS." | FIND /I /V ".CFG" >"%@CUR_FILES%"
 FOR /F "TOKENS=*" %%V IN ('FC /L "%@SRC_FILES%" "%@CUR_FILES%" ^| FIND /I "%@NO_DIFF%" ') DO SET @UPTODATE=TRUE
 FOR /F "TOKENS=*" %%S IN ('SC QUERY "EvtSys" ^| FIND /I "%@NOTFOUND%"') DO SET @SVCFOUND=FALSE
 FOR /F "TOKENS=4" %%S IN ('SC QUERY "EvtSys" ^| FIND "STATE"') DO SET @SVCSTATE=%%~S

 rem -- Update or Install EventLog-to-SysLog if Files Aren't Current
 IF "%@UPTODATE%%@SVCSTATE%"=="TRUERUNNING" (
	 ECHO EventLog-to-SysLog %@EDITION% service: *** UP-TO-DATE ***
 ) ELSE (
	 ECHO Installing/Updating EventLog-to-SysLog %@EDITION% service...
	 IF "%@SVCFOUND%"=="TRUE" NET STOP EVTSYS /Y
	 XCOPY "%@SOURCE2%\EVTSYS.*" "%@DEST2%" /C /I /F /H /K /Y
	 %@DEST2%\evtsys -u
	 SLEEP 5
	 %@DEST2%\evtsys -i -h %@SYSLOG% -l 2 -f Local1
 )

 rem -- Start EventLog-to-SysLog service if not running
 FOR /F "TOKENS=4" %%S IN ('SC QUERY "EvtSys" ^| FIND "STATE"') DO IF NOT "%%~S"=="RUNNING" (
	 ECHO Starting EventLog-to-SysLog %@EDITION% service...
	 NET START EVTSYS
 )


 rem ==========================================================================
 rem === Map Shares (except for H:, the Home Drive, and X:-Z:)
 rem === Last Modified On: 31 Dec 2006  (Prior Update: 26 Dec 2006)
 rem ==========================================================================
:MapShares
 ECHO:
 ECHO Mapping Server Shares...
 ECHO:

 rem -- Delete All Non-Reserved Mappings if @STRICT=TRUE
 IF "%@STRICT%"=="TRUE" FOR /F "TOKENS=2" %%V IN ('NET USE ^| FIND ":"') DO CALL :EraseMappings %%V

 rem -- Default Mappings for Domain Users
 CALL :MapGroup "Domain Users"   S: "%@FILESERVER%\Storage\Files\Downloads"
 CALL :MapGroup "Domain Users"   T: "%@FILESERVER%\Storage\Files\Installs"

 rem -- Skip unless Admin Account or Server
 IF EXIST "%@MARKER%" GOTO :CreateLogs
 FOR %%V IN (%@ACCOUNTS%) DO IF /I "%USERNAME%"=="%%V" GOTO :CreateLogs
 FOR %%V IN (%@SERVERS%) DO IF /I "%COMPUTERNAME%"=="%%V" GOTO :CreateLogs

 rem -- Custom Mappings based on Group Membership
 CALL :MapGroup "Domain Admins"  S: "%@FILESERVER%\Downloads$"
 CALL :MapGroup "Domain Admins"  Q: "%@FILESERVER%\Special Share"
 CALL :MapGroup "Domain Admins"  R: "%@FILESERVER%\Other Share$"


 rem ==========================================================================
 rem === Create System Diagnostics Log For Debug Purposes
 rem === Last Modified On: 24 Apr 2011  (Prior Update: 07 Nov 2010)
 rem ==========================================================================
:CreateLogs
 FOR %%V IN (%@SPECIAL%) DO IF /I "%COMPUTERNAME%"=="%%~V" GOTO :UserLogs

 ECHO:
 ECHO Generating Logon Diagnostics Log... [%@VER%]
 ECHO:
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%" >NUL
 KIX32 "%~dp0Configure.KIX"
 KIX32 "%~dp0LogonInfo.KIX"

 ( rem -- Consolidate LogFile Output
	 ECHO:
	 ECHO %@MAJORDIV%
	 FINDGRP %USERDOMAIN% %USERDOMAIN%\%USERNAME%
	 ECHO:
	 FINDGRP \\%COMPUTERNAME% %USERDOMAIN%\%USERNAME%
	 ECHO:
	 SHOWGRPS | FIND "User:" /I
	 ECHO:
	 SHOWGRPS | FIND "User:" /I /V | FIND "\" | SORT
	 ECHO:
	 NET USE
	 ECHO:
	 ECHO %@MAJORDIV%
	 SRVINFO -ns
	 ECHO:
	 ECHO %@MAJORDIV%
	 PSINFO -d
	 ECHO:
	 ECHO %@MAJORDIV%
	 NET START
	 ECHO:
	 ECHO %@MAJORDIV%
	 NET SHARE
	 ECHO:
	 ECHO %@MAJORDIV%
	 NET USER
	 ECHO:
	 ECHO %@MAJORDIV%
	 DIR "%~dp0" /OGN
	 DIR %@DEST1%\BAT /OGN
	 DIR %@DEST1%\UTILS /OGN
	 DIR %@DEST2%\EVTSYS.*
	 DIR %@LOGPATH%
	 ECHO:
	 ECHO:
	 ECHO Current Environment Variables
	 ECHO *****************************
	 SET
	 NOW System Diagnostics Log Completed
 ) >>"%@LOGPATH%\LMScript.TXT" 2>&1

:UserLogs
 NOW '%USERNAME%' Has Completed Logon Script on %COMPUTERNAME% >>"%@LOGPATH%\LMScript.TXT" 2>&1
 COPY "%@LOGPATH%\LMScript.*" "%@NETLOG%\%COMPUTERNAME%.*" >NUL
 ATTRIB +H "%@LOGPATH%" >NUL


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On: 23 Mar 2011  (Prior Update: 07 Dec 2003)
 rem ==========================================================================
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Map Shares Based On Group Membership
 rem === Last Modified On: 24 Apr 2011  (Prior Update: 26 Dec 2006)
 rem ==========================================================================
:MapGroup
 rem %1 = Group Membership to Check For
 rem %2 = Drive Letter To Use For Mapping
 rem %3 = Remote Resource To Map

 SET @GROUP=%@DOMAIN%\%~1
 SET @DRIVE=%~2
 SET @SHARE=%~3
 SET @COMPARE=

 rem -- Determine if drive is already mapped appropriately
 FOR /F "TOKENS=2*" %%C IN ('NET USE %@DRIVE% ^| FIND "\\"') DO SET @COMPARE=%%D
 IF /I "%@SHARE%"=="%@COMPARE%" GOTO :EOF

 rem -- Set Drive to New Share with a Persistent Mapping
 IFMEMBER "%@GROUP%"
 IF ERRORLEVEL 1 (
	 ECHO Currently Mapping Drive %@DRIVE%
   NET USE %@DRIVE% /D /Y         >NUL 2>NUL
   NET USE %@DRIVE% "%@SHARE%" /Y >NUL 2>NUL
 )
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Erase All Existing Mappings Except U-Z
 rem === Last Modified On: 24 Apr 2011  (Prior Update: 23 Mar 2011)
 rem ==========================================================================
:EraseMappings
 rem %1 = Current Drive Letter
 FOR %%D IN (%@RESERVED%) DO IF /I "%1"=="%%~D" GOTO :EOF
 NET USE %1 /D /Y
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Last Modified On: 03 Apr 2011  (Prior Update: 23 Mar 2011)
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" SET @VER=%~nx0 %~2
 IF /I "%~2"=="FINISHED" "%@END_DEBUG_MODE%"
 ECHO:
 ECHO *** %@SCRIPTSTATUS%: %@VER% [%DATE% at %TIME%] ***
 ECHO:
 GOTO :EOF
