@ECHO OFF
 rem ==========================================================================
 rem === LogOFF Script -- Log System/User Diagnostics Info
 rem ==========================================================================
 rem
 rem Created On: 26 Mar 2003
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 16 Oct 2023 / 16 Feb 2022
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2003 and later
 rem
 rem  Non-Native Utilities Used/Required:
 rem    BrainWave Utilities .... https://www.BrainWaveCC.com/brainwave-utilities
 rem
 rem    Resource Kit ........... https://en.wikipedia.org/wiki/Resource_Kit
 rem ==========================================================================

 :::  This is a generic ShutDown script.  This info is copied to a centralized
 :::  network share. It uses BrainWave NOW.exe, but it can be configured to use
 :::  only native utilities. And it can be expanded to perform other functions.
 :::
 :::  Be sure to add all of the files/folders into the appropriate GPO folder
 :::  in order to have them copied to your client systems.
 :::
 :::  Example:
 :::        -- Logon.Settings
 :::        -- NOW.EXE
 :::        -- DateInfo.EXE
 :::        -- CheckParams.EXE
 :::        -- ReadConfig.EXE
 :::        -- SyslogStatus.BAT
 :::        -- LogOFF.BAT
 :::
 :::  (Jun 2017) v1.6 -- Replaced NOW.EXE with DATEINFO.EXE;
 :::  Removed the legacy system inventory component.
 :::
 :::  (Feb 2018) v1.7 -- Changed Script Documentation to www.BrainWaveCC.com
 :::
 :::  (May 2018) v1.8 -- Changed to HTTPS links for Script Documentation;
 :::  -- Consolidated all BrainWave Utilities Links under one heading;
 :::
 :::  (Feb 2019) v2.0 -- Updated DEBUG routine; Changed Logging methodology;
 :::  -- Added new DATEINFO --Script-Variables routine to set default variables;
 :::
 :::  (Oct 2019) v2.1 -- Updated :ShowStatus routine to reset TITLE/CodePage;
 :::  -- Moved the CMD filtering to its own routine, and added {/?} filtering;
 :::
 :::  (Dec 2019) v2.2 -- Developed a drop-in replacement for Microsoft's
 :::  NOW.EXE utility, taking back that function from DATEINFO.EXE;
 :::
 :::  (Jan 2020) v3.0 -- The logon scripts are being modified to pull custom
 :::  settings from the "Logon.Settings.TXT" file to ensure that the scripts
 :::  themselves are consistent across various deployments;
 :::
 :::  (Mar 2020) v3.1 -- Add routine to process Syslog variables;
 ::   -- Made the HISTORY file name consistent with other logon/off scripts;
 :::
 :::  (Mar 2020) v3.2 -- Added routine to upload LogOff report to network;
 :::
 :::  (May 2020) v3.3 -- Updated :DebugMode routine to support the STEP option;
 :::  -- Use ReadConfig.exe to process the Logon.Settings config file;
 :::
 :::  (Jul 2020) v3.4 -- Add Version Information to the History Log;
 :::
 :::  (Jul 2020) v3.5 -- Added extra version info for the logon/logoff family
 :::  of scripts in the format of yyyy.mm.dd.hh.nn (@VERDATE);
 :::
 :::  (Aug 2020) v3.6 -- Minor update to consolidated status report;
 :::
 :::  (Aug 2020) v4.0 -- Alter sequence of Debug Verification routine;
 :::  -- Read additional debug related variables from Logon.Setting.TXT;
 :::  -- Make Header and Footer entries consistent across all scripts;
 :::
 :::  (Oct 2023) v4.1 -- Change the way the @SCRIPT_BEG# variable is
 :::  calculated in various subroutines by using DATEINFO instead of %DATE%;
 :::
 :::  NOTE: The logon/logoff/etc scripts are mostly self-contained, and make
 :::        use of their own central config file (Logon.Settings) rather than
 :::        the common config files of all the other scripts.
 :::
 :::
 :::  ADDITIONAL SCRIPTING TOOLS/INFO:
 :::  -------------------------------------------------------------------------
 :::  https://www.BrainWaveCC.com/knowledge-base/tools-for-managing-the-windows-eventlog/
 :::  https://www.BrainWaveCC.com/knowledge-base/scripting-and-automation-options-for-windows/
 :::  https://www.BrainWaveCC.com/knowledge-base/must-have-utilities-for-windows-usersadmins/
 :::  -------------------------------------------------------------------------


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 31 May 2020 / 05 Oct 2019
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 17 Aug 2020 / 11 Aug 2020
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v4.1.0.410  v2023.09.17.1500

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Search Logon.Settings.*.TXT for Custom Variables
 SET @SETTINGS=%~dp0Logon.Settings.
 SET @CONFIG=& FOR %%F IN ("TXT" "%COMPUTERNAME%.TXT") DO IF EXIST "!@SETTINGS!%%~F" SET @CONFIG="!@SETTINGS!%%~F"
 IF DEFINED @CONFIG (
	 FOR /F "TOKENS=*" %%P IN ('READCONFIG %@CONFIG% 2^>NUL') DO CALL :RunCMD %%P
 ) ELSE (
	 rem -- IP Address OR DNS Name for SysLog Server
	 FOR %%n IN ("" 1 2 3) DO SET @SYSLOG%%~n=192.168.255.22%%~n
 )
 SET @SYSLOG_SERVERS=& FOR %%X IN ("" 1 2 3 4 5 6 7 8 9 0) DO IF DEFINED @SYSLOG%%~X SET @SYSLOG_SERVERS=!@SYSLOG_SERVERS!;!@SYSLOG%%~X!

 rem -- Standard Log Variables
 SET @LOGPATH=%SystemDrive%\Storage\LogonData
 SET @LOGBASE=%@LOGPATH%\Logon Info
 SET @LOGFILE=%@LOGBASE%.%@FILESTAMP_R%
 SET @HISTORY=%@LOGBASE%.RECORDING.TXT
 SET @NETLOG=%@FILESERVER%\Maint\LogonData\%COMPUTERNAME%

 rem -- Version Info Messages
 SET @INITIATION=LogOFF Script ..... %@LVERSION% ... STARTED on %COMPUTERNAME% by '%USERNAME%'
 SET @COMPLETION=%@INITIATION:STARTED=COMPLETED%


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to TRUE/LOG/STEP/VERBOSE
 rem === Updated On: 16 Aug 2020 / 31 May 2020
 rem ==========================================================================
:DebugMode
 SET #DEBUG=& FOR %%d IN (LOG STEP TRUE VERBOSE) DO IF /I "%Debug%"=="%%~d" SET #DEBUG=TRUE
 FOR %%d IN (%@DEBUG_SYS%) DO IF /I "%COMPUTERNAME%"=="%%~d" (SET #DEBUG=TRUE& SET DEBUG=STEP)
 IF EXIST "%@DEBUG_FLAG%" (SET #DEBUG=TRUE& SET DEBUG=STEP)
 IF DEFINED #DEBUG (
	 SET @DIAGMODE=TRUE
	 SET @DEBUG_MODE=[DEBUG MODE ON]
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:^& TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 SET @COMPLETION=%@COMPLETION% !@DEBUG_MODE!
	 IF /I "%Debug%"=="LOG" (SET @PAUSE_IF_DEBUG=& SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:)
	 IF /I "%Debug%"=="STEP" (SET @PAUSE_IF_DEBUG=ECHO ##PAUSE##& SET @PRINT_IF_DEBUG=ECHO ##PRINT##)
	 IF /I "%Debug%"=="VERBOSE" (SET @VERBOSE_OFF=ECHO ON) ELSE (FOR %%t IN (ON OFF) DO SET @VERBOSE_%%t=ECHO %%t)
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE ( FOR %%d IN (DEBUG_MODE PAUSE_IF_DEBUG PRINT_IF_DEBUG END_DEBUG_MODE VERBOSE_ON VERBOSE_OFF) DO SET @%%d=)


 rem ==========================================================================
 rem === Capture Logoff Time and Username
 rem === Updated On: 17 Aug 2020 / 15 Mar 2020
 rem ==========================================================================
:RecordLogOff
 FOR %%D IN ("%@LOGPATH%" "%@NETLOG%") DO IF NOT EXIST "%%~D" MD "%%~D"
 ATTRIB +H "%@LOGPATH%"

 ( rem -- Write Log to File
	 NOW \*\v -- %@INITIATION%\n\*\n
	 SYSTEMINFO
	 COMPINFO
	 ECHO:
	 CALL :EchoAll Drive Connections at the end of the script...
	 NET USE
	 NOW \n\-\v -- %@COMPLETION%\n\-
	 %@PRINT_IF_DEBUG%
 ) >"%@LOGFILE%" 2>&1
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Send Syslog Message When Completed (if available)
 rem === Updated On: 17 Aug 2020 / 13 Jul 2020
 rem ==========================================================================
:SendSyslogMessage
 NOW %@COMPLETION% >>"%@HISTORY%"
 IF EXIST "%~dp0SyslogStatus.BAT" CALL "%~dp0SyslogStatus.BAT" "%@SYSLOG_SERVERS%" . "6" "%~n0" %@COMPLETION%
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Copy Results to Network
 rem === Updated On: 12 Mar 2020
 rem ==========================================================================
:CopyToNetwork
 IF EXIST "%@LOGBASE%*.TXT" (
	 COPY "%@LOGFILE%" "%@NETLOG%.LOG" /Y
	 COPY "%@HISTORY%" "%@NETLOG%.TXT" /Y
	 COPY "%@LOGBASE%*.TXT" "%@NETLOG%" /Y
	 TYPE "%@LOGFILE%"
 )
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 05 Oct 2019 / 25 Mar 2016
 rem ==========================================================================
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Execute Dynamic Command From Variable
 rem === Updated On: 05 Mar 2020
 rem ==========================================================================
:RunCMD
 rem %* = Command To Execute

 %*
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 16 Feb 2022
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version
 rem %3 = Date-based Extended Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF NOT "%~3"=="" (SET @VERDATE=%~n0 %~3& SET @LVERSION=%~3)
 IF /I "%~1"=="STARTED" SET @SCRIPT_BEG#="%DATE:~4,10% %TIME: =0%"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                           