@ECHO OFF
 rem ==========================================================================
 rem === Find User or Machine Name in Domain
 rem ==========================================================================
 rem
 rem Created On: 15 Aug 1996
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 16 Oct 2023 / 30 Nov 2020              
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 28 Nov 2020              
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 30 Nov 2020 / 26 May 2020              
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.12.0.220

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 ECHO:
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Create Log of Users/Computers and Store Results
 rem === Updated On: 07 Dec 2003
 rem ==========================================================================
:ShowResults
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 IF /I NOT "%~1"=="" (
	 NET VIEW | FIND /I /N "%~1" >"%@LOGFILE%"
 ) ELSE (
	 NET VIEW | FIND "\\" >"%@LOGFILE%"
 )


 rem ==========================================================================
 rem === Generate Final Job Report
 rem === Updated On: 21 Apr 2015                     
 rem ==========================================================================
:FinalReport
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 03 Oct 2019 / 28 Feb 2019              
 rem ==========================================================================
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019              
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                   