@REM - ASB (01 Jan 2003 // 16 Oct 2023 / 12 Dec 2021 / 24 Jan 2021 / 30 Nov 2020 / 22 Oct 2020 / 26 May 2020 / 24 Dec 2019): Initial Share and Folder Configuration for Scripts
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v4.7.0.600

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Initial Share and Folder Configuration for Scripts
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [OPTIONS]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO OPTION DEFINITIONS:
	 ECHO  -?, /H ..... Display This Help Message  ^(also --HELP^)
	 ECHO       .  .... Apply Permissions Only [Skip Folder/Share Creation]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Set Global Variables from Centralized Script
 SET @RESETDRIVE=TRUE
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 SET @WHICHDRV=%SystemDrive%
	 SET @STORAGE=!@WHICHDRV!\Storage
	 SET @LOGBASE=!@STORAGE!\Logs
	 FOR %%D IN (Backups Installs Downloads) DO SET @%%D=!@STORAGE!\%%~D
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @SCR_FOLDERS=Bat Utils\x64 Utils\Misc Perl PowerShell KIX VBS
 SET @STO_FOLDERS=Drivers Docs
 SET @OTH_FOLDERS="%@LOGBASE%\Setup" "%@LOGBASE%\Syslog" "%@BACKUPS%" "%@INSTALLS%" "%@DOWNLOADS%"
 SET @USERS=/USERS:10
 SET @LOGFILE="%TEMP%\%~n0.%@FILESTAMP_R%"


 rem -- Create Initial Folders Based on Environment Variables
:MakeFolders
 IF "%~1"=="." GOTO :SetPerms

 rem -- Folder for Drive %SystemDrive% (Usually C:)
 SET @CUSTOM_ERROR=

 ( rem -- Write to Log
	 FOR %%D IN (%@SCR_FOLDERS%) DO MD "%SystemDrive%\Scripts\%%~D"
	 FOR %%D IN (%@STO_FOLDERS%) DO MD "%SystemDrive%\Storage\%%~D"
	 FOR %%D IN (%@OTH_FOLDERS%) DO MD "%%~D"

	 rem -- Create Folders in Default Location if Custom Location Unavailable
	 IF NOT EXIST "%@LOGBASE%\Setup"  (SET @CUSTOM_ERROR=TRUE& MD "%SystemDrive%\Storage\Logs\Setup")
	 IF NOT EXIST "%@LOGBASE%\Syslog" (SET @CUSTOM_ERROR=TRUE& MD "%SystemDrive%\Storage\Logs\Syslog")
	 IF NOT EXIST "%@BACKUPS%"        (SET @CUSTOM_ERROR=TRUE& MD "%SystemDrive%\Storage\Backups")
	 IF NOT EXIST "%@INSTALLS%"       (SET @CUSTOM_ERROR=TRUE& MD "%SystemDrive%\Storage\Installs")
	 IF NOT EXIST "%@DOWNLOADS%"      (SET @CUSTOM_ERROR=TRUE& MD "%SystemDrive%\Storage\Downloads")
	 IF DEFINED @CUSTOM_ERROR SET @STORAGE=%SystemDrive%\Storage
 ) >>%@LOGFILE% 2>&1

 rem -- Temp Folders
 FOR %%T IN (C D E F G H I J K L M N O P Q R S T U V W X Y Z) DO IF EXIST "%%~T:\" MD "%%~T:\Temp" 2>>%@LOGFILE%


 rem -- Remove Existing Shares and Recreate Them
:MakeShares
 FOR %%D IN (Logs Drivers Backups Storage C_Store SysDocs Installs Downloads Docs) DO NET SHARE %%D$ /DELETE /Y 2>>%@LOGFILE%

 rem -- Shares for Drive %SystemDrive% (Usually C:)
 ( rem -- Write to Log
	 NET SHARE Scripts$=%SystemDrive%\Scripts
	 NET SHARE C_Store$=%SystemDrive%\Storage
	 NET SHARE SysDocs$=%SystemDrive%\Storage\Docs
	 NET SHARE Drivers$=%SystemDrive%\Storage\Drivers
 ) >>%@LOGFILE% 2>&1

 rem -- Shares for Other Drives (Potentially)
 ( rem -- Write to Log
	 NET SHARE Storage$=%@STORAGE%
	 NET SHARE Logs$=%@LOGBASE%
	 NET SHARE Backups$=%@BACKUPS%
	 NET SHARE Installs$=%@INSTALLS%
	 NET SHARE Downloads$=%@DOWNLOADS%
 ) >>%@LOGFILE% 2>&1


 rem -- Grant Administrators Full Control to These Shares
:SetPerms
 FOR %%D IN (%@STORAGE% %@BACKUPS% %@LOGBASE%) DO ATTRIB +S +H %%D
 FOR %%D IN (Drivers Installs Downloads)                   DO RMTSHARE \\%COMPUTERNAME%\%%D$ %@USERS% /GRANT Administrators:F /GRANT EVERYONE:R 2>>%@LOGFILE%
 FOR %%D IN (Backups Logs Scripts C_Store Storage SysDocs) DO RMTSHARE \\%COMPUTERNAME%\%%D$ %@USERS% /GRANT Administrators:F                   2>>%@LOGFILE%


 rem -- Set Appropriate Share Comments [removed when permissions were set]
:SetRemarks
 ( rem -- Write to Log
	 NET SHARE Backups$   /REMARK:"System Backups"
	 NET SHARE C_Store$   /REMARK:"SysDrive Storage"
	 NET SHARE Downloads$ /REMARK:"File Download Archive"
	 NET SHARE Drivers$   /REMARK:"System Drivers"
	 NET SHARE Installs$  /REMARK:"Software Install Point"
	 NET SHARE Logs$      /REMARK:"System Logs"
	 NET SHARE Scripts$   /REMARK:"Admin Scripts"
	 NET SHARE Storage$   /REMARK:"Parent folder of Primary Storage"
	 NET SHARE SysDocs$   /REMARK:"System Docs"
 ) >>%@LOGFILE% 2>&1


 rem -- Display Final Report
:FinalReport
 FOR %%O IN (CON %@LOGFILE%) DO (
	 NET SHARE
	 DIR %@LOGFILE%
 ) >>%%O 2>&1
 COPY %@LOGFILE% "%@LOGBASE%\Setup" /Y


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                            