'==========================================================================
'=== Enable Special Administrative Configuration Settings and Console
'==========================================================================
'
'Requires WSH v5.1 or greater
'
'Created On: 24 Nov 2001
'        By: Andrew S. Baker
'
'Updated On: 05 May 2022  (Prior Update: 29 Apr 2018)
'        By: Andrew S. Baker
'

'--------------------------------------------------------------------------
'  This script uses enables Command Completion for the CMD processor and
'  enlarges the default CMD window and history. It also enables Quick Edit
'  for the command prompt, and changes the user prompt to include the name
'  of the computer (which is great when you remote console to a box). It
'  also sets the size of the various EventLogs to 16MB and sets default
'  options for Crash Recovery.  Finally, it speeds up NTFS file access by
'  disabling LastAccessUpdate on files and folders.
'
'
'  ADDITIONAL SCRIPTING TOOLS/INFO:
'--------------------------------------------------------------------------
'  https://www.BrainWaveCC.com/knowledge-base/scripting-and-automation-options-for-windows/
'  https://www.BrainWaveCC.com/knowledge-base/must-have-utilities-for-windows-usersadmins/
'--------------------------------------------------------------------------


'==========================================================================
'=== Initialize Variables
'=== Updated On: 05 May 2022  (Prior Update: 22 Feb 2015)
'==========================================================================
 Option Explicit
 Dim AlerterKey, EventLogKey, RecoveryKey, ProfileKey, NTSetupKey, WinSetupKey, NTSourceLoc, BootINI, FileSysKey
 Dim DefCMDProcKey, CMDProcKey, AdminConsoleKey1, AdminConsoleKey2, DefConsoleKey, UserConsoleKey
 Dim MaxConnKey, MaxConnections, MaxConnectionsV1, MaxConnValue
 Dim Def_EULA_Key, User_EULA_Key
 Dim SysEnvironment, MyPrompt
 Dim WshShell, strRegVal
 Set WshShell = WScript.CreateObject("WScript.Shell")

 AlerterKey  = "HKLM\SYSTEM\CurrentControlSet\Services\Alerter\"
 EventLogKey = "HKLM\SYSTEM\CurrentControlSet\Services\EventLog\"
 RecoveryKey = "HKLM\SYSTEM\CurrentControlSet\Control\CrashControl\"
 FileSysKey  = "HKLM\SYSTEM\CurrentControlSet\Control\FileSystem\"
 ProfileKey  = "HKLM\Software\Microsoft\Windows NT\CurrentVersion\Winlogon"
 NTSetupKey  = "HKLM\Software\Microsoft\Windows NT\CurrentVersion\"
 WinSetupKey = "HKLM\Software\Microsoft\Windows\CurrentVersion\Setup\"

 NTSourceLoc = WshShell.ExpandEnvironmentStrings("%SystemDrive%") + "\Storage"
 BootINI     = WshShell.ExpandEnvironmentStrings("%SystemDrive%") + "\BOOT.INI"

 DefCMDProcKey    = "HKEY_USERS\.DEFAULT\Software\Microsoft\Command Processor\CompletionChar"
 CMDProcKey       = "HKCU\Software\Microsoft\Command Processor\CompletionChar"
 DefConsoleKey    = "HKEY_USERS\.DEFAULT\Console\"
 UserConsoleKey   = "HKCU\Console\"
 AdminConsoleKey1 = UserConsoleKey + "%SystemRoot%_System32_CMD.exe\"
 AdminConsoleKey2 = UserConsoleKey + "%SystemRoot%_SysWOW64_CMD.exe\"

 MaxConnKey       = "HKCU\Software\Microsoft\Windows\CurrentVersion\Internet Settings\"
 MaxConnections   = "MaxConnectionsPerServer"
 MaxConnectionsV1 = "MaxConnectionsPer1_0Server"
 MaxConnValue     = 10

 Def_EULA_Key  = "HKEY_USERS\.DEFAULT\Software\Sysinternals\"
 User_EULA_Key = "HKCU\Software\Sysinternals\"

 SysEnvironment = "HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment\Prompt"
 MyPrompt       = "$T$_[" + WshShell.ExpandEnvironmentStrings("%COMPUTERNAME%") + "] $P$_$+$G"


'==========================================================================
'=== Display Initial Configuration Notices...
'=== Updated On: 05 May 2022  (Prior Update: 29 Apr 2018)
'==========================================================================
 WScript.Echo "START: Configuring Custom System Settings... (v4.0.0)"


'==========================================================================
'=== Configure EventLog to 32MB and "Overwrite As Necessary"
'==========================================================================
 WScript.Echo " - Updating EventLog Settings"
 WshShell.RegWrite EventLogKey + "System\MaxSize", 33554432, "REG_DWORD"
 WshShell.RegWrite EventLogKey + "System\Retention", 0, "REG_DWORD"
 WshShell.RegWrite EventLogKey + "Security\MaxSize", 33554432, "REG_DWORD"
 WshShell.RegWrite EventLogKey + "Security\Retention", 0, "REG_DWORD"
 WshShell.RegWrite EventLogKey + "Application\MaxSize", 33554432, "REG_DWORD"
 WshShell.RegWrite EventLogKey + "Application\Retention", 0, "REG_DWORD"

 On Error Resume Next
 strRegVal = WshShell.RegRead(EventLogKey + "IExplore\")
 If Err = 0 Then
	 WshShell.RegWrite EventLogKey + "IExplore\MaxSize", 33554432, "REG_DWORD"
	 WshShell.RegWrite EventLogKey + "IExplore\Retention", 0, "REG_DWORD"
 End If

 strRegVal = WshShell.RegRead(EventLogKey + "Directory Service\")
 If Err = 0 Then
	 WshShell.RegWrite EventLogKey + "Directory Service\MaxSize", 33554432, "REG_DWORD"
	 WshShell.RegWrite EventLogKey + "Directory Service\Retention", 0, "REG_DWORD"
 End If

 strRegVal = WshShell.RegRead(EventLogKey + "DNS Server\")
 If Err = 0 Then
	 WshShell.RegWrite EventLogKey + "DNS Server\MaxSize", 33554432, "REG_DWORD"
	 WshShell.RegWrite EventLogKey + "DNS Server\Retention", 0, "REG_DWORD"
 End If

 strRegVal = WshShell.RegRead(EventLogKey + "File Replication Service\")
 If Err = 0 Then
	 WshShell.RegWrite EventLogKey + "File Replication Service\MaxSize", 33554432, "REG_DWORD"
	 WshShell.RegWrite EventLogKey + "File Replication Service\Retention", 0, "REG_DWORD"
 End If

 strRegVal = WshShell.RegRead(EventLogKey + "PowerShell\")
 If Err = 0 Then
	 WshShell.RegWrite EventLogKey + "PowerShell\MaxSize", 33554432, "REG_DWORD"
	 WshShell.RegWrite EventLogKey + "PowerShell\Retention", 0, "REG_DWORD"
 End If

 strRegVal = WshShell.RegRead(EventLogKey + "Virtual Server\")
 If Err = 0 Then
	 WshShell.RegWrite EventLogKey + "Virtual Server\MaxSize", 33554432, "REG_DWORD"
	 WshShell.RegWrite EventLogKey + "Virtual Server\Retention", 0, "REG_DWORD"
 End If

On Error Goto 0


'==========================================================================
'=== Enable SysInternals EULA Acceptance"
'=== Updated On: 04 Feb 2016  (Prior Update: 20 Jan 2015)
'==========================================================================
 WScript.Echo " - Setting SysInternals EULA Acceptance"
 WshShell.RegWrite Def_EULA_Key + "AccessChk", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "AccessEnum", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "AdExplorer", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "AdInsight", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "AdRestore", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "AutoLogon", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "AutoRuns", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "AutoRunsC", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "BgInfo", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "BlueScreen", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "CacheSet", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "ClockRes", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Contig", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "CoreInfo", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Ctrl2cap", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "DebugView", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Defrag", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Desktops", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Disk Usage", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Disk Usage (DU)", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Disk2VHD", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "DiskExt", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "DiskMon", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "DiskUsage", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "DiskView", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "DU", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "EFSDump", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Filemon", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "FindLinks", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Handle", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Hex2Dec", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Junction", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "LDMDump", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "ListDLLs", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "LiveKd", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "LoadOrder", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "LoggedOn", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "LogonSessions", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "MoveFile", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "NewSID", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "NTFSInfo", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PageDefrag", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PendMove", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PendMoves", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PhysMem", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PipeList", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PortMon", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "ProcDump", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Process Explorer", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Process Monitor", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "ProcFeatures", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "ProcMon", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsExec", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsFile", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsGetSID", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsInfo", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsKill", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsList", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsLoggedOn", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsLogList", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsPasswd", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsPing", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsService", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsShutdown", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsSuspend", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "PsTools", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "RAMMap", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "RegDelNull", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "RegHide", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Registry Usage (RU)", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "RegJump", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "RegMon", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "RootkitRevealer", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "RU", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "SDelete", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "ShareEnum", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "ShellRunas", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "SigCheck", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Streams", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Strings", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "Sync", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "System Monitor", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "TestLimit", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "TestLimit64", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "TCPView", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "VMMap", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "VolumeId", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "WhoIs", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "WinObj", 1, "REG_DWORD"
 WshShell.RegWrite Def_EULA_Key + "ZoomIt", 1, "REG_DWORD"

 WshShell.RegWrite User_EULA_Key + "AccessChk", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "AccessEnum", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "AdExplorer", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "AdInsight", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "AdRestore", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "AutoLogon", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "AutoRuns", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "AutoRunsC", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "BgInfo", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "BlueScreen", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "CacheSet", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "ClockRes", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Contig", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "CoreInfo", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Ctrl2cap", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "DebugView", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Defrag", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Desktops", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Disk Usage", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Disk Usage (DU)", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Disk2VHD", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "DiskExt", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "DiskMon", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "DiskUsage", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "DiskView", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "DU", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "EFSDump", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Filemon", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "FindLinks", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Handle", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Hex2Dec", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Junction", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "LDMDump", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "ListDLLs", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "LiveKd", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "LoadOrder", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "LoggedOn", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "LogonSessions", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "MoveFile", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "NewSID", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "NTFSInfo", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PageDefrag", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PendMove", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PendMoves", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PhysMem", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PipeList", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PortMon", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "ProcDump", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Process Explorer", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Process Monitor", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "ProcFeatures", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "ProcMon", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsExec", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsFile", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsGetSID", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsInfo", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsKill", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsList", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsLoggedOn", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsLogList", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsPasswd", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsPing", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsService", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsShutdown", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsSuspend", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "PsTools", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "RAMMap", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "RegDelNull", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "RegHide", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Registry Usage (RU)", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "RegJump", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "RegMon", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "RootkitRevealer", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "RU", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "SDelete", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "ShareEnum", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "ShellRunas", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "SigCheck", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Streams", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Strings", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "Sync", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "System Monitor", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "TestLimit", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "TestLimit64", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "TCPView", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "VMMap", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "VolumeId", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "WhoIs", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "WinObj", 1, "REG_DWORD"
 WshShell.RegWrite User_EULA_Key + "ZoomIt", 1, "REG_DWORD"


'==========================================================================
'=== Configure System Recovery
'==========================================================================
 WScript.Echo " - Updating System Recovery Settings"
 WshShell.RegWrite RecoveryKey + "AutoReboot", 1, "REG_DWORD"
 WshShell.RegWrite RecoveryKey + "CrashDumpEnabled", 2, "REG_DWORD"
 WshShell.RegWrite RecoveryKey + "DumpFile", "%SystemRoot%\MEMORY.DMP", "REG_EXPAND_SZ"
 WshShell.RegWrite RecoveryKey + "LogEvent", 1, "REG_DWORD"
 WshShell.RegWrite RecoveryKey + "MiniDumpDir", "%SystemRoot%\MiniDump", "REG_EXPAND_SZ"
 WshShell.RegWrite RecoveryKey + "Overwrite", 1, "REG_DWORD"
 WshShell.RegWrite RecoveryKey + "SendAlert", 1, "REG_DWORD"


'==========================================================================
'=== Menu Time To 5 Seconds in BOOT.INI
'==========================================================================
' WScript.Echo " - Updating System Recovery Settings"
' SHELL "ATTRIB -R -S -H $BootINI"
' $RC = WRITEPROFILESTRING($BootINI, "BOOT LOADER", "TIMEOUT", "5")
' SHELL "ATTRIB +R +S +H $BootINI"


'==========================================================================
'=== Speedup NTFS Access (Disable LastAccessUpdate)
'==========================================================================
 WScript.Echo " - Disabling LastAccessUpdate value for NTFS file systems"
 WshShell.RegWrite FileSysKey + "NtfsDisableLastAccessUpdate", 1, "REG_DWORD"


'==========================================================================
'=== Enable Windows 10 (Anniversary Edition) and Later to Use Long Paths
'=== Updated On: 17 Apr 2018  (Prior Update: n/a)
'==========================================================================
 WScript.Echo " - Enable Long Paths (>260 chars) in most Applications"
 WshShell.RegWrite FileSysKey + "LongPathsEnabled", 1, "REG_DWORD"


'==========================================================================
'=== Change Setup Source Directory To "%SystemDrive%\Storage\i386"
'==========================================================================
 WScript.Echo " - Updating Setup Source Location to " + NTSourceLoc
 WshShell.RegWrite NTSetupKey + "SourcePath", NTSourceLoc, "REG_SZ"
 WshShell.RegWrite WinSetupKey + "SourcePath", NTSourceLoc, "REG_SZ"
 WshShell.RegWrite WinSetupKey + "Installation Sources", NTSourceLoc, "REG_SZ"


'==========================================================================
'=== Set Simultaneous File Downloads in Browsers to 10
'=== Updated On: 05 May 2022  (Prior Update: n/a)
'==========================================================================
 WScript.Echo " - Setting Simultaneous File Downloads to " & MaxConnValue
 WshShell.RegWrite MaxConnKey + MaxConnections, MaxConnValue, "REG_DWORD"
 WshShell.RegWrite MaxConnKey + MaxConnectionsV1, MaxConnValue, "REG_DWORD"


'==========================================================================
'=== Enable CMD Completion Characters
'==========================================================================
 WScript.Echo " - Enabling CMD Completion Characters"
 WshShell.RegWrite DefCMDProcKey, 9, "REG_DWORD"
 WshShell.RegWrite CMDProcKey, 9, "REG_DWORD"


'==========================================================================
'=== Expanding Console Window and Changing Edit Defaults
'=== Updated On: 22 Feb 2015  (Prior Update: 20 Jan 2015)
'==========================================================================
 WScript.Echo " - Setting Console Window Options"
 WshShell.RegWrite DefConsoleKey + "QuickEdit", 1, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "InsertMode", 1, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "HistoryNoDup", 1, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "HistoryBufferSize", 100, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "NumberOfHistoryBuffers", 10, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "ScreenBufferSize", 327680120, "REG_DWORD"
 WshShell.RegWrite DefConsoleKey + "WindowSize", 2424952, "REG_DWORD"

 WshShell.RegWrite UserConsoleKey + "QuickEdit", 1, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "InsertMode", 1, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "HistoryNoDup", 1, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "HistoryBufferSize", 100, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "NumberOfHistoryBuffers", 10, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "ScreenBufferSize", 327680120, "REG_DWORD"
 WshShell.RegWrite UserConsoleKey + "WindowSize", 2424952, "REG_DWORD"

 WshShell.RegWrite AdminConsoleKey1 + "QuickEdit", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "InsertMode", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "HistoryNoDup", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "HistoryBufferSize", 100, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "NumberOfHistoryBuffers", 10, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "ScreenBufferSize", 327680120, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey1 + "WindowSize", 2424952, "REG_DWORD"

 WshShell.RegWrite AdminConsoleKey2 + "QuickEdit", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "InsertMode", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "HistoryNoDup", 1, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "HistoryBufferSize", 100, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "NumberOfHistoryBuffers", 10, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "ScreenBufferSize", 327680120, "REG_DWORD"
 WshShell.RegWrite AdminConsoleKey2 + "WindowSize", 2424952, "REG_DWORD"


'==========================================================================
'=== Change CMD Prompt
'==========================================================================
 WScript.Echo " - Changing CMD Prompt to " + MyPrompt
 WshShell.RegWrite SysEnvironment, MyPrompt


'==========================================================================
'=== Cleanup and Exit Script
'=== Updated On: 22 Feb 2015  (Prior Update: n/a)
'==========================================================================
 WScript.Echo "FINISHED: Configuring Custom System Settings!"
 WScript.Echo
 Set WshShell = Nothing
 WScript.Quit(0)
                                                    