@REM - ASB (08 Nov 2004 // 01 Dec 2023 / 16 Oct 2023 / 05 Dec 2021 / 14 Jan 2021 / 03 Jan 2021 / 24 Dec 2020 / 30 Nov 2020 / 30 Jul 2020 / 28 Jul 2020 / 23 Mar 2020 / 31 Jan 2020): Update Local Script Repository from a Script Source or Local Zip
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v7.3.0.730

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=0 -c "H HELP ?" -x "?? H2" -s %* >NUL
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @HERE=%~dp0
 SET @INPUT=%~dp0Input\
 SET @DEST=%SystemDrive%\Scripts
 SET @UPDATE=%@DEST%\BAT\%~n0.BAT
 SET @R_INPUT=%@DEST%\BAT\Input

 CALL :FindList CLEANUP_MAIN   [SyncScripts]
 CALL :FindList CLEANUP_CUSTOM  SyncScripts
 CALL :FindList COPYEXEMPT-SRC [CopyExemption]
 CALL :FindList COPYEXEMPT-SUB [CopyExemption-Plus]
 SET @COPYEXEMPT=%@COPYEXEMPT-SUB%

 rem -- Process Special Command-line Parameters
 SET @ALL_PARAMS=%*
 CALL :GetParams "I INTERNET" & IF DEFINED @OK (SET @DOWNLOAD=TRUE) ELSE (SET @DOWNLOAD=)
 CALL :GetParams "D DEBUG"    & IF DEFINED @OK (SET @DEBUG=STEP& ECHO ON) ELSE (SET @DEBUG=)

 rem -- Discard Selected Parameters from Main Parameter List
 FOR %%S IN (%@SELECTED%) DO (
	 SET @ALL_PARAMS=!@ALL_PARAMS:"%%S"=!
	 SET @ALL_PARAMS=!@ALL_PARAMS:%%S=!
 )
 CALL :GetAllParams %~f0 !@ALL_PARAMS!

 rem -- Check for Local Zip File Repository
 SET @NEWSOURCE=Scripts_Source
 SET @LOCAL_DIR=%SystemDrive%\Temp\%@NEWSOURCE%
 SET @LOCAL_ZIP=!@LOCAL_DIR:%@NEWSOURCE%=BWSource.ZIP!

 rem -- Facilitate the Downloading of the Basic Script Repository Archive
 SET @CURL=& FOR /F %%V IN ('WHERE CURL 2^>NUL') DO SET @CURL=TRUE
 SET @GET_ARCHIVE=http://bit.ly/37PYM1W
 SET @SAV_ARCHIVE=!@LOCAL_DIR:%@NEWSOURCE%=BWSource-Optional.ZIP!

 IF EXIST "%@LOCAL_ZIP%" (
	 IF /I NOT "%~f0"=="%@UPDATE%" IF EXIST "%@LOCAL_DIR%" REN "%@LOCAL_DIR%" "%@NEWSOURCE%.%@DIRSTAMP%"
	 SET @UNZIP=
	 FOR /F %%V IN ('WHERE UNZIP 2^>NUL') DO SET @UNZIP=%%V -o
	 FOR /F %%V IN ('WHERE TAR   2^>NUL') DO SET @UNZIP=%%V -xf
	 IF NOT EXIST "%@LOCAL_DIR%" MD "%@LOCAL_DIR%" >NUL 2>NUL
	 PUSHD "%@LOCAL_DIR%"
	 NOW Extracting Files from Local ZIP Repository...   Please Wait...
	 CMD /C !@UNZIP! "%@LOCAL_ZIP%"
	 IF EXIST "%@LOCAL_DIR%\UTILS" (
		 XCOPY "%@LOCAL_DIR%\BWUTIL" "%@LOCAL_DIR%\UTILS" /D /R /F /Y /I /C /S
	 ) ELSE (
		 REN "%@LOCAL_DIR%\BWUTIL" "UTILS"
	 )
	 POPD
	 REN "%@LOCAL_ZIP%" "*.%@DIRSTAMP%.Zip"
	 IF DEFINED @UNZIP GOTO :FindValidSources
 )

 rem -- Verify Validity of Source Path List, And Determine If Current System Is a Source Server
 IF DEFINED @DOWNLOAD GOTO :VerifySourceAccess
 CALL :FindList SOURCELIST ScriptSource
 IF EXIST "%@SOURCELIST%" (
	 FOR /F "USEBACKQ SKIP=2 TOKENS=2 EOL=; DELIMS=\"  %%S IN ("%@SOURCELIST%") DO SET @SOURCESYS=!@SOURCESYS! %%~S
	 FOR /F "USEBACKQ SKIP=2 TOKENS=1 EOL=; DELIMS=, " %%R IN ("%@SOURCELIST%") DO SET @REPOSITORY=!@REPOSITORY! "%%~R"
	 FOR %%B IN (!@SOURCESYS!) DO IF /I "%COMPUTERNAME%"=="%%~B" SET @IS_SOURCE=TRUE
 ) ELSE (
	 ECHO:
	 ECHO No Valid Source File Found: "%@SOURCELIST%" Missing...
	 ECHO:
	 GOTO :ExitBatch
 )


 rem -- Cycle Through Repository Paths in File List And Select Last Viable Path
:FindValidSources
 SET @IS_SOURCE=FALSE& FOR %%B IN (%@SOURCESYS%) DO IF /I "%COMPUTERNAME%"=="%%~B" (SET @IS_SOURCE=TRUE& SET @COPYEXEMPT=%@COPYEXEMPT-SRC%)
 SET @USERSELECT=& IF NOT "%@PARAM1%"=="" SET @USERSELECT="\\%@PARAM1%" "\\%@PARAM1%\Scripts" "\\%@PARAM1%\Scripts_Source$\Scripts"
 SET @REPOSITORY=%@REPOSITORY% \\%COMPUTERNAME%\Scripts_Source$\Scripts
 CALL :FixDirectoryPaths @USERSELECT

 FOR %%R IN (%@LOCAL_DIR% %@USERSELECT% %@REPOSITORY%) DO (
	 ECHO Trying to connect to "%%~R"
	 IF EXIST "%%~R\BAT\%~n0.BAT" (
		 SET @UPDATE=%%~R\BAT\%~n0.BAT
		 SET @ACOPY=%%~R\BAT\aCopy.BAT
		 SET @SOURCE=%%~R
		 IF EXIST "!@UPDATE!" XCOPY "%@SCRIPTNAME%" "!@UPDATE!" /D /F /Y
		 GOTO :RunRemoteUpdate "%%~R"
	 )
 )


 rem -- Verify Access to the Script Source
:VerifySourceAccess
 IF DEFINED @DOWNLOAD SET @ACOPY=
 IF "%@ACOPY%"=="" (
	 ECHO:
	 IF DEFINED @DOWNLOAD (
		 ECHO *** NOTICE: Preparing to download the current Scripts Repository archive ***
	 ) ELSE (
		 ECHO *** ERROR: You cannot reach any Scripts Source.  Please check your local network connectivity ***
	 )

	 IF DEFINED @CURL (
		 ECHO:
		 ECHO --- Attempting to download latest Script Repository archive.  Please Wait...
		 CURL --url "%@GET_ARCHIVE%" --location --output "%@SAV_ARCHIVE%"
		 ECHO:
		 IF EXIST "%@SAV_ARCHIVE%" (
			 ECHO Rename "%@SAV_ARCHIVE%" to "%@LOCAL_ZIP%" and run GetScripts again...
			 ECHO:
		 )
	 )
	 GOTO :ExitBatch
 )


 rem -- Call Remote Copy of the Script in Case it Has Been Updated (If No Parameter #2)
:RunRemoteUpdate
 IF "%@PARAM2%"=="" IF /I NOT "%@SCRIPTNAME%"=="%@UPDATE%" (
	 %@UPDATE% %* 2>NUL
	 GOTO :ExitBatch
 )


 rem -- Initiate The Update of Scripts, Executables and Input Files
:Main
 ECHO:
 ECHO Updating Scripts - Please Wait...
 ECHO:
 ECHO %@DIVIDER-%
 ECHO --- Update Script: %@ACOPY%
 ECHO %@DIVIDER-%
 IF EXIST "%@SOURCE%\BAT\Input\Generic Input Files.zip" COPY "%@SOURCE%\BAT\Input\Generic Input Files.zip" "%@DEST%\BAT\Input" /Y
 IF EXIST "%@SOURCE%\UTILS"  CALL "%@ACOPY%" "%@SOURCE%\UTILS" "%@DEST%\UTILS" /EXCLUDE:%@COPYEXEMPT%
 IF EXIST "%@SOURCE%\BAT"    CALL "%@ACOPY%" "%@SOURCE%\BAT"   "%@DEST%\BAT"   /EXCLUDE:%@COPYEXEMPT%
 START "Batch File Repository" /MIN EXPLORER "%@DEST%\BAT"


 rem -- Remove any Custom Input/Source Files for machines that are not the current one
:RemoveCustom
 IF /I "!@IS_SOURCE!"=="FALSE" (
	 CALL :DeleteOtherFiles "%@R_INPUT%\*.*.TXT"
	 CALL :DeleteOtherFiles "%@R_INPUT%\CustomVariables.MINI.*.TXT"
 )


 rem -- Remove the Logon Scripts folder for all non-Source systems
:RemoveLogonScripts
 IF /I "!@IS_SOURCE!"=="FALSE" IF EXIST "%SystemDrive%\Scripts\Bat\LogonScripts" (
	 ECHO  - %SystemDrive%\Scripts\Bat\LogonScripts
	 RD /S /Q "%SystemDrive%\Scripts\Bat\LogonScripts"
 )

 rem -- Cleanup Obsolete Files from Local System Only
 CALL :DeleteObsoleteFiles \\%COMPUTERNAME%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 GOTO :FINAL_CMD >NUL 2>NUL


 rem -- SUBROUTINE: Find the Most Relevant Input List
:FindList
 rem %1 = Variable Name
 rem %2 = Base Filename

 IF "%~2"=="" GOTO :EOF
 SET @VAR1=%@INPUT%%~2.%COMPUTERNAME%.TXT
 SET @VAR2=%@INPUT%%~2.TXT

 IF EXIST "%@VAR1%" (SET @%~1=%@VAR1%) ELSE (SET @%~1=%@VAR2%)
 GOTO :EOF


 rem -- SUBROUTINE: Delete Obsolete Files from Local or Remote Repository
:DeleteObsoleteFiles
 rem %1 = Current System and Optional Path
 rem %2 = Optional UNC Share

 ECHO:
 ECHO:
 ECHO  ...Deleting Obsolete Files...
 SET @CLEANUP_LOC="%~1" "%~1\%~2" "%~1\%~2\Scripts" "%~1\Scripts" "%~1\Scripts$" "%~1\Scripts_Source$\Scripts"
	 IF "%~2"=="" SET @CLEANUP_LOC="%~1" "%~1\Scripts" "%~1\Scripts$" "%~1\C$\Scripts" "%~1\Scripts_Source$\Scripts"
	 IF "%~1"=="" SET @CLEANUP_LOC="\\%COMPUTERNAME%\Scripts$" "\\%COMPUTERNAME%\C$\Scripts$" "\\%COMPUTERNAME%\Scripts_Source$\Scripts"

 FOR %%P IN ("%@HERE%" !@CLEANUP_LOC! %@CLOUD_CLEAN%) DO IF NOT DEFINED $$_%%~P IF EXIST "%%~P\*.*" (
	 SET $$_%%~P=TRUE
	 FOR %%L IN ("%@CLEANUP_MAIN%" "%@CLEANUP_CUSTOM%") DO IF EXIST "%%~L" (
		 FOR /F "USEBACKQ TOKENS=* EOL=;" %%F IN ("%%~L") DO IF EXIST "%%~P\%%~F" (
			 IF /I "%DEBUG%"=="DELETE" (
				 ECHO  * %%~P\%%~F
			 ) ELSE (
				 ECHO  - %%~P\%%~F
				 ATTRIB -S -H -R "%%~P\%%~F"
				 DEL "%%~P\%%~F"
			 )
		 )
	 )
 )
 ECHO %@DIVIDER-%
 GOTO :EOF


 rem -- SUBROUTINE: Delete Custom Input/Source Files for Other Machines
:DeleteOtherFiles
 rem %1 = Path/Folder Wildcard to Check

 IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=*" %%C IN ('DIR /B /A "%~1" 2^>NUL ^| FINDSTR /I /V ".%COMPUTERNAME%.TXT .Test.TXT" ') DO (
	 ECHO  - %@R_INPUT%\%%~C
	 DEL "%@R_INPUT%\%%~C"
 )
 GOTO :EOF


 rem -- SUBROUTINE: Remove Trailing/Excess \ From Supplied Folder Variables
:FixDirectoryPaths
 rem %1 = Folder Variable

 IF NOT DEFINED %1 GOTO :EOF
 SET %~1=!%~1:\\Scripts=\Scripts!
 SET %~1=!%~1:\"="!
 SET %~1=!%~1:\\\\=\\!
 SET %~1=!%~1:\\\\=\\!
 GOTO :EOF


 rem -- SUBROUTINE: Use CheckParams.exe to Capture Selected Parameters
:GetParams
 rem %1 = Parameters to Search For
 rem %2 = Variable to Set

 SET @OK=& IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=2-3*" %%v IN ('CHECKPARAMS -q -a -c "%~1" -s %@ALL_PARAMS% 2^>NUL') DO IF /I "%%~v"=="TRUE" (
	 SET @OK=T
	 SET @REQ=T
	 IF NOT "%~2"=="" SET %~2=%%~x
	 IF "%%~w"=="" GOTO :EOF
	 SET @USED=%%~w
	 SET @USED=!@USED:[=!
	 SET @USED=!@USED:]=!
	 SET @SELECTED=!@SELECTED! !@USED!
 )
 GOTO :EOF


 rem -- SUBROUTINE: Parse All Parameters and Store them as Permanent Variables
:GetAllParams
 rem %* = ScriptName + All Other Parameters (up to 4)

 SET @FULLCMD=%*
 IF NOT DEFINED @FULLCMD GOTO :EOF
 SET @SCRIPTNAME=%~1
 SET @PARAM1=%~2
 SET @PARAM2=%~3
 SET @PARAM3=%~4
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Update Local Script Repository from a Script Source or Local Zip
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [OPTIONS] [remote_server]
 ECHO  %~n0  [-d^|-debug] [remote_server]
 ECHO  %~n0  [-i^|-internet]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H .......... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 ......... Display Extended Help Message
 ECHO  -I,  /INTERNET ... Bypass Local Source File and Obtain from Internet
 ECHO  -D,  /DEBUG ...... Enable Debug Mode
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 \\some_remote_server
	 ECHO  %~n0 -D
	 ECHO  %~n0 -D \\%COMPUTERNAME%
	 ECHO  %~n0 /I
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * If /D [/DEBUG] is used, it should be the first parameter, and
	 ECHO    not the second.
	 ECHO:
	 ECHO  * The local file "%SystemDrive%\Temp\BWSource.ZIP" will be used
	 ECHO    as the source, if it exists.
 )
 CALL :ShowStatus "FINISHED"
 GOTO :EOF


 rem -- Rename Folder and Exit Quietly
:FINAL_CMD
 IF EXIST "%@LOCAL_DIR%" REN "%@LOCAL_DIR%" "%@NEWSOURCE%.%@DIRSTAMP%"
                                                                           