@REM - ASB (03 Mar 2007 // 16 Oct 2023 / 10 Apr 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 31 Aug 2018 / 26 Jul 2018 / 29 Apr 2018 / 27 Mar 2016): Lookup IP Ranges from Lists
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.6.0.260

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Lookup IP Ranges from Lists
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<ip address ^| ip address range^>
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @SEGMENTS=%~dp0Input\NetworkSegments.TXT
 SET @RANGE=An Unknown/Undocumented Subnet Range
 SET @COUNT=0


 rem -- Perform IP Lookup
:MatchSubnet
 FOR /F "TOKENS=1-3* DELIMS=./" %%I IN ('ECHO %~1') DO SET @SUBNET=%%I.%%J.%%K

 rem -- Lookup Subnet from IP Range List
 CALL :DetermineSubnet "%~1"
 IF "%@IS_IP%"=="VALID" (
	 ECHO The IP %~1 is in the following range: %@RANGE%
 ) ELSE (
	 ECHO The IP %~1 is invalid.  Please provide a valid IPv4 address [i.e. 10.10.10.10]
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Find Matching Subnet based on IP Address
:DetermineSubnet
 rem %1 = IP Address To Evaluate

 SET @IS_IP=VALID

 FOR /F "TOKENS=1-4 DELIMS=./()[]" %%I IN ('ECHO %~1') DO (
	 SET @OCT1=%%I
	 SET @OCT2=%%J
	 SET @OCT3=%%K
	 SET @OCT4=%%L
	 SET @SUBNET=%%I.%%J.%%K.
 )

 FOR %%N IN ("%@OCT1%" "%@OCT2%" "%@OCT3%" "%@OCT4%") DO (
	 SET /A @COUNT+=1
	 IF %%~N0 LSS 00 SET @IS_IP=INVALID
	 IF %%~N0 GTR 2550 SET @IS_IP=INVALID
	 ECHO  -- Segment #!@COUNT! of %~1 is !@IS_IP!
 )

 ECHO:
 IF /I "%@IS_IP%"=="VALID" FOR /F "TOKENS=*" %%R IN ('TYPE "%@SEGMENTS%" ^| FIND /I "%@SUBNET%"') DO (
	 SET @RANGE=%%R
	 SET @RANGE=!@RANGE:^(=[!
	 SET @RANGE=!@RANGE:^)=]!
 )
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                   