@REM - ASB (30 Sep 2008 // 17 Oct 2023 / 16 Oct 2023 / 03 Jan 2021 / 30 Nov 2020 / 08 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 28 Oct 2018 / 26 Jul 2018 / 08 May 2018 / 09 Dec 2016): Create/Update Folder/Share for Scripts Repository
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Enable Debug Mode If 'Debug' Variable is Set to TRUE/LOG/STEP/VERBOSE
:DebugMode
 SET #DEBUG=& FOR %%d IN (LOG STEP TRUE VERBOSE) DO IF /I "%Debug%"=="%%~d" SET #DEBUG=TRUE
 IF DEFINED #DEBUG (
	 SET @DIAGMODE=TRUE
	 SET @DEBUG_MODE=[DEBUG MODE ON]
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:^& TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 IF /I "%Debug%"=="LOG" (SET @PAUSE_IF_DEBUG=& SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:)
	 IF /I "%Debug%"=="STEP" (SET @PAUSE_IF_DEBUG=ECHO ##PAUSE##& SET @PRINT_IF_DEBUG=ECHO ##PRINT##)
	 IF /I "%Debug%"=="VERBOSE" (SET @VERBOSE_OFF=ECHO ON) ELSE (FOR %%t IN (ON OFF) DO SET @VERBOSE_%%t=ECHO %%t)
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE ( FOR %%d IN (DEBUG_MODE PAUSE_IF_DEBUG PRINT_IF_DEBUG END_DEBUG_MODE VERBOSE_ON VERBOSE_OFF) DO SET @%%d=)


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.5.0.290

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %* >NUL
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @INPUT=%SystemDrive%\Scripts\Bat\Input\ScriptSource.TXT
 SET @MYEXE=Now DateInfo
 SET @DEST=%~1;&  IF /I "%~1"=="" SET @DEST=%SystemDrive%\Storage\Source\Repository
 SET @SHARE=%~2&  IF /I "%~2"=="" SET @SHARE=Scripts_Source$
 SET @REMARK=%~3& IF /I "%~3"=="" SET @REMARK=Remote Scripts Repository Share
 SET @CUSTOM=%~4& IF NOT EXIST "%~4" SET @CUSTOM=

 rem -- Drop Trailing \Scripts folder from Share Path, and any trailing \ characters
 FOR %%S IN (0,1,9) DO SET @DEST=!@DEST:\\=\!
 SET @DEST=!@DEST:\;=!
 SET @DEST=!@DEST:\Scripts;=!
 SET @DEST=!@DEST:;=!


 rem -- Allow User To Abort Operation
:DblCheck
 ECHO === Prepare to Create Scripts Repository Folder ===
 ECHO:
 ECHO  Folder Name ......... %@DEST%
 ECHO  Share Name .......... %@SHARE%
 ECHO  Share Descripton .... %@REMARK%
 IF DEFINED @CUSTOM ECHO  Custom Source ....... %@CUSTOM%
 ECHO:
 CHOICE /C YNQEX /T 20 /D Y /N /M "Continue running this script? (Y/N/Q) "
 IF !ERRORLEVEL! GTR 1 GOTO :ExitBatch


 rem -- Update Scripts and Utilities (Source Location)
:CreateRepository
 ECHO:
 ECHO Creating Scripts Repository
 ECHO %@DIVIDER*%
 ECHO:
 IF NOT EXIST "%@DEST%\Scripts" MD "%@DEST%\Scripts"
 IF EXIST "%~dp0Repository-Install.BAT" COPY "%~dp0Repository-Install.BAT" "%@DEST%\Install.BAT" /Y /V
 FOR %%F IN (%@MYEXE%) DO IF EXIST "%~dp0..\Utils\%%~F.exe" COPY "%~dp0..\Utils\%%~F.exe" "%@DEST%\%%~F.exe" /Y /V
 FOR /F "USEBACKQ EOL=; SKIP=2 TOKENS=1-3 DELIMS=, " %%S IN ("%@INPUT%") DO IF "!@DESTDIR!"=="" IF EXIST "%%~S\BAT" SET @DESTDIR=%%~S
 IF DEFINED @CUSTOM SET @DESTDIR=%@CUSTOM%
 CALL ACopy "%@DESTDIR%" "%@DEST%\Scripts"
 RMTSHARE \\%COMPUTERNAME%\%@SHARE% /DELETE
 RMTSHARE \\%COMPUTERNAME%\%@SHARE%=%@DEST% /UNLIMITED /GRANT Everyone:R /GRANT Administrators:F /REMARK:"%@REMARK%"
 RMTSHARE \\%COMPUTERNAME%\%@SHARE% /REMARK:"%@REMARK%"
 RMTSHARE \\%COMPUTERNAME%\%@SHARE%
 ECHO %@DIVIDER-%
 ECHO:


 rem -- Setting Permissions on Scripts Folders
:SetPermissions
 ECHO:
 ECHO Setting Restricted Permissions on Scripts Repository
 ECHO %@DIVIDER*%
 ECHO:
 ICACLS "%@DEST%\*" /grant:r "SYSTEM:(CI)(F)" "Administrators:(CI)(F)" "EVERYONE:(CI)(R)" /inheritance:e /T /C
 ICACLS "%@DEST%"   /grant:r "SYSTEM:(CI)(F)" "Administrators:(CI)(F)" "EVERYONE:(CI)(R)" /inheritance:e
 ICACLS "%@DEST%"
 ECHO %@DIVIDER-%
 ECHO:


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Create Folder and Network Share for Hosting Scripts Repository
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [local folder] [sharename] [sharename description] [custom source location]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 %SystemDrive%\Storage\Scripts_Source\MyDomain
	 ECHO  %~n0 %SystemDrive%\Storage\Source\%USERDOMAIN%  Scripts_Source$
	 ECHO  %~n0 "D:\My Scripts"  Repository$  "Scripts Archive"
	 ECHO  %~n0 "E:\Repository\Scripts"  ScriptsRepository$  "Scripts Repository" C:\Temp\Scripts
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * Long filenames which contain spaces must be surrounded by quotes.
	 ECHO    Shortnames *can* be surrounded by quotes, but it is not mandatory.
 )
 CALL :ShowStatus "FINISHED"
                                                                 