@REM - ASB (23 Oct 2013 // 16 Oct 2023 / 01 Dec 2020 / 24 Dec 2019 / 30 Sep 2019 / 26 Jul 2018 / 30 Apr 2018 / 25 Feb 2018 / 27 Mar 2016): Create Multiple Test Environments and Run Test Backups
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.1.0.210

 SET @PRIOR=%~2& IF "%~2"=="" SET @PRIOR=2
 SET @SCRIPTS=%~d0\Scripts\BAT

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage


 rem -- Verify Operation Before Proceeding
:VerifyOperation
 NOW \s \z Getting Ready to Run: %0 %* \n \-
 CHOICE /C YNQEX /T 20 /D Y /N /M "Continue running this script? (Y/N/Q) "
 IF ERRORLEVEL 2 GOTO :ExitBatch


 rem -- Call Other Scripts to Generate Environment
:MakeTempEnvironment
 IF "%~4"=="." CALL %@SCRIPTS%\Bat\CleanTemp

 FOR /L %%L IN (%@PRIOR%,-1,1) DO (
	 FOR /F %%D IN ('DATEINFO -p %%L -f "mm/dd/yy" -q') DO SET @MM/DD/YY=%%D
	 FOR /F %%D IN ('DATEINFO -p %%L -f "yyyy-mm-dd" -q') DO SET @YYYY-MM-DD=%%D
	 FOR %%I IN (TITLE CALL) DO CALL :RunCMD %%~I %@SCRIPTS%\MakeTempLogs !@MM/DD/YY!
	 FOR %%I IN (TITLE CALL) DO CALL :RunCMD %%~I %@SCRIPTS%\RetainBackups %~1 /d:!@YYYY-MM-DD! %~3
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Execute Dynamic Command From Variable
:RunCMD
 rem %1 = Command To Execute

 %*
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Create Multiple Test Environments and Run Test Backups
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<name of RetainBackups job^> [# of days in past] [OTHER] [SPECIAL]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO   -?,  /H  ... Display This Help Message  (also --HELP)
 ECHO   -??, /H2 ... Display Extended Help Message
 ECHO        /R .... The 3rd parameter is used by RetainBackups.BAT, if it exists
 ECHO        .  .... The 4th parameter, if it exists, will clean out all old jobs
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 MultiTest 10
	 ECHO  %~n0 MultiTest2 5
	 ECHO  %~n0 SomeTest 20 "/R"
	 ECHO  %~n0 OtherTest 15 "" .
	 ECHO  %~n0 /?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
                           