@REM - ASB (29 Mar 2006 // 16 Oct 2023 / 30 Nov 2020 / 20 Sep 2020 / 24 Dec 2019 / 30 Sep 2019 / 26 Jul 2018 / 27 Mar 2016 / 05 May 2015): Create a Temp Log Folder Structure for Testing Scripts
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.4.0.340

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Main Variables
 SET @DEST=%SystemDrive%\Temp\Logs
 SET @DATE=%~1& IF "%~1"=="" SET @DATE=01/01/11
 SET @TIME=%~2& IF "%~2"=="" SET @TIME=00-15-00
 SET @DATE=%@DATE:-=/%
 SET @TIME=%@TIME::=-%
 SET @VALID=
 SET @DIVIDER*=*******************************************************


 rem -- Verify Date and Time Format
:VerifyInput
 FOR /F "TOKENS=1-6 DELIMS=/-:" %%A IN ('ECHO %@DATE%:%@TIME%') DO (
	 IF 1%%~A GEQ 11 IF %%~A LEQ 112 SET @VALID=TRUE;!@VALID!
	 IF 1%%~B GEQ 11 IF %%~B LEQ 131 SET @VALID=TRUE;!@VALID!
	 IF 1%%~C GEQ 10 IF %%~C LEQ 199 SET @VALID=TRUE;!@VALID!
	 IF 1%%~D GEQ 10 IF %%~D LEQ 123 SET @VALID=TRUE;!@VALID!
	 IF 1%%~E GEQ 10 IF %%~E LEQ 159 SET @VALID=TRUE;!@VALID!
	 IF 1%%~F GEQ 10 IF %%~F LEQ 159 SET @VALID=TRUE;!@VALID!
 )
 IF /I NOT "!@VALID!"=="TRUE;TRUE;TRUE;TRUE;TRUE;TRUE;" GOTO :HelpMessage


 rem -- Generate or Replenish Log Files
:Main
 IF EXIST "%@DEST%-Source" (
	 CALL aCopy "%@DEST%-Source" "%@DEST%"
 ) ELSE (
	 FOR %%V IN (Replication Debug Defrag Maint) DO (
		 FOR %%D IN (C D E F) DO (
			 SET @SOURCE=%%~D:\Storage\Logs\%%~V
			 IF EXIST "!@SOURCE!\*.*" (
				 ECHO Copying Files from "!@SOURCE!" to "%@DEST%\%%~V"
				 CALL aCopy "!@SOURCE!" "%@DEST%\%%~V"
			 )
		 )
	 )
 )


 rem -- Change the Time/Date on All Log Files and Make Backup
:TimeStamp
 FILEDATE "%@DEST%\*.*" %@DATE% %@TIME% /r
 CALL aCopy "%@DEST%" "%@DEST%-Source"


 rem -- Create Zip Archives
:ArchiveLogs
 CALL ZipLogs-Daily "%@DEST%" 2 10 TRUE
 SCHTASKS /DELETE /TN "Daily Log Archive of [C_Temp_Logs]" /F
 FILEDATE "%@DEST%\*.ZIP" %@DATE% %@TIME% /r
 CALL aCopy "%@DEST%-Source" "%@DEST%"
 DIR "%@DEST%" /S /A
 ECHO:
 ECHO:
 ECHO %@DIVIDER*%
 ECHO *** Date and Time of Logs set to %@DATE% at %@TIME:-=:%
 ECHO %@DIVIDER*%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Create a Temp Log Folder Structure for Testing Scripts
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [date in dd/mm/yy format] [time in hr-min-sec format]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 10/01/04
	 ECHO  %~n0 02/02/12 10-10-00
	 ECHO  %~n0 04/14/10 12:30:00
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
                                                        