@REM - ASB (04 Apr 2011 // 15 Apr 2024 / 06 Apr 2024 / 18 Mar 2024 / 16 Mar 2024 / 12 Mar 2024 / 16 Oct 2023 / 21 Jan 2022 / 12 Jan 2022 / 17 Dec 2021 / 14 Apr 2021 / 30 Nov 2020 / 24 Dec 2019): Select Systems to RDP to from a List
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v6.0.0.600

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Check for Essential Utilities and/or Scripts
 SET @ESSENTIALS=CHECKPARAMS.EXE DATEINFO.EXE NOW.EXE CHCP.COM FIND.EXE
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f %@ESSENTIALS% CHOICE.EXE FINDSTR.EXE MSTSC.EXE PSLIST.EXE SLEEP.EXE TASKLIST.EXE TIMEOUT.EXE
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Determine Which Console Session is Active for the Script
 SET @SERVICE_ACCTS="SYSTEM" "NTAUTHORITY" "Services"
 SET @CONSOLE_SESSION=TRUE& FOR %%u IN (%@SERVICE_ACCTS%) DO IF /I "%USERNAME%"=="%%~u" SET @CONSOLE_SESSION=FALSE
 IF DEFINED @NOPROMPT SET @CONSOLE_SESSION=FALSE

 SET @INPUT=%~d0\Scripts\BAT\Input
 SET @LONGWAIT=180
 SET @WAIT=10
 SET @NUM=0
 SET @FIND_RDP=IMAGENAME eq MSTSC.exe
 SET @ORPHANED=0:00:0..Remote.Desktop.Connection
 SET @W10_CHECK=Wait:Unknown
 SET @W11_CHECK=Wait:LpcReply
 SET @CLEANUP=N
 SET @FINISH=
 
 rem -- Determine Correct Check for Win11 vs Win10 and earlier
 IF %@OSBUILD% LEQ 19045 (SET @RDP_CHECK=%@W10_CHECK%) ELSE (SET @RDP_CHECK=%@W11_CHECK%)
 

 rem -- Determine Correct Server Input List
:DetermineList
 IF "%~1"=="" (
	 SET @FINDLIST="%@INPUT%\MyServers"
 ) ELSE (
	 SET @FINDLIST="%~dpn1" "%~n1*" "%~dp0%~n1*" "%~dp0Input\%~n1*" "%~dp0Input\*%~1*" "%@INPUT%\%~n1*" "%@INPUT%\*%~1*" "%@INPUT%\MyServers" "*%~dpn1*"
 )

 FOR %%F IN (%@FINDLIST%) DO FOR %%E IN ("" ".%COMPUTERNAME%.TXT" ".TXT") DO IF EXIST "%%~F%%~E" IF NOT DEFINED #ASKED_%%~F%%~E (
	 SET @SOURCE=%%~F%%~E
	 SET #ASKED_%%~F%%~E=TRUE
	 IF /I "!@SOURCE:~-4!"==".TXT" (
		 IF /I "%@CONSOLE_SESSION%"=="TRUE" (
			 CHOICE /C ACYNQEX /T 10 /D Y /N /M "Use the following system list? - '!@SOURCE!' "
		 ) ELSE (
			 CHOICE /C Y /T 0 /D Y /N
		 )
	 )
	 IF ERRORLEVEL 5 GOTO :ExitBatch
	 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 3 (SET @WAIT=0)
	 IF ERRORLEVEL 2 IF NOT ERRORLEVEL 3 (SET @CLEANUP=Y& GOTO :SessionCleanup)
	 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 4 (GOTO :InitiateRDP)
 )


 rem -- Abort script if no system list has been provided/accepted
:AbortExecution
 ECHO:
 ECHO ERROR: No Valid System List Was Provided -- Script Execution Aborted...
 ECHO:
 GOTO :HelpMessage


 rem -- Initiate Remote Connection to Systems that are Currently Inactive
:InitiateRDP
 TITLE Manage RDP Connections
 ECHO %@DIVIDER-%
 ECHO  Using Server List: "%@SOURCE%"
 ECHO %@DIVIDER-%

 rem -- Find Previous RDP Sessions for a Specific Computer
 FOR /F "TOKENS=1,6* USEBACKQ EOL=;" %%C IN ("%@SOURCE%") DO (
	 CALL :SetVar @DESCRIPTION=%%E
	 SET @ISRUNNING=FALSE
	 SET @COMPUTER=%%~C& SET @COMPUTER=!@COMPUTER:\=!
	 SET @ID=00!@NUM!
	 SET @ID=!@ID:~-3!
	 SET @INDEX=@RDP_!@ID!_!@COMPUTER!
	 SET !@INDEX!=
	 SET /A @NUM+=1

	 ECHO:
	 ECHO Searching for RDP session on !@COMPUTER! [!@DESCRIPTION!]
	 IF /I "%COMPUTERNAME%"=="!@COMPUTER!" (
		 ECHO *** Cannot Connect Remotely to Local System ***
	 ) ELSE (
		 CALL :RemoveObsoleteSessions !@COMPUTER!

		 IF /I "!@CLEANUP!"=="N" (
			 IF /I "!@ISRUNNING!"=="FALSE" (
				 CHOICE /C COAFYNEXQ /T !@WAIT! /D Y /N /M "Connect to !@COMPUTER!? (A/O/F/Y/N/X/Q) "
				 IF ERRORLEVEL 8 (
					 ECHO:
					 ECHO *** Aborting RDP initiation process...
					 GOTO :ExitBatch
				 )
				 IF ERRORLEVEL 7 GOTO :LaunchRDP
				 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 4 (SET @WAIT=0)
				 IF ERRORLEVEL 4 IF NOT ERRORLEVEL 5 (SET @FINISH=TRUE)
				 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 3 (SET @CLEANUP=Y& GOTO :SessionCleanup)
				 IF NOT ERRORLEVEL 6 (
					 ECHO  - RDP session will be initiated on !@COMPUTER!
					 SET !@INDEX!=START
					 IF DEFINED @FINISH GOTO :LaunchRDP
				 )
			 ) ELSE (
				 ECHO  - RDP session already running on !@COMPUTER!
				 SET !@INDEX!=RUNNING
			 )
		 )
	 )
 )


 rem -- Launch Selected RDP Sessions in selected order
:LaunchRDP
 ECHO:
 ECHO:
 ECHO Initiating RDP Sessions...
 ECHO %@DIVIDER-%
 FOR /F "TOKENS=3-4 DELIMS=_=" %%R IN ('SET @RDP_ 2^>NUL') DO IF /I "%%~S"=="START" (
	 ECHO  - Initiating RDP session on %%~R
	 START MSTSC /ADMIN /V:%%~R
	 SLEEP 5
 )


 rem -- Find Previous RDP Sessions that Are Not Connected to any Computer
:SessionCleanup
 ECHO %@DIVIDER*%
 ECHO:
 CHOICE /C WYNEXQ /T %@LONGWAIT% /D %@CLEANUP% /N /M "Clean up Orphaned RDP Connections? (W/Y/N/X/Q) "
 IF NOT ERRORLEVEL 2 (ECHO Please Wait for %@LONGWAIT% Seconds...& SLEEP %@LONGWAIT%)
 IF NOT ERRORLEVEL 3 (CALL :RemoveObsoleteSessions)


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set Variable Without Trailing Spaces
:SetVar
 rem %* = Variable to Set

 SET %*
 GOTO :EOF


 rem -- SUBROUTINE: Check for Existing/Active/Orphaned RDP Sessions
:RemoveObsoleteSessions
 rem %1 = Name of Computer; If Blank Then Evaluate All RDP Sessions

 SET @CHECKALL=& IF "%~1"=="" SET @CHECKALL=TRUE

 IF DEFINED @CHECKALL (
	 ECHO:
	 ECHO Searching for any orphaned/zombie RDP Connections...
	 FOR /F "TOKENS=2" %%R IN ('TASKLIST /FI "%@FIND_RDP%" /V 2^>NUL ^| FINDSTR /I /R "%@ORPHANED%" ') DO PSKILL %@PSPARAMS% -t %%~R | FIND "."
	 FOR /F "TOKENS=2" %%R IN ('TASKLIST /FI "%@FIND_RDP%" /V 2^>NUL ^| FIND ":" ') DO (
		 SET @ISRUNNING=PARTIAL
		 FOR /F %%A IN ('PSLIST %@PSPARAMS% -X %%~R 2^>NUL ^| FIND /I "%@RDP_CHECK%" ') DO SET @ISRUNNING=TRUE
		 IF /I "!@ISRUNNING!"=="PARTIAL" PSKILL %@PSPARAMS% -t %%~R
	 )
 ) ELSE (
	 FOR /F "TOKENS=2" %%R IN ('TASKLIST /FI "%@FIND_RDP%" /V 2^>NUL ^| FIND /I "%~1" ') DO (
		 SET @ISRUNNING=PARTIAL
		 FOR /F %%A IN ('PSLIST %@PSPARAMS% -X %%~R 2^>NUL ^| FIND /I "%@RDP_CHECK%" ') DO SET @ISRUNNING=TRUE
		 IF /I "!@ISRUNNING!"=="PARTIAL" (
			 PSKILL %@PSPARAMS% -t %%~R
			 SET @ISRUNNING=FALSE
		 )
	 )
 )
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Manage RDP Connections [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Select Systems to RDP to from a List
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [list_of_systems]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:
 ECHO -------------------
 ECHO CHOICE SELECTIONS:
 ECHO -------------------
 ECHO        A ..... Select ALL without further prompting and connect via RDP
 ECHO        C ..... CLEAN all orphaned sessions without further prompting; make no RDP connections
 ECHO        W ..... CLEAN all orphaned sessions without further prompting, after 3 minutes
 ECHO        O ..... Select NO to current entry; clean all ORPHANED sessions without further prompting; process existing requests
 ECHO        F ..... Select YES to current entry; FINISH making requests; process exising requests
 ECHO        Y ..... Select YES to current entry; continue making requests
 ECHO        N ..... Select NO to current entry; continue making requests
 ECHO        E ..... Select NO to current entry; END new requests; process existing requests
 ECHO        X ..... EXIT immediately without processing any requests
 ECHO        Q ..... QUIT immediately without processing any requests (same as X)
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 MyList
	 ECHO  %~n0 E:\ThisList.TXT
	 ECHO  %~n0 %~dp0Input\ServerList.TXT
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Long filenames which contain spaces must be surrounded by quotes.
	 ECHO:
	 ECHO  * The filename of the list used for processing must be a short name.
	 ECHO:
	 ECHO  * Alternate ServerList files can be specified using their full path.
	 ECHO    For files which reside in the default INPUT folder, you can use the
	 ECHO    filename only.  (The default INPUT folder is %SystemDrive%\Scripts\Bat\Input)
 )
 CALL :ShowStatus "FINISHED"
                                                      