@ECHO OFF
 rem ==========================================================================
 rem === Map The Highest Free Drive To A Remote Resource
 rem ==========================================================================
 rem
 rem Created On: 29 May 2001
 rem         By: Andrew S. Baker (based on an idea by George Lenzer)
 rem
 rem Updated On: 06 Sep 2001
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: NT4 or later
 rem
 rem  Non-Native Utilities Required: NONE
 rem ==========================================================================

 :::  This script uses PUSHD to find the highest free drive which
 :::  is available to be mapped to a remote resource, and then it
 :::  makes the connection, tracking the chosen variable for use
 :::  with other scripts.  It will check to see if the resource
 :::  is already mapped, and if so, it will simply open the
 :::  existing connection. The remote resource can be supplied by
 :::  the variable "@RESOURCE" or it can be provided as a command
 :::  line parameter.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 06 Sep 2001
 rem ==========================================================================
:NeedHelp
 IF "%~1"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 23 Aug 2001
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @RESOURCE=%~1
 SET @DRIVE=


 rem ==========================================================================
 rem === Check For Existing Network Connection To Resource
 rem === Last Modified On 29 May 2001
 rem ==========================================================================
:Check
 FOR /F "TOKENS=2" %%V IN ('NET USE ^| FIND /I "%@RESOURCE%"') DO SET @DRIVE=%%V
 IF /I NOT "%@DRIVE%"=="" (
   ECHO "%@RESOURCE%" Is Already Mapped To %@DRIVE%
   START %@DRIVE%
   GOTO :ExitBatch
 )


 rem ==========================================================================
 rem === Map Resource To Highest Free Drive
 rem === Last Modified On 29 May 2001
 rem ==========================================================================
:SetDrive
 PUSHD "%@RESOURCE%"
 IF %ERRORLEVEL% EQU 0 FOR /F "DELIMS=\" %%D IN ('CD') DO SET @DRIVE=%%D
 POPD
 IF /I "%@DRIVE%"=="" (
   ECHO Unable To Map "%@RESOURCE%" To Any Drive Letter...
   ECHO:
   ECHO Script Aborted.
   GOTO :ExitBatch
 )
 NET USE %@DRIVE% "%@RESOURCE%"
 START %@DRIVE%


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 29 May 2001
 rem ==========================================================================
:ExitBatch
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 23 Aug 2001
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for MAPDRIVE.BAT
 ECHO:
 ECHO === MapDrive [HIGHEST^|LOWEST] {\\remote_server\share}
 ECHO:
 ECHO Example: MapDrive \\MyPDC\SomeResource
 ECHO          MapDrive \\FileServer\SomeDir\OtherResource
 ECHO          MapDrive "\\FileServer\Long Folder\Resource"
 ECHO          MapDrive HIGHEST \\FileServer\SomeDir
 ECHO          MapDrive LOWEST \\MyPDC\YourResource
 ECHO          MapDrive LOWEST "\\FileServer\Long Folder\Resource"
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Share/Folder names containing spaces
 ECHO       should be surrounded by quotation marks.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
