@ECHO OFF
 rem ==========================================================================
 rem === Create Local Client Mapping in Citrix, Unless It Already Exists
 rem ==========================================================================
 rem
 rem Created On: 18 Apr 2008
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 16 Oct 2023 / 30 Nov 2020              
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 08 Mar 2019              
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to TRUE/LOG/STEP/VERBOSE
 rem === Updated On: 13 May 2020 / 08 Mar 2019              
 rem ==========================================================================
:DebugMode
 SET #DEBUG=& FOR %%d IN (LOG STEP TRUE VERBOSE) DO IF /I "%Debug%"=="%%~d" SET #DEBUG=TRUE
 IF DEFINED #DEBUG (
	 SET @DIAGMODE=TRUE
	 SET @DEBUG_MODE=[DEBUG MODE ON]
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:^& TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 IF /I "%Debug%"=="LOG" (SET @PAUSE_IF_DEBUG=& SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:)
	 IF /I "%Debug%"=="STEP" (SET @PAUSE_IF_DEBUG=ECHO ##PAUSE##& SET @PRINT_IF_DEBUG=ECHO ##PRINT##)
	 IF /I "%Debug%"=="VERBOSE" (SET @VERBOSE_OFF=ECHO ON) ELSE (FOR %%t IN (ON OFF) DO SET @VERBOSE_%%t=ECHO %%t)
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE ( FOR %%d IN (DEBUG_MODE PAUSE_IF_DEBUG PRINT_IF_DEBUG END_DEBUG_MODE VERBOSE_ON VERBOSE_OFF) DO SET @%%d=)


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 30 Nov 2020 / 08 Mar 2019              
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.4.0.240

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Main Variables
 SET @MYSHARE=\\CLIENT& IF DEFINED DEBUG SET @MYSHARE=\\%COMPUTERNAME%
 SET @DRIVES=C D E
 SET @MAPPED=FALSE
 SET @OPTION=NEW /NEW -NEW TRUE /TRUE -TRUE CLEAR /CLEAR -CLEAR YES /YES -YES
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Create Local Client Mapping in Citrix, Unless It Already Exists
 rem === Updated On: 04 May 2011 / 23 Mar 2011              
 rem ==========================================================================
:MapDrive
 ECHO:
 ECHO Preparing to Map Local Drives...
 ECHO:

 FOR /F "TOKENS=2-3" %%S IN ('NET USE ^| FIND /I "%@MYSHARE%\"') DO (
	 FOR %%D IN (%@DRIVES%) DO IF /I "%%~T"=="%@MYSHARE%\%%~D$" (
		 SET @MAPPED=TRUE
		 FOR %%O IN (%@OPTION%) DO IF /I "%~1"=="%%~O" CALL :DeleteMapping %%~S %%~T
	 )
 )

 IF /I "%@MAPPED%"=="FALSE" (
	 FOR %%D IN (%@DRIVES%) DO (
		 FOR /F %%M IN ('NET USE * %@MYSHARE%\%%~D$ /PERSISTENT:YES 2^>NUL ^| FIND /I "successfully."') DO ECHO Mapping to %@MYSHARE%\%%~D$ ...
	 )
 ) ELSE (
	 ECHO Client Drives Already Mapped...
 )
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 03 Oct 2019 / 08 Mar 2019              
 rem ==========================================================================
:ExitBatch
 IF DEFINED DEBUG NET USE
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Delete Mapped Drives
 rem === Updated On: 04 May 2011 / 18 Apr 2008              
 rem ==========================================================================
:DeleteMapping
 rem %1 = Current Drive Letter
 rem %2 = Old String To Change
 SET @DRIVE=%~1
 SET @SHARE=%~2
 SET @MAPPED=FALSE

 IF /I "%@DRIVE:~1,1%"==":" ECHO Unmapping %@DRIVE% From "%@SHARE%" ...
 IF /I "%@DRIVE:~0,2%"=="\\" ECHO Unmapping "%@DRIVE%" ...
 NET USE %@DRIVE% /D /Y >NUL
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019              
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Updated On: 30 Nov 2020 / 08 Mar 2019              
 rem ==========================================================================
:HelpMessage
 ECHO Create Local Client Mapping in Citrix, Unless It Already Exists
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [option_to_clear_all_drive_mappings]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO  -CLEAR ...... Clear All Drive Mappings (also /TRUE or /YES)
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 TRUE
	 ECHO  %~n0 /TRUE
	 ECHO  %~n0 CLEAR
	 ECHO  %~n0 /CLEAR
	 ECHO  %~n0 YES
	 ECHO  %~n0 /YES
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
                                                             