@REM - ASB (27 Dec 2012 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 27 May 2019 / 31 Aug 2018 / 26 Jul 2018 / 14 May 2018): Migrate Scheduled Jobs to New Folder
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.3.0.190

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=4 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Migrate Scheduled Jobs to New Folder
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<system^> ^<jobname^> ^<new folder^> ^<service account^> [password ^| *]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Standard Log Variables
 SET @LOGINFO=%~n0.%@FILESTAMP_R%
 SET @LOGFILE=%TEMP%\%@LOGINFO%.TXT
 SET @TEMPLOG=%TEMP%\%@LOGINFO%.TEMP.TXT

 rem -- Main Variables
 SET @SYSTEM=%~1& IF "%~1"=="" SET @SYSTEM=%COMPUTERNAME%
 SET @SYSTEM=%@SYSTEM:\=%
 SET @WHICHTASK=%~2
 SET @NEWFOLDER=%~3& IF "%~3"=="\" SET @NEWFOLDER=
 SET @ACCOUNT=%~4
 SET @PASSWORD=%~5& IF "%~5"=="." FOR /F "TOKENS=*" %%P IN ('GetInput -p "Please Enter New Password: " -q') DO SET @PASSWORD="%%P"
 SET @PASSWORD="!@PASSWORD:"=!"
 SET @READONLY=FALSE& IF "%~5"=="" SET @READONLY=TRUE
 SET @EXCLUDE=Microsoft\
 SET @TASKNAME=TaskName:
 SET @JOBPARAM=Task to Run:
 SET @RUNAS=Run As User:
 SET @SCHTASKS=SCHTASKS /S %@SYSTEM% /QUERY /FO LIST


 rem -- Execute Commands Against Selected Systems
:Main
 CLS
 ECHO:
 ECHO Looking for Scheduled Tasks Matching the Following:
 ECHO %@DIVIDER-%
 ECHO  SYSTEM ....... %@SYSTEM%
 ECHO  TASK NAME .... %@WHICHTASK%
 ECHO  ACCOUNT ...... %@ACCOUNT%
 ECHO  NEW FOLDER ... %@NEWFOLDER%
 ECHO %@DIVIDER-%

 FOR /F "TOKENS=1* DELIMS=\" %%S IN ('%@SCHTASKS% ^| FIND /I "%@TASKNAME%" ^| FIND /I /V "%@EXCLUDE%"') DO (
	 FOR /F "TOKENS=1* DELIMS=\" %%z IN ('%@SCHTASKS% /V /TN "%%~T" ^| FIND /I "%@RUNAS%" ^| FIND /I "%@ACCOUNT%"') DO (
		 %@SCHTASKS% /V /TN "%%~T" >"%@TEMPLOG%" 2>&1
		 FOR /F "TOKENS=3* DELIMS=: " %%J IN ('TYPE "%@TEMPLOG%" ^| FIND /I "%@JOBPARAM%"') DO (
			 SET @TASKINFO=%%~K
			 SET @TASKINFO=!@TASKINFO:"=!
			 ECHO:
			 IF /I "%@READONLY%"=="TRUE" (
				 ECHO Displaying Task Info for: %%~T
				 TYPE "%@TEMPLOG%" >CON
				 TIMEOUT 10
			 ) ELSE (
				 ECHO Setting Credentials for: %%~T
				 ECHO SCHTASKS /S %@SYSTEM% /CHANGE /TN "%%~T" /TR "!@TASKINFO!" /RU %@ACCOUNT% /RP %@PASSWORD%
			 )
			 ECHO:
		 )
	 )
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 IF EXIST "%@TEMPLOG%" DEL "%@TEMPLOG%" >NUL
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                           