@REM - ASB (15 Jul 2010 // 09 Apr 2024 / 16 Oct 2023 / 30 Nov 2020): Separate Huge Collection of Log Files into Subfolders by Date
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.0.0.400

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Separate Huge Collection of Log Files into Subfolders by Date
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<base folder^> [valid extensions] ***
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO      OPTIONS:
	 ECHO      Base Folder ......... D:\Logs
	 ECHO      Extensions .......... TXT LOG
	 ECHO:
	 ECHO      EXAMPLE: %~n0 D:\MyLogs
	 ECHO               %~n0 E:\LogFiles "TXT LOG INFO"
	 ECHO               %~n0 D:\MyLogs "TXT DAT"
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO    * If selecting multiple extensions, put them in quotes.
	 GOTO :ExitBatch
 )

 rem -- Check for Essential Utilities and/or Scripts
 SET @ESSENTIALS="%~dp0SetDrive.BAT" CHECKPARAMS.EXE DATEINFO.EXE NOW.EXE READCONFIG.EXE SUBSTRING.EXE CHCP.COM FIND.EXE
 SET @MSUTILS=CHOICE.EXE TREE.COM
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f %@ESSENTIALS% %@MSUTILS% TIMEOUT.EXE
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Default Variables (Override via CustomVariables.*.TXT)
 SET @BASE_EXT=TXT LOG

 rem -- Set Global Variables from Centralized Script
 CALL "%~dp0SetDrive.BAT" "%~n0"

 rem -- Main Variables
 SET @BASEDIR=%~1
 SET @EXTS=%~2& IF "%~2"=="" SET @EXTS=%@BASE_EXT%
 IF DEFINED @EXTS (
	 FOR /F "TOKENS=*" %%s IN ('SUBSTRING "!@EXTS!" "*" "" 2^>NUL') DO SET @EXTS=%%s
	 SET @EXTS=!@EXTS:"=!
	 SET @EXTS=!@EXTS:.=!
	 SET @EXTS=!@EXTS:?=!
 )
 FOR %%E IN (%@EXTS%) DO SET @SHOW_EXTS=!@SHOW_EXTS! *.%%~E


 rem -- Determine that Files with Correct Format Exist in Current Folder
:VerifyFiles
 SET @ERRORMSG=** No Valid Log Files Exist in "%@BASEDIR%"...
 IF NOT EXIST "%@BASEDIR%" SET @ERRORMSG=** The Directory "%@BASEDIR%" does not exist...
 FOR %%E IN (%@EXTS%) DO IF EXIST "%@BASEDIR%\*.%%~E" SET @ERRORMSG=

 IF DEFINED @ERRORMSG (
	 ECHO %@ERRORMSG%
	 ECHO:
	 GOTO :ExitBatch
 )


 rem -- Verify the Job Operation Parameters
:VerifyOperation
 ECHO Please verify that you want to created dated folders to move your log files into:
 ECHO %@DIVIDER-%
 ECHO   -- Base Folder ............ "%@BASEDIR%"
 ECHO   -- Search for .............%@SHOW_EXTS%
 ECHO %@DIVIDER-%

 IF /I "%@CONSOLE_SESSION%"=="TRUE" (
	 CHOICE /C YNQEX /T 20 /D Y /N /M "Continue running this script? (Y/N/Q) "
	 IF !ERRORLEVEL! GTR 1 GOTO :ExitBatch
 )


 rem -- Create Subfolders and Move Files as Necessary
:MoveLogFiles
 ECHO
 ECHO Processing Logs in "%@BASEDIR%"

 PUSHD "%@BASEDIR%"
 FOR %%E IN (%@EXTS%) DO FOR %%F IN ("%@BASEDIR%\*.%%~E") DO (
	CALL :GetFileInfo "%%~F"
	IF NOT "!@DIRDATE!"=="%@YYYY%-%@MM%" IF NOT "!@DIRDATE!"=="%@LASTMONTH_EXP%" (
		IF NOT EXIST "!@DIRDATE!" MD "!@DIRDATE!"
		ECHO Moving [!@DIRDATE!] - "%%~F"
		MOVE "%%~F" "!@DIRDATE!"
	 )
 )


 rem -- Generate Final Report
:FinalReport
 ECHO
 ECHO Final Report
 ECHO %@DIVIDER-%
 TREE
 ECHO %@DIVIDER-%
 TIMEOUT 30
 TREE /F
 POPD


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Get File Date Info
:GetFileInfo
 rem %1 = Current Filename

 FOR %%f IN ("%~1") DO SET @FILEDATE=%%~tf
 FOR /F "TOKENS=*" %%d IN ('DATEINFO -S "!@FILEDATE!" -F "YYYY-MM" -Q 2^>NUL') DO SET @DIRDATE=%%~d
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                             