@REM - ASB (03 Nov 2013 // 16 Oct 2023 / 06 Jun 2023 / 31 Jan 2022 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 26 Jul 2018 / 29 Apr 2018): Move Dated Memory Dump Files to File Server
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.2.0.220

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Move Dated Memory Dump Files to File Server
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [system] [remote_storage_location]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @SYSTEM=%~1& IF "%~1"=="" (SET @SYSTEM=\\%COMPUTERNAME%) ELSE (SET @SYSTEM=\\!@SYSTEM:\=!)
 SET @DUMPFILES=%@SYSTEM%\ADMIN$\????-??-?? *MEMORY.DMP
 SET @REPOSITORY=%~2& IF "%~2"=="" SET @REPOSITORY=%@FILESERVER%\Maint\Diagnostics


 rem -- Verify Destination Folder
:VerifyDestination
 IF NOT EXIST "%@REPOSITORY%" MD "%@REPOSITORY%"
 IF NOT EXIST "%@REPOSITORY%" (
	 ECHO CANNOT FIND "%@REPOSITORY%" ...
	 GOTO :ExitBatch
 )


 rem -- Move Dated Memory Dump Files to File Server
:MoveFiles
 ECHO Searching for Memory Dump Files on %@SYSTEM%
 IF EXIST "%@DUMPFILES%" (
	 IF NOT EXIST "%@REPOSITORY%\%@SYSTEM:\=%" MD "%@REPOSITORY%\%@SYSTEM:\=%"
	 ECHO:
	 DIR "%@DUMPFILES%" | FIND ":"
	 ECHO:
	 ECHO **** MOVING MEMORY DUMP FILES TO NETWORK ****
	 MOVE "%@DUMPFILES%" "%@REPOSITORY%\%@SYSTEM:\=%"
 ) ELSE (
	 ECHO:
	 ECHO **** NO DATED MEMORY DUMP FILE FOUND ****
	 ECHO:
 )


 rem -- Generate Final Report
:FinalReport
 FOR %%D IN ("%@SYSTEM%\ADMIN$" "%@REPOSITORY%\%@SYSTEM:\=%") DO IF EXIST "%%~D\*.DMP" DIR /OGD "%%~D\*.DMP"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                