@REM - ASB (27 Jul 2004 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 21 Apr 2019 / 18 Feb 2019 / 01 May 2018): Display Uptime for Current Domain/Workgroup
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.5.0.270

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @UPTIME=UPTIME2 /nologo /COMPUTERNAME:
 SET @xPARAMS=-nodn -s SUB -maxe 5000 -csv attr name dnshostname -nodn -csvnoq -excldn "OBSOLETE;RETIRED;DECOMMISSIONED"
 SET @ADQUERY=ADFIND -f "(&(objectcategory=computer)(operatingSystem=Windows*))" %@xPARAMS%
 SET @ERROR1=host is not reachable
 SET @ERROR2=Failed to get uptime.


 rem -- Get Uptime Stats
:GetUptime
 ECHO %@TIMESTAMP%: Displaying Current Uptime... [%@VER%]
 ECHO:
 ECHO %@DIVIDER*%
 ECHO *** BASIC UPTIME INFO
 ECHO %@DIVIDER*%
 FOR /F "SKIP=1 TOKENS=1 DELIMS=," %%V IN ('%@ADQUERY%') DO CALL :UpTime %%~V

 IF "%~1"=="." (
	 ECHO:
	 ECHO:
	 ECHO %@DIVIDER*%
	 ECHO *** EXTENDED UPTIME INFO
	 ECHO %@DIVIDER*%

	 FOR /F "SKIP=1 TOKENS=1 DELIMS=," %%V IN ('%@ADQUERY%') DO (
		 !@UPTIME!%%~V /S
		 rem !@UPTIME!%%~V /S | FIND /I "(last"
		 rem !@UPTIME!%%~V /S | FIND /I "prior"
		 rem !@UPTIME!%%~V /S | FIND /I "Mean Time"
		 ECHO %@DIVIDER-%
		 ECHO:
	 )
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Display Server Uptime
:UpTime
 rem %1 = Current Server For Which Stats Will Be Obtained

 SET @ALARM=
 SET @DAYS_UP=0
 SET @CSYSTEM=%~1                    .
 SET @UPINFO=- UNABLE TO COLLECT UPTIME DATA FROM THIS HOST...
 FOR /F "TOKENS=1*" %%S IN ('%@UPTIME%%1 ^| FIND /I /V "%@ERROR1%" ^| FIND /I /V "%@ERROR2%"') DO SET @UPINFO=%%T
 SET @UPINFO=%@UPINFO:(s)=%
 FOR /F "TOKENS=5" %%D IN ('ECHO !@UPINFO!') DO SET @DAYS_UP=%%D
 IF "!@DAYS_UP!"=="0" SET @ALARM=***
 ECHO  -!@CSYSTEM:~0,16! !@UPINFO! 	!@ALARM!
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                              