@ECHO OFF
@REM - ASB (23 Aug 2005 // 16 Oct 2023 / 22 Aug 2021 / 09 Dec 2020 / 30 Nov 2020 / 04 Jun 2020 / 02 Apr 2020 / 29 Mar 2020 / 24 Dec 2019 / 30 Sep 2019 / 08 May 2018 / 27 Mar 2016 / 05 May 2015): Power Down All Physical Systems in Emergency
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.3.0.230

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Main Variables
 SET @SERVERLIST=%~dp0Input\FolderDefaults.TXT
 SET @WHICHTYPES=Server: Workstation: MediaPC:& IF "%~2"=="." SET @WHICHTYPES=:
 SET @MSSHUTDOWN=& FOR /F %%V IN ('WHERE SHUTDOWN 2^>NUL') DO SET @MSSHUTDOWN=TRUE


 rem -- Determine Whether to Shutdown or Abort
:ChooseOption
 FOR %%d IN ("" - /) DO (
	 FOR %%P IN (YES TRUE ON DOWN TEST) DO IF /I "%~1"=="%%~d%%~P" GOTO :ShutDown
	 FOR %%P IN (NO FALSE OFF UP ) DO IF /I "%~1"=="%%~d%%~P" GOTO :Abort-ShutDown
 )
 GOTO :HelpMessage


 rem -- Shutdown Systems
:ShutDown
 IF /I "%~1"=="TEST" (SET @CMD=ECHO) ELSE (SET @CMD=)
 FOR /F "EOL=;" %%S IN ('TYPE %@SERVERLIST% ^| FIND /I "Physical:" ^| FINDSTR /I "%@WHICHTYPES%"') DO (
	 SET @MSG=Initiating Emergency System Shutdown on %%S
	 ECHO !@MSG!
	 IF DEFINED @MSSHUTDOWN (
		 START "!@MSG!" !@CMD! SHUTDOWN -s -f -m \\%%S -t 75 -c "Emergency Shutdown" -d P:100:4096
	 ) ELSE (
		 START "!@MSG!" !@CMD! PSSHUTDOWN -k -f -t 75 -m "Emergency Shutdown" -e P:100:4096 \\%%S
	 )
 )
 GOTO :ExitBatch


 rem -- Abort System Shutdown
:Abort-Shutdown
 FOR /F "EOL=;" %%A IN (%@SERVERLIST%) DO (
	 SET @MSG=ABORTING SYSTEM SHUTDOWN on %%A
	 ECHO !@MSG!
	 IF DEFINED @MSSHUTDOWN (
		 START "!@MSG!" SHUTDOWN -a -m \\%%A
	 ) ELSE (
		 START "!@MSG!" PSSHUTDOWN -a \\%%A
	 )
 )

 rem -- Abort System Shutdown
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Power Down All Physical Systems in Emergency
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<YES ^| NO ^| TRUE ^| FALSE ^| ON ^| OFF ^| UP ^| DOWN^>  [.]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 YES
	 ECHO  %~n0 FALSE
	 ECHO  %~n0 TRUE .
	 ECHO  %~n0 TRUE SERVER:
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * If the 2nd parameter is ".", then ALL physical systems will be shutdown
	 ECHO:
	 ECHO  * All positive values ^(YES, TRUE, ON^) and the DOWN value, will result
	 ECHO    in the computers in the main list of servers being shut down in 75
	 ECHO    seconds. The use of the reverse values ^(NO, FALSE, OFF, UP^) will try
	 ECHO    to abort any shutdown attempt which is in progress.
 )
 CALL :ShowStatus "FINISHED"
                                                              