@REM - ASB (19 Apr 2008 // 16 Oct 2023 / 30 Nov 2020 / 18 Aug 2020 / 29 Jul 2020 / 26 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 28 Oct 2018 / 26 Jul 2018 / 27 Feb 2018 / 27 Mar 2016): Enable/Disable HTTP Proxy Configuration for Windows
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT=%*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] -  %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.2.0.220

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Enable/Disable HTTP Proxy Configuration for Windows
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<ENABLE ^| DISABLE^>
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Default Proxy Settings (Can be overridden by CustomVariables.TXT)
 SET @EXTERNAL_NAMES=*.CYLANCE.COM
 SET @LOCAL_NAMES=*.MYDOMAIN.COM;SERVER1;SERVER2
 SET @PROXY_SERVER=proxy.mydomain.com
 SET @PROXY_PORT=3128
 SET @HTTP_PROXY=!@PROXY_SERVER!:%@PROXY_PORT%
 SET @HTTPS_PROXY=!@PROXY_SERVER!:%@PROXY_PORT%
 SET @FTP_PROXY=!@PROXY_SERVER!:%@PROXY_PORT%
 SET @SOCKS_PROXY=!@PROXY_SERVER!:%@PROXY_PORT%

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Other Variables
 SET @STATUS=YOUR INTERNET BROWSER PROXY IS CURRENTLY:
 SET @EXEMPTIONS=*.local;%@LOCAL_NAMES%;%@EXTERNAL_NAMES%
 SET @EXEMPTIONS=%@EXEMPTIONS:;;=;%;^<local^>
 SET @PROXY_KEY=HKCU\Software\Microsoft\Windows\CurrentVersion\Internet Settings
 SET @PROXYENABLE=
 FOR %%V IN (ON ENABLE TRUE SET) DO IF /I "%~1"=="%%~V" SET @PROXYENABLE=1
 FOR %%V IN (OFF DISABLE FALSE) DO  IF /I "%~1"=="%%~V" SET @PROXYENABLE=0


 rem -- Enable/Disable/Display HTTP Proxy Configuration for Windows
:ConfigureProxy
 ECHO Configuring Browser Proxy Settings
 ECHO:

 rem -- Set Correct Proxy Variable for Windows 10 vs Older
 IF %@OSBUILD% GEQ 10240 (
	 SET @PROXY_VALUE=%@PROXY_SERVER%:%@PROXY_PORT%
 ) ELSE (
	 SET @PROXY_VALUE=http://%@HTTP_PROXY%;https://%@HTTPS_PROXY%;ftp://%@FTP_PROXY%;socks://%@SOCKS_PROXY%
 )

 rem -- Display and/or Change Proxy Configuration
 IF NOT "%~1"=="" CALL :ShowProxyConfig

 IF "%@PROXYENABLE%"=="1" (
	 ECHO Setting HTTP/HTTPS/FTP/SOCKS Proxy to ENABLED
	 ECHO  HTTP Proxy:  "%@HTTP_PROXY%"
	 ECHO  HTTPS Proxy: "%@HTTPS_PROXY%"
	 ECHO  FTP Proxy:   "%@FTP_PROXY%"
	 ECHO  SOCKS Proxy: "%@SOCKS_PROXY%"
	 ECHO  EXEMPTIONS:  "%@EXEMPTIONS%"
	 ECHO:
	 REG ADD "%@PROXY_KEY%" /V "ProxyHttp1.1"  /T REG_DWORD /D %@PROXYENABLE% /F
	 REG ADD "%@PROXY_KEY%" /V "ProxyEnable"   /T REG_DWORD /D %@PROXYENABLE% /F
	 REG ADD "%@PROXY_KEY%" /V "ProxyServer"   /T REG_SZ    /D "%@PROXY_VALUE%" /F
	 REG ADD "%@PROXY_KEY%" /V "ProxyOverride" /T REG_SZ    /D "%@EXEMPTIONS%" /F
	 ECHO %@DIVIDER-%
 )

 rem -- Disable Proxy Configuration
 IF "%@PROXYENABLE%"=="0" (
	 ECHO Setting HTTP/HTTPS/FTP/SOCKS Proxy to DISABLED
	 ECHO:
	 REG ADD "%@PROXY_KEY%" /V "ProxyEnable"   /T REG_DWORD /D %@PROXYENABLE% /F
	 REG ADD "%@PROXY_KEY%" /V "ProxyHttp1.1"  /T REG_DWORD /D %@PROXYENABLE% /F
	 ECHO %@DIVIDER-%
 )

 rem -- Show Proxy Configuration
 CALL :ShowProxyConfig


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Execute Dynamic Command From Variable
:RunCMD
 rem %1 = Command To Execute

 %*
 GOTO :EOF


 rem -- SUBROUTINE: Show Current Proxy Values
:ShowProxyConfig
 ECHO:
 FOR /F "TOKENS=3 EOL=!" %%V IN ('REG QUERY "%@PROXY_KEY%" /V "ProxyEnable"') DO IF "%%~V"=="0x1" (SET @MSG=ENABLED [%%~V]) ELSE (SET @MSG=*** DISABLED *** [%%~V])
 ECHO %@STATUS% %@MSG%
 ECHO:
 REG QUERY "%@PROXY_KEY%" | FINDSTR /I "ProxyEnable ProxyServer ProxyHTTP ProxyOverride"
 ECHO %@DIVIDER-%
 ECHO:
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                             