@REM - ASB (11 May 2006 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 03 Oct 2019 / 13 Apr 2018 / 05 Apr 2017 / 26 Mar 2017): Generate a Random Password for an Account
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.2.0.220

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Generate a Random Password for an Account
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [password length] [username] [other net user parameters]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO     EXAMPLES:
	 ECHO          %~n0 20
	 ECHO          %~n0 32 ThisUser
	 ECHO          %~n0 64 "That User" "/DOMAIN"
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Default Password Length is 16 characters; Max Length = 256.
	 ECHO    * If a username is provided, the password will be applied to that account.
	 ECHO    * If username contains spaces, or multiple parameters are used,
	 ECHO      then quotes need to be used around each category of item.
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @LENGTH=%~1& IF "%~1"=="" SET @LENGTH=16
 SET @THEUSER=%~2
 SET @MORECMDS=%~3
 SET @ACCT=RandomUser%@RANDOM%
 SET @SEED=%@ACCT%-%DATE%-!TIME!-!RANDOM!
 SET @USE_FILEHASH=FALSE& FOR /F "TOKENS=*" %%F IN ('WHERE FileHash 2^>NUL') DO SET @USE_FILEHASH=TRUE
 SET @USE_RNDPASS=FALSE& FOR /F "TOKENS=*" %%F IN ('WHERE RandomPass 2^>NUL') DO SET @USE_RNDPASS=TRUE

 rem -- Max Length = 256
 IF !@LENGTH! GTR 256 (SET @LENGTH=256 & ECHO Max Allowed Password Length = 256 & ECHO:)


 rem -- Generate Random Password using one of 3 Methods (RandomPass or FileHash or NET USER)
:GeneratePWD
 IF /I "%@USE_RNDPASS%"=="TRUE" (
	 rem -- Use BrainWave RandomPass
	 FOR /F "TOKENS=1-3*" %%L IN ('RANDOMPASS %@LENGTH% /C /Q /E') DO (
		 SET @LENGTH=%%L
		 SET @HASH=%%M
		 SET @PWD=%%O
		 SET @METHOD=RandomPass
	 )
 ) ELSE (

	 rem -- Use BrainWave FileHash
	 IF /I "%@USE_FILEHASH%"=="TRUE" (
		 FOR /F %%P IN ('FILEHASH -SHA3 "%@SEED%"') DO SET @PWD=%%P
		 SET @PWD=!@PWD:~-%@LENGTH%!
		 SET @LEN=& FOR /L %%L IN (0,1,999) DO IF "!@PWD:~%%L,1!"=="" IF NOT DEFINED @LEN SET /A @LEN=%%L
		 SET @LENGTH=!@LEN!
		 SET @METHOD=FileHash
	 ) ELSE (

		 rem -- Use native NET USER command
		 FOR /F "TOKENS=2 DELIMS=:" %%P IN ('NET USER "%@ACCT%" /RANDOM:%@LENGTH% /ADD') DO SET @PWD=%%P
		 NET USER "%@ACCT%" /DELETE
		 SET @METHOD=NET USER
	 )
 )


 rem -- Final Report
:FinalReport
 ECHO Generating random password using %@METHOD%...
 ECHO %@DIVIDER-%
 ECHO  Password Length .......... %@LENGTH%
 ECHO  Password ................. %@PWD%
 IF DEFINED @THEUSER (
	 ECHO  Username ................. %@THEUSER%
	 IF DEFINED @MORECMDS ECHO  Other NET USER Options ... %@MORECMDS%
	 ECHO %@DIVIDER-%
	 FOR /F "TOKENS=*" %%R IN ('NET USER %@THEUSER% "%@PWD%" %@MORECMDS% /Y 2^>^&1') DO ECHO  NET USER RESULTS ......... %%R
 )
 ECHO %@DIVIDER-%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                           