@REM - ASB (20 Jun 2011 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 17 Oct 2019 / 30 Sep 2019 / 03 Mar 2019 / 31 Jul 2018 / 28 Apr 2015): Update Local Scripts and Push Repository to Remote Systems
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Skip to Updates if Running from %TEMP%
:RunUniqueInstance
 IF /I "%~dp0"=="%TEMP%\" (
	 GOTO :Variables
 ) ELSE (
	 COPY "%~df0" "%TEMP%\%~nx0" /Y
	 "%TEMP%\%~nx0" %*
	 GOTO :ExitBatch
 )


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.5.0.320

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @SLEEP=1800& IF NOT "%~1"=="" SET /A @SLEEP=%~1
 IF "%@SLEEP%"=="0" SET @SLEEP=1800
 SET @SPATH=%SystemDrive%\Scripts\Bat
 SET @LOGFILE="%TEMP%\%~n0.%@FILESTAMP_R%"
 SET @TEE=& FOR /F "TOKENS=*" %%F IN ('WHERE TEE 2^>NUL') DO SET @TEE=^| "%%~F" -a %@LOGFILE%


 rem -- Get Updates from SOURCE and Distribute Them
:GetUpdates
 TITLE %@VER% - Waiting...
 ECHO Initiated at %TIME% on %DATE% and waiting for %@SLEEP% seconds
 TIMEOUT %@SLEEP%
 TITLE %@VER% - Executing...
 CMD /C %@SPATH%\GetScripts.BAT %~2 %@TEE%
 CMD /C %@SPATH%\ReSyncScripts.BAT . %@TEE%


 rem -- Generate Final Report
:FinalReport
 IF EXIST %@LOGFILE% DIR %@LOGFILE%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 POPD
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Update Local Scripts and Push Repository to Remote Systems
 ECHO:
 ECHO    YOU TYPED: %0 %*
 ECHO:
 ECHO   CMD SYNTAX: %~n0  [delay_duration] [\\unc_path_for_script_source]
 ECHO               %~n0  [-h^|-?]
 ECHO:
 ECHO  USAGE NOTES:
 ECHO    * Parameters surrounded by ^<^> are mandatory.
 ECHO    * Parameters surrounded by [] are optional.
 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
 CALL :ShowStatus "FINISHED"
                                                                                