@REM - ASB (06 Sep 2011 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 22 Sep 2019 / 31 Aug 2018 / 26 Jul 2018 / 29 Apr 2018): Remove Any Line From a Text File Based on Contents
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.10.0.200

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Remove Any Line From a Text File Based on Contents
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<filename^> ^<search value^>
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @REMOVED=0
 SET @FOUND=FALSE
 SET @FILENAME=%~1
 SET @SEARCH=%~2
 SET @TEMPFILE=%TEMP%\%~nx1-%@FILESTAMP_R%


 rem -- Verify Input File Exists
:VerifyFile
 IF NOT EXIST "%@FILENAME%" (
	 ECHO File "%@FILENAME%" could not be found...
	 GOTO :ExitBatch
 )


 rem -- Determine if Search Text is in Current File
:FindSearchString
 ECHO Searching for "%@SEARCH%" in "%@FILENAME%"...
 FOR /F "TOKENS=* EOL=" %%V IN ('TYPE "%@FILENAME%" ^| FIND /I "%@SEARCH%" ') DO SET @FOUND=TRUE
 IF /I "%@FOUND%"=="FALSE" (
	 ECHO No instance of "%@SEARCH%" was found in "%@FILENAME%"
	 GOTO :ExitBatch
 )


 rem -- Search for text to remove from file
:RemoveLine
 ECHO Removing any line containing "%@SEARCH%" from "%@FILENAME%"...
 FOR /F "TOKENS=* EOL=" %%V IN ('TYPE "%@FILENAME%" ^| FIND /I "%@SEARCH%" ') DO (SET /A @REMOVED+=1& @ECHO --^> %%V)
 TYPE "%@FILENAME%" | FIND /I /V "%@SEARCH%" >"%@TEMPFILE%"
 COPY "%@TEMPFILE%" "%@FILENAME%" /V /Y
 DEL "%@TEMPFILE%"
 ECHO:
 ECHO ----------
 ECHO # of Lines Removed: %@REMOVED%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                         