@REM - ASB (08 Dec 2021 // 12 Apr 2024 / 12 Jan 2024 / 16 Oct 2023 / 27 Mar 2022 / 06 Mar 2022 / 01 Mar 2022 / 24 Feb 2022 / 18 Feb 2022): Remove WebRoot SecureAnywhere Agent, Locally or Remotely
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.9.0.390

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=0 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Remove WebRoot SecureAnywhere Agent, Locally or Remotely
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [remote_system_name] [#^|/D^|/DELETE]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  CMD OPTIONS:
	 ECHO    /D, # .... Delete Webroot WMI Entries
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Check for Essential Utilities and/or Scripts
 PATH %PATH%;%~dp0
 SET @ESSENTIALS=NOW.EXE DATEINFO.EXE CHECKPARAMS.EXE REG.EXE CHCP.COM CSCRIPT.EXE FIND.EXE FINDSTR.EXE REG.EXE WMIC.EXE
 FINDFILES -w -m -f %@ESSENTIALS% SetACL.EXE READABLE.EXE SC.EXE
 FINDFILES --rc  -f %@ESSENTIALS%
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Process Special Command-line Parameters
 SET @ALL_PARAMS=%*
 SET @DELETE_WMI=& CALL :GetParams "# D DELETE" & IF DEFINED @OK SET @DELETE_WMI=TRUE

 rem -- Main Variables
 SET @SYSTEM=%~1
	 IF DEFINED @SYSTEM (
		 SET @HOSTNAME=!@SYSTEM:\=!
		 SET @SYSTEM=\\!@HOSTNAME!\
		 SET @ProgramData=!@SYSTEM!C$\ProgramData
		 SET @ProgramFiles="!@SYSTEM!C$\Program Files (x86)" "!@SYSTEM!C$\Program Files"
	 ) ELSE (
		 SET @HOSTNAME=%COMPUTERNAME%
		 SET @ProgData=%ProgramData%
		 SET @ProgramFiles="%ProgramFiles(x86)%" "%ProgramFiles%"
	 )

 SET @FOLDER1="%@ProgramData%\WRCore"
 SET @FOLDER2="%@ProgramData%\WRData"
 SET @REG_ROOT=%@SYSTEM%HKLM\SOFTWARE
 SET @SEC_CENTER=%@REG_ROOT%\Microsoft\Security Center\Provider\Av
 SET @WSH_ENABLE=%@REG_ROOT%\Microsoft\Windows Script Host\Settings
 SET @WR_GUID0="{A16A5B28-D1C0-417E-771B-123558EECC69}"
 SET @WR_GUID1="{DF901FA1-F926-253B-C464-B01C79DCAD48}"
 SET @WR_GUID2="{EA22F846-E33A-0128-9418-185509C86920}"
 SET @WR_GUID3="{2936F8B3-571B-7336-8577-2471F5CC8C22}"
 SET @WR_GUID4="{4646A877-74EB-CD3B-8FDB-210DB94FA61A}"
 SET @WR_GUID5=
 SET @WR_GUID6=
 SET @WR_GUID7=
 SET @WR_GUID8=
 SET @WR_GUID9=
 SET @WR_GUIDs=& FOR /L %%G IN (0, 1, 9) DO SET @WR_GUIDs=!@WR_GUIDs! !@WR_GUID%%~G!
 SET @WR_AGENT=
 SET @UNINSTALL=
 SET @REMOVE=*** NO INSTALL OF WEBROOT FOUND ***

 rem -- Check for existing instance of Webroot (Local or Remote, as appropriate)
 FOR %%P IN (%@ProgramFiles%) DO IF EXIST "%%~P\Webroot\WRSA.exe" (
	 IF /I "%@HOSTNAME%"=="%COMPUTERNAME%" SET @UNINSTALL=TRUE
	 SET @WR_ROOT=%%~P\Webroot
	 SET @WR_AGENT=!@WR_ROOT!\WRSA.exe
	 SET @REMOVE="!@WR_AGENT!" -uninstall
 )

 rem -- Standard Log Variables
 SET @LOGPATH=%TEMP%\%~n0
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP_R%
 SET @TEMPLOG=%@LOGPATH%\%~n0.TEMP.%@FILESTAMP_R%


 rem -- Determine if Remote System is Available
:VerifyAccess
 IF DEFINED @SYSTEM (
	 CALL :ShowHeader0 Determine if Remote System [%@HOSTNAME%] is available...

	 SET @ACCESSIBLE=
	 PING %@HOSTNAME% 2>&1
	 ECHO:
	 FOR /F %%R IN ('DIR "%@SYSTEM%C$" 2^>NUL') DO SET @ACCESSIBLE=TRUE
	 IF DEFINED @ACCESSIBLE (
		 ECHO  +++ SYSTEM IS ONLINE AND ACCESSIBLE +++
	 ) ELSE (
		 ECHO  *** SYSTEM NOT ACCESSIBLE ***
		 GOTO :ExitBatch
	 )
 )

 rem -- Start "Remote Registry" service on Remote System if not running
:GetRegistryAccess
 FOR /F "TOKENS=4" %%S IN ('SC %@SYSTEM% QUERY "RemoteRegistry" ^| FIND "STATE"') DO (
	 IF NOT "%%~S"=="RUNNING" (
		 CALL :ShowHeader2 Starting Remote Registry Service on %@SYSTEM%...
		 SC %@SYSTEM% CONFIG RemoteRegistry start= AUTO
		 SC %@SYSTEM% START RemoteRegistry
		 ECHO:
	 )
 )


 rem -- Make VBScript to Delete All Known WebRoot SecureAnywhere Instances in WMI
:MakeVBScript
 CALL :ShowHeader0 Generate WebRoot WMI Removal Script for %@HOSTNAME%

 SET @VBSCRIPT="%@LOGPATH%\%~n0-%@RANDOM%.VBS"
 SET @LINE00='rem -- Generated on !DATE! at !TIME: =0! by %~n0 %@VERSION%
 SET @LINE01= on error resume next

 SET @LINE10= strComputer = "%@HOSTNAME%"
 SET @LINE11= strJobMode = "READ/ONLY"
 SET @LINE12= WScript.Echo
 SET @LINE13= WScript.Echo "Removing WebRoot WMI Config from " + strComputer + "    *** " + strJobMode + " MODE ENABLED ***"

 SET @LINE20= Set objWMIService = GetObject("winmgmts:{impersonationLevel=impersonate}^^^!\\" ^& strComputer ^& "\root\securitycenter2")
 SET @LINE21= Set colAV = objWMIService.ExecQuery("Select * from AntiVirusProduct")
 SET @LINE22= For Each objItem In colAV
 SET @LINE23=   If (objItem.instanceGuid = %@WR_GUID0%) or _
 SET @LINE24=      (objItem.instanceGuid = %@WR_GUID1%) or _
 SET @LINE25=      (objItem.instanceGuid = %@WR_GUID2%) or _
 SET @LINE26=      (objItem.instanceGuid = %@WR_GUID3%) or _
 SET @LINE27=      (objItem.instanceGuid = %@WR_GUID4%) Then
 SET @LINE28=     WScript.Echo "Found WebRoot Instance: " + objItem.instanceGuid + " on " + strComputer

 IF DEFINED @DELETE_WMI (
	 SET @LINE11= strJobMode = "DELETE"
	 SET @LINE40=     objItem.Delete_
 ) ELSE (
	 SET @LINE40=     WScript.Echo "Did NOT Delete .......: " + objItem.instanceGuid
 )

 SET @LINE50=   End If
 SET @LINE51= Next
 SET @LINE52= WScript.Echo "Finished WebRoot SecurityCenter Removal..."
 SET @LINE53= WScript.Echo

 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"
(FOR /F "TOKENS=1* DELIMS==" %%b IN ('SET @LINE 2^>NUL') DO @ECHO %%c) >!@VBSCRIPT!


 rem -- Attempt to Remove WebRoot SecureAnywhere Agent and Data
:Try2Remove
 CALL :ShowHeader Preparing to Clean WebRoot Entries from %@HOSTNAME%

 IF DEFINED @UNINSTALL (
	 CALL :ShowHeader2 Attempt to uninstall WebRoot agent: %@REMOVE%
	 %@REMOVE%
	 SLEEP 60
 )

 rem -- Don't Delete Folders or Keys if Main Program File Still Exists
 CALL :ShowHeader2 Check for Main WebRoot Executable...
 IF EXIST "%@WR_AGENT%" (
	 ECHO *** "%@WR_AGENT%" still exists -- Removal Aborted ***
	 GOTO :FinalReport
 ) ELSE (
	 ECHO  --- NOT FOUND: WebRoot SecureAnywhere Agent ---
 )
 ECHO:

 rem -- Continue with Cleanup Attempt
 CALL :ShowHeader2 Attempt to delete WebRoot folders...
 FOR %%V IN ("%@WR_ROOT%" %@FOLDER1% %@FOLDER2%) DO IF EXIST "%%~V" RD /S /Q "%%~V" 2>&1
 FOR %%V IN ("%@WR_ROOT%" %@FOLDER1% %@FOLDER2%) DO IF EXIST "%%~V" (
	 DIR /OGD /S "%%~V"
	 ECHO:
 ) ELSE (
	 IF NOT "%%~V"=="" ECHO  --- NOT FOUND: "%%~V" ---
 )
 ECHO:

 rem -- Delete WMI-related Entries
 CALL :ShowHeader2 Attempt to delete obsolete Security Center WMI entries for Webroot...
 REG ADD "%@WSH_ENABLE%" /v "Enabled" /t REG_DWORD /d 1 /f 2>&1
 CSCRIPT //H:CScript //NoLogo %@VBSCRIPT%                  2>&1

 rem -- Delete Registry-related Entries
 CALL :ShowHeader2 Attempt to delete WebRoot registry entries...
 FOR %%W IN (Core Data) DO CALL :DeleteRegKey "%@REG_ROOT%\WR%%~W"

 CALL :ShowHeader2 Attempt to delete obsolete Security Center registry entries for Webroot...
 FOR %%G IN (%@WR_GUIDs%) DO (
	SET @KEY_EXISTS=
	FOR /F %%R IN ('REG QUERY "!@SEC_CENTER!\%%~G" 2^>NUL') DO SET @KEY_EXISTS="!@SEC_CENTER!\%%~G"
	IF DEFINED @KEY_EXISTS (
		 ECHO  --- FOUND: !@KEY_EXISTS! ---
		 ECHO:
		 CALL :DeleteRegKey !@KEY_EXISTS!
	 ) ELSE (
		 ECHO  --- NOT FOUND: "!@SEC_CENTER!\%%~G" ---
	 )
 )


 rem -- Generate Final Report
:FinalReport
 CALL :ShowHeader Security Center Entries via Registry and WMIC on \\%@HOSTNAME% ...
 REG QUERY "%@REG_ROOT%" | FINDSTR /I "WRCore WRData"                                                          2>&1
 REG QUERY "!@SEC_CENTER!" /S                                                                                  2>&1
 WMIC /Node:"%@HOSTNAME%" /Namespace:\\root\SecurityCenter2 Path AntiVirusProduct get * /value >>"%@TEMPLOG%"  2>&1

 FINDFILES --rc -f READABLE.EXE
 IF NOT ERRORLEVEL 1 (
	 READABLE "%@TEMPLOG%" -A -F "=" --SB "displayName" --LB "displayName" --DL 1 --LC "~"
 ) ELSE (
	 TYPE "%@TEMPLOG%"
 )


 rem -- Perform Log Maintenance
:LogMaint
 IF NOT DEFINED DEBUG FOR %%L IN ("%@TEMPLOG%" "%@LOGFILE%" %@VBSCRIPT%) DO IF EXIST "%%~L" DEL "%%~L" >NUL 2>NUL


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Show the Header
:ShowHeader
:ShowHeader2
 rem %* = Header Info to Display

 ECHO:
 ECHO:
:ShowHeader0
 IF /I "%~0"==":ShowHeader2" (SET @DIV=%@DIVIDER%) ELSE (SET @DIV=%@DIVIDER*%)
 ECHO %@DIV%
 ECHO %*
 ECHO %@DIV%
 GOTO :EOF


 rem -- SUBROUTINE: Change Perms on Registry Key, then Delete
:DeleteRegKey
 rem %1 = Registry Key

 IF "%~1"=="" GOTO :EOF
 SET @FOUNDIT=
 FOR /F %%Z IN ('REG QUERY "%~1" 2^>NUL') DO SET @FOUNDIT=TRUE
 IF DEFINED @FOUNDIT (
	 FINDFILES --rc -f SetACL.EXE
	 IF NOT ERRORLEVEL 1 (
		 SetACL -on "%~1" -ot reg -actn setowner -ownr "n:Administrators"   2>&1
		 SetACL -on "%~1" -ot reg -actn ace -ace "n:Administrators;p:full"  2>&1
	 )
	 REG DELETE "%~1" /F  2>&1
 ) ELSE (
	 ECHO  --- NOT FOUND: "%~1"
 )
 GOTO :EOF


 rem -- SUBROUTINE: Use CheckParams.exe to Capture Selected Parameters
:GetParams
 rem %1 = Parameters to Search For
 rem %2 = Variable to Set

 SET @OK=& IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=2-3*" %%v IN ('CHECKPARAMS -q -a -c "%~1" -s %@ALL_PARAMS% 2^>NUL') DO IF /I "%%~v"=="TRUE" (
	 SET @OK=T
	 SET @REQ=T
	 IF NOT "%~2"=="" SET %~2=%%~x
 )
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
           