@ECHO OFF
 rem ==========================================================================
 rem === Rename Files With Spaces
 rem ==========================================================================
 rem
 rem Created On: 06 Nov 2000
 rem         By: Andrew S. Baker (adapted from a script by Frank Knobbe)
 rem
 rem Updated On: 16 Oct 2023 / 30 Nov 2020              
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2000 or later
 rem
 rem  Non-Native Utilities Used/Required:
 rem    BrainWave Utilities .... https://www.BrainWaveCC.com/brainwave-utilities
 rem ==========================================================================

 :::  This script will rename all files in the current directory which contain
 :::  spaces, by converting the spaces to underscores.
 :::
 :::  (Apr 2018) v2.0 -- Changed Script Documentation to www.BrainWaveCC.com;
 :::  -- Added filtered CMD Title Routine;
 :::
 :::  (Oct 2018) v2.1 -- Corrected and expanded the DEBUG logging routine;
 :::
 :::  (Feb 2019) v2.2 -- Enabled Code Page 1252 Support;
 :::
 :::  (Oct 2019) v2.3 -- Updated :ShowStatus routine to reset TITLE/CodePage;
 :::
 :::  (May 2020) v2.4 -- Updated :DebugMode routine to support the STEP option;
 :::
 :::  (Nov 2020) v2.5 -- Provided extended HELP options (--?? / --H2);
 :::  -- New CHECKPARAMS syntax for processing extended help options;
 :::
 :::  (Oct 2023) v2.6 -- Change the way the @SCRIPT_BEG# variable is
 :::  calculated in various subroutines by using DATEINFO instead of %DATE%;
 :::
 :::
 :::  ADDITIONAL SCRIPTING TOOLS/INFO:
 :::  -------------------------------------------------------------------------
 :::  https://www.BrainWaveCC.com/knowledge-base/scripting-and-automation-options-for-windows/
 :::  https://www.BrainWaveCC.com/knowledge-base/must-have-utilities-for-windows-usersadmins/
 :::  -------------------------------------------------------------------------


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 02 May 2018              
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to TRUE/LOG/STEP/VERBOSE
 rem === Updated On: 13 May 2020 / 28 Oct 2018              
 rem ==========================================================================
:DebugMode
 SET #DEBUG=& FOR %%d IN (LOG STEP TRUE VERBOSE) DO IF /I "%Debug%"=="%%~d" SET #DEBUG=TRUE
 IF DEFINED #DEBUG (
	 SET @DIAGMODE=TRUE
	 SET @DEBUG_MODE=[DEBUG MODE ON]
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:^& TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 IF /I "%Debug%"=="LOG" (SET @PAUSE_IF_DEBUG=& SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:)
	 IF /I "%Debug%"=="STEP" (SET @PAUSE_IF_DEBUG=ECHO ##PAUSE##& SET @PRINT_IF_DEBUG=ECHO ##PRINT##)
	 IF /I "%Debug%"=="VERBOSE" (SET @VERBOSE_OFF=ECHO ON) ELSE (FOR %%t IN (ON OFF) DO SET @VERBOSE_%%t=ECHO %%t)
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE ( FOR %%d IN (DEBUG_MODE PAUSE_IF_DEBUG PRINT_IF_DEBUG END_DEBUG_MODE VERBOSE_ON VERBOSE_OFF) DO SET @%%d=)


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 30 Nov 2020 / 02 May 2018              
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.5.0.250

 SET @FILESPEC=*.DOC


 rem ==========================================================================
 rem === Select Files To Rename
 rem === Updated On: 06 Nov 2000                     
 rem ==========================================================================
:SelectFiles
 FOR /F "TOKENS=1 DELIMS=/" %%F IN ('DIR /B %@FILESPEC%') DO CALL :Rename "%%F"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 04 Oct 2019 / 28 Feb 2019              
 rem ==========================================================================
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Rename Files Which Contain Spaces
 rem === Updated On: 23 Feb 2006                     
 rem ==========================================================================
:Rename
 SET @CURRENT=%~1
 SET @NEW=%@CURRENT: =_%
 IF /I "%@CURRENT%"=="%@NEW%" GOTO :EOF
 ECHO Changing %@CURRENT% TO %@NEW%
 REN %@CURRENT% %@NEW%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019              
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                           