@REM - ASB (12 Feb 2016 // 12 Jan 2024 / 16 Oct 2023 / 11 Feb 2022 / 30 Nov 2020 / 14 May 2020 / 22 Jan 2020 / 24 Dec 2019 / 30 Sep 2019 / 29 Apr 2018 / 06 May 2016): Repair Windows Using SFC and DISM
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.1.0.210

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=0 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Repair Windows Using SFC and DISM
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [WIM_drive] [non-blank-to-delete-folders]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO    * Default drive for WIM images, if available, is W:
	 GOTO :ExitBatch
 )

 rem -- Check for Essential Utilities and/or Scripts
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f "NOW.EXE" "DATEINFO.EXE" "CHECKPARAMS.EXE" "SFC.EXE" "DISM.EXE"
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @DRV=W:& IF NOT "%~1"=="" SET @DRV=%~1:
 SET @SOURCE=/SOURCE:WIM:%@DRV:~0,1%:\Sources\Install.wim:1 /LimitAccess
 SET @EXTENDED=%~2

 rem -- DISM/SFC Commands
 SET @COMMANDS0=DISM.exe /Online /CleanUp-Image /CheckHealth
 SET @COMMANDS1=DISM.exe /Online /CleanUp-Image /ScanHealth
 SET #COMMANDS2=DISM.exe /Online /CleanUp-Image /CleanUpImage
 SET @COMMANDS3=DISM.exe /Online /CleanUp-Image /RestoreHealth %@SOURCE%
 SET @COMMANDS4=DISM.exe /Online /CleanUp-Image /StartComponentCleanup
 SET @COMMANDS5=SFC /ScanNow
 SET @COMMANDS6=START NOTEPAD %windir%\logs\CBS\Checksur.log
 SET @COMMANDS7=START NOTEPAD %windir%\Logs\DISM\dism.log
 SET @COMMANDS8=
 SET @COMMANDS9=


 rem -- Execute Extended Windows Repair Commands
:ExtendedRepair
 TITLE Repairing Windows Installation >NUL
 IF DEFINED @EXTENDED (
	 ECHO Deleting Old Windows Update Folders...
	 ECHO:
	 NET STOP wuauserv
	 NET STOP cryptSvc
	 NET STOP bits
	 NET STOP msiserver
	 REN C:\Windows\SoftwareDistribution SoftwareDistribution.%@DIRSTAMP%
	 REN C:\Windows\System32\Catroot2 Catroot2.%@DIRSTAMP%
	 NET START wuauserv
	 NET START cryptSvc
	 NET START bits
	 NET START msiserver
 )


 rem -- Execute Standard Windows Repair Commands
:StandardRepair
 ECHO Executing Standard Repair Commands...
 ECHO:
 FOR /F "TOKENS=1* DELIMS==" %%B IN ('SET @COMMANDS') DO (
	 FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SECTION_BEG#="%%~d"
	 NOW %%C
	 %%C
	 DATEINFO -t !@SECTION_BEG#! -e "min:sec.ms" -o "\**** SECTION DURATION: \v\n\*\n\n" 2>NUL
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                               