@REM - ASB (29 Jan 2014 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 14 May 2018 / 30 Apr 2018 / 08 Nov 2017): Reset Permissions of Folders with Inaccessible Permissions
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.6.0.270

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @FOLDER=%~1& IF "%~1"=="" SET @FOLDER=%SystemDrive%\Temp
 SET @PERMS-B="Administrators:(F)" "SYSTEM:(F)" "Everyone:(R)"
 SET @PERMS-I="Administrators:(CI)(OI)(F)" "SYSTEM:(CI)(OI)(F)" "Everyone:(CI)(OI)(R)"
 SET @SOURCE=%~d0\Scripts
 SET PATH=%@SOURCE%\BAT;%@SOURCE%\UTILS;%@SOURCE%\UTILS\Misc;%PATH%

 rem -- Standard Log Variables
 SET @LOGINFO=%~n0.%@DIRSTAMP_R%
 SET @LOGFILE="%TEMP%\%@LOGINFO%.TXT"
 SET @TEMPLOG="%TEMP%\%@LOGINFO%.TEMP.TXT"


 rem -- Check for Folder Validity
:CheckFolder
 IF NOT EXIST "%@FOLDER%" (
	 ECHO The folder "%@FOLDER%" does not exist...
	 GOTO :ExitBatch
 )


 rem -- Take Ownership and Reset Permissions of Selected Folder
:ResetPermissions
 ECHO: |                                                   TEE    "%@TEMPLOG%"
 NOW Making Permissions Changes to the following folder |  TEE -a "%@TEMPLOG%"
 ECHO  -- "%@FOLDER%" |                                    TEE -a "%@TEMPLOG%"
 ECHO: |                                                   TEE -a "%@TEMPLOG%"
 ECHO  Taking Administrative Ownership |                   TEE -a "%@TEMPLOG%"
 TAKEOWN /F "%@FOLDER%" /R    /D Y >>                             "%@TEMPLOG%"
 ECHO: |                                                   TEE -a "%@TEMPLOG%"
 TAKEOWN /F "%@FOLDER%" /R /A /D Y >>                             "%@TEMPLOG%"
 ECHO: |                                                   TEE -a "%@TEMPLOG%"
 ECHO  Changing Basic Permissions |                        TEE -a "%@TEMPLOG%"
 ICACLS "%@FOLDER%" /grant:r %@PERMS-B% /inheritance:r /C /T   >> "%@TEMPLOG%"
 IF "%~2"=="." ICACLS "%@FOLDER%" /grant:r %@PERMS-I% /C /T    >> "%@TEMPLOG%"
 ICACLS "%@FOLDER%\*" /inheritance:e /C /T                     >> "%@TEMPLOG%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 IF EXIST "%@TEMPLOG%" TYPE "%@TEMPLOG%" & DIR "%@TEMPLOG%"
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                          