@REM - ASB (30 Jun 2003 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 26 Jul 2018 / 29 Apr 2018): Display All Installed Services
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.4.0.250

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @COMPUTER=%~2& IF "%~2"=="" SET @COMPUTER=%COMPUTERNAME%
 SET @COMPUTER=\\%@COMPUTER:\=%
 SET @DISPLAY_NAME=FALSE& FOR %%P IN (-D /D -B /B "") DO IF /I "%~1"=="%%~P" SET @DISPLAY_NAME=TRUE
 SET @SERVICE_NAME=FALSE& FOR %%P IN (-S /S -B /B   ) DO IF /I "%~1"=="%%~P" SET @SERVICE_NAME=TRUE


 rem -- Show Service Display Names
:ShowDisplayName
 IF /I "%@DISPLAY_NAME%"=="TRUE" (
	 ECHO:
	 ECHO %@DIVIDER-:-=*%
	 ECHO Display Services on %@COMPUTER% [DISPLAY NAME]
	 ECHO %@DIVIDER-:-=*%
	 SC %@COMPUTER% QUERY | FIND "DISPLAY_NAME"
	 ECHO %@DIVIDER-%
	 ECHO:
 )


 rem -- Show Actual Service Names
:ShowServiceName
 IF /I "%@SERVICE_NAME%"=="TRUE" (
	 ECHO:
	 ECHO %@DIVIDER-:-=*%
	 ECHO Display Services on %@COMPUTER% [ACTUAL SERVICE NAME]
	 ECHO %@DIVIDER-:-=*%
	 SC %@COMPUTER% QUERY | FIND "SERVICE_NAME"
	 ECHO %@DIVIDER-%
	 ECHO:
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Display All Installed Services
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [-d^|-s^|-b] [computername]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       /D ..... Show Service Display Names  ***DEFAULT***
 ECHO       /S ..... Show Actual Service Names
 ECHO       /B ..... Show Both Display and Actual Service Names
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 /D
	 ECHO  %~n0 /S \\MYCOMPUTER
	 ECHO  %~n0 /B \\THATCOMPUTER
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Options are case insensitive, and can be prefaced with "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
                                           