@ECHO OFF
 rem ==========================================================================
 rem === Configure SUS on Remote Systems (Server System Config)
 rem ==========================================================================
 rem
 rem Created On: 10 Mar 2005
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 28 Jan 2020  (Prior Update: 24 Dec 2019)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2000 or later
 rem
 rem  Non-Native Utilities Required:
 rem    Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem    psEXEC ................. https://technet.microsoft.com/en-us/sysinternals/bb896649
 rem
 rem  Input Files Used By Script (stored in %SystemDrive%\Scripts\Bat\Input):
 rem    SUS_Servers.TXT ........ List of Machines to Configure for SUS/WSUS
 rem
 rem  Other Scripts Called:
 rem    SetDrive.BAT ........... Primary Script for Setting Common Variables
 rem ==========================================================================

 :::  This script uses several tools to configure SUS options on a list of
 :::  remote systems found in the SUS_Servers.TXT file. This file must exist
 :::  in the same folder as the SetSUS batch script.  The configuration is for
 :::  Servers to download ONLY from the SUS server daily at 3am, but not
 :::  install or reboot.
 :::
 :::  (Nov 2010) Changed the default log extension of the reports from .LOG to
 :::  .TXT so that the reports that are mailed to mobile devices can be read
 :::  automatically. (Not too many devices can natively handle .LOG files)
 :::
 :::  (Apr 2015) v2.7 -- Updated :ShowStatus routine to track script duration.
 :::
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to "TRUE"
 rem === Last Modified On: 05 May 2015  (Prior Update: 15 Feb 2015)
 rem ==========================================================================
:DebugMode
 FOR %%d IN (TRUE LOG) DO IF /I "%Debug%"=="%%~d" (
	 SET @DIAGMODE=TRUE
	 SET @DEBUG_MODE=[DEBUG MODE ON]
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:^& TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 IF /I "%Debug%"=="LOG" (SET @PAUSE_IF_DEBUG=& SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:)
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE ( FOR %%d IN (DEBUG_MODE PAUSE_IF_DEBUG PRINT_IF_DEBUG END_DEBUG_MODE) DO SET @%%d=)


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On: 28 Jan 2020  (Prior Update: 21 Apr 2015)
 rem ==========================================================================
:Variables
 TITLE [%USERDOMAIN%\%USERNAME%] -  %~f0 %* >NUL
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.7.2.002

 rem -- Display Syntax Help if Required/Requested
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage

 rem -- Set Global Variables from Centralized Script
 IF EXIST "%~dp0SetDrive.BAT" (
	 CALL "%~dp0SetDrive.BAT"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %~dp0SetDrive.BAT
	 ECHO:
	 DIR "%~dp0SetDrive.BAT"
	 ECHO:
	 GOTO :ExitBatch
 )

 rem -- SUS Registry Variables     (Clients = Install and Reboot; Servers = Download Only)
 IF NOT DEFINED @SUS_SERVER SET @SUS_SERVER=wsus.mydomain.com
 SET @TEST_KEY=HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\Setup
 SET @TEST_VAL=Bootdir
 SET @SUS_KEY=HKLM\SOFTWARE\Policies\Microsoft\Windows\WindowsUpdate
 SET @TARGET_GROUP=SERVER SYSTEMS
 SET @AU_OPTIONS=3

 rem -- Standard Variables
 SET @SOURCE=%~1&  IF "%~1"=="" SET @SOURCE=%~dp0SUS_Servers.TXT
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Configure SUS Settings for List of Server Systems
 rem === Last Modified On: 15 Feb 2015  (Prior Update: 23 Oct 2013)
 rem ==========================================================================
:ConfigureSUS
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 ( rem -- Write to Log
	 ECHO %@TIMESTAMP%: Configuring SUS Server Options
	 ECHO %@MINORDIV%
	 ECHO:
 ) >"%@LOGFILE%"

 FOR /F "TOKENS=1" %%V IN ('TYPE "%@SOURCE%"') DO (
	 SET @COMPUTER=%%~V
	 SET @COMPUTER=\\!@COMPUTER:\=!
	 ECHO:
	 ECHO:
	 ECHO:
	 ECHO Configuring SUS Options on: "!@COMPUTER!"
	 ECHO Configuring SUS Options on: "!@COMPUTER!" >>"%@LOGFILE%" 2>&1

  :VerifyAccess
   SET @REGCHECK=System Unavailable
   FOR /F %%A IN ('REG QUERY "!@COMPUTER!\%@TEST_KEY%" /v "%@TEST_VAL%"') DO SET @REGCHECK=%%A

   IF NOT "!@REGCHECK!"=="%@TEST_VAL%" (
		 ECHO %%V is not available, or access was denied. [!@REGCHECK!] >>"%@LOGFILE%"
	 ) ELSE (
		 REG ADD "!@COMPUTER!\%@SUS_KEY%" /v "WUServer"           /t REG_SZ    /d "http://%@SUS_SERVER%/" /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%" /v "WUStatusServer"     /t REG_SZ    /d "http://%@SUS_SERVER%/" /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%" /v "TargetGroup"        /t REG_SZ    /d "%@TARGET_GROUP%"      /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%" /v "TargetGroupEnabled" /t REG_DWORD /d 1                      /f

		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "NoAUShutdownOption"            /t REG_DWORD /d 0             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "NoAUAsDefaultShutdownOption"   /t REG_DWORD /d 1             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "NoAutoRebootWithLoggedOnUsers" /t REG_DWORD /d 1             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "AutoInstallMinorUpdates"       /t REG_DWORD /d 1             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "NoAutoUpdate"                  /t REG_DWORD /d 0             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "AUOptions"                     /t REG_DWORD /d %@AU_OPTIONS% /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "ScheduledInstallDay"           /t REG_DWORD /d 0             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "ScheduledInstallTime"          /t REG_DWORD /d 5             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "UseWUServer"                   /t REG_DWORD /d 1             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "RescheduleWaitTimeEnabled"     /t REG_DWORD /d 1             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "RescheduleWaitTime"            /t REG_DWORD /d 2             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "DetectionFrequencyEnabled"     /t REG_DWORD /d 1             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "DetectionFrequency"            /t REG_DWORD /d 12            /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "RebootWarningTimeoutEnabled"   /t REG_DWORD /d 1             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "RebootWarningTimeout"          /t REG_DWORD /d 30            /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "RebootRelaunchTimeoutEnabled"  /t REG_DWORD /d 1             /f
		 REG ADD "!@COMPUTER!\%@SUS_KEY%\AU" /v "RebootRelaunchTimeout"         /t REG_DWORD /d 60            /f

		 START "Restarting AutoUpdate Service on !@COMPUTER!" /MIN PSSERVICE !@COMPUTER! RESTART "Automatic Updates"
		 SLEEP 5 >NUL 2>&1

		 ( rem -- Write to Log
			 REG QUERY "!@COMPUTER!\%@SUS_KEY%" /s
			 PSSERVICE !@COMPUTER! QUERY "Automatic Updates"
			 PSSERVICE !@COMPUTER! QUERY "Windows Update"
		 ) >>"%@LOGFILE%" 2>&1
	 )

	 ( rem -- Write to Log
		 ECHO %@MINORDIV%
		 ECHO:
		 ECHO:
		 ECHO:
	 ) >>"%@LOGFILE%"
 )


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On: 15 Feb 2015  (Prior Update: 24 Mar 2011)
 rem ==========================================================================
:ExitBatch
 ECHO:
 START "%@LOGFILE%" "%@LOGFILE%" & DIR "%@LOGFILE%"
 CALL :ShowStatus "FINISHED"
 TITLE Command Prompt (%USERDOMAIN%\%USERNAME%)   %@DEBUG_MODE%
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Last Modified On: 24 Dec 2019  (Prior Update: 05 May 2015)
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" SET @SCRIPT_BEG#="!DATE:~4,99! !TIME: =0!"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 SET @SCRIPT_END#="!DATE:~4,99! !TIME: =0!"
	 ECHO:
	 DATEINFO -t %@SCRIPT_BEG#% -n !@SCRIPT_END#! -e "hr:min:sec.ms" -o "*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n                               
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Last Modified On: 04 May 2011  (Prior Update: n/a)
 rem ==========================================================================
:HelpMessage
 ECHO Configure WSUS on Remote Systems (Client System Config)
 ECHO:
 ECHO:
 ECHO   YOU TYPED: %0 %*
 ECHO:
 ECHO  CMD SYNTAX: %~n0  ^<system_list^>
 ECHO:
 ECHO  EXAMPLE(S): %~n0 ServerList.TXT
 ECHO              %~n0 %SystemDrive%\Scripts\Bat\Input\SomeList.TXT
 ECHO:
 CALL :ShowStatus "FINISHED"
                                      