@ECHO OFF
 rem ==========================================================================
 rem === Save Event Logs (using PSLOGLIST)
 rem ==========================================================================
 rem
 rem Created On: 03 Apr 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 06 Dec 2003
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows NT Family (NT4/2000/XP/2003)
 rem
 rem  Non-Native Utilities Required:
 rem  	PSTOOLS ................ http://www.sysinternals.com/Utilities/PsTools.html
 rem  	Alternate Tools ........ http://KB.ultratech-llc.com/?File=EventLog.TXT
 rem ==========================================================================

 :::  This script dumps a copy of the selected Event Logs to a
 :::  file, using the current date, with the option of clearing
 :::  the Event Logs if "-c" is used as a parameter.
 :::
 :::  This version will work with whatever Eventlogs are in use on
 :::  the system.  Some error checking is performed to verify which
 :::  Logs actually contain data.
 :::  		Application
 :::  		System
 :::  		Security
 :::  		DNS Server                (only on AD or DNS servers)
 :::      Directory Service         (only on AD servers)
 :::      File Replication Service  (only on AD servers)
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 06 Sep 2001
 rem ==========================================================================
:NeedHelp
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 03 Dec 2003
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Calculate Date/Time (Short Procedure - No ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=1-3 DELIMS=:. " %%T IN ('ECHO %TIME: =0%') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG

 rem -- Job Scheduling Variables
 SET @JOBNAME=Save Event Logs
 SET @JOBPATH=%~f0
 SET @JOBFREQ=DAILY
 SET @JOBTIME=01:00:00
 SET @JOBUSER=NT AUTHORITY\SYSTEM

 rem -- Standard Variables
 SET @LOGS="Application"  "System"  "Security"  "DNS Server"  "Directory Service"  "File Replication Service"
 SET @ERRORMSG=Could not open Registry on %COMPUTERNAME% so event strings will not be processed:
 SET @PARAMS=%1 %2 %3 %4 %5 %6 %7 %8 %9
 SET @LOGPATH=%@STORAGE%\Logs\EventLogs
 SET @LOGFILE=%@LOGPATH%\EventLog.%@FILESTAMP%


 rem ==========================================================================
 rem === Create Scheduled Job using SCHTASKS or AT
 rem === Last Modified On 06 Dec 2003
 rem ==========================================================================
:ScheduleJobs
 ECHO:
 ECHO Scheduling "%@JOBNAME%"...
 ECHO:

 IF EXIST "%SystemRoot%\System32\SCHTASKS.EXE" (
	 SCHTASKS /QUERY /V /FO LIST | FIND /I "%@JOBPATH%" >NUL
	 IF ERRORLEVEL 1 (
		 SCHTASKS /CREATE /TN "%@JOBNAME%" /TR "%@JOBPATH%" /SC "%@JOBFREQ%" /ST %@JOBTIME% /RU "%@JOBUSER%"
	 )
 ) ELSE (
	 AT | FIND /I "%@JOBPATH%" >NUL
	 IF ERRORLEVEL 1 AT %@JOBTIME% /EVERY:M,T,W,TH,F,SA,SU  "%@JOBPATH%"
 )

 rem -- If the only parameter is "." then exit as soon as the job is scheduled
 IF /I "%1"=="." GOTO :EOF


 rem ==========================================================================
 rem === Save Event Logs
 rem === Last Modified On 30 Nov 2003
 rem ==========================================================================
:SaveLogs
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 ECHO Dumping EventLogs...
 FOR %%V IN (%@LOGS%) DO CALL :DumpLogs %%V
 ECHO Finished Dumping EventLogs!


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 06 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Dump Each Valid Event Log
 rem === Last Modified On 30 Nov 2003
 rem ==========================================================================
:DumpLogs
 rem - %1 = Current Log
 FOR /F "TOKENS=*" %%E IN ('PSLOGLIST -n 1 "%~1" ^| FIND /I "%@ERRORMSG%"') DO GOTO :EOF
 PSLOGLIST -s "%~1" %@PARAMS% >>"%@LOGFILE%" 2>&1
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 23 Jun 2003
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for SAVELOGS.BAT
 ECHO:
 ECHO === SaveLogs [-c]
 ECHO:
 ECHO Example: SaveLogs
 ECHO          SaveLogs -c
 ECHO:
