@REM - ASB (18 Apr 2011 // 16 Oct 2023 / 22 Jan 2022 / 30 Nov 2020 / 03 Feb 2020 / 24 Dec 2019 / 30 Sep 2019 / 10 Mar 2019 / 13 Aug 2018): Perform Scheduled Time Sync With Domain Server
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.6.0.260

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Perform Scheduled Time Sync With Domain Server
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [sync duration] [/F]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @DURATION=%~1& IF "%~1"=="" SET @DURATION=15
 SET @FORCE=/F& IF "%~2"=="" SET @FORCE=

 rem -- Job Scheduling Variables
 SET @JOBNAME=Schedule Domain Time Sync
 SET @JOBUSER=SYSTEM
 SET @JOBFREQ=MINUTE /MO %@DURATION%
 SET @JOBTIME=00:00:00
 SET @JOBDATE=
 SET @JOBPATH=%~f0
 SET @JOBTYPE=

 rem -- Set Global Variables from Centralized Script
 IF EXIST "%~dp0SetDrive.BAT"  CALL "%~dp0SetDrive.BAT"

 rem -- Check for Variable to Force Rescheduling
 FOR %%P IN (%*) DO IF "%%~P"=="." (
	 SET @UPDATESCHED=TRUE
	 SET @SCHEDULEONLY=TRUE
 )

 rem -- Standard Logging Variables
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.TXT
 SET @SAVELOG=%@LOGPATH%\%~n0.%@TODAY%.TXT
 %@PAUSE_IF_DEBUG%


 rem -- Create Scheduled Job using SCHTASKS (XP/2003/Vista/+)
:ScheduleJobs
 IF /I "%@NOSCHED%"=="TRUE" IF /I NOT "%@UNSCHED%"=="TRUE" (
	 SET @JOBTYPE= // ONE-TIME
	 ECHO:
	 ECHO *** Job Scheduling Disabled ***
	 ECHO:
	 GOTO :ScheduleJobs_END
 )

 ECHO:
 ECHO Scheduling "%@JOBNAME%" on %COMPUTERNAME% at %@DURATION% minute Intervals...
 ECHO:

 IF %@OSBUILD% LSS 6000 SET @TASKFOLDER=
 SET @NAMECHK=%@JOBNAME:[=\[%
 SET @NAMECHK=!@NAMECHK:]=\]!
 SET @CHK_SCHED=SCHTASKS /QUERY /V /FO LIST
 SET @SET_SCHED=SCHTASKS /CREATE /TN "!@TASKFOLDER!%@JOBNAME%" /TR "%@JOBPATH%" /RU "%@JOBUSER%" /SC %@JOBFREQ% %@JOBDATE% /ST %@JOBTIME% %@JOBLEVEL% %@FORCE%

 rem -- Delete Scheduled Task from Old Custom Folders on Vista/2008+
 IF %@OSBUILD% GEQ 6000 (
	 FOR /F "TOKENS=1* DELIMS=\ " %%s IN ('%@CHK_SCHED% 2^>NUL ^| FIND "TaskName:" ^| FINDSTR /I /R /C:"\\%@NAMECHK%$"') DO (
		 IF /I NOT "%@TASKFOLDER%%@JOBNAME%"=="%%t" SCHTASKS /DELETE /TN "%%t" /F >NUL 2>&1
	 )
 )

 rem -- Check for Schedule Update Parameters
 IF /I "%@UPDATESCHED%"=="TRUE" (!@SET_SCHED!) ELSE (CALL :CheckSched "%~f0")
 ECHO %@MINORDIV%
 ECHO:
 IF /I "%@SCHEDULEONLY%"=="TRUE" (
	 ECHO Task has been scheduled.  Now exiting script...
	 IF %@OSBUILD% LSS 6000 (SCHTASKS) ELSE (%@CHK_SCHED% /TN "!@TASKFOLDER!%@JOBNAME%")
	 GOTO :ExitBatch
 )
:ScheduleJobs_END
 %@PAUSE_IF_DEBUG%


 rem -- Initialize File and Log Folder
:GenerateHeader
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%" >NUL
 IF NOT EXIST "%@SAVELOG%" ECHO Generated by %@VER% [%DATE% at %TIME%] >"%@SAVELOG%"


 rem -- Run Configuration Scripts on Local Machine
:SynchronizeTime
 FOR /F "TOKENS=*" %%T IN ('NET TIME /DOMAIN ^| FIND /I "CURRENT TIME"') DO (
	 CALL :ConvertTime "!TIME!" @BASETIME
	 FOR /F "TOKENS=4,7" %%C IN ('ECHO %%~T') DO SET @TIMESERVER=%%~C& CALL :ConvertTime "%%~D" @COMPTIME
	 SET /A @OFFSET=@COMPTIME - @BASETIME
	 IF !@OFFSET! EQU 0 (
		 ECHO !DATE! @ !TIME! -- IN SYNC --- !@TIMESERVER:\=!
	 ) ELSE (
		 IF "!@OFFSET:~-1!"=="1" (
			 ECHO !DATE! @ !TIME! -- OFF-SYNC -- !@TIMESERVER:\=! [!@OFFSET! seconds]
		 ) ELSE (
			 ECHO:
			 ECHO %@MINORDIV%
			 ECHO !DATE! @ !TIME! -- RESYNC INITIATED [Offset = !@OFFSET! seconds]
			 ECHO:
			 W32TM /RESYNC /REDISCOVER
			 W32TM /QUERY /STATUS
			 ECHO !DATE! @ !TIME! -- RESYNCHED
			 ECHO %@MINORDIV%
			 ECHO:
		 )
	 )
 ) >>"%@SAVELOG%" 2>&1
 COPY "%@SAVELOG%" "%@LOGFILE%" /Y


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Convert Time to Number
:ConvertTime
 rem %1 = Current Time to Convert
 rem %2 = New Variable To Store Resulting Time Value
 SET @TIMEVAL=0
 FOR /F "TOKENS=1-3 DELIMS=:." %%N IN ('ECHO %~1') DO (
	 SET @T_HH=%%~N& FOR %%Z IN (8 9) DO IF "%%~N"=="0%%~Z" SET @T_HH=%%~Z
	 SET @T_MM=%%~O& FOR %%Z IN (8 9) DO IF "%%~O"=="0%%~Z" SET @T_MM=%%~Z
	 SET @T_SS=%%~P& FOR %%Z IN (8 9) DO IF "%%~P"=="0%%~Z" SET @T_SS=%%~Z
	 FOR %%Z IN (@T_HH @T_MM @T_SS) DO IF NOT DEFINED %%~Z SET %%~Z=0
	 IF !@T_HH! GEQ 12 SET /A @T_HH-=12
 )

 IF %@OSBUILD% LEQ 3790 SET @T_SS=0
 SET /A @TIMEVAL=(@T_HH * 3600) + (@T_MM * 60) + @T_SS
 SET %~2=%@TIMEVAL%
 GOTO :EOF


 rem -- SUBROUTINE: Check if Scheduled Job is Already Running
:CheckSched
 rem %1 = Standard Search Criteria
 rem %2 = Advanced Search Criteria

 SET @CHK=%2
 IF DEFINED @CHK (
	 %@CHK_SCHED% 2>NUL | FIND /I "%~1" | FINDSTR /I /R /C:%2 >NUL
 ) ELSE (
	 %@CHK_SCHED% 2>NUL | FIND /I "%~1" >NUL
 )
 IF ERRORLEVEL 1 %@SET_SCHED%
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
    