@REM - ASB (12 Jun 2020 // 16 Oct 2023 / 23 Dec 2021 / 12 Dec 2021 / 30 Nov 2020 / 29 Sep 2020 / 24 Sep 2020 / 20 Sep 2020 / 14 Sep 2020 / 17 Jul 2020 / 14 Jul 2020 / 16 Jun 2020 / 12 Jun 2020): Summarize Script Usage Based on @SCRIPT_METRICS logging
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v4.1.0.410

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @SYSLOG_LIST=FastVue VisualSyslog WinSyslog WhatsUp Kiwi TFTPD NxLog
 SET @BASENAME=\Storage\Logs\Syslog\Syslog
 SET @ALTLOGNAME=\Storage\Logs\SyslogD\Main\SyslogCatchAll.TXT
 SET @FOUNDLOG=

 rem -- Process Special Command-line Parameters
 SET @ALL_PARAMS=%*
 CALL :GetParams "S SERVICE"     @SERVICE  & IF NOT DEFINED @SERVICE  (SET @SERVICE=Tftpd32_svc)
 CALL :GetParams "W WHICHLOG"    @WHICHLOG & IF NOT DEFINED @WHICHLOG (SET @WHICHLOG=--NXLOG) ELSE (SET @WHICHLOG=--!@WHICHLOG!)
 CALL :GetParams "L LOGFILE"     @LOGFILE  & IF NOT DEFINED @LOGFILE IF EXIST "%~1" (SET @LOGFILE="%~1")
 CALL :GetParams "F FIND SEARCH" @SEARCH   & IF DEFINED @SEARCH   SET @SEARCH=-S !@SEARCH!
 CALL :GetParams "M MAX-LINES"   @MAXLINES & IF DEFINED @MAXLINES SET @MAXLINES=-M !@MAXLINES!

 CALL :GetParams "R ROLLOVER @"            & IF DEFINED @OK (SET @ROLLOVER=TRUE) ELSE (SET @ROLLOVER=)
 CALL :GetParams "A ALPHA"                 & IF DEFINED @OK (SET @ALPHASORT=-A)  ELSE (SET @ALPHASORT=)
 CALL :GetParams "N NUMBER #"              & IF DEFINED @OK (SET @NUMBERSORT=-N) ELSE (SET @NUMBERSORT=)


 rem -- Determine Correct Logfile and Syslog Type for All Valid Logs
 rem -- Generate Full Report via SyslogTally v2.0.0+
:ParseLogFile
 IF DEFINED @LOGFILE (
	 SET @FOUNDLOG=TRUE
	 SYSLOGTALLY %@LOGFILE% %@ALPHASORT% %@NUMBERSORT% %@MAXLINES% %@SEARCH% %@WHICHLOG%
 ) ELSE (
	 FOR %%L IN (%@ALPHABET%) DO IF EXIST "%%~L:%@ALTLOGNAME%" (
		 SET @FOUNDLOG=TRUE
		 ECHO *** FOUND: Enterprise KIWISYSLOG Logfile ***
		 ECHO:
		 SYSLOGTALLY "%%~L:%@ALTLOGNAME%" %@ALPHASORT% %@NUMBERSORT% %@MAXLINES% %@SEARCH% --KIWI
		 MAKESTRING "#" 100
		 ECHO:
		 ECHO:
	 )

	 FOR %%L IN (%@ALPHABET%) DO FOR %%S IN (%@SYSLOG_LIST%) DO IF EXIST "%%~L:%@BASENAME%-%%~S.TXT" (
		 SET @FOUNDLOG=TRUE
		 SET @LOGFILE="%%~L:%@BASENAME%-%%~S.TXT"
		 SET @WHICHLOG=--%%~S
		 ECHO *** FOUND: %%~S Logfile ***
		 SYSLOGTALLY !@LOGFILE! %@ALPHASORT% %@NUMBERSORT% %@MAXLINES% %@SEARCH% !@WHICHLOG!
		 MAKESTRING "#" 100
		 ECHO:
		 ECHO:
	 )
 )


 rem -- Alert on Missing Logfile, or Jump to Rollover
:Check4Rollover
 IF NOT DEFINED @FOUNDLOG (
	 NOW \n\**** \v -- NO VALID SYSLOG FILE FOUND\n\*
	 GOTO :ExitBatch
 )


 rem -- Backup Old Log and Start New One
:Rollover
 IF DEFINED @ROLLOVER (
	 NOW \n\**** \v -- ROLLOVER CURRENT LOG\n\*
	 NET STOP %@SERVICE%
	 REN %@LOGFILE% "*.%@FILESTAMP_R%"
	 NET START %@SERVICE%
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Use CheckParams.exe to Capture Selected Parameters
:GetParams
 rem %1 = Parameters to Search For
 rem %2 = Variable to Set

 SET @OK=& IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=2-3*" %%v IN ('CHECKPARAMS -q -a -c "%~1" -s %@ALL_PARAMS% 2^>NUL') DO IF /I "%%~v"=="TRUE" (
	 SET @OK=T
	 SET @REQ=T
	 IF NOT "%~2"=="" SET %~2=%%~x
 )
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Summarize Script Usage Based on @SCRIPT_METRICS logging
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [log_file_name] [OPTIONS]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       /L ..... Name of Logfile  (Default = \Storage\Logs\Syslog\Syslog.TXT)
 ECHO       /R ..... Rollover Log to Start New Log
 ECHO       /S ..... Name of Local Syslog Service  (Default = Tftpd32_svc)
 ECHO       /W ..... Which Syslog Type  (Default = NXLOG)
 ECHO       /A ..... Sort by Name of Process/Job
 ECHO       /N ..... Sort by Number of Process/Job Completed
 ECHO       /F ..... Search for specific processes (substring search)
 ECHO       /M ..... Set the Maximum number of entries to return
 ECHO:
 ECHO  VALID Entries for -W are:
 ECHO       NXLOG
 ECHO       TFTPD     (also LEGACY)
 ECHO       KIWISYSLOG
 ECHO       WHATSUP
 ECHO       WINSYSLOG
 ECHO       VISUALSYSLOG
 ECHO       FASTVUE
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 %SystemDrive%\Logs\Syslog.TXT
	 ECHO  %~n0 D:\JobTracker\JobSyslog.TXT /A
	 ECHO  %~n0 "E:\Syslogs\Script Log.TXT" /N /R
	 ECHO  %~n0 "F:\Logs\Syslog.TXT" /F:"Time" /M:25
	 ECHO  %~n0 "G:\Log Management\SomeSyslog.TXT" /W:NXLOG
	 ECHO  %~n0 "H:\LocalSyslog\MySyslog.TXT" /R /S:"Other Service Name"
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * Folder Paths containing spaces should be enclosed in quotes.
	 ECHO  * -N does not work in Legacy Mode [-O].
 )
 CALL :ShowStatus "FINISHED"
                                                             