@ECHO OFF
 rem ==========================================================================
 rem === Disable Accounts or Remove Password Expiration Flag
 rem ==========================================================================
 rem
 rem Created On: 03 Mar 2005
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 04 Apr 2024 / 02 Apr 2024 / 16 Oct 2023 / 30 Nov 2020
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2003 OR later
 rem
 rem  Non-Native Utilities Used/Required:
 rem    BrainWave Utilities .... https://www.BrainWaveCC.com/brainwave-utilities
 rem
 rem    GetUserInfo ............ http://www.joeware.net/win/free/tools/getuserinfo.htm
 rem    CHOICE ................. Native in Windows 2003+ / Reskit in NT/2000
 rem    NETDOM ................. Native in Windows 2003+ with AD Mgmt Components Installed
 rem    Resource Kit ........... https://en.wikipedia.org/wiki/Resource_Kit
 rem
 rem  Required Scripts:
 rem    SetDrive.BAT ........... Set Global Variables for this Environment
 rem ==========================================================================

 :::  This script uses several tools to process a user-defined list of users
 :::  so that their accounts can be enabled or disabled, set to have password
 :::  expiration or be exempted from expiration or be deleted.
 :::
 :::  (Nov 2010) Changed the default log extension of the reports from .LOG to
 :::  .TXT so that the reports that are mailed to mobile devices can be read
 :::  automatically. (Not too many devices can natively handle .LOG files)
 :::
 :::  (Oct 2013) v2.3 -- The delimiter for all parameters can be either the
 :::  "-" or the "/" character.  This includes the help parameters.
 :::
 :::  (Feb 2014) v2.8 -- The script now checks for more variables to determine
 :::  if the current session is running as a local OR RDP console, and if so,
 :::  offers more prompts.
 :::
 :::  (Apr 2015) v2.9 -- Updated :ShowStatus routine to track script duration.
 :::
 :::  (Jul 2018) v3.0 -- The new BrainWave CheckParams utility is now used to
 :::  check for the /H and /? parameters, replacing the use of FIND/FINDSTR;
 :::  -- Added new Filtered CMD Title and Syntax Help processing routines;
 :::  -- Changed Script Documentation to www.BrainWaveCC.com
 :::
 :::  (Oct 2018) v3.1 -- Corrected and expanded the DEBUG logging routine;
 :::
 :::  (Oct 2019) v3.2 -- Updated :ShowStatus routine to reset TITLE/CodePage;
 :::
 :::  (May 2020) v3.3 -- Migrated :DebugMode routine to SetDrive.BAT;
 :::
 :::  (Nov 2020) v3.4 -- Provided extended HELP options (--?? / --H2);
 :::  -- New CHECKPARAMS syntax for processing extended help options;
 :::
 :::  (Oct 2023) v3.5 -- Change the way the @SCRIPT_BEG# variable is
 :::  calculated in various subroutines by using DATEINFO instead of %DATE%;
 :::
 :::  (Apr 2024) v3.6 -- Check for essential utilities with FINDFILES;
 :::
 :::
 :::  ADDITIONAL SCRIPTING TOOLS/INFO:
 :::  -------------------------------------------------------------------------
 :::  https://www.BrainWaveCC.com/knowledge-base/scripting-and-automation-options-for-windows/
 :::  https://www.BrainWaveCC.com/knowledge-base/must-have-utilities-for-windows-usersadmins/
 :::  -------------------------------------------------------------------------


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 30 Jul 2018
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 04 Apr 2024 / 02 Apr 2024 / 30 Nov 2020 / 26 May 2020
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.6.0.370

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Check for Essential Utilities and/or Scripts
 SET @ESSENTIALS="%~dp0SetDrive.BAT" CHECKPARAMS.EXE DATEINFO.EXE NOW.EXE READCONFIG.EXE FIND.EXE
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f %@ESSENTIALS% CHOICE.EXE CUSRMGR.EXE GETUSERINFO.EXE NETDOM.EXE
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Set Global Variables from Centralized Script
 CALL "%~dp0SetDrive.BAT" "%~n0"

 rem -- Main Variables
 SET @MESSAGE1="Re-Enabled by Script at %@FILESTAMP% from %COMPUTERNAME%"
 SET @MESSAGE2="Disabled by Script at %@FILESTAMP% from %COMPUTERNAME%"
 SET @SUCCESS="The command completed successfully."

 SET @DOMAIN=%~1& IF "%~1"=="" SET @DOMAIN=%USERDOMAIN%
 SET @SOURCE=%~3& IF "%~3"=="" SET @SOURCE=%~dp0UserAccounts.TXT
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Process Command-line Parameters
 rem === Updated On: 23 Oct 2013 / 09 Mar 2005
 rem ==========================================================================
:Params
 FOR %%d IN (- /) DO (
	 FOR %%P IN (E ENABLE) DO   IF /I "%~2"=="%%~d%%~P" SET @EXECUTE=:ENABLED
	 FOR %%P IN (D DISABLE) DO  IF /I "%~2"=="%%~d%%~P" SET @EXECUTE=:DISABLED
	 FOR %%P IN (R REMOVE) DO   IF /I "%~2"=="%%~d%%~P" SET @EXECUTE=:REMOVED
	 FOR %%P IN (N NOEXPIRE) DO IF /I "%~2"=="%%~d%%~P" SET @EXECUTE=:NOEXPIRATION
	 FOR %%P IN (X EXPIRE) DO   IF /I "%~2"=="%%~d%%~P" SET @EXECUTE=:EXPIRED
 )


 rem ==========================================================================
 rem === Allow User To Abort Operation
 rem === Updated On: 19 Feb 2014 / 30 Mar 2011
 rem ==========================================================================
:DblCheck
 ECHO === Prepare to Set Accounts Options in the %@DOMAIN% domain ===
 ECHO:
 ECHO Accounts listed in Domain "%@DOMAIN%" will be set to %@EXECUTE::=%.
 ECHO:
 IF /I "%@CONSOLE_SESSION%"=="TRUE" (
	 CHOICE /C YNQEX /T 20 /D Y /N /M "Continue running this script? (Y/N/Q) "
	 IF !ERRORLEVEL! GTR 1 GOTO :ExitBatch
 )


 rem ==========================================================================
 rem === Get Domain Controller for Selected Domain
 rem === Updated On: 05 Feb 2015 / 29 Mar 2011
 rem ==========================================================================
:FindDC
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%" >NUL

 FOR /F "SKIP=2" %%D IN ('NETDOM QUERY PDC /DOMAIN:%@DOMAIN% ^| FIND /V %@SUCCESS%') DO SET @DC=%%D
 IF /I "%@DC%"=="" (
	 ECHO No Valid Domain Controller for %@DOMAIN%
	 GOTO :ExitBatch
 )
 GOTO %@EXECUTE%


 rem ==========================================================================
 rem === Set Accounts in %@DOMAIN% To Enabled
 rem === Updated On: 05 Feb 2015 / 23 Oct 2013
 rem ==========================================================================
:Enabled
 ( rem -- Write to Log
	 ECHO %@TIMESTAMP%: Enable Accounts In %@DOMAIN%
	 ECHO %@MINORDIV%
	 ECHO:
 ) >"%@LOGFILE%" 2>&1

 FOR /F "TOKENS=*" %%V IN (%@SOURCE%) DO (
	 ECHO Setting Account to Enabled for: "%%V"
	 ( rem -- Write to Log
		 ECHO Setting Account to Enabled for: "%%V"
		 CUSRMGR -m \\%@DC% -u "%%V" -s AccountDisabled
		 CUSRMGR -m \\%@DC% -u "%%V" -c %@MESSAGE1%
	 ) >>"%@LOGFILE%" 2>&1
   CALL :GetUserInfo "%%V"
 )
 GOTO :ExitBatch


 rem ==========================================================================
 rem === Set Accounts in %@DOMAIN% To DISABLED
 rem === Updated On: 05 Feb 2015 / 23 Oct 2013
 rem ==========================================================================
:Disabled
 ( rem -- Write to Log
	 ECHO %@TIMESTAMP%: DISABLE Accounts In %@DOMAIN%
	 ECHO %@MINORDIV%
	 ECHO:
 ) >"%@LOGFILE%" 2>&1

 FOR /F "TOKENS=*" %%V IN (%@SOURCE%) DO (
	 ECHO Setting Account to DISABLED for: "%%V"
	 ( rem -- Write to Log
		 ECHO Setting Account to DISABLED for: "%%V"
		 CUSRMGR -m \\%@DC% -u "%%V" +s AccountDisabled
		 CUSRMGR -m \\%@DC% -u "%%V" -r "_%%V" -c %@MESSAGE2%
	 ) >>"%@LOGFILE%" 2>&1
   CALL :GetUserInfo "_%%V""
 )
 GOTO :ExitBatch


 rem ==========================================================================
 rem === Remove Accounts from the Domain
 rem === Updated On: 05 Feb 2015 / 23 Oct 2013
 rem ==========================================================================
:Removed
 ( rem -- Write to Log
	 ECHO %@TIMESTAMP%: Permanently DELETING Accounts In %@DOMAIN%
	 ECHO %@MINORDIV%
	 ECHO:
 ) >"%@LOGFILE%" 2>&1

 FOR /F "TOKENS=*" %%V IN (%@SOURCE%) DO (
	 ECHO Permanently DELETING the Following Account: "%%V"
	 ( rem -- Write to Log
		 ECHO Permanently DELETING the Following Account: "%%V"
		 CUSRMGR -m \\%@DC% -u "%%V" +s AccountDisabled
		 CUSRMGR -m \\%@DC% -u "%%V" -r "_%%V" -c %@MESSAGE2%
	 ) >>"%@LOGFILE%" 2>&1
   CALL :GetUserInfo "_!%%V""
 )
 GOTO :ExitBatch


 rem ==========================================================================
 rem === Enable Password Expiration for Accounts in %@DOMAIN%
 rem === Updated On: 05 Feb 2015 / 23 Oct 2013
 rem ==========================================================================
:Expired
 ( rem -- Write to Log
	 ECHO %@TIMESTAMP%: Enable Password Expiration In %@DOMAIN%
	 ECHO %@MINORDIV%
	 ECHO:
 ) >"%@LOGFILE%" 2>&1

 FOR /F "TOKENS=*" %%V IN (%@SOURCE%) DO (
	 ECHO Enabling Password Expiration for: "%%V"
	 ( rem -- Write to Log
		 ECHO Enabling Password Expiration for: "%%V"
		 CUSRMGR -m \\%@DC% -u "%%V" -s PasswordNeverExpires
	 ) >>"%@LOGFILE%" 2>&1
   CALL :GetUserInfo "%%V"
 )
 GOTO :ExitBatch


 rem ==========================================================================
 rem === Disable Password Expiration for Accounts in %@DOMAIN%
 rem === Updated On: 05 Feb 2015 / 23 Oct 2013
 rem ==========================================================================
:NoExpiration
 ( rem -- Write to Log
	 ECHO %@TIMESTAMP%: Disable Password Expiration In %@DOMAIN%
	 ECHO %@MINORDIV%
	 ECHO:
 ) >"%@LOGFILE%" 2>&1

 FOR /F "TOKENS=*" %%V IN (%@SOURCE%) DO (
	 ECHO Removing Password Expiration from: "%%V"
	 ( rem -- Write to Log
		 ECHO Removing Password Expiration from: "%%V"
		 CUSRMGR -m \\%@DC% -u "%%V" +s PasswordNeverExpires
	 ) >>"%@LOGFILE%" 2>&1
   CALL :GetUserInfo "%%V"
 )
 GOTO :ExitBatch


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 04 Oct 2019 / 28 Feb 2019
 rem ==========================================================================
:ExitBatch
 ECHO:
 START "%@LOGFILE%" "%@LOGFILE%" & DIR "%@LOGFILE%"
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Get User Info & Add Separator To Logfile
 rem === Updated On: 05 Feb 2015 / 23 Oct 2013
 rem ==========================================================================
:GetUserInfo
 rem %1 = Current User Account

 ( rem -- Write to Log
	 ECHO:
	 GetUserInfo "%@DOMAIN%\%~1"
	 ECHO %@MINORDIV%
	 ECHO:
	 ECHO:
 ) >>"%@LOGFILE%" 2>&1
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Updated On: 30 Nov 2020 / 23 Oct 2013
 rem ==========================================================================
:HelpMessage
 ECHO Disable Accounts or Remove Password Expiration Flag
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<domain^> ^<OPTIONS^>
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       /E  .... Enable/Activate the Accounts
 ECHO       /D  .... Disable the Accounts
 ECHO       /R  .... Remove/Delete The Accounts from the Domain
 ECHO       /X  .... Set the Passwords of the Accounts to Expire
 ECHO       /N  .... Disable Password Expiration for the Accounts
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 Your_Domain /D
	 ECHO  %~n0 %USERDOMAIN% /E
	 ECHO  %~n0 SomeOtherDomain /X
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
 )
 CALL :ShowStatus "FINISHED"
                              