@ECHO OFF
 rem ==========================================================================
 rem === Configure SUS on Remote Systems (Client System Config)
 rem ==========================================================================
 rem
 rem Created On: 10 Mar 2005
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 14 Nov 2010  (Prior Update: 08 Jan 2007)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2000 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem  	psEXEC ................. http://www.microsoft.com/technet/sysinternals/utilities/PsTools.mspx
 rem
 rem  Input Files Used By Script (stored in %SystemDrive%\Scripts\Bat\Input):
 rem    SUS_Clients.TXT ........ List of Machines to Configure for SUS/WSUS
 rem
 rem  Other Scripts Called:
 rem    SetDrive.BAT ........... Primary Script for Setting Common Variables
 rem ==========================================================================

 :::  This script uses several tools to configure SUS options on a list of
 :::  remote systems found in the SUS_Clients.TXT file. This file must exist in
 :::  the same folder as the SetSUS batch script.  The configuration is for
 :::  Clients to download and install patches from the SUS server daily at 5am,
 :::  and only reboot if no one is logged on.
 :::
 :::  (Nov 2010) Changed the default log extension of the reports from .LOG to
 :::  .TXT so that the reports that are mailed to mobile devices can be read
 :::  automatically. (Not too many devices know what to do with the .LOG files)
 :::
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to "TRUE"
 rem === Last Modified On: 25 Oct 2005
 rem ==========================================================================
:DebugMode
 IF /I "%Debug%"=="TRUE" (
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE (
	 SET @PAUSE_IF_DEBUG=
	 SET @END_DEBUG_MODE=
 )


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On: 14 Nov 2010  (Prior Update: 08 Jan 2007)
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION
 SET @VER=%~nx0 v2.3.1

 rem -- Display Syntax Help if Required/Requested
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage

 rem -- Call Centralized Script for Setting Global Log and Date/Time Variables
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" (
	 CALL "%~dp0SetDrive.BAT"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO You Need The Date Routines from %~dp0SetDrive.BAT, which cannot be found.
	 ECHO:
	 DIR "%~dp0SetDrive.BAT"
	 ECHO:
	 GOTO :EOF
 )

 rem -- SUS Registry Variables     (Clients = Install and Reboot; Servers = Download Only)
 SET @SUS_SERVER=wsus.mydomain.com
 SET @TEST_KEY=HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\Setup
 SET @TEST_VAL=Bootdir
 SET @SUS_KEY=HKLM\SOFTWARE\Policies\Microsoft\Windows\WindowsUpdate
 SET @TARGET_GROUP=DESKTOP SYSTEMS
 SET @AU_OPTIONS=4

 rem -- Standard Variables
 SET @SOURCE=%~1&  IF "%~1"=="" SET @SOURCE=%~dp0SUS_Clients.TXT
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Configure SUS Settings for List of Clients
 rem === Last Modified On: 09 Mar 2006
 rem ==========================================================================
:ConfigureSUS
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 ( rem -- Consolidate LogFile Output
	 ECHO %@TIMESTAMP%: Configuring SUS Client Options
	 ECHO ---------------------------------------------------------------------------
	 ECHO:
 ) >"%@LOGFILE%"

 FOR /F "TOKENS=*" %%V IN ('TYPE "%@SOURCE%"') DO (
	 ECHO:
	 ECHO:
	 ECHO:
	 ECHO Configuring SUS Options on: "%%V"
	 ECHO Configuring SUS Options on: "%%V" >>"%@LOGFILE%" 2>&1

  :VerifyAccess
   SET @REGCHECK=System Unavailable
   FOR /F %%A IN ('REG QUERY "\\%%V\%@TEST_KEY%" /v "%@TEST_VAL%"') DO SET @REGCHECK=%%A

   IF NOT "!@REGCHECK!"=="%@TEST_VAL%" (
		 ECHO %%V is not available, or access was denied. [!@REGCHECK!] >>"%@LOGFILE%"
	 ) ELSE (
		 REG ADD "\\%%V\%@SUS_KEY%" /v "WUServer"           /t REG_SZ    /d "http://%@SUS_SERVER%/" /f
		 REG ADD "\\%%V\%@SUS_KEY%" /v "WUStatusServer"     /t REG_SZ    /d "http://%@SUS_SERVER%/" /f
		 REG ADD "\\%%V\%@SUS_KEY%" /v "TargetGroup"        /t REG_SZ    /d "%@TARGET_GROUP%"      /f
		 REG ADD "\\%%V\%@SUS_KEY%" /v "TargetGroupEnabled" /t REG_DWORD /d 1                      /f

		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "NoAUShutdownOption"            /t REG_DWORD /d 0             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "NoAUAsDefaultShutdownOption"   /t REG_DWORD /d 1             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "NoAutoRebootWithLoggedOnUsers" /t REG_DWORD /d 1             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "AutoInstallMinorUpdates"       /t REG_DWORD /d 1             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "NoAutoUpdate"                  /t REG_DWORD /d 0             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "AUOptions"                     /t REG_DWORD /d %@AU_OPTIONS% /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "ScheduledInstallDay"           /t REG_DWORD /d 0             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "ScheduledInstallTime"          /t REG_DWORD /d 5             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "UseWUServer"                   /t REG_DWORD /d 1             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "RescheduleWaitTimeEnabled"     /t REG_DWORD /d 1             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "RescheduleWaitTime"            /t REG_DWORD /d 2             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "DetectionFrequencyEnabled"     /t REG_DWORD /d 1             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "DetectionFrequency"            /t REG_DWORD /d 12            /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "RebootWarningTimeoutEnabled"   /t REG_DWORD /d 1             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "RebootWarningTimeout"          /t REG_DWORD /d 30            /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "RebootRelaunchTimeoutEnabled"  /t REG_DWORD /d 1             /f
		 REG ADD "\\%%V\%@SUS_KEY%\AU" /v "RebootRelaunchTimeout"         /t REG_DWORD /d 60            /f

		 START "Restarting AutoUpdate Service on %%V" /MIN PSSERVICE \\%%V RESTART "Automatic Updates"
		 SLEEP 5 >NUL 2>&1

		 ( rem -- Consolidate LogFile Output
			 REG QUERY "\\%%V\%@SUS_KEY%" /s
			 PSSERVICE \\%%V QUERY "Automatic Updates"
		 ) >>"%@LOGFILE%" 2>&1
	 )

	 ( rem -- Consolidate LogFile Output
		 ECHO ---------------------------------------------------------------------------
		 ECHO:
		 ECHO:
		 ECHO:
	 ) >>"%@LOGFILE%"
 )


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On: 25 Oct 2005
 rem ==========================================================================
:ExitBatch
 ECHO:
 START "%@LOGFILE%" "%@LOGFILE%" & DIR "%@LOGFILE%"
 %@END_DEBUG_MODE%
 ENDLOCAL
