@REM - ASB (14 Mar 2019 // 16 Oct 2023 / 22 Mar 2022 / 30 Nov 2020 / 29 Sep 2020 / 06 Aug 2020 / 17 May 2020 / 24 Dec 2019 / 17 Oct 2019 / 30 Sep 2019 / 27 May 2019 / 14 Mar 2019): Set Service Account for Task Schedule Jobs
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %1 %2
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.6.0.120

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Main Variables
 SET @NOPROMPT=TRUE
 SET @SANITIZED=TRUE
 SET @OLDACCT=%~1& IF "%~1"=="" SET @OLDACCT=AdminScripts
 SET @NEWACCT=%~2& IF "%~2"=="" SET @NEWACCT=%USERDOMAIN%\AdminScripts
 SET @SYSLIST=%~3& IF "%~3"=="" SET @SYSLIST=.


 rem -- Change/Update Task Schedule Account
:UpdateAccount
 FOR /F "TOKENS=*" %%P IN ('GetInput -p "Enter the password for %@NEWACCT%: " -q') DO SET @PWD="%%P"
 SET @PWD="!@PWD:"=!"
 IF !@PWD!=="" (
	 ECHO Password for %@NEWACCT% cannot be blank!
	 ECHO:
	 GOTO :UpdateAccount
 )
  CALL %~dp0DO.BAT %@SYSLIST% %~dp0TaskConfig.BAT ## %@OLDACCT% /N:%@NEWACCT% /P:%@PWD%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Set Service Account for Task Schedule Jobs
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<service_name_without_domain^> ^<domain\service_name^> [OPTIONS^|some_server_list]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       .  ..... Use the default systems list  **DEFAULT**
 ECHO       @  ..... Generate a dynamic list of ALL domain controllers using the ADFIND command
 ECHO       #  ..... Generate a dynamic list of domain servers (minus DCs) using the ADFIND command
 ECHO       $  ..... Generate a dynamic list of ALL domain servers using the ADFIND command
 ECHO       +  ..... Generate a dynamic list of domain computers (minus ALL servers) using the ADFIND command
 ECHO       *  ..... Generate a dynamic list of domain computers (minus DCs) using the ADFIND command
 ECHO      **  ..... Generate a dynamic list of ALL domain computers (everything) using the ADFIND command
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 AdminScripts %USERDOMAIN%\AdminScripts
	 ECHO  %~n0 DOMAIN1\OldService DOMAIN2\NewService @
	 ECHO  %~n0 THISDOMAIN\MyService THATDOMAIN\MyService *
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * This script cannot process passwords containing the following:
	 ECHO    ? * \ / ^" %% ^( ^) ^< ^> ^| or the exclamation point
	 ECHO:
	 ECHO  * Alternate ServerList files can be specified using their full path.
	 ECHO    For files which reside in the default INPUT folder, you can use the
	 ECHO    filename or filename.ext only.  ^(The default INPUT folder is typically
	 ECHO    %SystemDrive%\Scripts\Bat\Input^)
 )
 CALL :ShowStatus "FINISHED"
                                                                          