@REM - ASB (13 Apr 2018 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 13 Apr 2018): Display Most Current StorageInfo.TXT Report [Local or Remote]
@ECHO OFF
 CLS


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.1.0.110

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Display Most Current StorageInfo.TXT Report [Local or Remote]
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [servername]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO     EXAMPLES:
	 ECHO          %~n0
	 ECHO          %~n0 someserver
	 ECHO          %~n0 \\otherserver
	 ECHO          %~n0 -?
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 SET @FOUND=0
 SET @DRIVES=J I H G F E D C
 SET @REPORT=\Storage\Logs\Maint\StorageInfo.TXT
 SET @SERVER=%~1
 SET @REMOTE=
 SET @RUNONCE=

 rem - Local vs Remote Connection Variables
 IF DEFINED @SERVER (
	 SET @SERVER=\\%@SERVER:\=%
	 SET @RUNONCE=TRUE
 ) ELSE (
	 SET @SERVER=%COMPUTERNAME%
 )


 rem - Search for Most Recent StorageInfo.TXT Report
:GetReport
 ECHO Searching for Current StorageInfo.TXT Report on %@SERVER%
 FOR %%V IN (%@REMOTE% %@DRIVES%) DO (
	 IF /I "%@SERVER%"=="%COMPUTERNAME%" (
		 SET @LOCATION=%%~V:
		 SET @MYREPORT="!@LOCATION!%@REPORT%"
	 ) ELSE (
		 IF DEFINED @RUNONCE (
			 SET @LOCATION=%@SERVER%\Logs$
			 SET @MYREPORT="!@LOCATION!\Maint\StorageInfo.TXT"
			 SET @RUNONCE=
		 ) ELSE (
			 SET @LOCATION=%@SERVER%\%%~V$
			 SET @MYREPORT="!@LOCATION!%@REPORT%"
		 )
	 )

	 IF EXIST !@MYREPORT! (
		 SET /A @FOUND+=1
		 ECHO  - StorageInfo.TXT Report Found Here: !@MYREPORT!
		 START "Storage Report from Location: !@LOCATION!" !@MYREPORT!
	 )
 )

 rem -- Final Report
 ECHO:
 ECHO TOTAL StorageInfo Reports Found: %@FOUND%


 rem - Reset Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                     