@ECHO OFF
 rem ==========================================================================
 rem === Obtain Service Info For All Installed Services
 rem ==========================================================================
 rem
 rem Created On: 01 Dec 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 06 Dec 2003
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: NT4 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.ultratech-llc.com/?File=ResKit.TXT
 rem  	Alternate Tools ........ http://KB.ultratech-llc.com/?File=Services.TXT
 rem ==========================================================================

 :::  This script uses SC and SCLIST from the ResKit to display
 :::  account and configuration info for every installed service.
 :::  It will work locally or remotely.
 :::
 :::  Because of the routine used to handle services which have
 :::  spaces in their names, this is an amazingly slow script.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 06 Dec 2003
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Calculate Date/Time (Short Procedure - ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=4-6 DELIMS=: " %%T IN ('NOW') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG

 rem -- Standard Variables
 SET @COMPUTER=%~1& IF "%~1"=="" SET @COMPUTER=%COMPUTERNAME%
 SET @COMPUTER=%@COMPUTER:\=%
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Process Commandline Parameters
 rem === Last Modified On 06 Sep 2001
 rem ==========================================================================
:Params
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Cycle Through Local/Remote Service List and Generate Info
 rem === Last Modified On 01 Dec 2001
 rem ==========================================================================
:GetServices
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 NOW Obtaining Service Information For %@COMPUTER% >"%@LOGFILE%"
 ECHO Obtaining Service Information For %@COMPUTER%
 ECHO:
 FOR /F "TOKENS=1* SKIP=4" %%V IN ('SCLIST \\%@COMPUTER%') DO CALL :GetInfo "%%W"
 ECHO Obtaining Service Information For %@COMPUTER%
 ECHO:


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 03 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Obtain Config Info for Each Service
 rem === Last Modified On 01 Dec 2001
 rem ==========================================================================
:GetInfo
 rem %1 = Registry Key of Current Service
 SET @THISSVC=%~1
 SET @THISSVC=%@THISSVC:~0,33%
 FOR /L %%T IN (1,1,33) DO CALL :TrimSpaces @THISSVC "%@THISSVC%

 ECHO Obtaining Configuration Info for %@THISSVC%...
 SC \\%@COMPUTER% QC %@THISSVC%
 IF ERRORLEVEL 1 (
   ECHO There were problems obtaining info for %@THISSVC%
   ECHO %@THISSVC% - Could Not Obtain Info For This Service >>"%@LOGFILE%"
   ECHO:
 )
 ECHO:
 ECHO:
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Remove Trailing Spaces
 rem === Last Modified On 01 Dec 2001
 rem ==========================================================================
:TrimSpaces
 rem %1 = New Variable Name
 rem %2 = Current Text With Trailing Spaces
 SET @TRIM="%~2"
 SET %1=%@TRIM: "="%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 01 Dec 2001
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for SVCINFO.BAT
 ECHO:
 ECHO === SvcInfo [\\computername]
 ECHO:
 ECHO Example: SvcInfo
 ECHO          SvcInfo \\mysystem
 ECHO          SvcInfo \\yoursystem
 ECHO:
