@ECHO OFF
 rem ==========================================================================
 rem === Replace Server/Share Name In Drive Mappings
 rem ==========================================================================
 rem
 rem Created On: 23 Aug 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 16 Oct 2023 / 30 Nov 2020              
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2003 OR later
 rem
 rem  Non-Native Utilities Used/Required:
 rem    BrainWave Utilities .... https://www.BrainWaveCC.com/brainwave-utilities
 rem ==========================================================================

 :::  This script will cycle through a user's mapped drives and replace all
 :::  shares which have a particular SERVER or SHARE name to an entirely
 :::  different SERVER or SHARE name.  It can be used with any substring.  It
 :::  will now work with mappings that don't have drive letters as well.
 :::
 :::  Great for logon scripts after you've made changes to your file servers.
 :::
 :::  I tried to structure the IFs in the :SWAPMAPPING subroutine as compound
 :::  statements, but it seems that with the use of string manipulation,
 :::  neither 2000 nor XP expanded the variables properly (or, more precisely,
 :::  they didn't expand them in the same manner as they did outside of
 :::  parenthesis), so I had to grudgingly abandon the parentheses.
 :::
 :::  (Jul 2018) v2.0 -- The new BrainWave CheckParams utility is now used to
 :::  check for the /H and /? parameters, replacing the use of FIND/FINDSTR;
 :::  -- Added new Filtered CMD Title and Syntax Help processing routines;
 :::  -- Changed Script Documentation to www.BrainWaveCC.com
 :::
 :::  (Oct 2018) v2.1 -- Corrected and expanded the DEBUG logging routine;
 :::
 :::  (Oct 2019) v2.2 -- Updated :ShowStatus routine to reset TITLE/CodePage;
 :::
 :::  (May 2020) v2.3 -- Updated :DebugMode routine to support the STEP option;
 :::
 :::  (Nov 2020) v2.4 -- Provided extended HELP options (--?? / --H2);
 :::  -- New CHECKPARAMS syntax for processing extended help options;
 :::
 :::  (Oct 2023) v2.5 -- Change the way the @SCRIPT_BEG# variable is
 :::  calculated in various subroutines by using DATEINFO instead of %DATE%;
 :::
 :::
 :::  ADDITIONAL SCRIPTING TOOLS/INFO:
 :::  -------------------------------------------------------------------------
 :::  https://www.BrainWaveCC.com/knowledge-base/scripting-and-automation-options-for-windows/
 :::  https://www.BrainWaveCC.com/knowledge-base/must-have-utilities-for-windows-usersadmins/
 :::  -------------------------------------------------------------------------


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 30 Jul 2018              
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to TRUE/LOG/STEP/VERBOSE
 rem === Updated On: 13 May 2020 / 28 Oct 2018              
 rem ==========================================================================
:DebugMode
 SET #DEBUG=& FOR %%d IN (LOG STEP TRUE VERBOSE) DO IF /I "%Debug%"=="%%~d" SET #DEBUG=TRUE
 IF DEFINED #DEBUG (
	 SET @DIAGMODE=TRUE
	 SET @DEBUG_MODE=[DEBUG MODE ON]
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:^& TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 IF /I "%Debug%"=="LOG" (SET @PAUSE_IF_DEBUG=& SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:)
	 IF /I "%Debug%"=="STEP" (SET @PAUSE_IF_DEBUG=ECHO ##PAUSE##& SET @PRINT_IF_DEBUG=ECHO ##PRINT##)
	 IF /I "%Debug%"=="VERBOSE" (SET @VERBOSE_OFF=ECHO ON) ELSE (FOR %%t IN (ON OFF) DO SET @VERBOSE_%%t=ECHO %%t)
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE ( FOR %%d IN (DEBUG_MODE PAUSE_IF_DEBUG PRINT_IF_DEBUG END_DEBUG_MODE VERBOSE_ON VERBOSE_OFF) DO SET @%%d=)


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 30 Nov 2020 / 04 Oct 2019              
 rem ==========================================================================
:Variables
 TITLE [%USERDOMAIN%\%USERNAME%] -  %~f0 %* >NUL
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.5.0.250

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Main Variables
 SET @OLDSTRING=%~1
 SET @NEWSTRING=%~2


 rem ==========================================================================
 rem === Find Mappings Containing Old Text String
 rem === Updated On: 02 Mar 2005                     
 rem ==========================================================================
:GetMapping
 ECHO Preparing To Swap Mappings Containing "%@OLDSTRING%"
 ECHO:
 FOR /F "TOKENS=2*" %%S IN ('NET USE ^| FIND /I "%@OLDSTRING%"') DO CALL :SwapMappings %%S "%%T"
 ECHO FINISHED Swapping Mappings!
 ECHO:
 NET USE


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 04 Oct 2019 / 28 Feb 2019              
 rem ==========================================================================
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Replace Drive Mapping For All String Matches
 rem === Updated On: 08 Mar 2005                     
 rem ==========================================================================
:SwapMappings
 rem %1 = Current Drive Letter
 rem %2 = Old String To Change
 SET @DRIVE=%1
 IF /I NOT "%@DRIVE:~1,1%"==":" GOTO :SwapUNC
   SET @SHARE=%2
   SET @SHARE=%@SHARE:Microsoft Windows Network=%

 rem -- Brute Force Fix to deal with extra spaces.
   FOR /L %%S IN (1,1,20) DO SET @SHARE=%@SHARE: "="%

   CALL :SwapIt @SHARE %%@SHARE:%@OLDSTRING%=%@NEWSTRING%%%
   ECHO Changing drive %@DRIVE% to "%@SHARE%" ...
   NET USE %@DRIVE% /D /Y >NUL
   NET USE %@DRIVE% "%@SHARE%"
 GOTO :EOF

:SwapUNC
 IF /I NOT "%@DRIVE:~0,2%"=="\\" GOTO :EOF
   CALL :SwapIt @SHARE "%%@DRIVE:%@OLDSTRING%=%@NEWSTRING%%%"
   ECHO Changing mapping from "%@DRIVE%" to "%@SHARE%" ...
   NET USE %@DRIVE% /D /Y >NUL
   NET USE "%@SHARE%"
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Expand Share Substitution String
 rem === Updated On: 02 Mar 2005                     
 rem ==========================================================================
:SwapIt
 rem %1 = New Variable Name
 rem %2 = Share Substitution String
 SET %1=%~2
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019              
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Updated On: 30 Nov 2020 / 30 Jul 2018              
 rem ==========================================================================
:HelpMessage
 ECHO Replace Server/Share Name In Local Drive Mappings...
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<old_servername^> ^<new_servername^>
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 THISSERVER THATSERVER
	 ECHO  %~n0 SERVER-A1 BIGSERVER-B2
	 ECHO  %~n0 OLD_SERVER NEW_SERVER
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * Share names containing spaces are not supported by this script.
 )
 CALL :ShowStatus "FINISHED"
                      