@ECHO OFF
 rem ==========================================================================
 rem === Display Scheduled Task Info for Automation Scripts
 rem ==========================================================================
 rem
 rem Created On: 02 Mar 2015
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 16 Oct 2023 / 02 May 2022              
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows 2003 and later
 rem
 rem  Non-Native Utilities Used/Required:
 rem    BrainWave Utilities .... https://www.BrainWaveCC.com/brainwave-utilities
 rem ==========================================================================

 :::  This script displays information about all scheduled tasks except those
 :::  in custom Microsoft folders.  This routine was derived from OpsLogs.BAT
 :::
 :::  (May 2018) v1.4 -- Changed the HELP routine to use FINDSTR;
 :::  -- Added new Filtered CMD Title and Syntax Help processing routines;
 :::  -- Changed Script Documentation to www.BrainWaveCC.com
 :::
 :::  (Jul 2018) v1.5 -- The new BrainWave CheckParams utility is now used to
 :::  check for the /H and /? parameters, replacing the use of FIND/FINDSTR;
 :::
 :::  (Oct 2018) v1.6 -- Corrected and expanded the DEBUG logging routine;
 :::
 :::  (Feb 2019) v1.7 -- Enabled Code Page 1252 Support;
 :::
 :::  (Oct 2019) v1.8 -- Updated :ShowStatus routine to reset TITLE/CodePage;
 :::
 :::  (May 2020) v1.9 -- Migrated :DebugMode routine to SetDrive.BAT;
 :::
 :::  (Nov 2020) v2.0 -- Provided extended HELP options (--?? / --H2);
 :::  -- New CHECKPARAMS syntax for processing extended help options;
 :::
 :::  (Oct 2023) v2.1 -- Change the way the @SCRIPT_BEG# variable is
 :::  calculated in various subroutines by using DATEINFO instead of %DATE%;
 :::
 :::
 :::  ADDITIONAL SCRIPTING TOOLS/INFO:
 :::  -------------------------------------------------------------------------
 :::  https://www.BrainWaveCC.com/knowledge-base/scripting-and-automation-options-for-windows/
 :::  https://www.BrainWaveCC.com/knowledge-base/must-have-utilities-for-windows-usersadmins/
 :::  -------------------------------------------------------------------------


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 08 May 2018              
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 30 Nov 2020 / 26 May 2020              
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.1.0.240

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 SET @SYSTEM=%~1& FOR %%C IN ("" .) DO IF "%~1"=="%%~C" SET @SYSTEM=%COMPUTERNAME%
 SET @SYSTEM=%@SYSTEM:\=%
 SET @REMOTE=/S %@SYSTEM%
 SET @SCHTASKS=/FO LIST /V& IF "%~2"=="" SET @SCHTASKS=/FO TABLE
 SET @COUNT=0

 rem -- Standard Log Variables
 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0-%@SYSTEM%.%@FILESTAMP%
 %@PRINT_IF_DEBUG%


 rem ==========================================================================
 rem === Display Scheduled Events Summary (via SCHTASKS)
 rem === Updated On: 02 Mar 2015                     
 rem ==========================================================================
:GetSchedule
 ECHO SEARCHING FOR SCHEDULED TASKS ON: %@SYSTEM%

 ( rem -- Write to Log
	 ECHO:
	 ECHO List of All Scheduled Task Folders
	 ECHO %@DIVIDER-%
	 SCHTASKS /QUERY %@REMOTE% %@SCHTASKS% | FIND "Folder:" | FIND /I /V " \Microsoft"
	 ECHO:
	 ECHO:
	 ECHO List of All Scheduled Tasks [non-Microsoft folders]
	 ECHO %@DIVIDER-%
	 FOR /F "TOKENS=*" %%S IN ('SCHTASKS /QUERY %@REMOTE% %@SCHTASKS%') DO (
		 SET @PRINTOUT=ECHO %%~S
		 IF /I "!@PRINTOUT:~5,7!"=="Folder:" (
			 IF /I "!@PRINTOUT:~14,9!"=="Microsoft" (SET @PRINT=FALSE) ELSE (SET @PRINT=TRUE& ECHO:)
			 IF NOT "%~2"=="" SET @PRINTOUT=
		 )

		 IF /I "!@PRINT!"=="TRUE" (
			 IF /I "!@PRINTOUT:~5,9!"=="HostName:" (
				 SET /A @COUNT+=1
				 IF !@COUNT! GTR 1 ECHO:
				 ECHO %@SYSTEM%: SCHEDULED JOB #!@COUNT!
			 ) ELSE (
				 !@PRINTOUT!
			 )
		 )
	 )
	 ECHO %@DIVIDER*%
	 ECHO:
	 IF NOT "!@COUNT!"=="0" ECHO TOTAL TASKS = !@COUNT!
 ) >%@LOGFILE% 2>&1

 IF EXIST "%@LOGFILE%" TYPE "%@LOGFILE%"
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 04 Oct 2019 / 28 Feb 2019              
 rem ==========================================================================
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019              
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Updated On: 02 May 2022 / 30 Nov 2020 / 08 May 2018              
 rem ==========================================================================
:HelpMessage
 ECHO Display Scheduled Task Info for Automation Scripts
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [system ^| .] [FULL ^| /F]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO FULL, /F ..... Show Task Details
 ECHO       .  ..... Name of Current Computer
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 %COMPUTERNAME%
	 ECHO  %~n0 SERVER1 FULL
	 ECHO  %~n0 MACHINE10 /F
	 ECHO  %~n0 COMPUTER5
	 ECHO  %~n0 \\THATMACHINE
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * Any parameters that contain spaces should be surrounded by quotes,
	 ECHO    including the option prefix itself.
	 ECHO:
	 ECHO  * An elevated CMD promt is required in Windows 2008 ^(and beyond^) in
	 ECHO    order to set or display the list of scheduled tasks.
 )
 CALL :ShowStatus "FINISHED"
                               