@REM - ASB (26 Mar 2017 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 31 Aug 2018 / 26 Jul 2018 / 01 May 2018): Change Time Temporarily, Then Reset to Current Time
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.7.0.070

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Change Time Temporarily, Then Reset to Current Time
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<new time in hh:mm format^>  [new date in mm/dd/yyyy format]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO    * This only supports the US-EN date and time formats.
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @OLDTIME=!TIME: =0!
 SET @OLDDATE=!DATE:~4,99!
 SET @NEWTIME=%~1
 SET @NEWDATE=%~2& IF "%~2"=="" SET @NEWDATE=!@OLDDATE!
 SET @WAIT=1000
 SET @TIMESVC=W32Time

 rem -- Ensure Correct Time Source Format for NET TIME vs W32TM Commands
 SET @TIMESOURCE=1.us.pool.ntp.org  1.north-america.pool.ntp.org  nist1-ny.ustiming.org
 FOR %%T IN (%@TIMESOURCE%) DO (
	 SET @OLD_TIMESOURCE=!@OLD_TIMESOURCE!,%%~T
	 SET @NEW_TIMESOURCE=!@NEW_TIMESOURCE! %%~T,0x1
	 SET @BAK_TIMESOURCE=!@BAK_TIMESOURCE! %%~T,0x2
 )


 rem -- Change Time Temporarily
:SetNewTime
 ECHO Date and Time @ 1st Checkpoint .... !@OLDDATE! at !@OLDTIME!
 ECHO New Date and Time to Set .......... !@NEWDATE! at !@NEWTIME!
 ECHO:
 CHOICE /C YNQEX /T 20 /D Y /N /M "Change System Time? (Y/N) - "
 IF !ERRORLEVEL! GTR 1 GOTO :ExitBatch
 SET @SAVTIME=!TIME: =0!
 SET @SAVDATE=!DATE:~4,99!
 DATE !@NEWDATE!
 TIME !@NEWTIME!


 rem -- Change Time Back
:ResetOldTime
 ECHO:
 ECHO Press [ENTER] to Reset to Current Time
 TIMEOUT !@WAIT!
 FOR /F "TOKENS=*" %%D IN ('DATEINFO -t "!@NEWDATE! !@NEWTIME!" -q') DO SET @DURATION=%%~D
 FOR /F "TOKENS=1-2" %%S IN ('DATEINFO -t "!@SAVDATE! !@SAVTIME!" -z %@DURATION% -f "mm/dd/yyyy hh:nn:ss" -q') DO (
	 SET @NOWDATE=%%~S
	 SET @NOWTIME=%%~T
 )
 ECHO Resetting Date and Time to ........ !@NOWDATE! at !@NOWTIME!
 DATE !@NOWDATE!
 TIME !@NOWTIME!


 rem -- Try to Obtain Precise Time from Time Server
:ResyncWithNTP
 ECHO Recalibrating Time from Time Server
 W32TM /CONFIG "/ManualPeerList:!@NEW_TIMESOURCE:~1,999!" /SyncFromFlags:DOMHIER /RELIABLE:NO /UPDATE
 SC STOP "%@TIMESVC%"
 SLEEP 5
 SC START "%@TIMESVC%"
 SLEEP 5
 W32TM /ReSync /NoWait


 rem -- Generate a Report Summary
:FinalReport
 ECHO:
 ECHO %@DIVIDER-%
 ECHO Date and Time @ 1st Checkpoint .... !@OLDDATE! at !@OLDTIME!
 ECHO Date and Time Just Before Reset ... !@SAVDATE! at !@SAVTIME!
 ECHO Date and Time Manually Set To ..... !@NEWDATE! at !@NEWTIME!
 ECHO Duration of New Time Operation .... !@DURATION!
 ECHO Time Reset To ..................... !@NOWDATE! at !@NOWTIME!
 ECHO Current Time and Date ............. !DATE:~4,99! at !TIME: =0!
 ECHO %@DIVIDER-%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
 