@REM - ASB (26 Jul 2020 // 12 Jan 2024 / 16 Oct 2023 / 11 Feb 2022 / 02 Feb 2022 / 30 Nov 2020 / 26 Jul 2020): Test File IO across network systems
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.5.0.150

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Check for Essential Utilities and/or Scripts
 PATH %PATH%;%~dp0
 FINDFILES -w -m -f "NOW.EXE" "DATEINFO.EXE" "CHECKPARAMS.EXE" "READABLE.EXE" "FILEIOTEST.EXE"
 IF ERRORLEVEL 64 GOTO :ExitBatch

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @SOURCELIST="%~dp0Input\FileIO.TXT"  "%~dp0Input\FileIO.%COMPUTERNAME%.TXT"  "%~dp0Input\%~1"  "%~dp0Input\%~1.TXT"  "%~1"
 FOR %%F IN (%@SOURCELIST%) DO IF EXIST "%%~F" IF NOT "%%~nxF"=="" SET @SYSLIST=%%~F

 rem -- Standard Log Variables
 SET @LOGINFO=%~n0.%@DIRSTAMP_R%
 SET @LOGROOT=%TEMP%\%@LOGINFO%
 SET @LOGFILE=%TEMP%\%@LOGINFO%.TXT

 rem -- Process Special Command-line Parameters
 SET @ALL_PARAMS=%*
 CALL :GetParams "I ITERATIONS" @ITERATIONS & IF NOT DEFINED @ITERATIONS SET @ITERATIONS=1000

 rem -- Generate Benchmark Variables
 IF EXIST "%@SYSLIST%" (
	 ECHO USING: "%@SYSLIST%"
	 SET @COUNT=1000
	 FOR /F "USEBACKQ TOKENS=1-2 EOL=; DELIMS=, " %%S IN ("%@SYSLIST%") DO (
		 SET @SYSTEM=%%~S%%~T
		 SET @SYSTEM=!@SYSTEM:\=!
		 SET @SYSTEM=!@SYSTEM:=\!
		 SET #!@COUNT!*%%~S=%%~S=FileIOTest -target !@SYSTEM! -iterations !@ITERATIONS!
		 SET /A @COUNT+=1
	 )
 ) ELSE (
	 ECHO *** NO LIST OF STORAGE DEVICES OR LOCATIONS FOUND: "%@SYSLIST%"
	 SET #127.0.0.1=localhost=FileIOTest -target \\127.0.0.1\Storage$ -iterations 1000
 )


 rem -- Make and Record Network Benchmarking
:BeginBenchmarking
 IF NOT EXIST "%@LOGROOT%" MD "%@LOGROOT%"
 NOW \s \n\*Preparing to Benchmark Network Reads/Writes\n\*\n

 FOR /F "TOKENS=1-2* DELIMS==" %%V IN ('SET # 2^>NUL') DO (
	 NOW %%~W\n\-
	 ECHO EXECUTING: %%X
	 %%X
	 ECHO %@DIVIDER#%
	 ECHO:
	 ECHO:
 ) | TEE -a "%@LOGFILE%"


 rem -- Generate Final Report
:FinalReport
 ECHO:
 ECHO  DIR "%@LOGFILE%"
 DIR "%@LOGFILE%" 2>NUL | FINDSTR /R "^[0-9][0-9].[0-9][0-9].[0-9][0-9][0-9][0-9]"
 ECHO %@DIVIDER~%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Use CheckParams.exe to Capture Selected Parameters
:GetParams
 rem %1 = Parameters to Search For
 rem %2 = Variable to Set

 SET @OK=& IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=2-3*" %%v IN ('CHECKPARAMS -q -a -c "%~1" -s %@ALL_PARAMS% 2^>NUL') DO IF /I "%%~v"=="TRUE" (
	 SET @OK=T
	 SET @REQ=T
	 IF NOT "%~2"=="" SET %~2=%%~x
 )
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Test File IO across network systems
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [system_list] [OPTIONS]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ..... Display This Help Message   (also --HELP)
 ECHO  -??, /H2 .... Display Extended Help Message
 ECHO       /I ..... Number of Iterations        (Default = 1000)
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0
	 ECHO  %~n0 "%SystemDrive%\Systems\StorageList.TXT"
	 ECHO  %~n0 "D:\SysLists\ThisList.TXT" /I:10000
	 ECHO  %~n0 /I:5000
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO  * Folder Paths containing spaces should be enclosed in quotes.
 )
 CALL :ShowStatus "FINISHED"
                                                                                            