@ECHO OFF
 rem ==========================================================================
 rem === Send Test Message to Verify Mail Server Configuration
 rem ==========================================================================
 rem
 rem Created On: 01 Jun 1999
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 16 Oct 2023 / 30 Nov 2020              
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 25 Feb 2018              
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 30 Nov 2020 / 26 May 2020              
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.9.0.390

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Default Variables (Override via CustomVariables.*.TXT)
 SET @CONFIG=FALSE
 SET @MAILPORT=25
 SET @MAILSERVER=mail.test.yourdomain.com
 SET @RCPT=Test@MyDomain.com
 SET @FROM=LogAdmin@MyDomain.com
 SET @SUBJ=Test Message from %COMPUTERNAME% at %TIME: =0%
 SET @ORG=-o "Your Organization, Inc."
 SET @HOST=-hostname "%COMPUTERNAME%_SCRIPT"
 SET @TRACK=-x "X-Return-Receipt-To: %@FROM%"
 SET @XHEAD=-noh2 -r %@HOST% %@ORG%

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Get Local FQDN and IP Address
 SET @SYSTEM=%COMPUTERNAME%
 FOR /F "TOKENS=2-3" %%I IN ('PING %COMPUTERNAME% ^| FIND "Pinging"') DO SET @SYSTEM=%%I %%J

 rem -- Logging Variables
 SET @LOGPATH=%@STORAGE%\Logs\Misc
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%

 rem -- Process Special Command-line Parameters
 SET @ALL_PARAMS=%*
 CALL :GetParams "D"               & IF DEFINED @OK SET @CONFIG=TRUE
 CALL :GetParams "M"   @MAILSERVER & IF DEFINED @OK IF NOT DEFINED @MAILSERVER (GOTO :HelpMessage) ELSE (SET @CONFIG=TRUE)
 CALL :GetParams "P"   @MAILPORT   & IF DEFINED @OK IF NOT DEFINED @MAILPORT   (GOTO :HelpMessage) ELSE (SET @CONFIG=TRUE)
 CALL :GetParams "T R" @RCPT       & IF DEFINED @OK IF NOT DEFINED @RCPT       (GOTO :HelpMessage) ELSE (SET @CONFIG=TRUE)
 CALL :GetParams "F"   @FROM       & IF DEFINED @OK IF NOT DEFINED @FROM       (GOTO :HelpMessage) ELSE (SET @CONFIG=TRUE)
 CALL :GetParams "S"   @SUBJ       & IF DEFINED @OK IF NOT DEFINED @SUBJ       (GOTO :HelpMessage) ELSE (SET @CONFIG=TRUE)
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Send Test Mail
 rem === Updated On: 21 Feb 2018 / 05 Feb 2015              
 rem ==========================================================================
:SendMail
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 ( rem -- Write to Log
	 NOW This Is an eMail Test -- THIS IS ONLY A TEST
	 ECHO:
	 ECHO Test sent from %COMPUTERNAME% by %USERNAME% at %@TIME% using %@VER%
	 ECHO:
	 ECHO %@MAJORDIV%
	 ECHO MAILSERVER --------- %@MAILSERVER% [port %@MAILPORT%]
	 ECHO LOGFILE NAME ------- %@LOGFILE%
	 ECHO:
	 ECHO SENDING SYSTEM ----- %@SYSTEM%
	 ECHO SENDER ------------- %@FROM%
	 ECHO RECIPIENT ---------- %@RCPT%
	 ECHO MESSAGE SUBJECT ---- "%@SUBJ%"
	 ECHO %@MAJORDIV%
 ) >>"%@LOGFILE%"

 IF "%@CONFIG%"=="TRUE" BLAT -install %@MAILSERVER% %@FROM% 5 %@MAILPORT%
 BLAT %@LOGFILE% -to %@RCPT% -s "%@SUBJ%" %@XHEAD%
 SLEEP 1
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 03 Oct 2019 / 28 Feb 2019              
 rem ==========================================================================
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Execute Dynamic Command From Variable
 rem === Updated On: 12 Jan 2007                     
 rem ==========================================================================
:RunCMD
 rem %1 = Command To Execute

 %*
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Use CheckParams.exe to Capture Selected Parameters
 rem === Updated On: 21 Jan 2020 / 03 Oct 2019              
 rem ==========================================================================
:GetParams
 rem %1 = Parameters to Search For
 rem %2 = Variable to Set

 SET @OK=& IF "%~1"=="" GOTO :EOF
 FOR /F "TOKENS=2-3*" %%v IN ('CHECKPARAMS -q -a -c "%~1" -s %@ALL_PARAMS% 2^>NUL') DO IF /I "%%~v"=="TRUE" (
	 SET @OK=T
	 SET @REQ=T
	 IF NOT "%~2"=="" SET %~2=%%~x
 )
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019              
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help if Required/Requested
 rem === Updated On: 30 Nov 2020 / 08 May 2018              
 rem ==========================================================================
:HelpMessage
 ECHO Send Test Message to Verify Mail Server Configuration
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  [/D] ^<OPTIONS^>
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H .................... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 ................... Display Extended Help Message
 ECHO  /D ......................... Reset all options to default
 ECHO  /M:mailserver.domain.com ... Mail Server to Test Relay
 ECHO  /P:mailserver port # ....... TCP Port to use [default=25]
 ECHO  /T:recipient@domain.com .... Recipients to deliver messages [also /R]
 ECHO  /F:sent_by@domain.com ...... Sender for each message
 ECHO  /S:subject ................. Message subject [a default is generated]
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 /M:Server001.MyDomain.com /F:User@MyDomain.com
	 ECHO  %~n0 /M:MailServer.domain.tld /F:User@MyDomain.com /T:OneAddress@YourDomain.com
	 ECHO  %~n0 /M:Mail1.SomeDomain.org /F:TestUser@ThisDomain.com "/T:User1@Domain1.com,User2@Domain2.com"
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * Multiple recipients must be enclosed in "" with the /T parameter,
	 ECHO    and with no spaces between any of the recipient names.
 )
 CALL :ShowStatus "FINISHED"
                                   