@REM - ASB (27 Feb 2014 // 16 Oct 2023 / 11 Dec 2021 / 30 Nov 2020 / 12 Jun 2020 / 13 May 2020 / 24 Dec 2019 / 30 Sep 2019 / 11 Aug 2019 / 28 Oct 2018 / 31 Aug 2018 / 26 Jul 2018 / 15 May 2018): Send Test Messages to Syslog Servers
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Enable Debug Mode If 'Debug' Variable is Set to TRUE/LOG/STEP/VERBOSE
:DebugMode
 SET #DEBUG=& FOR %%d IN (LOG STEP TRUE VERBOSE) DO IF /I "%Debug%"=="%%~d" SET #DEBUG=TRUE
 IF DEFINED #DEBUG (
	 SET @DIAGMODE=TRUE
	 SET @DEBUG_MODE=[DEBUG MODE ON]
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:^& TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 IF /I "%Debug%"=="LOG" (SET @PAUSE_IF_DEBUG=& SET @PRINT_IF_DEBUG=ECHO:^& SET @^& ECHO:)
	 IF /I "%Debug%"=="STEP" (SET @PAUSE_IF_DEBUG=ECHO ##PAUSE##& SET @PRINT_IF_DEBUG=ECHO ##PRINT##)
	 IF /I "%Debug%"=="VERBOSE" (SET @VERBOSE_OFF=ECHO ON) ELSE (FOR %%t IN (ON OFF) DO SET @VERBOSE_%%t=ECHO %%t)
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE ( FOR %%d IN (DEBUG_MODE PAUSE_IF_DEBUG PRINT_IF_DEBUG END_DEBUG_MODE VERBOSE_ON VERBOSE_OFF) DO SET @%%d=)


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.1.0.610

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Send Test Messages to Syslog Servers
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<"set of syslog servers"^> ^<"set of ports to test"^> ["test message"]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @QUIET=-q& IF /I "%Debug%"=="TRUE" SET @QUIET=
 SET @SYSLOG_SERVERS=%~1& IF "%~1"=="." SET @SYSLOG_SERVERS=syslog
 SET @SYSLOG_PORTS=%~2& IF "%~2"=="." SET @SYSLOG_PORTS=514
 SET @TEST_MSG=%*& IF "%~3"=="" SET @TEST_MSG=%1 %2 This is a Syslog Test Message from %COMPUTERNAME%
 SET @SYSLOGGEN=%~dp0..\Utils\SyslogGen.EXE& IF NOT EXIST "!@SYSLOGGEN!" SET @SYSLOGGEN=REM !@SYSLOGGEN!
 SET @NO_SYSLOGGEN=Unable to recognize target address or hostname: No such host is known.
 SET @WHEN=!DATE! at !TIME: =0!
 CALL :Prepare4Syslog %@TEST_MSG%
 %@PRINT_IF_DEBUG%


 rem -- Cycle Through Syslog Servers on various ports, and attempt messages via TCP and UDP
:Execution
 ECHO Message: %@S_MSG%
 ECHO:

 FOR %%S IN (%@SYSLOG_SERVERS%) DO FOR %%P IN (%@SYSLOG_PORTS%) DO FOR %%T IN ("" "-tcp") DO (
	 IF "%%~T"=="" (SET @PROTO=UDP) ELSE (SET @PROTO=TCP)
	 ECHO - Sending Test Syslog Message to %%~S:%%~P [!@PROTO!]
	 ECHO   --- Using SyslogGen...
	 %@SYSLOGGEN% -t:%%~S -p:%%~P %%~T -f:19 -s:6 -tg:"%~n0" -m:"%@WHEN% -- Using SyslogGen to connect to %%~S:%%~P (!@PROTO!): %@S_MSG2%" %@QUIET% -hn:%COMPUTERNAME% 2>NUL | FIND /V "%@NO_SYSLOGGEN%"
	 ECHO:
 )
 %@PAUSE_IF_DEBUG%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Execute Dynamic Command From Variable
:RunCMD
 rem %* = Command To Execute

 %*
 GOTO :EOF


 rem -- SUBROUTINE: Prepare Messages for SyslogGen Syslog Utility
:Prepare4Syslog
 rem %* = Syslog Message to be Cleaned Up

 SET @PREFIX=%1 %2
 SET @S_MSG=%*
 SET @S_MSG=!@S_MSG:%@PREFIX% =!

:TrimLeadingSpaces
 IF "!@S_MSG:~0,1!"==" " (
	 SET @S_MSG=!@S_MSG:~1,9999!
	 GOTO :TrimLeadingSpaces
 )

 SET @S_MSG2=!@S_MSG:\=\x5B!
 SET @S_MSG2=!@S_MSG2:"=\x22!
 %@PRINT_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
             