@REM - ASB (15 Jan 2020 // 16 Oct 2023 / 06 Jul 2021 / 30 Nov 2020 / 15 Jan 2020): Track Lockout Events Across Domain
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.2.0.060

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Main Variables
 SET @ADQUERY=ADFind -f "(&(objectCategory=computer)(|(primaryGroupId=516)(primaryGroupId=521)))" -nodn -s SUB -maxe 500 -csvnoq -csv attr name
 SET @HOWLONG=%~1& IF "%~1"=="" SET @HOWLONG=3
 SET @LOGFILE="%TEMP%\Lockout Events.TXT"

 rem -- Get Domain Controllers
 SET @DCS=& FOR /F "SKIP=1 TOKENS=1-2 DELIMS=," %%S IN ('%@ADQUERY%') DO SET @DCS=%%S,!@DCS!
 IF NOT DEFINED @DCS SET @DCS=%USERDNSDOMAIN%
 SET @MSG=Tracking Domain Lockouts for %@HOWLONG% Hour(s) on %@DCS%


 rem -- Track Lockout Events Across Domain
:TrackEvents
 FOR %%O IN (CON %@LOGFILE%) DO NOW %@MSG:,= % >%%O
 psloglist \\%@DCS% -H %@HOWLONG% -I 4740 -S SECURITY >>%@LOGFILE% 2>NUL


 rem -- Final Report
:FinalReport
 READABLE %@LOGFILE% --sb "\\" --sk "%@MSG:~0,24%"
 START %@LOGFILE% %@LOGFILE%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Track Lockout Events Across Domain
 ECHO:
 ECHO    YOU TYPED: %0 %*
 ECHO:
 ECHO   CMD SYNTAX: %~n0  [number_of_hours]
 ECHO               %~n0  [-h^|-?]
 ECHO:
 ECHO    EXAMPLES:
 ECHO     %~n0
 ECHO     %~n0 5
 ECHO     %~n0 10
 ECHO     %~n0 /?
 ECHO:
 ECHO  USAGE NOTES:
 ECHO    * Parameters surrounded by ^<^> are mandatory.
 ECHO    * Parameters surrounded by [] are optional.
 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
 ECHO    * Default Hours = 3, if none supplied.
 CALL :ShowStatus "FINISHED"
  