@ECHO OFF
 rem ==========================================================================
 rem === Obtain User Manager Info for Each User Account
 rem ==========================================================================
 rem
 rem Created On: 07 Jul 2001
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 03 Dec 2003
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: NT4 or later
 rem
 rem  Non-Native Utilities Required: NONE
 rem ==========================================================================

 :::  This script uses enumerates the user accounts on the local
 :::  machine or within the domain to provide detailed information
 :::  about the user account.  Unlike the "Home Directory" scripts
 :::  this script can handle User Accounts which contain spaces.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 07 Jul 2001
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Calculate Date/Time (Short Procedure - No ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=1-3 DELIMS=:. " %%T IN ('ECHO %TIME: =0%') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG

 rem -- Standard Variables
 SET @SKIP=4
 FOR %%P IN (%*) DO IF /I "%%P"=="/?" GOTO :HelpMessage
 FOR %%P IN (H HELP) DO IF /I "%1"=="/%%P" GOTO :HelpMessage
 FOR %%P IN (D DOMAIN) DO IF /I "%1"=="/%%P" (
   SET @DOMAIN=/DOMAIN
   SET @SKIP=6
 )

 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Cycle Through Account List And Obtain User Info
 rem === Last Modified On 03 Dec 2003
 rem ==========================================================================
:GetAccounts
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 NOW Obtaining Detailed Account Information... >"%@LOGFILE%"
 ECHO:
 FOR /F "TOKENS=* SKIP=%@SKIP% DELIMS=/" %%U IN ('NET USER %@DOMAIN%') DO CALL :ParseAccts %%U
 ECHO Finished Viewing Account Info For The Domain...
 ECHO:


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 03 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Parse Account Names From NET USER Output
 rem === Last Modified On 07 Jul 2001
 rem ==========================================================================
:ParseAccts
 rem %* - Current Line of Accounts To Be Parsed
 SET @PARAM=%*
 SET @ACCT1=%@PARAM:~00,25%
 SET @ACCT2=%@PARAM:~25,25%
 SET @ACCT3=%@PARAM:~50,25%
 CALL :ViewInfo %@ACCT1%
 CALL :ViewInfo %@ACCT2%
 CALL :ViewInfo %@ACCT3%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: View Detailed User Manager Account Info
 rem === Last Modified On 07 Jul 2001
 rem ==========================================================================
:ViewInfo
 rem %* - Current Account For Which To Provide Detailed Info
 SET @ACCT=%*
 IF /I "%@ACCT%"=="The command completed suc" GOTO :EOF
 IF /I "%@ACCT%"=="cessfully." GOTO :EOF
 IF /I NOT "%@ACCT%"=="" (
   NET USER "%@ACCT%" %@DOMAIN%
   NET USER "%@ACCT%" %@DOMAIN% >>"%@LOGFILE%"
 )
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?", "/H" or "/HELP"
 rem === Last Modified On 07 Jul 2001
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for UMGRINFO.BAT
 ECHO:
 ECHO === UMgrInfo [/D ^| /DOMAIN]
 ECHO:
 ECHO Example: UMgrInfo
 ECHO          UMgrInfo /D
 ECHO          UMgrInfo /DOMAIN
 ECHO:
 GOTO :ExitBatch
