@REM - ASB (17 Aug 2020 // 16 Oct 2023 / 30 Nov 2020 / 17 Aug 2020): Update All Instances of a File (or Files) in a Destination Tree
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.2.0.110

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 GOTO :HelpMessage

 rem -- Check for Special Modes
 SET @OVERWRITE=/D
 SET @OW_STATUS=FALSE
 FOR /F "TOKENS=2" %%T IN ('CHECKPARAMS -q -c "O OVERWRITE" -s %* 2^>NUL') DO (SET @OW_STATUS=TRUE& SET @OVERWRITE=)

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @PARAMS=%@OVERWRITE% /U /R /Y
 SET @SOURCE=%~1& CALL :FixDirectoryPath @SOURCE
 SET @DEST=%~2&   CALL :FixDirectoryPath @DEST

 rem -- Standard Log Variables
 SET @LOGPATH=%TEMP%\Replication
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%
 %@PRINT_IF_DEBUG%


 rem -- Verify Parameter Validity
:VerifyParameters
 IF NOT EXIST "%@SOURCE%" SET @END=TRUE& ECHO *** CANNOT FIND SOURCE: "%@SOURCE%"
 IF "%~1"==""             SET @END=TRUE& ECHO *** NO SOURCE FILESPEC PROVIDED...
 IF "%~2"==""             SET @END=TRUE& ECHO *** NO DESTINATION FOLDER PROVIDED...
 IF DEFINED @END GOTO :ExitBatch
 %@PAUSE_IF_DEBUG%


:VerifyConfiguration
 ECHO Preparing to Update Files...
 ECHO:
 ECHO %@DIVIDER-%
 ECHO  Source Filespec ...... %@SOURCE%
 ECHO  Destination Folder ... %@DEST%
 ECHO  Overwrite All? ....... %@OW_STATUS%
 ECHO  Logfile Name ......... %@LOGFILE%
 ECHO %@DIVIDER-%

 rem -- Verify Operation
 CHOICE /C YNQEX /T 30 /D Y /N /M "Continue running this script? (Y/N/Q) "
 IF ERRORLEVEL 2 GOTO :ExitBatch
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%" >NUL


 rem -- Generate Recursive Copies
:CopyRecursively
 NOW \n\n\*\v -- Generating Tree of: "%@DEST%" \n\* | TEE -a "%@LOGFILE%"
 FOR /F "TOKENS=*" %%D IN ('DIR /OGN /AD /B /S "%@DEST%"') DO (
	 ECHO:
	 ECHO %@DIVIDER-%
	 ECHO  In: "%%~D"
	 ECHO %@DIVIDER-%
	 XCOPY "%@SOURCE%" "%%~D" %@PARAMS%
	 ECHO %@DIVIDER%
	 ECHO:
 ) | TEE -a "%@LOGFILE%"
 NOW \n\*\v -- FINISHED Updating All Files\n\* | TEE -a "%@LOGFILE%"
 %@PAUSE_IF_DEBUG%


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 IF EXIST "%@LOGFILE%" DIR "%@LOGFILE%"
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Remove Trailing \ From Supplied Folder Path
:FixDirectoryPath
 rem %1 = Folder Variable

 IF NOT DEFINED %1 GOTO :EOF
 FOR /L %%X IN (1,1,9) DO IF "!%~1:~-1!"=="\" SET %~1=!%~1:~0,-1!
 IF "!%~1:~-1!"==":" SET %~1=!%~1!\
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF


 rem -- SUBROUTINE: Display Syntax Help if Required/Requested
:HelpMessage
 ECHO Update All Instances of a File (or Files) in a Destination Tree
 ECHO:
 ECHO ----------
 ECHO YOU TYPED:  %0 %*
 ECHO ----------
 ECHO:
 ECHO -----------
 ECHO CMD SYNTAX:
 ECHO -----------
 ECHO  %~n0  ^<FileSpec^> ^<DestinationPath^> [OPTIONS]
 ECHO  %~n0  [-h^|-?^|-h2^|-??]
 ECHO:
 ECHO -------------------
 ECHO OPTION DEFINITIONS:
 ECHO -------------------
 ECHO  -?,  /H ........... Display This Help Message  (also --HELP)
 ECHO  -??, /H2 .......... Display Extended Help Message
 ECHO  -O,  /OVERWRITE ... Overwrite destination files even if source file is older
 ECHO:

 IF ERRORLEVEL 8 IF NOT ERRORLEVEL 16 (
	 ECHO ----------------
	 ECHO SYNTAX EXAMPLES:
	 ECHO ----------------
	 ECHO  %~n0 C:\Source\SomeFile.EXE "D:\Some Destination"
	 ECHO  %~n0 "D:\Source Folder\OneFile.BAT" "E:\Destination Directory" /OVERWRITE
	 ECHO  %~n0 "E:\Files.*" \\REMOTE\SHARE\Directory
	 ECHO  %~n0 -?
	 ECHO:
	 ECHO ------------
	 ECHO USAGE NOTES:
	 ECHO ------------
	 ECHO  * Parameters surrounded by ^<^> are mandatory.
	 ECHO  * Parameters surrounded by [] are optional.
	 ECHO:
	 ECHO  * Options are case-insensitive, and can be prefaced by "-" or "/".
	 ECHO:
	 ECHO  * Any parameters which contain spaces should be surrounded by quotes.
	 ECHO    Shortnames *can* be surrounded by quotes if you choose, but it is not
	 ECHO    mandatory by any means.
 )
 CALL :ShowStatus "FINISHED"
                                                                                        