@REM - ASB (13 Mar 2012 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 27 Mar 2016): Add Disk Driver TimeOut Value for SAN Failover
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v2.4.0.220

 SET @DEFAULT=180
 SET @TIMEOUT_KEY=HKLM\SYSTEM\CurrentControlSet\Services\Disk
 SET @TIMEOUT_VAL=TimeOutValue
 SET @TIMEOUT_NUM=%~2& IF "%~2"=="" SET @TIMEOUT_NUM=%@DEFAULT%
 SET @CONNECT=\\%~1&  IF "%~1"=="" SET @CONNECT=%COMPUTERNAME%
 SET @CONNECT=\\%@CONNECT:\\=%


 rem -- View and/or Set the Disk Connection Timeout Entry
:Main
 ECHO Verifying Disk TimeOut Value on %@CONNECT% ...

 FOR /F "TOKENS=1-2*" %%R IN ('REG QUERY "%@CONNECT%\%@TIMEOUT_KEY%" /v "%@TIMEOUT_VAL%" 2^>^&1') DO (
	 SET @CHECK=%%R
	 SET @VALUE=%%T
	 SET @FULLMSG=%%R %%S %%T
 )

 IF "%@CHECK%"=="ERROR:" (
	 ECHO %@FULLMSG%
 ) ELSE (
	 SET /A @VALUE=%@VALUE%
	 ECHO Current Disk TimeOut Value is: !@VALUE! seconds
 )

 IF "%@FULLMSG%"=="ERROR: The network path was not found." GOTO :ExitBatch
 IF NOT "%~2"=="" (
	 IF %@TIMEOUT_NUM% LEQ 0 SET @TIMEOUT_NUM=%@DEFAULT%
	 IF %@TIMEOUT_NUM% GTR 300 SET @TIMEOUT_NUM=%@DEFAULT%
	 ECHO:
	 ECHO Changing Disk TimeOut Value for %@CONNECT% to: !@TIMEOUT_NUM! seconds
	 REG ADD "%@CONNECT%\%@TIMEOUT_KEY%" /v "%@TIMEOUT_VAL%" /t REG_DWORD /d "!@TIMEOUT_NUM!" /f
 )
 ECHO:
 ECHO Displaying All Disk-Related Setttings for %@CONNECT% ...
 REG QUERY "%@CONNECT%\%@TIMEOUT_KEY%"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                                  