@ECHO OFF
 rem ==========================================================================
 rem === Update GPO Script Files
 rem ==========================================================================
 rem
 rem Created On: 07 Dec 2003
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 16 Oct 2023 / 30 Nov 2020              
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem === Generate Filtered CMD Title
 rem === Updated On: 30 Nov 2020 / 15 May 2018              
 rem ==========================================================================
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Updated On: 30 Nov 2020 / 26 May 2020              
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.5.0.450

 SET @PARAMS=%1 %2 %3 %4 %5 %6 %7 %8 %9
 SET @MSCRIPTS=%SystemDrive%\Scripts
 SET @LSCRIPTS=%@MSCRIPTS%\BAT\LogonScripts

 rem -- Set Global Variables from Centralized Script
 SET @VARIABLES="%~dp0SetDrive.BAT"
 IF EXIST %@VARIABLES% (
	 CALL %@VARIABLES% "%~n0"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO Unable to initialize custom script variables. Could not find %@VARIABLES%
	 ECHO:
	 DIR %@VARIABLES%
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @EVTSYS_SOURCE=%SystemDrive%\Scripts\Bat\Services\EvtSys
 SET @EVTSYS_DEST=\\%@INTFQDN%\SysVol\%@INTFQDN%\Files\EvtSys
 SET @GPO_ROOT=\\%@INTFQDN%\SysVol\%@INTFQDN%\Policies

 SET @LOGON=User\Scripts\Logon
 SET @LOGOFF=User\Scripts\Logoff
 SET @STARTUP=Machine\Scripts\Startup
 SET @SHUTDOWN=Machine\Scripts\Shutdown

 SET @BIN_UPDATE=%@LOGON% %@STARTUP%
 SET @FULL_UPDATE=%@LOGON% %@LOGOFF% %@STARTUP% %@SHUTDOWN%

 SET @BIN_EXT=.EXE .COM .DLL
 SET @SCRIPT_EXT=.BAT .CMD .KIX .VBS .PS
 SET @XCOPY=/R /C /I /F /H /K /Y


 rem ==========================================================================
 rem === Update EvtSys Service Files (x32 and x64)
 rem === Updated On: 11 Mar 2014 / 28 Oct 2012              
 rem ==========================================================================
:UpdateEvtSys
 CALL :Divider Updating the EvtSys Service Source Files...
 CALL ACOPY "%@EVTSYS_SOURCE%" "%@EVTSYS_DEST%"


 rem ==========================================================================
 rem === Update Existing Files under Logon/Startup Scripts
 rem === Updated On: 13 Jan 2020 / 09 Dec 2019              
 rem ==========================================================================
:RefreshFiles
 CALL :Divider Updating Contents of LogonScripts Folders... %@VER%
 IF EXIST "%@LSCRIPTS%" (
	 SET @MYSCRIPTS=%@LSCRIPTS%
	 CALL :UpdateFiles "%@MSCRIPTS%\Bat"      "%@LSCRIPTS%"          "."
	 CALL :UpdateFiles "%@MSCRIPTS%\Utils"    "%@LSCRIPTS%"          "."
	 CALL :UpdateFiles "%@MSCRIPTS%"          "%@LSCRIPTS%\Scripts"  "Bat"
	 CALL :UpdateFiles "%@MSCRIPTS%"          "%@LSCRIPTS%\Scripts"  "Utils"
	 CALL :UpdateFiles "%@MSCRIPTS%"          "%@LSCRIPTS%\Scripts"  "Utils\x64"
	 CALL :UpdateFiles "%@MSCRIPTS%"          "%@LSCRIPTS%\Scripts"  "Bat\Input"
	 CALL :UpdateFiles "%@EVTSYS_SOURCE%\x86" "%@LSCRIPTS%\System32" "Evt*.*"
	 CALL :UpdateFiles "%@EVTSYS_SOURCE%"     "%@LSCRIPTS%\System32" "x64\Evt*.*"
 ) ELSE (
	 ECHO No Logon Scripts Folder Available...
	 SET @MYSCRIPTS=%@MSCRIPTS%\..
 )


 rem ==========================================================================
 rem === Update Scripts and Configs in the GPO
 rem === Updated On: 28 Jan 2020 / 13 Dec 2019              
 rem ==========================================================================
:UpdateScripts
 CALL :Divider Updating Scripts and Configs in all GPOs...
 FOR /F "TOKENS=*" %%R IN ('DIR /B /OGN "%@GPO_ROOT%\{*" 2^>NUL') DO (
	 NOW \n\- \v -- SEARCHING: %%~R\n\-

	 SET @CURRENT=%@GPO_ROOT%\%%~R
	 SET @FILES_HERE=FALSE
	 FOR /F "TOKENS=*" %%F IN ('DIR /B /S "!@CURRENT!" ^| FINDSTR /I "%@SCRIPT_EXT%" 2^>NUL') DO SET @FILES_HERE=TRUE

	 IF /I "!@FILES_HERE!"=="TRUE" (
		 IF EXIST "%@MYSCRIPTS%\Logon.Settings*TXT" XCOPY "%@MYSCRIPTS%\Logon.Settings*TXT" "!@CURRENT!" /Y
		 FOR %%S IN (%@FULL_UPDATE%) DO CALL ACOPY "%@MYSCRIPTS%" "!@CURRENT!\%%~S" /U %@PARAMS%
	 )
 )


 rem ==========================================================================
 rem === Update All Binary Files Under LogonScripts & \Scripts & \System32
 rem === Updated On: 14 Jan 2020 / 13 Dec 2019              
 rem ==========================================================================
:UpdateEXE
 CALL :Divider Updating Binary Files in the GPO...
 FOR /F "TOKENS=*" %%R IN ('DIR /B /OGN "%@GPO_ROOT%\{*" 2^>NUL') DO (
	 NOW \n\- \v -- SEARCHING: %%~R\n\-

	 SET @CURRENT=%@GPO_ROOT%\%%~R
	 SET @FILES_HERE=FALSE
	 FOR /F "TOKENS=*" %%F IN ('DIR /B /S "!@CURRENT!" ^| FINDSTR /I "%@BIN_EXT%" 2^>NUL') DO SET @FILES_HERE=TRUE

	 IF /I "!@FILES_HERE!"=="TRUE" (
		 FOR %%S IN (%@BIN_UPDATE%) DO @(
			 CALL :UpdateFiles-New "%@MYSCRIPTS%" "!@CURRENT!\%%~S" "."
			 IF EXIST "%@LSCRIPTS%" (
				 XCOPY "%@MYSCRIPTS%\System32"          "!@CURRENT!\%%~S\System32"          %@XCOPY% %@PARAMS%
				 XCOPY "%@MYSCRIPTS%\System32\x64"      "!@CURRENT!\%%~S\System32\x64"      %@XCOPY% %@PARAMS%
				 XCOPY "%@MYSCRIPTS%\Scripts\Utils\x64" "!@CURRENT!\%%~S\Scripts\Utils\x64" %@XCOPY% %@PARAMS%
			 )
		 )
	 )
 )


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Updated On: 03 Oct 2019 / 28 Feb 2019              
 rem ==========================================================================
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Execute Dynamic Command From Variable
 rem === Updated On: 31 May 2009                     
 rem ==========================================================================
:RunCMD
 rem %* = Command To Execute

 %*
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Ensure that Files are Updated from the Source
 rem === Updated On: 11 Mar 2014 / 28 Oct 2012              
 rem ==========================================================================
:UpdateFiles
:UpdateFiles-New
 rem %1 = Source Folder for updated files (Scripts and Utilities)
 rem %2 = Destination Folder for updated files (Scripts and Utilities)
 rem %3 = Path to append to Source and Destination Folders

 IF /I "%~0"==":UpdateFiles-New" (SET @U=) ELSE (SET @U=/U)
 FOR /L %%N IN (1,1,3) DO ECHO:
 ECHO Updating "%~1\%~3" to "%~2\%~3"
 XCOPY "%~1\%~3" "%~2\%~3" /I /C /R /K /H /F /Y /D %@U% %@PARAMS%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Generate Section Divider
 rem === Updated On: 13 Dec 2019 / 11 Mar 2014              
 rem ==========================================================================
:Divider
 rem %* = Message to Display

 NOW \n\n\n\#\v -- %*\n\#\n
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set/Display Script Version and Execution Status
 rem === Updated On: 16 Oct 2023 / 24 Dec 2019              
 rem ==========================================================================
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                    