@ECHO OFF
 rem ==========================================================================
 rem === Create Roaming Profile Folders on Based on NET USER Info
 rem ==========================================================================
 rem
 rem Created On: 15 Mar 2003
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 03 Dec 2003
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: NT4 or later
 rem
 rem  Non-Native Utilities Required:
 rem  	Resource Kit ........... http://KB.ultratech-llc.com/?File=ResKit.TXT
 rem  	Alternate Tools ........ http://KB.ultratech-llc.com/?File=UserMgr.TXT
 rem ==========================================================================

 :::  This script uses the results from the "NET USER /DOMAIN"
 :::  command to generate Roaming Profile Folders for each domain
 :::  user under the directory provided AT the command-line
 :::  (or via script variable).  Additionally, permissions on the
 :::  folders are set so that only the Administrators group and
 :::  the specific user will have access to their profile folder.
 :::
 :::  WARNING: The sharename you choose will be deleted and then
 :::  recreated, so don't make any typos.
 :::
 :::  In the FOR command, you need to skip 4 lines if you are
 :::  looking AT the local SAM database, but you must skip 6
 :::  lines if you are looking AT a domain SAM database.
 :::
 :::  This script supports UNC to allow it to operate remotely.
 :::  Folder names containing spaces should be entered AT the
 :::  command line surrounded by quotes.
 :::
 :::  Permissions are handled with XCACLS and the shares are
 :::  created using RMTSHARE. Various other ResKit utils are
 :::  used.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:NeedHelp
 IF "%~2"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 03 Dec 2003
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Calculate Date/Time (Short Procedure - ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=4-6 DELIMS=: " %%T IN ('NOW') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG

 rem -- Standard Variables
 SET @FOLDERPERMS="Administrators":F "SYSTEM":F /R "EVERYONE"
 SET @SHAREPERMS=/GRANT "Administrators":F /GRANT "EVERYONE":C
 SET @SHARENAME=%~1
 SET @PROFILE_ROOT=%~2
 FOR /F "DELIMS=\ " %%V IN ('ECHO %@PROFILE_ROOT%') DO SET @SERVER=%%V

 SET @LOGPATH=%@STORAGE%\Logs\Maint
 SET @LOGFILE=%@LOGPATH%\%~n0.%@FILESTAMP%


 rem ==========================================================================
 rem === Prepare Log File
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:PrepLogs
 IF NOT EXIST "%@LOGPATH%" MD "%@LOGPATH%"

 NOW Create User Profiles          >"%@LOGFILE%"
 ECHO:                            >>"%@LOGFILE%"
 ECHO Current Shares              >>"%@LOGFILE%"
 RMTSHARE \\%@SERVER              >>"%@LOGFILE%"
 RMTSHARE \\%@SERVER\%@SHARENAME% >>"%@LOGFILE%"
 ECHO:                            >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Create User Profile Share and Folders
 rem === Last Modified On 27 Mar 2003
 rem ==========================================================================
:MakeFolders
 IF NOT EXIST "%@PROFILE_ROOT%" MD "%@PROFILE_ROOT%"
 RMTSHARE \\%@SERVER%\%@SHARENAME% /D                              >>"%@LOGFILE%"
 RMTSHARE \\%@SERVER%\%@SHARENAME%="%@PROFILE_ROOT%" %@SHAREPERMS% >>"%@LOGFILE%"

 FOR /F "TOKENS=1-3 SKIP=4" %%F IN ('NET USER /DOMAIN') DO (
   IF "%%F"=="The" GOTO :SetPerms
   IF /I NOT "%%F"=="" (
		 MD "%@PROFILE_ROOT%\%%F.PDS" 2>NUL
		 NET USER %%F /DOMAIN /PROFILEPATH:\\%@SERVER%\%@SHARENAME%\%%F
	 )
   IF /I NOT "%%G"=="" (
		 MD "%@PROFILE_ROOT%\%%G.PDS" 2>NUL
		 NET USER %%G /DOMAIN /PROFILEPATH:\\%@SERVER%\%@SHARENAME%\%%G
	 )
   IF /I NOT "%%H"=="" (
		 MD "%@PROFILE_ROOT%\%%H.PDS" 2>NUL
		 NET USER %%H /DOMAIN /PROFILEPATH:\\%@SERVER%\%@SHARENAME%\%%H
	 )
 )


 rem ==========================================================================
 rem === Go To Home Directory and Set Permissions For Each Folder
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:SetPerms
 PUSHD "%@PROFILE_ROOT%"
 XCACLS "%@PROFILE_ROOT%" /Y /C /T /G %@FOLDERPERMS%
 FOR /F %%V IN ('DIR /B /AD "%@PROFILE_ROOT%"') DO (
   ECHO Setting New Permissions for "%@PROFILE_ROOT%\%%V"
   XCACLS "%@PROFILE_ROOT%\%%V"     /Y /C    /G "%%V":C %@FOLDERPERMS%
   XCACLS "%@PROFILE_ROOT%\%%V\*.*" /Y /C /T /G "%%V":C %@FOLDERPERMS%
 )
 POPD


 rem ==========================================================================
 rem === Display Log File
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:DisplayLog
 DIR "%@PROFILE_ROOT%" /OGD /A     >>"%@LOGFILE%"
 XCACLS "%@PROFILE_ROOT%" /Y /C /T >>"%@LOGFILE%"
 RMTSHARE \\%@SERVER%              >>"%@LOGFILE%"
 RMTSHARE \\%@SERVER%\%@SHARENAME% >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 03 Dec 2003
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 15 Mar 2003
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for USERPROFILES.BAT
 ECHO:
 ECHO === UserProfiles {name_of_profile_share} {\\server_name\share}
 ECHO:
 ECHO Example: UserProfiles \\MyPDC\SomeFolder
 ECHO          UserProfiles \\FileServer\ProfileShare
 ECHO          UserProfiles "\\Server\Long Dir Name"
 ECHO          UserProfiles "\\Server\ShortDir"
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Folder names containing spaces should
 ECHO       be surrounded by quotation marks.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
