@REM - ASB (04 Oct 2011 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 31 Aug 2018 / 26 Jul 2018 / 30 Apr 2018): Check Availability of Remote Share
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.7.0.170

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Check Availability of Remote Share
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [\\remote_server\some\path]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @SOURCE=%~1& IF "%~1"=="" SET @SOURCE=\\%COMPUTERNAME%\SomeShare


 rem -- Main Script
:Main
 CALL :CheckAvailability %@SOURCE%
 ECHO  "%@SOURCE%" is REACHABLE? %@REACHABLE%
 ECHO:
 ECHO:
 SET @


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Check Availability of Destination
:CheckAvailability
 rem %1 = String to Compare for Error Messages
 SET @FAILURE1=ERROR: Could not resolve hostname to IP Address.
 SET @FAILURE2=The network name cannot be found.
 SET @SUCCESS1=Packets: Sent = 4, Received = 4, Lost = 0 (0%% loss),
 SET @REACHABLE=TRUE
 FOR %%Z IN (IP PING MKDIR) DO SET @%%Z=FAILED

 rem -- Lookup Name
 ECHO !DATE! at !TIME! -- Lookup Name
 FOR /F "TOKENS=*" %%A IN ('RESOLVE %~1') DO SET @IP=%%~A
 IF "%@IP%"=="%@FAILURE1%" (
	 ECHO --- CANNOT RESOLVE NAME TO IP
	 SET @REACHABLE=FALSE
	 GOTO :ExitBatch
 )

 rem -- Ping Machine
 ECHO !DATE! at !TIME! -- Ping Machine
 FOR /F "TOKENS=*" %%A IN ('PING %@IP% ^| FIND "%%"') DO SET @PING=%%~A
 IF /I NOT "%@PING%"=="%@SUCCESS1%" (
	 SET @REACHABLE=FALSE
	 ECHO --- NOT PINGABLE
	 GOTO :ExitBatch
 )


 rem -- Attempt to Create Remote Directory
 ECHO !DATE! at !TIME! -- Attempt to Create Remote Directory
 FOR /F "TOKENS=*" %%A IN ('MD "%@SOURCE%"') DO SET @MKDIR=%%~A
 IF /I NOT "%@MKDIR%"=="%@SUCCESS1%" (
	 SET @REACHABLE=FALSE
	 ECHO --- CANNOT CREATE FOLDER
	 GOTO :ExitBatch
 )
 GOTO :EOF


 rem -- SUBROUTINE: Compare Current Input With Error Messages
:CheckAvailability_OLD
 rem %1 = String to Compare for Error Messages
 SET @UNREACHABLE=FALSE
 SET @STRING=%*
 SET @STRING=!@STRING:(=[!
 SET @STRING=!@STRING:)=]!
 SET @ACCESS=!@STRING:~19,7!

 FOR %%Z IN (%@ROBOCOPY_ERRORS%) DO IF /I "!@STRING!"=="%%~Z" SET @UNREACHABLE=TRUE
 FOR %%Z IN (%@ROBOCOPY_ERRORS%) DO IF /I "!@ACCESS!"=="%%~Z" SET @UNREACHABLE=TRUE
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                                 