@REM - ASB (19 Dec 2013 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 31 Aug 2018 / 26 Jul 2018 / 30 Apr 2018 / 27 Mar 2016): Enable or Disable Web Browsers at the Firewall
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.7.0.170

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=1 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Enable or Disable Web Browsers at the Firewall
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<ENABLE ^| DISABLE^>
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Main Variables
 SET @ACTION=ALLOW& FOR %%A IN (BLOCK DENY DISABLE) DO IF /I "%~1"=="%%~A" SET @ACTION=BLOCK

 rem -- Web Browser List
 SET @BROWSER01="Internet Explorer" "%ProgramFiles%\Internet Explorer\IExplore.exe"
 SET @BROWSER02="Internet Explorer" "%ProgramFiles(x86)%\Internet Explorer\IExplore.exe"
 SET @BROWSER03="Google Chrome"     "%ProgramFiles(x86)%\Google\Chrome\Application\Chrome.exe"
 SET @BROWSER04="Google Chrome"     "%ProgramFiles(x86)%\Google\Chrome Frame\Application\Chrome.exe"
 SET @BROWSER05="Mozilla Firefox"   "%ProgramFiles(x86)%\Mozilla Firefox\Firefox.exe"
 SET @BROWSER06="Mozilla Firefox"   "%ProgramFiles(x86)%\Mozilla Firefox\Updated\Firefox.exe"
 SET @BROWSER07="Opera"             "%ProgramFiles(x86)%\Opera\Opera.exe"
 SET @BROWSER08="Apple Safari"      "%ProgramFiles(x86)%\Apple\Safari\Safari.exe"
 SET @BROWSER09="Apple Safari"      "%ProgramFiles(x86)%\Apple Safari\Safari.exe"
 SET @BROWSER10="Apple Safari"      "%ProgramFiles(x86)%\Apple\Apple Safari\Safari.exe"


 rem -- Configure Firewall Rules
:ConfigRules
 FOR %%I IN (0 1 2) DO FOR /L %%J IN (0,1,9) DO IF DEFINED @BROWSER%%I%%J CALL :SetBrowserRule %@ACTION% !@BROWSER%%I%%J!


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Enable/Disable Browser Rules
:SetBrowserRule
 rem %1 = Enable or Disable Web Browser Rule
 rem %2 = Name of Web Browser Rule
 rem %3 = Full Path of Web Browser

 SET @FLAG=%~2
 SET @FLAG=!@FLAG: =_!
 SET @RULE="Block %~2"

 IF NOT DEFINED @CLEAR-!@FLAG! (
	 SET @CLEAR-!@FLAG!=TRUE
	 NETSH advfirewall firewall delete rule name=%@RULE%
 )

 IF /I "%~1"=="BLOCK" (
	 ECHO Blocking %~2 Browser Traffic on %COMPUTERNAME%
	 NETSH advfirewall firewall add rule name=%@RULE% dir=out program="%~3" action=BLOCK enable=yes profile=Domain,Private,Public description=%@RULE%
 ) ELSE (
	 ECHO Enabling %~2 Browser Traffic on %COMPUTERNAME%
	 NETSH advfirewall firewall add rule name=%@RULE% dir=out program="%~3" action=BLOCK enable=NO profile=Domain,Private,Public description=%@RULE%
 )
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                          