@REM - ASB (06 May 2016 // 16 Oct 2023 / 30 Nov 2020 / 24 Dec 2019 / 30 Sep 2019 / 31 Aug 2018 / 26 Jul 2018 / 29 Apr 2018 / 06 May 2016): Compare Windows Packages across Multiple Servers
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.5.0.140

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc --mp=2 -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Compare Windows Packages across Multiple Servers
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  ^<List_of_Files^> ^<List_of_Servers^>
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Main Variables
 SET @LIST=%~1&    IF "%~1"=="" SET @LIST=%TEMP%\PackageList.TXT
 SET @SERVERS=%~2& IF "%~2"=="" SET @SERVERS=%TEMP%\ServerList.TXT
 SET @COMPARE=%SystemRoot%& FOR /F "USEBACKQ TOKENS=2" %%S IN (%@SERVERS%) DO SET @COMPARE=!@COMPARE! \\%%~S\ADMIN$
 SET @COMPARE=%@COMPARE:\\\\=\\%


 rem -- Compare Corrupted Files Across Multiple Servers
:CompareFiles
 ECHO Compare Windows Package Files Across Multiple Servers
 ECHO %@DIVIDER%
 ECHO:
 FOR /F "USEBACKQ TOKENS=*" %%F IN (%@LIST%) DO (
	 ECHO  -- Compare: %%~F
	 MAKESTRING - 160
	 FOR %%S IN (%@COMPARE%) DO IF EXIST "%%~S\%%~F" FOR /F "TOKENS=*" %%E IN ('DIR "%%~S\%%~F" ^| FIND "/"') DO (
		 SET @SYS=%%~S%@SPACES%
		 SET @SYS=!@SYS:\ADMIN$=!
		 ECHO  !@SYS:~0,20! %%~E
	 )
	 ECHO:
	 ECHO:
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
    