@ECHO OFF
 rem ==========================================================================
 rem === Create Daily Archive of files from the FTP server (no recursion)
 rem ==========================================================================
 rem
 rem Created On: 01 Jul 2003
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 31 Jan 2008  (Prior Update: 09 Jan 2007)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows NT4 and later
 rem
 rem  Non-Native Utilities Required:
 rem  	InfoZip Utilities ...... http://www.info-zip.org/
 rem  	DOFF ................... http://www.jfitz.com/dos/index.html#DOFF
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This purpose of this script is to create a zip archive of all files in a
 :::  given directory tree.  The name of the root folder is the only parameter
 :::  which must be passed  to the script at the command line.   All other
 :::  variables should be set within the script itself.  This is another in
 :::  the family of Zip*.BAT scripts for archiving content.
 :::
 :::  The script will attempt to schedule a daily job to run as the SYSTEM
 :::  account, but the account can be  changed via the Task Scheduler or the
 :::  environment variables below.
 :::
 :::  Over time, you'll want to start pruning the zip archive folder, as it
 :::  will steadily consume diskspace.  The script now includes a self-purging
 :::  routine that will move files into an archive folder (Archives) after 7
 :::  days, and then delete any files in this archive folder than are older
 :::  than 90 days. These defaults can all be changed by altering the two
 :::  %@KEEP_% variables (@KEEP_SHORT-TERM and @KEEP_HISTORICAL), or by
 :::  entering the two parameters at the command prompt.  You might find it
 :::  best to keep the files around for a least 3 months for easy comparison.
 :::
 :::  The compression is courtesy of the free InfoZip utilities, and this
 :::  script was tested under XP and 2003, but should run just fine under
 :::  NT4 and 2000. The only limitation at present, is an inability to create
 :::  zip archives of files which are larger than 4GB.  This is supposed to
 :::  be addressed in Mid-to-Late 2006, but will probably take place in 2007.
 :::
 :::  The DOFF.EXE utility makes it much easier to determine the previous
 :::  day and month than in times past, and has been added to all DATE/TIME
 :::  scripts as a basic routine.
 :::
 :::  The issue of supporting long path names via SCHTASKS was a vexing one
 :::  until I came across a KB article that outlines the \ character as the
 :::  escape character for quotation marks.  (e.g. \" )
 :::  See http://support.microsoft.com/?KBID=823093 for details...
 :::
 :::  PLEASE NOTE:
 :::  		The ZIP parameters are case sensitive.
 :::  		This script processes the main folder + subdirectories.
 :::  		This script requires SETDRIVE.BAT for the DATE/TIME routines.
 :::  		This SCHTASKS portion of the script does NOT work properly with
 :::       Vista RTM (32-bit or 64-bit).  This has been fixed with SP1
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to "TRUE"
 rem === Last Modified On 25 Oct 2005
 rem ==========================================================================
:DebugMode
 IF /I "%Debug%"=="TRUE" (
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE (
	 SET @PAUSE_IF_DEBUG=
	 SET @END_DEBUG_MODE=
 )


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 31 Jan 2008  (Prior Update: 09 Jan 2007)
 rem ==========================================================================
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION
 SET @VER=%~nx0 v1.2.1

 rem -- Calculate Date/Time (Short Procedure - No ResKit)
 FOR /F "TOKENS=2-5 DELIMS=/ " %%D IN ('DATE /T') DO SET @TODAY=%%F%%D%%E
 FOR /F "TOKENS=1-3 DELIMS=:. " %%T IN ('ECHO %TIME: =0%') DO SET @NOW=%%T%%U%%V
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG
 SET @TIMESTAMP=%DATE% at %TIME%

 rem -- Get Official Drive Letters and Calculate Date/Time for NON-US Regions
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Standard Variables
 SET @PARAMS=%*
 SET @TARGET=%~1& FOR %%P IN (!@TARGET!\..) DO SET @ROOTDIR=%%~fP
 SET @DEST=%~s1\ARGI\Processing\Archives
 SET @EXCLUDE=-x \Zips \*(Old*
 SET @TEMPFLAG=Created by FTP Archival Script - %@TODAY%.DAT

 rem -- Historical Archiving Variables (in Days)
 SET @GRAVEYARD=%@DEST%\Zips
 SET @KEEP_SHORT-TERM=%~2& IF "%~2"=="" SET @KEEP_SHORT-TERM=7
 SET @KEEP_HISTORICAL=%~3& IF "%~3"=="" SET @KEEP_HISTORICAL=90
 FOR /F %%O IN ('DOFF yyyy-mm-dd -%@KEEP_SHORT-TERM%') DO SET @STARTDATE=%%O

 rem -- Job Scheduling Variables
 SET @JOBNAME=Compressed FTP Archive of '%@TARGET%'
 SET @JOBNAME=%@JOBNAME::\=_%
 SET @JOBNAME=%@JOBNAME:\=_%
 SET @JOBFREQ=DAILY
 SET @JOBTIME=03:30:00
 SET @JOBDATE=
 SET @JOBUSER=SYSTEM
 SET @JOBVRFY=%~f0 ""%@TARGET%""
 SET @JOBPATH=\"%~f0\" \"%@TARGET%\" %@KEEP_SHORT-TERM% %@KEEP_HISTORICAL%
 SET @JOBPATH=%@JOBPATH:(=^(%
 SET @JOBPATH=%@JOBPATH:)=^)%
 SET @AT_PATH=%~f0 """%@TARGET%""" %@KEEP_SHORT-TERM% %@KEEP_HISTORICAL%

 rem -- ZipName Variables
 SET @ZIPNAME=Archive of %@TARGET%
 SET @ZIPNAME=%@ZIPNAME::\=_%
 SET @ZIPNAME=%@ZIPNAME:\=_%
 SET @ARCHIVE=%@DEST%\%@ZIPNAME%.%@TODAY%.ZIP

 rem -- LogName Variables
 SET @LOGPATH=%@STORAGE%\Logs\Archiving
 SET @LOGFILE=%@LOGPATH%\%@JOBNAME%.%@FILESTAMP%


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 14 Oct 2005
 rem ==========================================================================
:NeedHelp
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Validate Source and Script Log Folders
 rem === Last Modified On 25 Jan 2008  (Prior Update: 08 Nov 2006)
 rem ==========================================================================
:CheckFolders
 IF NOT EXIST "%@TARGET%" (
	 ECHO *** SCRIPT ERROR ***
	 ECHO THE FOLLOWING FOLDER COULD NOT BE FOUND: "%@TARGET%"
	 ECHO:
	 GOTO :HelpMessage
 ) ELSE (
	 FOR %%F IN ("%@DEST%" "%@LOGPATH%") DO IF NOT EXIST "%%~F" MD "%%~F" >NUL
 )


 rem ==========================================================================
 rem === Allow User To Abort Operation
 rem === Last Modified On 04 Jan 2007  (Prior Update: 26 May 2006)
 rem ==========================================================================
:DblCheck
 CLS
 ECHO === Prepare to Create FTP Zip Archive of %@TARGET% ===
 ECHO:
 ECHO  Main archives will be kept for %@KEEP_SHORT-TERM% days...
 ECHO  Historical archives will be kept for %@KEEP_HISTORICAL% days...
 ECHO:
 ECHO Press [CTRL-C] To Abort, Any Other Key To Continue...
 ECHO:
 TIMEOUT 20


 rem ==========================================================================
 rem === Create Scheduled Job using SCHTASKS (XP/2003/Vista) or AT (NT/2000)
 rem === Last Modified On 04 Jan 2007  (Prior Update: 14 Jul 2006)
 rem ==========================================================================
:ScheduleJobs
 ECHO:
 ECHO Scheduling "%@JOBNAME%" on %COMPUTERNAME%...
 ECHO:

 IF EXIST "%SystemRoot%\System32\SCHTASKS.EXE" (
	 SCHTASKS /QUERY /V /FO LIST | FIND /I "%@JOBVRFY%" >NUL
	 IF ERRORLEVEL 1 (
		 SCHTASKS /CREATE /TN "%@JOBNAME%" /TR "%@JOBPATH%" /RU "%@JOBUSER%" /SC "%@JOBFREQ%" %@JOBDATE% /ST %@JOBTIME%  %@FORCE%
	 )
 ) ELSE (
	 AT | FIND /I "%@JOBVRFY%" >NUL
	 IF ERRORLEVEL 1 AT %@JOBTIME% /EVERY:1  %@AT_PATH%
 )

 rem -- If ANY of the parameters is "." then update the scheduled job and exit the script
 FOR %%P IN (%*) DO IF "%%~P"=="." (
	 SCHTASKS /CREATE /TN "%@JOBNAME%" /TR "%@JOBPATH%" /RU "%@JOBUSER%" /SC "%@JOBFREQ%" %@JOBDATE% /ST %@JOBTIME%  %@FORCE%
	 GOTO :EOF
 )


 rem ==========================================================================
 rem === Start at Root Folder for this FTP account and Process All Subfolders
 rem === Last Modified On 25 Jan 2008  (Prior Update: 23 Jun 2003)
 rem ==========================================================================
:ProcessFolders
 NOW Processing "%@TARGET%" and subfolders for files to archive... >"%@LOGFILE%"
 ECHO Processing "%@TARGET%" and subfolders for files to archive...
 ECHO:
 FOR /R "%@TARGET%" %%V IN (.) DO CALL :SetTempMarker "%%V"
 FOR /R "%@TARGET%" %%V IN (.) DO CALL :MakeArchive "%%V" *.*
 DEL "%@TARGET%\%@TEMPFLAG%" /S

:SetPerms
 ( rem -- Consolidate LogFile Output
	 ECHO:
	 ECHO Setting Permissions on the "%@TARGET%" folder... >CON
	 ECHO Setting Permissions on the "%@TARGET%" folder...
	 iCACLS "%@TARGET%\ARGI" /t /c /grant:r "ARGI\Domain Admins":F "ARGI\Domain Users":R "SYSTEM":F
	 ECHO:
 ) >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Move Zips Into GraveYard After %@KEEP_SHORT-TERM% Days (Default=7)
 rem === Last Modified On 25 Jan 2008  (Prior Update: 15 May 2006)
 rem ==========================================================================
:MoveIntoGraveYard
 SET @FORFILES=FORFILES -p"%@DEST%" -m*.ZIP -d-%@KEEP_SHORT-TERM% -c"CMD /C IF @ISDIR==FALSE ECHO @PATH\@FILE"
 IF EXIST "%SystemRoot%\System32\FORFILES.EXE" (
	 SET @FORFILES=%SystemRoot%\System32\FORFILES -p "%@DEST%" -m *.ZIP -d -%@KEEP_SHORT-TERM% -c "CMD /C IF @ISDIR==FALSE ECHO @PATH"
 )

 ( rem -- Consolidate LogFile Output
	 IF NOT EXIST "%@GRAVEYARD%" MD "%@GRAVEYARD%"
	 ECHO:
	 ECHO:
	 ECHO Manage Primary Archives
	 ECHO  -- Move all archives older than %@KEEP_SHORT-TERM% days to the GraveYard --
	 FOR /F "TOKENS=*" %%V IN ('%@FORFILES% 2^>NUL') DO (
		 ECHO Moving "%%~V" into Archive Graveyard Folder
		 MOVE "%%~V" "%@GRAVEYARD%"
	 )
 ) >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Delete All Zips Older Than %@KEEP_HISTORICAL% Days (Default=90)
 rem === Last Modified On 25 Jan 2008  (Prior Update: 15 May 2006)
 rem ==========================================================================
:PruneArchive
 SET @FORFILES=FORFILES -p"%@GRAVEYARD%" -m*.ZIP -d-%@KEEP_HISTORICAL% -c"CMD /C IF @ISDIR==FALSE ECHO @PATH\@FILE"
 IF EXIST "%SystemRoot%\System32\FORFILES.EXE" (
	 SET @FORFILES=%SystemRoot%\System32\FORFILES -p "%@GRAVEYARD%" -m *.ZIP -d -%@KEEP_HISTORICAL% -c "CMD /C IF @ISDIR==FALSE ECHO @PATH"
 )

 ( rem -- Consolidate LogFile Output
	 ECHO:
	 ECHO:
	 ECHO Pruning Old Backups from Archive Folder
	 ECHO  -- Delete all archives older than %@KEEP_HISTORICAL% days old --
	 FOR /F "TOKENS=*" %%V IN ('%@FORFILES% 2^>NUL') DO (
		 ECHO Deleting "%%~V" from Archive Graveyard Folder
		 DEL "%%~V"
	 )
 ) >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 23 Oct 2005
 rem ==========================================================================
:ExitBatch
 ECHO FINISHED Creating Archive of %@TARGET%!
 DIR /OGN "%@DEST%"
 DIR /OGN "%@DEST%"    >>"%@LOGFILE%"
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%"
 %@END_DEBUG_MODE%
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Create a Temp Marker File for Each Folder
 rem === Last Modified On 25 Jan 2008
 rem ==========================================================================
:SetTempMarker
 rem %1 = Current Folder (Full Path Name)

 SET @CURRENTDIR=%~f1

 PUSHD "%@CURRENTDIR%"
 ECHO Creating Temp Marker File for "%@CURRENTDIR%" folder... >CON
 ECHO %@TEMPFLAG% >"%@CURRENTDIR%\%@TEMPFLAG%"
 POPD
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Create Zip Archive and Move All Log Files
 rem === Last Modified On 25 Jan 2008  (Prior Update: 28 May 2006)
 rem ==========================================================================
:MakeArchive
 rem %1 = Current Folder (Full Path Name)
 rem %2 = Current FileSpec

 SET @TEMPFLAG=Created by FTP Archival Script - %@TODAY%.DAT
 SET @CURRENTDIR=%~f1
 SET @CURRENTSPEC=%~2

 CALL :VarSubstitution @LONGNAME @CURRENTDIR "%@ROOTDIR%\="
 SET @LONGNAME=%@LONGNAME::\=_%
 SET @LONGNAME=%@LONGNAME:\=_%
 SET @ARCHIVE=%@DEST%\%@LONGNAME%.%@TODAY%.ZIP

 IF EXIST "%@CURRENTDIR%\%@CURRENTSPEC%" (
	 PUSHD "%@CURRENTDIR%"
	 ECHO Processing "%@CURRENTDIR%\%@CURRENTSPEC%" Files... >CON
	 ECHO:
	 ECHO ----------------------------------------------------------------------
	 ECHO Processing "%@CURRENTDIR%\%@CURRENTSPEC%" Files...
	 ECHO:
	 DIR "%@CURRENTSPEC%" | FIND /I /V "%@TEMPFLAG%"
	 ECHO:
	 ZIP -m -9 -v -T -tt %@STARTDATE% "%@ARCHIVE%" %@CURRENTSPEC% %@EXCLUDE%
	 ECHO:
	 DIR | FIND /I /V "%@TEMPFLAG%"
	 POPD
 ) >>"%@LOGFILE%"

 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Set New Complex Variable with Variable Substitution
 rem === Last Modified On 25 Jan 2008
 rem ==========================================================================
:VarSubstitution
 rem %1 = New Variable to Set
 rem %2 = Old Variable to Derive Value From
 rem %3 = Variable to Change

 CALL :ExecuteCommand SET %~1=%%%~2:%~3%%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Execute Command
 rem === Last Modified On 25 Jan 2008
 rem ==========================================================================
:ExecuteCommand
 rem %1 = Command to Execute

 %*
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 25 Jan 2008  (Prior Update: 28 May 2006)
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for %~nx0
 ECHO:
 ECHO === %~n0 ^<folder^> [days before archive] [days before graveyard purge]
 ECHO:
 ECHO 	Number of days before zip files are archived .....: %@KEEP_SHORT-TERM%
 ECHO 	Number of days before archived zips are purged ...: %@KEEP_HISTORICAL%
 ECHO:
 ECHO Example: %~n0
 ECHO          %~n0 C:\Scripts
 ECHO          %~n0 "D:\Script Archive" 150
 ECHO          %~n0 "E:\App Data Files" 200 900
 ECHO          %~n0 "F:\Doc File Repository" %@KEEP_SHORT-TERM% %@KEEP_HISTORICAL%
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Any parameters which contain spaces should be surrounded by quotes.
 ECHO       Shortnames *can* be surrounded by quotes if you choose, but it is
 ECHO       not mandatory by any means.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
