@ECHO OFF
 rem ==========================================================================
 rem === Compress Old Files into New Dated Archive (Folder + Subfolders)
 rem ==========================================================================
 rem
 rem Created On: 22 Jun 2003
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 26 Oct 2005
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows NT4 and later
 rem
 rem  Non-Native Utilities Required:
 rem  	InfoZip Utilities ...... http://www.info-zip.org/
 rem  	Resource Kit ........... http://KB.ultratech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This purpose of this script is to create a zip archive of
 :::  all files in a given directory tree which match a particular
 :::  pattern such as *.LOG, *.TXT, or S*.DAT.  The name of the
 :::  root folder is the only parameter which must be passed to the
 :::  script AT the command line.  All other variables can be set
 :::  within the script itself.
 :::
 :::  All files in the selected folder (plus all subfolders) which
 :::  match the filespec, but are AT least one day older than the
 :::  current day in which the script is run, will be zipped into
 :::  a file bearing the current date, and then deleted one the
 :::  archive has been validated. (If you don't want the originals
 :::  deleted, remove the -m parameter from the ZIP command). The
 :::  script will attempt to schedule a MONTHLY job to run as the
 :::  current user (it will ask for credentials),  but the account
 :::  can be  changed via the Task Scheduler or the environment
 :::  variables below.
 :::
 :::  As constructed, this script is useful for daily OR monthly
 :::  archiving. If monthly archiving is more to your liking, and
 :::  you only want it to touch files which have been created in
 :::  a previous month, use the second ZIP command (currently
 :::  commented out with the %@BEGMONTH% variable).  It all
 :::  depends on your environment.
 :::
 :::  The compression is courtesy of the free InfoZip utilities,
 :::  and this script was tested under XP and 2003, but should
 :::  run just fine under NT4 and 2000.
 :::
 :::  PLEASE NOTE:
 :::  		The ZIP paramaters are case sensitive.
 :::  		This script processes the main folder + subdirectories.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.ultratech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to "TRUE"
 rem === Last Modified On 25 Oct 2005
 rem ==========================================================================
:DebugMode
 IF /I "%Debug%"=="TRUE" (
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE (
	 SET @PAUSE_IF_DEBUG=
	 SET @END_DEBUG_MODE=
 )


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 22 Jun 2003
 rem ==========================================================================
:NeedHelp
 IF "%~2"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 10 Jan 2004
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" CALL "%~dp0SetDrive.BAT"

 rem -- Calculate Date/Time
 FOR /F "TOKENS=2" %%D IN ('DATE /T') DO SET @DATE=%%D
 FOR /F "TOKENS=1-5" %%D IN ('NOW') DO (
	 SET @DAY=%%D
	 SET @DD=%%F
 	 SET @MM=%@DATE:~0,2%
	 SET @MMM=%%E
	 SET @YYYY=%%H
	 SET @TIME=%%G
 )
 SET @TODAY=%@YYYY%%@MM%%@DD%
 SET @MMDDYYYY=%@MM%%@DD%%@YYYY%
 SET @BEGMONTH=%@MM%01%@YYYY%
 SET @NOW=%@TIME::=%
 SET @FILESTAMP=%@TODAY%-%@NOW%.LOG

 rem -- Standard Variables
 SET @FILESPEC=LOG TXT INFO CSV BAK
 SET @EXCLUDE=-x \*.ZIP
 SET @FOLDER=%~f2
 SET @DEST=%~s2\ZipFiles

 rem -- Surround Any Spaces In The Folder Name With Quotes
 SET @PARAM=""%@FOLDER%""
 SET @PARAM=%@PARAM: =" "%

 rem -- Job Scheduling Variables
 SET @JOBNAME=Log Archive of '%~1'
 SET @JOBFREQ=MONTHLY
 SET @JOBTIME=00:15:00
 SET @JOBUSER=SYSTEM
 SET @JOBPATH=%~f0 %@PARAM%& SET @JOBCHECK=%~f0 ""%@FOLDER%""
 SET @AT_PATH=%~f0 """%@FOLDER%"""

 rem -- LogName Variables
 SET @LOGPATH=%@STORAGE%\Logs\Archiving
 SET @LOGFILE=%@LOGPATH%\%@JOBNAME%.%@FILESTAMP%
:Variables
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Allow User To Abort Operation
 rem === Last Modified On 22 Jun 2003
 rem ==========================================================================
:DblCheck
 CLS
 ECHO === Prepare to Create Zip Archive of "%@FOLDER%" and subfolders ===
 ECHO:
 ECHO Press [CTRL-C] To Abort, Any Other Key To Continue...
 ECHO:
 TIMEOUT 20
:DblCheck
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Create Scheduled Job using SCHTASKS or AT
 rem === Last Modified On 10 Jan 2004
 rem ==========================================================================
:ScheduleJobs
 ECHO:
 ECHO Scheduling %@JOBNAME%...
 ECHO:

 IF EXIST "%SystemRoot%\System32\SCHTASKS.EXE" (
	 SCHTASKS /QUERY /V /FO LIST | FIND /I "%@JOBCHECK%" >NUL
	 IF ERRORLEVEL 1 (
		 SCHTASKS /CREATE /TN "%@JOBNAME%" /TR "%@JOBPATH%" /SC "%@JOBFREQ%" /ST %@JOBTIME% /RU "%@JOBUSER%" /D 1
	 )
 ) ELSE (
	 AT | FIND /I "%@JOBCHECK%" >NUL
	 IF ERRORLEVEL 1 AT %@JOBTIME% /EVERY:1 %@AT_PATH%
 )
:ScheduleJob
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Validate Source and Script Log Folders
 rem === Last Modified On 04 Jan 2004
 rem ==========================================================================
:CheckFolders
 FOR %%F IN ("%@DEST%" "%@LOGPATH%") DO IF NOT EXIST %%F MD %%F >NUL
 IF NOT EXIST "%@FOLDER%" (
	 ECHO *** SCRIPT ERROR ***
	 ECHO THE FOLLOWING FOLDER COULD NOT BE FOUND: "%@FOLDER%"
	 ECHO:
	 GOTO :EOF
 )


 rem ==========================================================================
 rem === Start AT Root Log Folder and Process All Subfolders
 rem === Last Modified On 23 Jun 2003
 rem ==========================================================================
:ProcessFolders
 NOW Processing "%@FOLDER%" and subfolders for log files to Zip... >"%@LOGFILE%"
 ECHO Processing "%@FOLDER%" and subfolders for log files to Zip...
 ECHO:
 FOR /R "%@FOLDER%" %%V IN (.) DO FOR %%F IN (%@FILESPEC%) DO CALL :MakeArchive "%%V" *.%%F
:ProcessFolders
 %@PAUSE_IF_DEBUG%


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 26 Oct 2006
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%" & DIR "%@DEST%"
 %@END_DEBUG_MODE%
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Create Zip Archive and Move All Log Files
 rem === Last Modified On 31 Dec 2003
 rem ==========================================================================
:MakeArchive
 rem %1 = Current Folder (Full Path Name)
 rem %2 = Current FileSpec

 SET @CURRENTDIR=%~f1
 SET @CURRENTSPEC=%~2
 SET @ARCHIVE="%@DEST%\%~n1.%@TODAY%.ZIP"

 IF EXIST "%@CURRENTDIR%\%@CURRENTSPEC%" (
	 PUSHD "%@CURRENTDIR%"
	 ECHO Processing "%@CURRENTDIR%\%@CURRENTSPEC%" Files...
	 ECHO:                                                               >>"%@LOGFILE%"
	 ECHO -------------------------------------------------------------  >>"%@LOGFILE%"
	 ECHO Processing "%@CURRENTDIR%\%@CURRENTSPEC%" Files...             >>"%@LOGFILE%"
	 ECHO:                                                               >>"%@LOGFILE%"
	 DIR "%@CURRENTSPEC%"                                                >>"%@LOGFILE%"
	 ECHO:                                                               >>"%@LOGFILE%"
	 ZIP -m -9 -v -T -tt %@MMDDYYYY% %@ARCHIVE% %@CURRENTSPEC% -x \*.ZIP >>"%@LOGFILE%"
	 rem ZIP -m -9 -v -T -tt %@BEGMONTH% %@ARCHIVE% %@CURRENTSPEC% -x \*.ZIP >>"%@LOGFILE%"
	 ECHO:                                                               >>"%@LOGFILE%"
	 DIR                                                                 >>"%@LOGFILE%"
	 POPD
 )
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 26 Oct 2005
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for ZIPLOGS.BAT
 ECHO:
 ECHO === ZipLogs {Jobname} {folder}
 ECHO:
 ECHO Example: ZipLogs SysLogs C:\LOGS
 ECHO          ZipLogs Backups D:\Backup
 ECHO          ZipLogs "Misc Logs" D:\TEST
 ECHO          ZipLogs "System Logs" "F:\SYSTEM LOGS"
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Any parameters which contain spaces
 ECHO       should be surrounded by quotes.
 ECHO       Shortnames *can* be surrounded by
 ECHO       quotes if you choose, but it is not
 ECHO       mandatory by any means.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
