@ECHO OFF
 rem ==========================================================================
 rem === Monthly Archive of Old Log Files in ZIP (Traverse Directory Tree)
 rem ==========================================================================
 rem
 rem Created On: 22 Jun 2003
 rem         By: Andrew S. Baker
 rem
 rem Updated On: 08 Jan 2007  (Prior Update: 14 Jul 2006)
 rem         By: Andrew S. Baker
 rem


 rem ==========================================================================
 rem  OS Required: Windows NT4 and later
 rem
 rem  Non-Native Utilities Required:
 rem  	InfoZip Utilities ...... http://www.info-zip.org/
 rem  	PSTOOLS ................ http://www.microsoft.com/technet/sysinternals/utilities/PsTools.mspx
 rem  	Resource Kit ........... http://KB.UltraTech-llc.com/?File=ResKit.TXT
 rem ==========================================================================

 :::  This purpose of this script is to create a zip archive of all files in a
 :::  given directory tree which match a particular pattern such as *.LOG,
 :::  *.TXT, or LOG*.TXT.  The name of the root folder is the only parameter
 :::  which must be passed to the script at the command line.  All other
 :::  variables should be set within the script itself.
 :::
 :::  All files in the folder which match the filespec, but are older than the
 :::  1st day of the month in which the script is run (basically, all files
 :::  created in a previous month) will be zipped into a file containing the
 :::  current year+month in the name, and then deleted once the archive has
 :::  been validated. (If you don't want the originals deleted, remove the -m
 :::  parameter from the ZIP command). The script will attempt to schedule a
 :::  monthly job to run as SYSTEM, but the account can be changed via the
 :::  Task Scheduler or the environment variables.
 :::
 :::  Over time, you'll want to start pruning the zip archive folder, as it
 :::  will steadily consume diskspace.  The script now includes a self-purging
 :::  routine that will move files into an "Archive" folder after 100 days,
 :::  and then delete any files in this archive folder than are older than
 :::  550 days. These defaults can all be changed by altering the two %@KEEP_%
 :::  variables (@KEEP_SHORT-TERM and @KEEP_HISTORICAL), or by entering the
 :::  two parameters at the command prompt.  You might find it best to keep
 :::  the files around for a least 3 months for easy comparison.
 :::
 :::  The compression is courtesy of the free InfoZip utilities, and this
 :::  script was tested under XP and 2003, but should run just fine under
 :::  NT4 and 2000. The only limitation at present, is an inability to create
 :::  zip archives of files which are larger than 4GB.  This is supposed to
 :::  be addressed in Mid-to-Late 2006, but will probably take place in 2007.
 :::
 :::  The issue of supporting long path names via SCHTASKS was a vexing one
 :::  until I came across a KB article that outlines the \ character as the
 :::  escape character for quotation marks.  (e.g. \" )
 :::  See http://support.microsoft.com/?KBID=823093 for details...
 :::
 :::  PLEASE NOTE:
 :::  		The ZIP paramaters are case sensitive.
 :::  		This script processes the main folder + subdirectories.
 :::  		This script requires SETDRIVE.BAT for the DATE/TIME routines.
 :::
 :::  For More Scripting Assistance, see the following:
 :::  http://KB.UltraTech-llc.com/?File=Scripting.TXT


 rem ==========================================================================
 rem === Enable Debug Mode If 'Debug' Variable is Set to "TRUE"
 rem === Last Modified On 25 Oct 2005
 rem ==========================================================================
:DebugMode
 IF /I "%Debug%"=="TRUE" (
	 SET @PAUSE_IF_DEBUG=TIMEOUT 5
	 SET @END_DEBUG_MODE=ECHO:^& ECHO *** DEBUG MODE FINISHED ***^& ECHO:^& SET @^& TIMEOUT 30
	 ECHO *** DEBUG MODE = ON ***
	 ECHO ON
 ) ELSE (
	 SET @PAUSE_IF_DEBUG=
	 SET @END_DEBUG_MODE=
 )


 rem ==========================================================================
 rem === Initialize Environment Variables
 rem === Last Modified On 08 Jan 2007  (Prior Update: 29 May 2006)
 rem ==========================================================================
:Variables
 SETLOCAL
 SET @VER=%~nx0 v3.3.0

 rem -- Get Official Drive Letters and Calculate Date/Time for NON-US Regions
 SET @STORAGE=%SystemDrive%\STORAGE& IF EXIST "%~dp0SetDrive.BAT" (
	 CALL "%~dp0SetDrive.BAT"
 ) ELSE (
	 ECHO *** WARNING: CRITICAL SCRIPT COMPONENT MISSING ***
	 ECHO:
	 ECHO You Need The Date Routine from %~dp0SetDrive.BAT, which cannot be found.
	 ECHO:
	 DIR "%~dp0SetDrive.BAT"
	 ECHO:
	 GOTO :EOF
 )
 CALL :SetLastMonth @ZIPDATE

 rem -- Standard Variables
 SET @PARAMS=%*
 SET @FILESPEC=LOG TXT INFO CSV BAK PP2 EVT SAV
 SET @EXCLUDE=-x \*.ZIP
 SET @TARGET=%~f1
 SET @DEST=%~s1\ZipFiles

 rem -- Historical Archiving Variables (in Days)
 SET @GRAVEYARD=%@DEST%\Archives
 SET @KEEP_SHORT-TERM=%~2& IF "%~2"=="" SET @KEEP_SHORT-TERM=100
 SET @KEEP_HISTORICAL=%~3& IF "%~3"=="" SET @KEEP_HISTORICAL=550

 rem -- Job Scheduling Variables
 SET @JOBNAME=Log Archive of '%@TARGET%'
 SET @JOBNAME=%@JOBNAME::\=_%
 SET @JOBNAME=%@JOBNAME:\=_%
 SET @JOBFREQ=MONTHLY
 SET @JOBTIME=00:15:00
 SET @JOBDATE=/D 1
 SET @JOBUSER=SYSTEM
 SET @JOBVRFY=%~f0 ""%@TARGET%""
 SET @JOBPATH=\"%~f0\" \"%@TARGET%\" %@KEEP_SHORT-TERM% %@KEEP_HISTORICAL%
 SET @AT_PATH=%~f0 """%@TARGET%""" %@KEEP_SHORT-TERM% %@KEEP_HISTORICAL%

 rem -- LogName Variables
 SET @LOGPATH=%@STORAGE%\Logs\Archiving
 SET @LOGFILE=%@LOGPATH%\%@JOBNAME%.%@FILESTAMP%


 rem ==========================================================================
 rem === Display Syntax Help if Required/Requested
 rem === Last Modified On 22 Jun 2003
 rem ==========================================================================
:NeedHelp
 IF "%~1"=="" GOTO :HelpMessage
 FOR /F "TOKENS=2" %%H IN ('CHECKPARAMS -q -c "H HELP ?" -s %* 2^>NUL') DO GOTO :HelpMessage


 rem ==========================================================================
 rem === Validate Source and Script Log Folders
 rem === Last Modified On 28 May 2006
 rem ==========================================================================
:CheckFolders
 IF NOT EXIST "%@TARGET%" (
	 ECHO *** SCRIPT ERROR ***
	 ECHO THE FOLLOWING FOLDER COULD NOT BE FOUND: "%@TARGET%"
	 ECHO:
	 GOTO :HelpMessage
 ) ELSE (
	 FOR %%F IN ("%@DEST%" "%@LOGPATH%") DO IF NOT EXIST %%F MD %%F >NUL
 )


 rem ==========================================================================
 rem === Allow User To Abort Operation
 rem === Last Modified On 26 May 2006
 rem ==========================================================================
:DblCheck
 CLS
 ECHO === Prepare to Create Zip Archive of "%@TARGET%" and subfolders ===
 ECHO:
 ECHO  Main archives will be kept for %@KEEP_SHORT-TERM% days...
 ECHO  Historical archives will be kept for %@KEEP_HISTORICAL% days...
 ECHO:
 ECHO Press [CTRL-C] To Abort, Any Other Key To Continue...
 ECHO:
 TIMEOUT 20


 rem ==========================================================================
 rem === Create Scheduled Job using SCHTASKS (XP/2003/Vista) or AT (NT/2000)
 rem === Last Modified On 04 Jan 2007  (Prior Update: 14 Jul 2006)
 rem ==========================================================================
:ScheduleJobs
 ECHO:
 ECHO Scheduling "%@JOBNAME%" on %COMPUTERNAME%...
 ECHO:

 IF EXIST "%SystemRoot%\System32\SCHTASKS.EXE" (
	 SCHTASKS /QUERY /V /FO LIST | FIND /I "%@JOBVRFY%" >NUL
	 IF ERRORLEVEL 1 (
		 SCHTASKS /CREATE /TN "%@JOBNAME%" /TR "%@JOBPATH%" /RU "%@JOBUSER%" /SC "%@JOBFREQ%" %@JOBDATE% /ST %@JOBTIME%  %@FORCE%
	 )
 ) ELSE (
	 AT | FIND /I "%@JOBVRFY%" >NUL
	 IF ERRORLEVEL 1 AT %@JOBTIME% /EVERY:1  %@AT_PATH%
 )

 rem -- If ANY of the parameters is "." then update the scheduled job and exit the script
 FOR %%P IN (%*) DO IF "%%~P"=="." (
	 SCHTASKS /CREATE /TN "%@JOBNAME%" /TR "%@JOBPATH%" /RU "%@JOBUSER%" /SC "%@JOBFREQ%" %@JOBDATE% /ST %@JOBTIME%  %@FORCE%
	 GOTO :EOF
 )


 rem ==========================================================================
 rem === Start at Root Log Folder and Process All Subfolders
 rem === Last Modified On 23 Jun 2003
 rem ==========================================================================
:ProcessFolders
 NOW Processing "%@TARGET%" and subfolders for log files to Zip... >"%@LOGFILE%"
 ECHO Processing "%@TARGET%" and subfolders for log files to Zip...
 ECHO:
 FOR /R "%@TARGET%" %%V IN (.) DO FOR %%F IN (%@FILESPEC%) DO CALL :MakeArchive "%%V" *.%%F


 rem ==========================================================================
 rem === Move Zips Into GraveYard After %@KEEP_SHORT-TERM% Days (Default=100)
 rem === Last Modified On 15 May 2006
 rem ==========================================================================
:MoveIntoGraveYard
 SET @FORFILES=FORFILES -p"%@DEST%" -m*.ZIP -d-%@KEEP_SHORT-TERM% -c"CMD /C IF @ISDIR==FALSE ECHO @PATH\@FILE"
 IF EXIST "%SystemRoot%\System32\FORFILES.EXE" (
	 SET @FORFILES=%SystemRoot%\System32\FORFILES -p "%@DEST%" -m *.ZIP -d -%@KEEP_SHORT-TERM% -c "CMD /C IF @ISDIR==FALSE ECHO @PATH"
 )

 ( rem -- Consolidate LogFile Output
	 IF NOT EXIST "%@GRAVEYARD%" MD "%@GRAVEYARD%"
	 ECHO:
	 ECHO:
	 ECHO Manage Primary Archives
	 ECHO  -- Move all archives older than %@KEEP_SHORT-TERM% days to the GraveYard --
	 FOR /F "TOKENS=*" %%V IN ('%@FORFILES% 2^>NUL') DO (
		 ECHO Moving "%%~V" into Archive Graveyard Folder
		 MOVE "%%~V" "%@GRAVEYARD%"
	 )
 ) >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Delete All Zips Older Than %@KEEP_HISTORICAL% Days (Default=550)
 rem === Last Modified On 15 May 2006
 rem ==========================================================================
:PruneArchive
 SET @FORFILES=FORFILES -p"%@GRAVEYARD%" -m*.ZIP -d-%@KEEP_HISTORICAL% -c"CMD /C IF @ISDIR==FALSE ECHO @PATH\@FILE"
 IF EXIST "%SystemRoot%\System32\FORFILES.EXE" (
	 SET @FORFILES=%SystemRoot%\System32\FORFILES -p "%@GRAVEYARD%" -m *.ZIP -d -%@KEEP_HISTORICAL% -c "CMD /C IF @ISDIR==FALSE ECHO @PATH"
 )

 ( rem -- Consolidate LogFile Output
	 ECHO:
	 ECHO:
	 ECHO Pruning Old Backups from Archive Folder
	 ECHO  -- Delete all archives older than %@KEEP_HISTORICAL% days old --
	 FOR /F "TOKENS=*" %%V IN ('%@FORFILES% 2^>NUL') DO (
		 ECHO Deleting "%%~V" from Archive Graveyard Folder
		 DEL "%%~V"
	 )
 ) >>"%@LOGFILE%"


 rem ==========================================================================
 rem === Reset Environment Variables and Exit Batch File
 rem === Last Modified On 23 Oct 2005
 rem ==========================================================================
:ExitBatch
 TYPE "%@LOGFILE%" & DIR "%@LOGFILE%" & DIR "%@DEST%"
 %@END_DEBUG_MODE%
 ENDLOCAL
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Create Zip Archive and Move All Log Files
 rem === Last Modified On 28 May 2006
 rem ==========================================================================
:MakeArchive
 rem %1 = Current Folder (Full Path Name)
 rem %2 = Current FileSpec

 SET @EMPTYDIR=TRUE
 SET @CURRENTDIR=%~f1
 SET @CURRENTSPEC=%~2
 SET @ARCHIVE="%@DEST%\%~n1.%@ZIPDATE%.ZIP"

 IF EXIST "%@CURRENTDIR%\%@CURRENTSPEC%" (
	 PUSHD "%@CURRENTDIR%"
	 ECHO Processing "%@CURRENTDIR%\%@CURRENTSPEC%" Files... >CON
	 ECHO:
	 ECHO ----------------------------------------------------------------------
	 ECHO Processing "%@CURRENTDIR%\%@CURRENTSPEC%" Files...
	 ECHO:
	 DIR "%@CURRENTSPEC%"
	 ECHO:
	 rem ZIP -m -9 -v -T -tt %@TODAY_EXP% %@ARCHIVE% %@CURRENTSPEC% %@EXCLUDE%
	 ZIP -m -9 -v -T -tt %@BEGMONTH% %@ARCHIVE% %@CURRENTSPEC% %@EXCLUDE%
	 ECHO:
	 DIR
	 POPD
 ) >>"%@LOGFILE%"
 %@PAUSE_IF_DEBUG%

 rem -- Delete Empty and Unattached Folders After Archiving Logs...
 IF NOT EXIST "%@CURRENTDIR%" GOTO :EOF
 FOR /F %%E IN ('DIR /A /B "%@CURRENTDIR%"') DO SET @EMPTYDIR=FALSE
 FOR /F "TOKENS=1*" %%A IN ('PSFILE ^| FIND "]"') DO IF /I "%@CURRENTDIR%"=="%%~B" SET @EMPTYDIR=FALSE

 IF "%@EMPTYDIR%"=="TRUE" (
	 ECHO Deleting Empty Folder: "%@CURRENTDIR%"... >CON
	 ECHO:
	 ECHO Deleting Empty Folder: "%@CURRENTDIR%"...
	 RD /Q "%@CURRENTDIR%"
	 ECHO ----------------------------------------------------------------------
	 ECHO:
	 ECHO:
 ) >>"%@LOGFILE%"
 %@PAUSE_IF_DEBUG%
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Calculate Last Month's Date (YYYY-MM)
 rem === Last Modified On 29 May 2006
 rem ==========================================================================
:SetLastMonth
 rem %1 = Variable to be set to End of Last Month
 SET /A @LASTYEAR=(@YYYY - 1)
 SET /A @LASTMONTH=(10%@MM% - 1)
 SET @LASTMONTH=%@LASTMONTH:~-2%
 SET %1=%@YYYY%-%@LASTMONTH%& IF %@LASTMONTH% EQU 0 SET %1=%@LASTYEAR%-12
 GOTO :EOF


 rem ==========================================================================
 rem === SUBROUTINE: Display Syntax Help For "/?"
 rem === Last Modified On 28 May 2006
 rem ==========================================================================
:HelpMessage
 ECHO:
 ECHO Syntax Help for %~nx0
 ECHO:
 ECHO === %~n0 {folder} [days before archive] [days before graveyard purge]
 ECHO:
 ECHO 	Number of days before zip files are archived .....: %@KEEP_SHORT-TERM%
 ECHO 	Number of days before archived zips are purged ...: %@KEEP_HISTORICAL%
 ECHO:
 ECHO Example: %~n0 C:\LOGS
 ECHO          %~n0 D:\Backup 150
 ECHO          %~n0 D:\TEST 200 900
 ECHO          %~n0 "F:\SYSTEM LOGS" %@KEEP_SHORT-TERM% %@KEEP_HISTORICAL%
 ECHO:
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO NOTE: Any parameters which contain spaces should be surrounded by quotes.
 ECHO       Shortnames *can* be surrounded by quotes if you choose, but it is
 ECHO       not mandatory by any means.
 ECHO ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ECHO:
