@REM - ASB (24 Sep 2018 // 16 Oct 2023 / 18 Nov 2021 / 02 Dec 2020 / 30 Nov 2020 / 08 Jul 2020 / 24 Dec 2019 / 29 Sep 2019 / 17 Jun 2019 / 03 Mar 2019 / 24 Sep 2018): Generate an nMAP of a Subnet and Format the Output
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v3.2.0.300

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Generate an nMAP of a Subnet and Format the Output
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [subnet/mask]
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO     EXAMPLES:
	 ECHO          %~n0 192.168.10.0/24
	 ECHO          %~n0 10.100.100.128/25
	 ECHO          %~n0 172.16.100.0
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Get Subnet Info, Including Mask
 SET @NETWORK=%~1& IF "%~1"=="" FOR /F "TOKENS=3-5 DELIMS=:. " %%N IN ('IPCONFIG ^| FIND /I "Gateway"') DO SET @NETWORK=%%N.%%O.%%P.0/24
 FOR /F %%M IN ('ECHO %@NETWORK% ^| FIND /V "/"') DO SET @NETWORK=%@NETWORK%/24

 rem -- Main Variables
 SET @LOGFILE=%TEMP%\nMap-%@NETWORK:/=_%.Full-%@FILESTAMP%
 SET @SSL_LOG=%@LOGFILE:Full-=SSL-%
 SET @TEMPLOG=%@LOGFILE:Full-=Temp-%
 SET @TINYLOG=%@LOGFILE:Full-=Tiny-%
 SET @SUMMARY=%@LOGFILE:Full-=%
 SET @SCANMSG=nMAP Scan of %@NETWORK%
 SET @READABLE_OPTIONS=-E --SB="Nmap scan report for;Scanning;Starting Nmap" --LB="Read data files from:" --LA="Scanning"

 rem -- Determine Correct nMap Folder
:GetNMapFolder
 SET @NMAPDIRS="%SystemDrive%\Nmap";"%SystemDrive%\Programs\NMap";"%ProgramFiles%\Nmap";"%ProgramFiles(x86)%\Nmap"
 SET @NMAP=
 FOR %%F IN (%@NMAPDIRS%) DO IF EXIST "%%~F\nMap.exe" (
	 SET @NMAP="%%~F\nMap.exe"
	 PATH !PATH!;%%~F
 )


 rem -- Scan Subnet with nMap
:ScanSubnet
 ECHO Generating %@SCANMSG%
 %@NMAP% -v -sn %@NETWORK% >"%@TEMPLOG%" 2>&1
 %@NMAP% --script ssl-enum-ciphers -p 443 %@NETWORK% >"%@SSL_LOG%" 2>&1

 READABLE "%@TEMPLOG%" -O="%@LOGFILE%" %@READABLE_OPTIONS% --SK="ARP;Parallel DNS"
 READABLE "%@TEMPLOG%" -O="%@SUMMARY%" %@READABLE_OPTIONS% --SK="[host down];ARP;Parallel DNS"
 READABLE "%@SUMMARY%" -O="%@TINYLOG%" %@READABLE_OPTIONS%   -F="Nmap scan report for;Nmap done:;Read data"

 rem -- Add SSL/TLS Cipher Log
 IF EXIST "%@SSL_LOG%"  (
	 READABLE "%@SSL_LOG%" -O="%@TEMPLOG%" %@READABLE_OPTIONS:"Scanning"="Mac Address:"%
	 ( rem -- Write to Log
		 NOW \**** \v -- SSL/TLS Ciphers Summary \n\*  
		 TYPE "%@TEMPLOG%"
	 ) >"%@SSL_LOG%" 2>&1
 ) 

 rem -- Aggregate Main Logs
 IF EXIST "%@TINYLOG%" (
	 FOR %%L IN ("%@LOGFILE%" "%@SUMMARY%") DO IF EXIST "%%~L" (
		 NOW \n\n\n\**** \v -- IP/MAC Address Summary \n\*
		 TYPE "%@TINYLOG%"
	 ) >>"%%~L"
 )


 rem -- Generate Final Report
:FinalReport
 IF EXIST "%@LOGFILE%" IF EXIST "%@SUMMARY%" DEL "%@TEMPLOG%" >NUL 2>NUL
 FOR %%F IN ("%@LOGFILE%" "%@SUMMARY%" "%@TINYLOG%" "%@SSL_LOG%") DO START "%@SCANMSG%" "%%~F"


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
      