@REM - ASB (21 Nov 2021 // 16 Oct 2023 / 23 Nov 2021 / 21 Nov 2021): Perform nMap Scans of all Listed Segments
@ECHO OFF


 rem -- Generate Filtered CMD Title
:DisplayTitle
 SET @TTT= %*
 SET @TTT=%@TTT:/?={HELP}%
 TITLE [%USERDOMAIN%\%USERNAME%] - %~f0 %@TTT% >NUL 2>NUL
 SET @TTT=


 rem -- Initialize Environment Variables
:Variables
 SETLOCAL ENABLEDELAYEDEXPANSION & CALL :ShowStatus "STARTED" v1.2.0.110

 rem -- Display Syntax Help if Required/Requested
 CHECKPARAMS --rc -c "H HELP ?" -x "?? H2" -s %*
 IF ERRORLEVEL 1 IF NOT ERRORLEVEL 16 (
	 ECHO Perform nMap Scans of all Listed Segments
	 ECHO:
	 ECHO    YOU TYPED: %0 %*
	 ECHO:
	 ECHO   CMD SYNTAX: %~n0  [list of networks to scan]   {default = %~dp0Input\ScanList.TXT}
	 ECHO               %~n0  [-h^|-?]
	 ECHO:
	 ECHO  USAGE NOTES:
	 ECHO    * Parameters surrounded by ^<^> are mandatory.
	 ECHO    * Parameters surrounded by [] are optional.
	 ECHO    * Options are case-insensitive, and can be prefaced by "-" or "/".
	 GOTO :ExitBatch
 )

 rem -- Obtain Date/Time and Supporting Core Variables
 FOR /F "TOKENS=1-2 DELIMS=;" %%P IN ('DATEINFO --Script-Variables 2^>NUL') DO SET %%P=%%~Q

 rem -- Get List of Network Subnets to Scan with nMap
 SET @SOURCELIST="%~dp0Input\ScanList.TXT"  "%~dp0Input\ScanList.%COMPUTERNAME%.TXT"  "%~dp0Input\%~1"  "%~dp0Input\%~1.TXT"  "%~1"
 FOR %%F IN (%@SOURCELIST%) DO IF EXIST "%%~F" IF NOT "%%~nxF"=="" SET @NMAPLIST=%%~F
 IF EXIST "%@NMAPLIST%" (
	 ECHO USING: "%@NMAPLIST%"
	 SET @COUNT=1000
	 FOR /F "USEBACKQ TOKENS=1-2 EOL=;" %%I IN ("%@NMAPLIST%") DO (
		 IF NOT "%%~J"=="" SET $@SUMMARY-%%I=%%~J
		 SET @NAME-OR-IP=%%I
		 SET @NAME-OR-IP=!@NAME-OR-IP:\=!
		 SET #!@COUNT!!@NAME-OR-IP!=!@NAME-OR-IP!
		 SET /A @COUNT+=1
	 )
 ) ELSE (
	 ECHO *** NO LIST OF NETWORK SUBNETS FOUND: "%@NMAPLIST%"
	 SET #127.0.0.1/32=127.0.0.1/32
 )

 rem -- Standard Log Variables
 SET @LOGINFO=%~n0.%@DIRSTAMP_R%
 SET @LOGROOT=%TEMP%\%@LOGINFO%
 SET @LOGFILE=%TEMP%\%@LOGINFO%.TXT


 rem -- Make and Log nMap Scans
:ScanAllSegments
 IF NOT EXIST "%@LOGROOT%" MD "%@LOGROOT%"
 ECHO:
 ECHO %@DIVIDER-%
 ECHO Preparing to Scan the Following Segments
 ECHO %@DIVIDER-%
 FOR /F "TOKENS=1* DELIMS==" %%V IN ('SET # 2^>NUL') DO ECHO  -- %%W
 ECHO:
 ECHO Please Wait for the Scan Processes to Finish Execution...
 FOR /F "TOKENS=1* DELIMS==" %%V IN ('SET # 2^>NUL') DO (
	 ECHO  [!TIME: =0!] Scanning in progress: %%W
	 CALL nMapScan "%%~W" >>"%@LOGFILE%"
 )


 rem -- Reset Environment Variables and Exit Batch File
:ExitBatch
 CALL :ShowStatus "FINISHED"
 ENDLOCAL
 GOTO :EOF


 rem -- SUBROUTINE: Set/Display Script Version and Execution Status (STARTED/FINISHED)
:ShowStatus
 rem %1 = Run Status of Script
 rem %2 = Current Application Version

 IF NOT DEFINED @DATEFMT SET @DATEFMT=-F "mm/dd/yyyy hh:nn:ss.zzz"
 SET @SCRIPTSTATUS=%~1& IF "%~1"=="" SET @SCRIPTSTATUS=RUNNING
 IF NOT "%~2"=="" (SET @VER=%~nx0 %~2& SET @VERSION=%~2)
 IF /I "%~1"=="STARTED" FOR /F "TOKENS=*" %%d IN ('DATEINFO -S %@DATEFMT% -Q 2^>NUL') DO SET @SCRIPT_BEG#="%%~d"
 IF /I "%~1"=="FINISHED" (
	 IF DEFINED $CODEPAGE FOR /F "TOKENS=1* DELIMS=:" %%B IN ('CHCP %$CODEPAGE%') DO SET @CHCP_STATUS= {Restoring Code Page:%%C}
	 IF DEFINED @END_DEBUG_MODE %@END_DEBUG_MODE:"=%
	 TITLE Command Prompt [%USERDOMAIN%\%USERNAME%]   !@DEBUG_MODE!
	 DATEINFO -t %@SCRIPT_BEG#% -e "hr:min:sec.ms" -o "\n*** DURATION: " 2>NUL
 )
 NOW \n*** %@SCRIPTSTATUS%: %@VER% [\v] *** %@CHCP_STATUS%\n!@CRLF-%~1!
 GOTO :EOF
                                   